import * as cdk from "aws-cdk-lib";
import * as constructs from "constructs";
/**
 * Returns, adds, edits, and removes network peering containers and peering connections.
 *
 * @schema CfnNetworkPeeringProps
 */
export interface CfnNetworkPeeringProps {
    /**
     * Unique 24-hexadecimal digit string that identifies your project.
     *
     * @schema CfnNetworkPeeringProps#ProjectId
     */
    readonly projectId: string;
    /**
     * Unique 24-hexadecimal digit string that identifies the MongoDB Cloud network container that contains the specified network peering connection.
     *
     * @schema CfnNetworkPeeringProps#ContainerId
     */
    readonly containerId: string;
    /**
     * Amazon Web Services (AWS) region where the Virtual Peering Connection (VPC) that you peered with the MongoDB Cloud VPC resides. The resource returns null if your VPC and the MongoDB Cloud VPC reside in the same region.
     *
     * @schema CfnNetworkPeeringProps#AccepterRegionName
     */
    readonly accepterRegionName?: string;
    /**
     * Unique twelve-digit string that identifies the Amazon Web Services (AWS) account that owns the VPC that you peered with the MongoDB Cloud VPC.
     *
     * @schema CfnNetworkPeeringProps#AwsAccountId
     */
    readonly awsAccountId?: string;
    /**
     * Internet Protocol (IP) addresses expressed in Classless Inter-Domain Routing (CIDR) notation of the VPC's subnet that you want to peer with the MongoDB Cloud VPC.
     *
     * @schema CfnNetworkPeeringProps#RouteTableCIDRBlock
     */
    readonly routeTableCidrBlock?: string;
    /**
     * Unique string that identifies the VPC on Amazon Web Services (AWS) that you want to peer with the MongoDB Cloud VPC.
     *
     * @schema CfnNetworkPeeringProps#VpcId
     */
    readonly vpcId: string;
    /**
     * The profile is defined in AWS Secret manager. See [Secret Manager Profile setup](../../../examples/profile-secret.yaml).
     *
     * @schema CfnNetworkPeeringProps#Profile
     */
    readonly profile?: string;
}
/**
 * Converts an object of type 'CfnNetworkPeeringProps' to JSON representation.
 */
export declare function toJson_CfnNetworkPeeringProps(obj: CfnNetworkPeeringProps | undefined): Record<string, any> | undefined;
/**
 * A CloudFormation `MongoDB::Atlas::NetworkPeering`
 *
 * @cloudformationResource MongoDB::Atlas::NetworkPeering
 * @stability external
 */
export declare class CfnNetworkPeering extends cdk.CfnResource {
    /**
     * The CloudFormation resource type name for this resource class.
     */
    static readonly CFN_RESOURCE_TYPE_NAME = "MongoDB::Atlas::NetworkPeering";
    /**
     * Resource props.
     */
    readonly props: CfnNetworkPeeringProps;
    /**
     * Attribute `MongoDB::Atlas::NetworkPeering.Id`
     */
    readonly attrId: string;
    /**
     * Attribute `MongoDB::Atlas::NetworkPeering.StatusName`
     */
    readonly attrStatusName: string;
    /**
     * Attribute `MongoDB::Atlas::NetworkPeering.ErrorStateName`
     */
    readonly attrErrorStateName: string;
    /**
     * Attribute `MongoDB::Atlas::NetworkPeering.ConnectionId`
     */
    readonly attrConnectionId: string;
    /**
     * Create a new `MongoDB::Atlas::NetworkPeering`.
     *
     * @param scope - scope in which this resource is defined
     * @param id    - scoped id of the resource
     * @param props - resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnNetworkPeeringProps);
}
