import * as cdk from "aws-cdk-lib";
import * as constructs from "constructs";
/**
 * Adds one private endpoint for Federated Database Instances and Online Archives to the specified projects. To use this resource, the requesting API Key must have the Project Atlas Admin or Project Charts Admin roles. This resource doesn't require the API Key to have an Access List.
 *
 * @schema CfnPrivateEndpointAdlProps
 */
export interface CfnPrivateEndpointAdlProps {
    /**
     * Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided default is used
     *
     * @schema CfnPrivateEndpointAdlProps#Profile
     */
    readonly profile?: string;
    /**
     * Unique 24-hexadecimal digit string that identifies your project.
     *
     * @schema CfnPrivateEndpointAdlProps#ProjectId
     */
    readonly projectId: string;
    /**
     * Human-readable string to associate with this private endpoint.
     *
     * @schema CfnPrivateEndpointAdlProps#Comment
     */
    readonly comment?: string;
    /**
     * Unique 22-character alphanumeric string that identifies the private endpoint.
     *
     * @schema CfnPrivateEndpointAdlProps#EndpointId
     */
    readonly endpointId?: string;
    /**
     * Human-readable label that identifies the cloud service provider. Atlas Data Lake supports Amazon Web Services only.
     *
     * @schema CfnPrivateEndpointAdlProps#Provider
     */
    readonly provider: string;
    /**
     * Human-readable label that identifies the resource type associated with this private endpoint.
     *
     * @schema CfnPrivateEndpointAdlProps#Type
     */
    readonly type?: string;
}
/**
 * Converts an object of type 'CfnPrivateEndpointAdlProps' to JSON representation.
 */
export declare function toJson_CfnPrivateEndpointAdlProps(obj: CfnPrivateEndpointAdlProps | undefined): Record<string, any> | undefined;
/**
 * A CloudFormation `MongoDB::Atlas::PrivateEndpointADL`
 *
 * @cloudformationResource MongoDB::Atlas::PrivateEndpointADL
 * @stability external
 */
export declare class CfnPrivateEndpointAdl extends cdk.CfnResource {
    /**
     * The CloudFormation resource type name for this resource class.
     */
    static readonly CFN_RESOURCE_TYPE_NAME = "MongoDB::Atlas::PrivateEndpointADL";
    /**
     * Resource props.
     */
    readonly props: CfnPrivateEndpointAdlProps;
    /**
     * Create a new `MongoDB::Atlas::PrivateEndpointADL`.
     *
     * @param scope - scope in which this resource is defined
     * @param id    - scoped id of the resource
     * @param props - resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnPrivateEndpointAdlProps);
}
