import { Construct } from "constructs";
import { CfnServerlessPrivateEndpoint, AwsPrivateEndpointConfig } from "../../index";
import { AtlasServerlessBasic } from "../atlas-serverless-basic";
import { AtlasServerlessBasicProps } from "../common/props";
/**
 * @description
 * @export
 * @class AtlasBasicPrivateEndpoint
 * @extends {Construct}
 */
export declare class AtlasBasicServerlessPrivateEndpoint extends Construct {
    readonly atlasServerlessBasic: AtlasServerlessBasic;
    readonly serverlessPrivateEndpoint: CfnServerlessPrivateEndpoint;
    /**
     * Creates an instance of AtlasBasicServerlessPrivateEndpoint.
     * @param {Construct} scope
     * @param {string} id
     * @param {AtlasServerlessBasicPrivateEndpointProps} props
     * @memberof AtlasBasicServerlessPrivateEndpoint
     */
    constructor(scope: Construct, id: string, props: AtlasServerlessBasicPrivateEndpointProps);
}
/**
 * @description
 * @export
 * @interface AtlasServerlessBasicPrivateEndpointProps
 */
export interface AtlasServerlessBasicPrivateEndpointProps {
    readonly profile?: string;
    readonly instanceName: string;
    /**
     * @description AWS Region
     * @type {string}
     * @default us-east-1
     * @memberof AtlasServerlessPrivateEndpointProps
     */
    readonly region?: string;
    /**
     * @description
     * @type {AtlasBasicProps}
     * @memberof AtlasServerlessPrivateEndpointProps
     */
    readonly atlasServerlessBasicProps: AtlasServerlessBasicProps;
    /**
     * @description
     * @type {CfnServerlessPrivateEndpointProps}
     * @memberof AtlasServerlessPrivateEndpointProps
     */
    readonly serverlessPrivateEndpointProps: ServerlessPrivateEndpointProps;
}
/**
 * @schema PrivateEndpoint
 */
export interface ServerlessPrivateEndpointProps {
    /**
     * string to represent the comment
     * @schema PrivateEndpoint#comment
     */
    readonly comment?: string;
    /**
     * If true the resource will create the aws private endpoint and assign the Endpoint ID
     *
     * @schema CfnServerlessPrivateEndpointProps#CreateAndAssignAWSPrivateEndpoint
     */
    readonly createAndAssignAwsPrivateEndpoint?: boolean;
    /**
     * Properties used to configure Aws private endpoint
     *
     * @schema CfnServerlessPrivateEndpointProps#AwsPrivateEndpointConfigurationProperties
     */
    readonly awsPrivateEndpointConfigurationProperties?: AwsPrivateEndpointConfig;
}
