# MongoDB Atlas AWS CDK Resources
[![Code Health](https://github.com/mongodb/awscdk-resources-mongodbatlas/actions/workflows/code-health.yml/badge.svg?event=push)](https://github.com/mongodb/awscdk-resources-mongodbatlas/actions/workflows/code-health.yml)
[![Package CDK](https://github.com/mongodb/awscdk-resources-mongodbatlas/actions/workflows/package.yml/badge.svg?branch=main)](https://github.com/mongodb/awscdk-resources-mongodbatlas/actions/workflows/package.yml)
[![npm version](https://badge.fury.io/js/awscdk-resources-mongodbatlas.svg)](https://badge.fury.io/js/awscdk-resources-mongodbatlas)
[![PyPI version](https://badge.fury.io/py/awscdk-resources-mongodbatlas.svg)](https://badge.fury.io/py/awscdk-resources-mongodbatlas)
[![NuGet version](https://badge.fury.io/nu/MongoDB.AWSCDKResourcesMongoDBAtlas.svg)](https://badge.fury.io/nu/MongoDB.AWSCDKResourcesMongoDBAtlas)
[![Maven Central](https://maven-badges.herokuapp.com/maven-central/org.mongodb/awscdk-resources-mongodbatlas/badge.svg)](https://central.sonatype.com/artifact/org.mongodb/awscdk-resources-mongodbatlas)
[![Go Reference](https://pkg.go.dev/badge/github.com/mongodb/awscdk-resources-mongodbatlas-go/awscdkresourcesmongodbatlas.svg)](https://pkg.go.dev/github.com/mongodb/awscdk-resources-mongodbatlas-go/awscdkresourcesmongodbatlas)

[![View on Construct Hub](https://constructs.dev/badge?package=aws-cdk-lib)](https://constructs.dev/packages/awscdk-resources-mongodbatlas)

Use MongoDB Atlas [AWS CDK](https://aws.amazon.com/cdk/) (or Cloud Development Kit) constructs to manage [MongoDB Atlas](https://www.mongodb.com/cloud/atlas). The AWS CDK is a framework for defining infrastructure as code (IaC). It allows developers to write code in their preferred programming language, such as TypeScript for example, to define and deploy infrastructure. AWS CDK gets synthesized down into [AWS CloudFormation](https://aws.amazon.com/cloudformation/) templates at deployment so users no longer have to write or maintain YAML/JSON based CloudFormation templates.

## Available Packages

### NPM
The npm package is available at [awscdk-resources-mongodbatlas](https://www.npmjs.com/package/awscdk-resources-mongodbatlas)
```bash
npm i awscdk-resources-mongodbatlas
```

### PyPI
The PyPI package is available at [awscdk-resources-mongodbatlas](https://pypi.org/project/awscdk-resources-mongodbatlas/)
```bash
pip install awscdk-resources-mongodbatlas
```

### Nuget
The Nuget package is available at [MongoDB.AWSCDKResourcesMongoDBAtlas](https://www.nuget.org/packages/MongoDB.AWSCDKResourcesMongoDBAtlas)
```bash
dotnet add package MongoDB.AWSCDKResourcesMongoDBAtlas --version 1.0.0
```

### Maven
The Maven package is available at [awscdk-resources-mongodbatlas](https://central.sonatype.com/artifact/org.mongodb/awscdk-resources-mongodbatlas/1.0.0)

```Maven
<dependency>
    <groupId>org.mongodb</groupId>
    <artifactId>awscdk-resources-mongodbatlas</artifactId>
    <version>1.0.0</version>
</dependency>
```

### Go
The go package is generated into the [github.com/mongodb/awscdk-resources-mongodbatlas-go](https://github.com/mongodb/awscdk-resources-mongodbatlas-go) package.
```bash
go get github.com/mongodb/awscdk-resources-mongodbatlas-go/awscdkresourcesmongodbatlas
```



## Available Constructors
MongoDB Atlas AWS CDK Resources provides L1, L2 and L3 CDK constructors. Please, have a look at [README.md](src/README.md#cdk-constructors) for a full lists of constructors and examples.
## Getting Started
See the [cdk examples](examples/README.md) for how to setup prerequisites & get started with your first cluster, using our AWS CDK sample code. We also provide a quick guide on [How to Deploy MongoDB Atlas with AWS CDK in TypeScript](https://www.mongodb.com/developer/products/atlas/deploy-mongodb-atlas-aws-cdk-typescript/).

## Support, Bugs, Feature Requests
Feature requests can be submitted at [feedback.mongodb.com](https://feedback.mongodb.com/forums/924145-atlas/category/392596-atlas-cloudformation-resources) - just select "Atlas CloudFormation Resources" as the category or vote for an already suggested feature.

Support for the MongoDB Atlas Resource Provider for CloudFormation is provided under MongoDB Atlas support plans, starting with Developer. Please submit support questions within the Atlas UI. In addition, support questions submitted under the Issues section of this repo are also being monitored. Bugs should be filed under the Issues section of this repo.

## MongoDB Atlas API Keys Credential Management
Atlas API keys Configuration are required for both CloudFormation and CDK resources, and this Atlas API key pair are provided as input by the use of a Profile

AWS CloudFormation limits Third Parties from using non-AWS API Keys as either hardcoded secrets in CloudFormation templates or via CDK, hence we now require all the users store MongoDB Atlas API Keys via [AWS Secrets Manager](https://aws.amazon.com/secrets-manager/).

`NOTE: the process for configuring the PROFILE is the same and is required both for CloudFormation and CDK`

### 1. Configure your MongoDB Atlas API Keys
You'll need to generate an API key pair (public and private keys) for your Atlas organization and configure them to grant CloudFormation access to your Atlas project.
Refer to the [Atlas documentation](https://www.mongodb.com/docs/atlas/configure-api-access/#manage-programmatic-access-to-an-organization) for detailed instructions.

### 2. Configure your Profile
To use Atlas CloudFormation resources, you must configure a "profile" with your API keys using [AWS Secrets Manager](https://aws.amazon.com/secrets-manager/).

The secret should follow this format:
```
SecretName: cfn/atlas/profile/{ProfileName}
SecretValue: {"PublicKey": "YourPublicKey", "PrivateKey": "YourPrivateKey"}
```

To create a new secret for a default profile, use the [PROFILE SECRET TEMPLATE](/examples/profile-secret.yaml) file provided in this repository.

Here are some examples of how to use this template:

#### example 1:
```
  ProfileName: default
  SecretName: cfn/atlas/profile/default
  SecretValue: {"PublicKey": "YourPublicKey", "PrivateKey": "YourPrivateKey"}
```
#### example 2:
```
  ProfileName: testProfile
  SecretName: cfn/atlas/profile/testProfile
  SecretValue: {"PublicKey": "YourPublicKey", "PrivateKey": "YourPrivateKey"}
```

## Contributing
See our [CONTRIBUTING.md](CONTRIBUTING.md) guide.

## Issues

### Autoclose stale issues and PRs
- After 5 days of no activity (no comments or commits on an issue/PR) we automatically tag it as "stale" and add a message: ```This issue/PR has gone 5 days without any activity and meets the project's definition of "stale". This will be auto-closed if there is no new activity over the next 5 days. If the issue is still relevant and active, you can simply comment with a "bump" to keep it open, or add the label "not_stale". Thanks for keeping our repository healthy!```
- After 5 more days of no activity we automatically close the issue/PR.

### One-click reproducible issues principle
Our support will prioritise issues that contain all the required information that follows the following principles:

* We should be able to make no changes to your provided script and **successfully run a local execution reproducing the issue**.
  * This means that you should kindly **provide all the required instructions**. This includes but not limited to:
    * AWS CDK package version used to reproduce the issue
    * CFN resource version and AWS region used to reproduce the issue
  * Issues that **cannot be properly reproduced will be de-prioritised** in favour of the ones that succeed.
* Before opening an issue, you have to try to specifically isolate it to the **CDK MongoDB Atlas constructor** by **removing as many dependencies** as possible. If the issue only happens with other dependencies, then:
  * If other CDK constructors are required, please make sure you also include those. _Same "one-click reproducible issue" principle applies_.
  * If external components are required to replicate it, please make sure you also provides instructions on those parts.


# API Reference <a name="API Reference" id="api-reference"></a>

## Constructs <a name="Constructs" id="Constructs"></a>

### AtlasBasic <a name="AtlasBasic" id="awscdk-resources-mongodbatlas.AtlasBasic"></a>

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.AtlasBasic.Initializer"></a>

```typescript
import { AtlasBasic } from 'awscdk-resources-mongodbatlas'

new AtlasBasic(scope: Construct, id: string, props: AtlasBasicProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasBasic.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasBasic.Initializer.parameter.id">id</a></code> | <code>string</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasBasic.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.AtlasBasicProps">AtlasBasicProps</a></code> | *No description.* |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.AtlasBasic.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.AtlasBasic.Initializer.parameter.id"></a>

- *Type:* string

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.AtlasBasic.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.AtlasBasicProps">AtlasBasicProps</a>

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasBasic.toString">toString</a></code> | Returns a string representation of this construct. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.AtlasBasic.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasBasic.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.AtlasBasic.isConstruct"></a>

```typescript
import { AtlasBasic } from 'awscdk-resources-mongodbatlas'

AtlasBasic.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.AtlasBasic.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasBasic.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasBasic.property.ipAccessList">ipAccessList</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnProjectIpAccessList">CfnProjectIpAccessList</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasBasic.property.mCluster">mCluster</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnCluster">CfnCluster</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasBasic.property.mDBUser">mDBUser</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUser">CfnDatabaseUser</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasBasic.property.mProject">mProject</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnProject">CfnProject</a></code> | *No description.* |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.AtlasBasic.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `ipAccessList`<sup>Required</sup> <a name="ipAccessList" id="awscdk-resources-mongodbatlas.AtlasBasic.property.ipAccessList"></a>

```typescript
public readonly ipAccessList: CfnProjectIpAccessList;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnProjectIpAccessList">CfnProjectIpAccessList</a>

---

##### `mCluster`<sup>Required</sup> <a name="mCluster" id="awscdk-resources-mongodbatlas.AtlasBasic.property.mCluster"></a>

```typescript
public readonly mCluster: CfnCluster;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnCluster">CfnCluster</a>

---

##### `mDBUser`<sup>Required</sup> <a name="mDBUser" id="awscdk-resources-mongodbatlas.AtlasBasic.property.mDBUser"></a>

```typescript
public readonly mDBUser: CfnDatabaseUser;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnDatabaseUser">CfnDatabaseUser</a>

---

##### `mProject`<sup>Required</sup> <a name="mProject" id="awscdk-resources-mongodbatlas.AtlasBasic.property.mProject"></a>

```typescript
public readonly mProject: CfnProject;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnProject">CfnProject</a>

---


### AtlasBasicPrivateEndpoint <a name="AtlasBasicPrivateEndpoint" id="awscdk-resources-mongodbatlas.AtlasBasicPrivateEndpoint"></a>

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.AtlasBasicPrivateEndpoint.Initializer"></a>

```typescript
import { AtlasBasicPrivateEndpoint } from 'awscdk-resources-mongodbatlas'

new AtlasBasicPrivateEndpoint(scope: Construct, id: string, props: AtlasBasicPrivateEndpointProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasBasicPrivateEndpoint.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasBasicPrivateEndpoint.Initializer.parameter.id">id</a></code> | <code>string</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasBasicPrivateEndpoint.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.AtlasBasicPrivateEndpointProps">AtlasBasicPrivateEndpointProps</a></code> | *No description.* |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.AtlasBasicPrivateEndpoint.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.AtlasBasicPrivateEndpoint.Initializer.parameter.id"></a>

- *Type:* string

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.AtlasBasicPrivateEndpoint.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.AtlasBasicPrivateEndpointProps">AtlasBasicPrivateEndpointProps</a>

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasBasicPrivateEndpoint.toString">toString</a></code> | Returns a string representation of this construct. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.AtlasBasicPrivateEndpoint.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasBasicPrivateEndpoint.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.AtlasBasicPrivateEndpoint.isConstruct"></a>

```typescript
import { AtlasBasicPrivateEndpoint } from 'awscdk-resources-mongodbatlas'

AtlasBasicPrivateEndpoint.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.AtlasBasicPrivateEndpoint.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasBasicPrivateEndpoint.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasBasicPrivateEndpoint.property.atlasBasic">atlasBasic</a></code> | <code><a href="#awscdk-resources-mongodbatlas.AtlasBasic">AtlasBasic</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasBasicPrivateEndpoint.property.awsPrivateEndpoint">awsPrivateEndpoint</a></code> | <code>aws-cdk-lib.aws_ec2.CfnVPCEndpoint</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasBasicPrivateEndpoint.property.privateEndpointAws">privateEndpointAws</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAws">CfnPrivateEndpointAws</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasBasicPrivateEndpoint.property.privateEndpointService">privateEndpointService</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointService">CfnPrivateEndpointService</a></code> | *No description.* |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.AtlasBasicPrivateEndpoint.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `atlasBasic`<sup>Required</sup> <a name="atlasBasic" id="awscdk-resources-mongodbatlas.AtlasBasicPrivateEndpoint.property.atlasBasic"></a>

```typescript
public readonly atlasBasic: AtlasBasic;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.AtlasBasic">AtlasBasic</a>

---

##### `awsPrivateEndpoint`<sup>Required</sup> <a name="awsPrivateEndpoint" id="awscdk-resources-mongodbatlas.AtlasBasicPrivateEndpoint.property.awsPrivateEndpoint"></a>

```typescript
public readonly awsPrivateEndpoint: CfnVPCEndpoint;
```

- *Type:* aws-cdk-lib.aws_ec2.CfnVPCEndpoint

---

##### `privateEndpointAws`<sup>Required</sup> <a name="privateEndpointAws" id="awscdk-resources-mongodbatlas.AtlasBasicPrivateEndpoint.property.privateEndpointAws"></a>

```typescript
public readonly privateEndpointAws: CfnPrivateEndpointAws;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAws">CfnPrivateEndpointAws</a>

---

##### `privateEndpointService`<sup>Required</sup> <a name="privateEndpointService" id="awscdk-resources-mongodbatlas.AtlasBasicPrivateEndpoint.property.privateEndpointService"></a>

```typescript
public readonly privateEndpointService: CfnPrivateEndpointService;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointService">CfnPrivateEndpointService</a>

---


### AtlasEncryptionAtRest <a name="AtlasEncryptionAtRest" id="awscdk-resources-mongodbatlas.AtlasEncryptionAtRest"></a>

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.AtlasEncryptionAtRest.Initializer"></a>

```typescript
import { AtlasEncryptionAtRest } from 'awscdk-resources-mongodbatlas'

new AtlasEncryptionAtRest(scope: Construct, id: string, props: AtlasEncryptionAtRestProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasEncryptionAtRest.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasEncryptionAtRest.Initializer.parameter.id">id</a></code> | <code>string</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasEncryptionAtRest.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.AtlasEncryptionAtRestProps">AtlasEncryptionAtRestProps</a></code> | *No description.* |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.AtlasEncryptionAtRest.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.AtlasEncryptionAtRest.Initializer.parameter.id"></a>

- *Type:* string

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.AtlasEncryptionAtRest.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.AtlasEncryptionAtRestProps">AtlasEncryptionAtRestProps</a>

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasEncryptionAtRest.toString">toString</a></code> | Returns a string representation of this construct. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.AtlasEncryptionAtRest.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasEncryptionAtRest.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.AtlasEncryptionAtRest.isConstruct"></a>

```typescript
import { AtlasEncryptionAtRest } from 'awscdk-resources-mongodbatlas'

AtlasEncryptionAtRest.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.AtlasEncryptionAtRest.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasEncryptionAtRest.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasEncryptionAtRest.property.cfnEncryptionAtRest">cfnEncryptionAtRest</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnEncryptionAtRest">CfnEncryptionAtRest</a></code> | *No description.* |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.AtlasEncryptionAtRest.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `cfnEncryptionAtRest`<sup>Required</sup> <a name="cfnEncryptionAtRest" id="awscdk-resources-mongodbatlas.AtlasEncryptionAtRest.property.cfnEncryptionAtRest"></a>

```typescript
public readonly cfnEncryptionAtRest: CfnEncryptionAtRest;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnEncryptionAtRest">CfnEncryptionAtRest</a>

---


### AtlasEncryptionAtRestExpress <a name="AtlasEncryptionAtRestExpress" id="awscdk-resources-mongodbatlas.AtlasEncryptionAtRestExpress"></a>

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.AtlasEncryptionAtRestExpress.Initializer"></a>

```typescript
import { AtlasEncryptionAtRestExpress } from 'awscdk-resources-mongodbatlas'

new AtlasEncryptionAtRestExpress(scope: Construct, id: string, props: AtlasEncryptionAtRestExpressProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasEncryptionAtRestExpress.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasEncryptionAtRestExpress.Initializer.parameter.id">id</a></code> | <code>string</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasEncryptionAtRestExpress.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.AtlasEncryptionAtRestExpressProps">AtlasEncryptionAtRestExpressProps</a></code> | *No description.* |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.AtlasEncryptionAtRestExpress.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.AtlasEncryptionAtRestExpress.Initializer.parameter.id"></a>

- *Type:* string

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.AtlasEncryptionAtRestExpress.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.AtlasEncryptionAtRestExpressProps">AtlasEncryptionAtRestExpressProps</a>

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasEncryptionAtRestExpress.toString">toString</a></code> | Returns a string representation of this construct. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.AtlasEncryptionAtRestExpress.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasEncryptionAtRestExpress.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.AtlasEncryptionAtRestExpress.isConstruct"></a>

```typescript
import { AtlasEncryptionAtRestExpress } from 'awscdk-resources-mongodbatlas'

AtlasEncryptionAtRestExpress.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.AtlasEncryptionAtRestExpress.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasEncryptionAtRestExpress.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasEncryptionAtRestExpress.property.encryptionAtRest">encryptionAtRest</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnEncryptionAtRest">CfnEncryptionAtRest</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasEncryptionAtRestExpress.property.accessList">accessList</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnProjectIpAccessList">CfnProjectIpAccessList</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasEncryptionAtRestExpress.property.cluster">cluster</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnCluster">CfnCluster</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasEncryptionAtRestExpress.property.databaseUser">databaseUser</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUser">CfnDatabaseUser</a></code> | *No description.* |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.AtlasEncryptionAtRestExpress.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `encryptionAtRest`<sup>Required</sup> <a name="encryptionAtRest" id="awscdk-resources-mongodbatlas.AtlasEncryptionAtRestExpress.property.encryptionAtRest"></a>

```typescript
public readonly encryptionAtRest: CfnEncryptionAtRest;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnEncryptionAtRest">CfnEncryptionAtRest</a>

---

##### `accessList`<sup>Optional</sup> <a name="accessList" id="awscdk-resources-mongodbatlas.AtlasEncryptionAtRestExpress.property.accessList"></a>

```typescript
public readonly accessList: CfnProjectIpAccessList;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnProjectIpAccessList">CfnProjectIpAccessList</a>

---

##### `cluster`<sup>Optional</sup> <a name="cluster" id="awscdk-resources-mongodbatlas.AtlasEncryptionAtRestExpress.property.cluster"></a>

```typescript
public readonly cluster: CfnCluster;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnCluster">CfnCluster</a>

---

##### `databaseUser`<sup>Optional</sup> <a name="databaseUser" id="awscdk-resources-mongodbatlas.AtlasEncryptionAtRestExpress.property.databaseUser"></a>

```typescript
public readonly databaseUser: CfnDatabaseUser;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnDatabaseUser">CfnDatabaseUser</a>

---


### AtlasServerlessBasic <a name="AtlasServerlessBasic" id="awscdk-resources-mongodbatlas.AtlasServerlessBasic"></a>

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.AtlasServerlessBasic.Initializer"></a>

```typescript
import { AtlasServerlessBasic } from 'awscdk-resources-mongodbatlas'

new AtlasServerlessBasic(scope: Construct, id: string, props: AtlasServerlessBasicProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasServerlessBasic.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasServerlessBasic.Initializer.parameter.id">id</a></code> | <code>string</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasServerlessBasic.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.AtlasServerlessBasicProps">AtlasServerlessBasicProps</a></code> | *No description.* |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.AtlasServerlessBasic.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.AtlasServerlessBasic.Initializer.parameter.id"></a>

- *Type:* string

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.AtlasServerlessBasic.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.AtlasServerlessBasicProps">AtlasServerlessBasicProps</a>

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasServerlessBasic.toString">toString</a></code> | Returns a string representation of this construct. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.AtlasServerlessBasic.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasServerlessBasic.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.AtlasServerlessBasic.isConstruct"></a>

```typescript
import { AtlasServerlessBasic } from 'awscdk-resources-mongodbatlas'

AtlasServerlessBasic.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.AtlasServerlessBasic.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasServerlessBasic.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasServerlessBasic.property.ipAccessList">ipAccessList</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnProjectIpAccessList">CfnProjectIpAccessList</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasServerlessBasic.property.mDBUser">mDBUser</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUser">CfnDatabaseUser</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasServerlessBasic.property.mProject">mProject</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnProject">CfnProject</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasServerlessBasic.property.mserverless">mserverless</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstance">CfnServerlessInstance</a></code> | *No description.* |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.AtlasServerlessBasic.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `ipAccessList`<sup>Required</sup> <a name="ipAccessList" id="awscdk-resources-mongodbatlas.AtlasServerlessBasic.property.ipAccessList"></a>

```typescript
public readonly ipAccessList: CfnProjectIpAccessList;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnProjectIpAccessList">CfnProjectIpAccessList</a>

---

##### `mDBUser`<sup>Required</sup> <a name="mDBUser" id="awscdk-resources-mongodbatlas.AtlasServerlessBasic.property.mDBUser"></a>

```typescript
public readonly mDBUser: CfnDatabaseUser;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnDatabaseUser">CfnDatabaseUser</a>

---

##### `mProject`<sup>Required</sup> <a name="mProject" id="awscdk-resources-mongodbatlas.AtlasServerlessBasic.property.mProject"></a>

```typescript
public readonly mProject: CfnProject;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnProject">CfnProject</a>

---

##### `mserverless`<sup>Required</sup> <a name="mserverless" id="awscdk-resources-mongodbatlas.AtlasServerlessBasic.property.mserverless"></a>

```typescript
public readonly mserverless: CfnServerlessInstance;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnServerlessInstance">CfnServerlessInstance</a>

---


### CfnAccessListApiKey <a name="CfnAccessListApiKey" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey"></a>

A CloudFormation `MongoDB::Atlas::AccessListAPIKey`.

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.Initializer"></a>

```typescript
import { CfnAccessListApiKey } from 'awscdk-resources-mongodbatlas'

new CfnAccessListApiKey(scope: Construct, id: string, props: CfnAccessListApiKeyProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAccessListApiKey.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - scope in which this resource is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAccessListApiKey.Initializer.parameter.id">id</a></code> | <code>string</code> | - scoped id of the resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAccessListApiKey.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnAccessListApiKeyProps">CfnAccessListApiKeyProps</a></code> | - resource properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

scope in which this resource is defined.

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.Initializer.parameter.id"></a>

- *Type:* string

scoped id of the resource.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnAccessListApiKeyProps">CfnAccessListApiKeyProps</a>

resource properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAccessListApiKey.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAccessListApiKey.overrideLogicalId">overrideLogicalId</a></code> | Overrides the auto-generated logical ID with a specific ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAccessListApiKey.addDeletionOverride">addDeletionOverride</a></code> | Syntactic sugar for `addOverride(path, undefined)`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAccessListApiKey.addDependency">addDependency</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAccessListApiKey.addDependsOn">addDependsOn</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAccessListApiKey.addMetadata">addMetadata</a></code> | Add a value to the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAccessListApiKey.addOverride">addOverride</a></code> | Adds an override to the synthesized CloudFormation resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAccessListApiKey.addPropertyDeletionOverride">addPropertyDeletionOverride</a></code> | Adds an override that deletes the value of a property from the resource definition. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAccessListApiKey.addPropertyOverride">addPropertyOverride</a></code> | Adds an override to a resource property. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAccessListApiKey.applyRemovalPolicy">applyRemovalPolicy</a></code> | Sets the deletion policy of the resource based on the removal policy specified. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAccessListApiKey.getAtt">getAtt</a></code> | Returns a token for an runtime attribute of this resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAccessListApiKey.getMetadata">getMetadata</a></code> | Retrieve a value value from the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAccessListApiKey.obtainDependencies">obtainDependencies</a></code> | Retrieves an array of resources this resource depends on. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAccessListApiKey.obtainResourceDependencies">obtainResourceDependencies</a></code> | Get a shallow copy of dependencies between this resource and other resources in the same stack. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAccessListApiKey.removeDependency">removeDependency</a></code> | Indicates that this resource no longer depends on another resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAccessListApiKey.replaceDependency">replaceDependency</a></code> | Replaces one dependency with another. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `overrideLogicalId` <a name="overrideLogicalId" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.overrideLogicalId"></a>

```typescript
public overrideLogicalId(newLogicalId: string): void
```

Overrides the auto-generated logical ID with a specific ID.

###### `newLogicalId`<sup>Required</sup> <a name="newLogicalId" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.overrideLogicalId.parameter.newLogicalId"></a>

- *Type:* string

The new logical ID to use for this stack element.

---

##### `addDeletionOverride` <a name="addDeletionOverride" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.addDeletionOverride"></a>

```typescript
public addDeletionOverride(path: string): void
```

Syntactic sugar for `addOverride(path, undefined)`.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.addDeletionOverride.parameter.path"></a>

- *Type:* string

The path of the value to delete.

---

##### `addDependency` <a name="addDependency" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.addDependency"></a>

```typescript
public addDependency(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

This can be used for resources across stacks (or nested stack) boundaries
and the dependency will automatically be transferred to the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.addDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### ~~`addDependsOn`~~ <a name="addDependsOn" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.addDependsOn"></a>

```typescript
public addDependsOn(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.addDependsOn.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `addMetadata` <a name="addMetadata" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.addMetadata"></a>

```typescript
public addMetadata(key: string, value: any): void
```

Add a value to the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.addMetadata.parameter.key"></a>

- *Type:* string

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.addMetadata.parameter.value"></a>

- *Type:* any

---

##### `addOverride` <a name="addOverride" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.addOverride"></a>

```typescript
public addOverride(path: string, value: any): void
```

Adds an override to the synthesized CloudFormation resource.

To add a
property override, either use `addPropertyOverride` or prefix `path` with
"Properties." (i.e. `Properties.TopicName`).

If the override is nested, separate each nested level using a dot (.) in the path parameter.
If there is an array as part of the nesting, specify the index in the path.

To include a literal `.` in the property name, prefix with a `\`. In most
programming languages you will need to write this as `"\\."` because the
`\` itself will need to be escaped.

For example,
```typescript
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
```
would add the overrides
```json
"Properties": {
  "GlobalSecondaryIndexes": [
    {
      "Projection": {
        "NonKeyAttributes": [ "myattribute" ]
        ...
      }
      ...
    },
    {
      "ProjectionType": "INCLUDE"
      ...
    },
  ]
  ...
}
```

The `value` argument to `addOverride` will not be processed or translated
in any way. Pass raw JSON values in here with the correct capitalization
for CloudFormation. If you pass CDK classes or structs, they will be
rendered with lowercased key names, and CloudFormation will reject the
template.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.addOverride.parameter.path"></a>

- *Type:* string

The path of the property, you can use dot notation to override values in complex types.

Any intermediate keys
will be created as needed.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.addOverride.parameter.value"></a>

- *Type:* any

The value.

Could be primitive or complex.

---

##### `addPropertyDeletionOverride` <a name="addPropertyDeletionOverride" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.addPropertyDeletionOverride"></a>

```typescript
public addPropertyDeletionOverride(propertyPath: string): void
```

Adds an override that deletes the value of a property from the resource definition.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.addPropertyDeletionOverride.parameter.propertyPath"></a>

- *Type:* string

The path to the property.

---

##### `addPropertyOverride` <a name="addPropertyOverride" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.addPropertyOverride"></a>

```typescript
public addPropertyOverride(propertyPath: string, value: any): void
```

Adds an override to a resource property.

Syntactic sugar for `addOverride("Properties.<...>", value)`.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.addPropertyOverride.parameter.propertyPath"></a>

- *Type:* string

The path of the property.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.addPropertyOverride.parameter.value"></a>

- *Type:* any

The value.

---

##### `applyRemovalPolicy` <a name="applyRemovalPolicy" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.applyRemovalPolicy"></a>

```typescript
public applyRemovalPolicy(policy?: RemovalPolicy, options?: RemovalPolicyOptions): void
```

Sets the deletion policy of the resource based on the removal policy specified.

The Removal Policy controls what happens to this resource when it stops
being managed by CloudFormation, either because you've removed it from the
CDK application or because you've made a change that requires the resource
to be replaced.

The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
cases, a snapshot can be taken of the resource prior to deletion
(`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
can be found in the following link:

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options)

###### `policy`<sup>Optional</sup> <a name="policy" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.applyRemovalPolicy.parameter.policy"></a>

- *Type:* aws-cdk-lib.RemovalPolicy

---

###### `options`<sup>Optional</sup> <a name="options" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.applyRemovalPolicy.parameter.options"></a>

- *Type:* aws-cdk-lib.RemovalPolicyOptions

---

##### `getAtt` <a name="getAtt" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.getAtt"></a>

```typescript
public getAtt(attributeName: string, typeHint?: ResolutionTypeHint): Reference
```

Returns a token for an runtime attribute of this resource.

Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
in case there is no generated attribute.

###### `attributeName`<sup>Required</sup> <a name="attributeName" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.getAtt.parameter.attributeName"></a>

- *Type:* string

The name of the attribute.

---

###### `typeHint`<sup>Optional</sup> <a name="typeHint" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.getAtt.parameter.typeHint"></a>

- *Type:* aws-cdk-lib.ResolutionTypeHint

---

##### `getMetadata` <a name="getMetadata" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.getMetadata"></a>

```typescript
public getMetadata(key: string): any
```

Retrieve a value value from the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.getMetadata.parameter.key"></a>

- *Type:* string

---

##### `obtainDependencies` <a name="obtainDependencies" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.obtainDependencies"></a>

```typescript
public obtainDependencies(): Stack | CfnResource[]
```

Retrieves an array of resources this resource depends on.

This assembles dependencies on resources across stacks (including nested stacks)
automatically.

##### `obtainResourceDependencies` <a name="obtainResourceDependencies" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.obtainResourceDependencies"></a>

```typescript
public obtainResourceDependencies(): CfnResource[]
```

Get a shallow copy of dependencies between this resource and other resources in the same stack.

##### `removeDependency` <a name="removeDependency" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.removeDependency"></a>

```typescript
public removeDependency(target: CfnResource): void
```

Indicates that this resource no longer depends on another resource.

This can be used for resources across stacks (including nested stacks)
and the dependency will automatically be removed from the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.removeDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `replaceDependency` <a name="replaceDependency" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.replaceDependency"></a>

```typescript
public replaceDependency(target: CfnResource, newTarget: CfnResource): void
```

Replaces one dependency with another.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.replaceDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

The dependency to replace.

---

###### `newTarget`<sup>Required</sup> <a name="newTarget" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.replaceDependency.parameter.newTarget"></a>

- *Type:* aws-cdk-lib.CfnResource

The new dependency to add.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAccessListApiKey.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAccessListApiKey.isCfnElement">isCfnElement</a></code> | Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAccessListApiKey.isCfnResource">isCfnResource</a></code> | Check whether the given construct is a CfnResource. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.isConstruct"></a>

```typescript
import { CfnAccessListApiKey } from 'awscdk-resources-mongodbatlas'

CfnAccessListApiKey.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `isCfnElement` <a name="isCfnElement" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.isCfnElement"></a>

```typescript
import { CfnAccessListApiKey } from 'awscdk-resources-mongodbatlas'

CfnAccessListApiKey.isCfnElement(x: any)
```

Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).

Uses duck-typing instead of `instanceof` to allow stack elements from different
versions of this library to be included in the same stack.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.isCfnElement.parameter.x"></a>

- *Type:* any

---

##### `isCfnResource` <a name="isCfnResource" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.isCfnResource"></a>

```typescript
import { CfnAccessListApiKey } from 'awscdk-resources-mongodbatlas'

CfnAccessListApiKey.isCfnResource(construct: IConstruct)
```

Check whether the given construct is a CfnResource.

###### `construct`<sup>Required</sup> <a name="construct" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.isCfnResource.parameter.construct"></a>

- *Type:* constructs.IConstruct

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAccessListApiKey.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAccessListApiKey.property.creationStack">creationStack</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAccessListApiKey.property.logicalId">logicalId</a></code> | <code>string</code> | The logical ID for this CloudFormation stack element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAccessListApiKey.property.stack">stack</a></code> | <code>aws-cdk-lib.Stack</code> | The stack in which this element is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAccessListApiKey.property.ref">ref</a></code> | <code>string</code> | Return a string that will be resolved to a CloudFormation `{ Ref }` for this element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAccessListApiKey.property.cfnOptions">cfnOptions</a></code> | <code>aws-cdk-lib.ICfnResourceOptions</code> | Options for this resource, such as condition, update policy etc. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAccessListApiKey.property.cfnResourceType">cfnResourceType</a></code> | <code>string</code> | AWS resource type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAccessListApiKey.property.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnAccessListApiKeyProps">CfnAccessListApiKeyProps</a></code> | Resource props. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `creationStack`<sup>Required</sup> <a name="creationStack" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.property.creationStack"></a>

```typescript
public readonly creationStack: string[];
```

- *Type:* string[]

---

##### `logicalId`<sup>Required</sup> <a name="logicalId" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.property.logicalId"></a>

```typescript
public readonly logicalId: string;
```

- *Type:* string

The logical ID for this CloudFormation stack element.

The logical ID of the element
is calculated from the path of the resource node in the construct tree.

To override this value, use `overrideLogicalId(newLogicalId)`.

---

##### `stack`<sup>Required</sup> <a name="stack" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.property.stack"></a>

```typescript
public readonly stack: Stack;
```

- *Type:* aws-cdk-lib.Stack

The stack in which this element is defined.

CfnElements must be defined within a stack scope (directly or indirectly).

---

##### `ref`<sup>Required</sup> <a name="ref" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.

If, by any chance, the intrinsic reference of a resource is not a string, you could
coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.

---

##### `cfnOptions`<sup>Required</sup> <a name="cfnOptions" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.property.cfnOptions"></a>

```typescript
public readonly cfnOptions: ICfnResourceOptions;
```

- *Type:* aws-cdk-lib.ICfnResourceOptions

Options for this resource, such as condition, update policy etc.

---

##### `cfnResourceType`<sup>Required</sup> <a name="cfnResourceType" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.property.cfnResourceType"></a>

```typescript
public readonly cfnResourceType: string;
```

- *Type:* string

AWS resource type.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.property.props"></a>

```typescript
public readonly props: CfnAccessListApiKeyProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnAccessListApiKeyProps">CfnAccessListApiKeyProps</a>

Resource props.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAccessListApiKey.property.CFN_RESOURCE_TYPE_NAME">CFN_RESOURCE_TYPE_NAME</a></code> | <code>string</code> | The CloudFormation resource type name for this resource class. |

---

##### `CFN_RESOURCE_TYPE_NAME`<sup>Required</sup> <a name="CFN_RESOURCE_TYPE_NAME" id="awscdk-resources-mongodbatlas.CfnAccessListApiKey.property.CFN_RESOURCE_TYPE_NAME"></a>

```typescript
public readonly CFN_RESOURCE_TYPE_NAME: string;
```

- *Type:* string

The CloudFormation resource type name for this resource class.

---

### CfnAlertConfiguration <a name="CfnAlertConfiguration" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration"></a>

A CloudFormation `MongoDB::Atlas::AlertConfiguration`.

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.Initializer"></a>

```typescript
import { CfnAlertConfiguration } from 'awscdk-resources-mongodbatlas'

new CfnAlertConfiguration(scope: Construct, id: string, props: CfnAlertConfigurationProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAlertConfiguration.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - scope in which this resource is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAlertConfiguration.Initializer.parameter.id">id</a></code> | <code>string</code> | - scoped id of the resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAlertConfiguration.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnAlertConfigurationProps">CfnAlertConfigurationProps</a></code> | - resource properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

scope in which this resource is defined.

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.Initializer.parameter.id"></a>

- *Type:* string

scoped id of the resource.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnAlertConfigurationProps">CfnAlertConfigurationProps</a>

resource properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAlertConfiguration.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAlertConfiguration.overrideLogicalId">overrideLogicalId</a></code> | Overrides the auto-generated logical ID with a specific ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAlertConfiguration.addDeletionOverride">addDeletionOverride</a></code> | Syntactic sugar for `addOverride(path, undefined)`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAlertConfiguration.addDependency">addDependency</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAlertConfiguration.addDependsOn">addDependsOn</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAlertConfiguration.addMetadata">addMetadata</a></code> | Add a value to the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAlertConfiguration.addOverride">addOverride</a></code> | Adds an override to the synthesized CloudFormation resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAlertConfiguration.addPropertyDeletionOverride">addPropertyDeletionOverride</a></code> | Adds an override that deletes the value of a property from the resource definition. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAlertConfiguration.addPropertyOverride">addPropertyOverride</a></code> | Adds an override to a resource property. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAlertConfiguration.applyRemovalPolicy">applyRemovalPolicy</a></code> | Sets the deletion policy of the resource based on the removal policy specified. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAlertConfiguration.getAtt">getAtt</a></code> | Returns a token for an runtime attribute of this resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAlertConfiguration.getMetadata">getMetadata</a></code> | Retrieve a value value from the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAlertConfiguration.obtainDependencies">obtainDependencies</a></code> | Retrieves an array of resources this resource depends on. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAlertConfiguration.obtainResourceDependencies">obtainResourceDependencies</a></code> | Get a shallow copy of dependencies between this resource and other resources in the same stack. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAlertConfiguration.removeDependency">removeDependency</a></code> | Indicates that this resource no longer depends on another resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAlertConfiguration.replaceDependency">replaceDependency</a></code> | Replaces one dependency with another. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `overrideLogicalId` <a name="overrideLogicalId" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.overrideLogicalId"></a>

```typescript
public overrideLogicalId(newLogicalId: string): void
```

Overrides the auto-generated logical ID with a specific ID.

###### `newLogicalId`<sup>Required</sup> <a name="newLogicalId" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.overrideLogicalId.parameter.newLogicalId"></a>

- *Type:* string

The new logical ID to use for this stack element.

---

##### `addDeletionOverride` <a name="addDeletionOverride" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.addDeletionOverride"></a>

```typescript
public addDeletionOverride(path: string): void
```

Syntactic sugar for `addOverride(path, undefined)`.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.addDeletionOverride.parameter.path"></a>

- *Type:* string

The path of the value to delete.

---

##### `addDependency` <a name="addDependency" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.addDependency"></a>

```typescript
public addDependency(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

This can be used for resources across stacks (or nested stack) boundaries
and the dependency will automatically be transferred to the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.addDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### ~~`addDependsOn`~~ <a name="addDependsOn" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.addDependsOn"></a>

```typescript
public addDependsOn(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.addDependsOn.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `addMetadata` <a name="addMetadata" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.addMetadata"></a>

```typescript
public addMetadata(key: string, value: any): void
```

Add a value to the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.addMetadata.parameter.key"></a>

- *Type:* string

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.addMetadata.parameter.value"></a>

- *Type:* any

---

##### `addOverride` <a name="addOverride" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.addOverride"></a>

```typescript
public addOverride(path: string, value: any): void
```

Adds an override to the synthesized CloudFormation resource.

To add a
property override, either use `addPropertyOverride` or prefix `path` with
"Properties." (i.e. `Properties.TopicName`).

If the override is nested, separate each nested level using a dot (.) in the path parameter.
If there is an array as part of the nesting, specify the index in the path.

To include a literal `.` in the property name, prefix with a `\`. In most
programming languages you will need to write this as `"\\."` because the
`\` itself will need to be escaped.

For example,
```typescript
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
```
would add the overrides
```json
"Properties": {
  "GlobalSecondaryIndexes": [
    {
      "Projection": {
        "NonKeyAttributes": [ "myattribute" ]
        ...
      }
      ...
    },
    {
      "ProjectionType": "INCLUDE"
      ...
    },
  ]
  ...
}
```

The `value` argument to `addOverride` will not be processed or translated
in any way. Pass raw JSON values in here with the correct capitalization
for CloudFormation. If you pass CDK classes or structs, they will be
rendered with lowercased key names, and CloudFormation will reject the
template.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.addOverride.parameter.path"></a>

- *Type:* string

The path of the property, you can use dot notation to override values in complex types.

Any intermediate keys
will be created as needed.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.addOverride.parameter.value"></a>

- *Type:* any

The value.

Could be primitive or complex.

---

##### `addPropertyDeletionOverride` <a name="addPropertyDeletionOverride" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.addPropertyDeletionOverride"></a>

```typescript
public addPropertyDeletionOverride(propertyPath: string): void
```

Adds an override that deletes the value of a property from the resource definition.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.addPropertyDeletionOverride.parameter.propertyPath"></a>

- *Type:* string

The path to the property.

---

##### `addPropertyOverride` <a name="addPropertyOverride" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.addPropertyOverride"></a>

```typescript
public addPropertyOverride(propertyPath: string, value: any): void
```

Adds an override to a resource property.

Syntactic sugar for `addOverride("Properties.<...>", value)`.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.addPropertyOverride.parameter.propertyPath"></a>

- *Type:* string

The path of the property.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.addPropertyOverride.parameter.value"></a>

- *Type:* any

The value.

---

##### `applyRemovalPolicy` <a name="applyRemovalPolicy" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.applyRemovalPolicy"></a>

```typescript
public applyRemovalPolicy(policy?: RemovalPolicy, options?: RemovalPolicyOptions): void
```

Sets the deletion policy of the resource based on the removal policy specified.

The Removal Policy controls what happens to this resource when it stops
being managed by CloudFormation, either because you've removed it from the
CDK application or because you've made a change that requires the resource
to be replaced.

The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
cases, a snapshot can be taken of the resource prior to deletion
(`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
can be found in the following link:

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options)

###### `policy`<sup>Optional</sup> <a name="policy" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.applyRemovalPolicy.parameter.policy"></a>

- *Type:* aws-cdk-lib.RemovalPolicy

---

###### `options`<sup>Optional</sup> <a name="options" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.applyRemovalPolicy.parameter.options"></a>

- *Type:* aws-cdk-lib.RemovalPolicyOptions

---

##### `getAtt` <a name="getAtt" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.getAtt"></a>

```typescript
public getAtt(attributeName: string, typeHint?: ResolutionTypeHint): Reference
```

Returns a token for an runtime attribute of this resource.

Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
in case there is no generated attribute.

###### `attributeName`<sup>Required</sup> <a name="attributeName" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.getAtt.parameter.attributeName"></a>

- *Type:* string

The name of the attribute.

---

###### `typeHint`<sup>Optional</sup> <a name="typeHint" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.getAtt.parameter.typeHint"></a>

- *Type:* aws-cdk-lib.ResolutionTypeHint

---

##### `getMetadata` <a name="getMetadata" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.getMetadata"></a>

```typescript
public getMetadata(key: string): any
```

Retrieve a value value from the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.getMetadata.parameter.key"></a>

- *Type:* string

---

##### `obtainDependencies` <a name="obtainDependencies" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.obtainDependencies"></a>

```typescript
public obtainDependencies(): Stack | CfnResource[]
```

Retrieves an array of resources this resource depends on.

This assembles dependencies on resources across stacks (including nested stacks)
automatically.

##### `obtainResourceDependencies` <a name="obtainResourceDependencies" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.obtainResourceDependencies"></a>

```typescript
public obtainResourceDependencies(): CfnResource[]
```

Get a shallow copy of dependencies between this resource and other resources in the same stack.

##### `removeDependency` <a name="removeDependency" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.removeDependency"></a>

```typescript
public removeDependency(target: CfnResource): void
```

Indicates that this resource no longer depends on another resource.

This can be used for resources across stacks (including nested stacks)
and the dependency will automatically be removed from the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.removeDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `replaceDependency` <a name="replaceDependency" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.replaceDependency"></a>

```typescript
public replaceDependency(target: CfnResource, newTarget: CfnResource): void
```

Replaces one dependency with another.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.replaceDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

The dependency to replace.

---

###### `newTarget`<sup>Required</sup> <a name="newTarget" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.replaceDependency.parameter.newTarget"></a>

- *Type:* aws-cdk-lib.CfnResource

The new dependency to add.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAlertConfiguration.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAlertConfiguration.isCfnElement">isCfnElement</a></code> | Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAlertConfiguration.isCfnResource">isCfnResource</a></code> | Check whether the given construct is a CfnResource. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.isConstruct"></a>

```typescript
import { CfnAlertConfiguration } from 'awscdk-resources-mongodbatlas'

CfnAlertConfiguration.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `isCfnElement` <a name="isCfnElement" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.isCfnElement"></a>

```typescript
import { CfnAlertConfiguration } from 'awscdk-resources-mongodbatlas'

CfnAlertConfiguration.isCfnElement(x: any)
```

Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).

Uses duck-typing instead of `instanceof` to allow stack elements from different
versions of this library to be included in the same stack.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.isCfnElement.parameter.x"></a>

- *Type:* any

---

##### `isCfnResource` <a name="isCfnResource" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.isCfnResource"></a>

```typescript
import { CfnAlertConfiguration } from 'awscdk-resources-mongodbatlas'

CfnAlertConfiguration.isCfnResource(construct: IConstruct)
```

Check whether the given construct is a CfnResource.

###### `construct`<sup>Required</sup> <a name="construct" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.isCfnResource.parameter.construct"></a>

- *Type:* constructs.IConstruct

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAlertConfiguration.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAlertConfiguration.property.creationStack">creationStack</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAlertConfiguration.property.logicalId">logicalId</a></code> | <code>string</code> | The logical ID for this CloudFormation stack element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAlertConfiguration.property.stack">stack</a></code> | <code>aws-cdk-lib.Stack</code> | The stack in which this element is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAlertConfiguration.property.ref">ref</a></code> | <code>string</code> | Return a string that will be resolved to a CloudFormation `{ Ref }` for this element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAlertConfiguration.property.cfnOptions">cfnOptions</a></code> | <code>aws-cdk-lib.ICfnResourceOptions</code> | Options for this resource, such as condition, update policy etc. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAlertConfiguration.property.cfnResourceType">cfnResourceType</a></code> | <code>string</code> | AWS resource type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAlertConfiguration.property.attrEnabled">attrEnabled</a></code> | <code>aws-cdk-lib.IResolvable</code> | Attribute `MongoDB::Atlas::AlertConfiguration.Enabled`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAlertConfiguration.property.attrId">attrId</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::AlertConfiguration.Id`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAlertConfiguration.property.attrUpdated">attrUpdated</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::AlertConfiguration.Updated`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAlertConfiguration.property.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnAlertConfigurationProps">CfnAlertConfigurationProps</a></code> | Resource props. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `creationStack`<sup>Required</sup> <a name="creationStack" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.property.creationStack"></a>

```typescript
public readonly creationStack: string[];
```

- *Type:* string[]

---

##### `logicalId`<sup>Required</sup> <a name="logicalId" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.property.logicalId"></a>

```typescript
public readonly logicalId: string;
```

- *Type:* string

The logical ID for this CloudFormation stack element.

The logical ID of the element
is calculated from the path of the resource node in the construct tree.

To override this value, use `overrideLogicalId(newLogicalId)`.

---

##### `stack`<sup>Required</sup> <a name="stack" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.property.stack"></a>

```typescript
public readonly stack: Stack;
```

- *Type:* aws-cdk-lib.Stack

The stack in which this element is defined.

CfnElements must be defined within a stack scope (directly or indirectly).

---

##### `ref`<sup>Required</sup> <a name="ref" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.

If, by any chance, the intrinsic reference of a resource is not a string, you could
coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.

---

##### `cfnOptions`<sup>Required</sup> <a name="cfnOptions" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.property.cfnOptions"></a>

```typescript
public readonly cfnOptions: ICfnResourceOptions;
```

- *Type:* aws-cdk-lib.ICfnResourceOptions

Options for this resource, such as condition, update policy etc.

---

##### `cfnResourceType`<sup>Required</sup> <a name="cfnResourceType" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.property.cfnResourceType"></a>

```typescript
public readonly cfnResourceType: string;
```

- *Type:* string

AWS resource type.

---

##### `attrEnabled`<sup>Required</sup> <a name="attrEnabled" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.property.attrEnabled"></a>

```typescript
public readonly attrEnabled: IResolvable;
```

- *Type:* aws-cdk-lib.IResolvable

Attribute `MongoDB::Atlas::AlertConfiguration.Enabled`.

---

##### `attrId`<sup>Required</sup> <a name="attrId" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.property.attrId"></a>

```typescript
public readonly attrId: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::AlertConfiguration.Id`.

---

##### `attrUpdated`<sup>Required</sup> <a name="attrUpdated" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.property.attrUpdated"></a>

```typescript
public readonly attrUpdated: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::AlertConfiguration.Updated`.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.property.props"></a>

```typescript
public readonly props: CfnAlertConfigurationProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnAlertConfigurationProps">CfnAlertConfigurationProps</a>

Resource props.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAlertConfiguration.property.CFN_RESOURCE_TYPE_NAME">CFN_RESOURCE_TYPE_NAME</a></code> | <code>string</code> | The CloudFormation resource type name for this resource class. |

---

##### `CFN_RESOURCE_TYPE_NAME`<sup>Required</sup> <a name="CFN_RESOURCE_TYPE_NAME" id="awscdk-resources-mongodbatlas.CfnAlertConfiguration.property.CFN_RESOURCE_TYPE_NAME"></a>

```typescript
public readonly CFN_RESOURCE_TYPE_NAME: string;
```

- *Type:* string

The CloudFormation resource type name for this resource class.

---

### CfnApiKey <a name="CfnApiKey" id="awscdk-resources-mongodbatlas.CfnApiKey"></a>

A CloudFormation `MongoDB::Atlas::APIKey`.

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.CfnApiKey.Initializer"></a>

```typescript
import { CfnApiKey } from 'awscdk-resources-mongodbatlas'

new CfnApiKey(scope: Construct, id: string, props: CfnApiKeyProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnApiKey.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - scope in which this resource is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnApiKey.Initializer.parameter.id">id</a></code> | <code>string</code> | - scoped id of the resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnApiKey.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnApiKeyProps">CfnApiKeyProps</a></code> | - resource properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.CfnApiKey.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

scope in which this resource is defined.

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnApiKey.Initializer.parameter.id"></a>

- *Type:* string

scoped id of the resource.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnApiKey.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnApiKeyProps">CfnApiKeyProps</a>

resource properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnApiKey.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnApiKey.overrideLogicalId">overrideLogicalId</a></code> | Overrides the auto-generated logical ID with a specific ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnApiKey.addDeletionOverride">addDeletionOverride</a></code> | Syntactic sugar for `addOverride(path, undefined)`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnApiKey.addDependency">addDependency</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnApiKey.addDependsOn">addDependsOn</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnApiKey.addMetadata">addMetadata</a></code> | Add a value to the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnApiKey.addOverride">addOverride</a></code> | Adds an override to the synthesized CloudFormation resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnApiKey.addPropertyDeletionOverride">addPropertyDeletionOverride</a></code> | Adds an override that deletes the value of a property from the resource definition. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnApiKey.addPropertyOverride">addPropertyOverride</a></code> | Adds an override to a resource property. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnApiKey.applyRemovalPolicy">applyRemovalPolicy</a></code> | Sets the deletion policy of the resource based on the removal policy specified. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnApiKey.getAtt">getAtt</a></code> | Returns a token for an runtime attribute of this resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnApiKey.getMetadata">getMetadata</a></code> | Retrieve a value value from the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnApiKey.obtainDependencies">obtainDependencies</a></code> | Retrieves an array of resources this resource depends on. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnApiKey.obtainResourceDependencies">obtainResourceDependencies</a></code> | Get a shallow copy of dependencies between this resource and other resources in the same stack. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnApiKey.removeDependency">removeDependency</a></code> | Indicates that this resource no longer depends on another resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnApiKey.replaceDependency">replaceDependency</a></code> | Replaces one dependency with another. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.CfnApiKey.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `overrideLogicalId` <a name="overrideLogicalId" id="awscdk-resources-mongodbatlas.CfnApiKey.overrideLogicalId"></a>

```typescript
public overrideLogicalId(newLogicalId: string): void
```

Overrides the auto-generated logical ID with a specific ID.

###### `newLogicalId`<sup>Required</sup> <a name="newLogicalId" id="awscdk-resources-mongodbatlas.CfnApiKey.overrideLogicalId.parameter.newLogicalId"></a>

- *Type:* string

The new logical ID to use for this stack element.

---

##### `addDeletionOverride` <a name="addDeletionOverride" id="awscdk-resources-mongodbatlas.CfnApiKey.addDeletionOverride"></a>

```typescript
public addDeletionOverride(path: string): void
```

Syntactic sugar for `addOverride(path, undefined)`.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnApiKey.addDeletionOverride.parameter.path"></a>

- *Type:* string

The path of the value to delete.

---

##### `addDependency` <a name="addDependency" id="awscdk-resources-mongodbatlas.CfnApiKey.addDependency"></a>

```typescript
public addDependency(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

This can be used for resources across stacks (or nested stack) boundaries
and the dependency will automatically be transferred to the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnApiKey.addDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### ~~`addDependsOn`~~ <a name="addDependsOn" id="awscdk-resources-mongodbatlas.CfnApiKey.addDependsOn"></a>

```typescript
public addDependsOn(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnApiKey.addDependsOn.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `addMetadata` <a name="addMetadata" id="awscdk-resources-mongodbatlas.CfnApiKey.addMetadata"></a>

```typescript
public addMetadata(key: string, value: any): void
```

Add a value to the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnApiKey.addMetadata.parameter.key"></a>

- *Type:* string

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnApiKey.addMetadata.parameter.value"></a>

- *Type:* any

---

##### `addOverride` <a name="addOverride" id="awscdk-resources-mongodbatlas.CfnApiKey.addOverride"></a>

```typescript
public addOverride(path: string, value: any): void
```

Adds an override to the synthesized CloudFormation resource.

To add a
property override, either use `addPropertyOverride` or prefix `path` with
"Properties." (i.e. `Properties.TopicName`).

If the override is nested, separate each nested level using a dot (.) in the path parameter.
If there is an array as part of the nesting, specify the index in the path.

To include a literal `.` in the property name, prefix with a `\`. In most
programming languages you will need to write this as `"\\."` because the
`\` itself will need to be escaped.

For example,
```typescript
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
```
would add the overrides
```json
"Properties": {
  "GlobalSecondaryIndexes": [
    {
      "Projection": {
        "NonKeyAttributes": [ "myattribute" ]
        ...
      }
      ...
    },
    {
      "ProjectionType": "INCLUDE"
      ...
    },
  ]
  ...
}
```

The `value` argument to `addOverride` will not be processed or translated
in any way. Pass raw JSON values in here with the correct capitalization
for CloudFormation. If you pass CDK classes or structs, they will be
rendered with lowercased key names, and CloudFormation will reject the
template.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnApiKey.addOverride.parameter.path"></a>

- *Type:* string

The path of the property, you can use dot notation to override values in complex types.

Any intermediate keys
will be created as needed.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnApiKey.addOverride.parameter.value"></a>

- *Type:* any

The value.

Could be primitive or complex.

---

##### `addPropertyDeletionOverride` <a name="addPropertyDeletionOverride" id="awscdk-resources-mongodbatlas.CfnApiKey.addPropertyDeletionOverride"></a>

```typescript
public addPropertyDeletionOverride(propertyPath: string): void
```

Adds an override that deletes the value of a property from the resource definition.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnApiKey.addPropertyDeletionOverride.parameter.propertyPath"></a>

- *Type:* string

The path to the property.

---

##### `addPropertyOverride` <a name="addPropertyOverride" id="awscdk-resources-mongodbatlas.CfnApiKey.addPropertyOverride"></a>

```typescript
public addPropertyOverride(propertyPath: string, value: any): void
```

Adds an override to a resource property.

Syntactic sugar for `addOverride("Properties.<...>", value)`.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnApiKey.addPropertyOverride.parameter.propertyPath"></a>

- *Type:* string

The path of the property.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnApiKey.addPropertyOverride.parameter.value"></a>

- *Type:* any

The value.

---

##### `applyRemovalPolicy` <a name="applyRemovalPolicy" id="awscdk-resources-mongodbatlas.CfnApiKey.applyRemovalPolicy"></a>

```typescript
public applyRemovalPolicy(policy?: RemovalPolicy, options?: RemovalPolicyOptions): void
```

Sets the deletion policy of the resource based on the removal policy specified.

The Removal Policy controls what happens to this resource when it stops
being managed by CloudFormation, either because you've removed it from the
CDK application or because you've made a change that requires the resource
to be replaced.

The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
cases, a snapshot can be taken of the resource prior to deletion
(`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
can be found in the following link:

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options)

###### `policy`<sup>Optional</sup> <a name="policy" id="awscdk-resources-mongodbatlas.CfnApiKey.applyRemovalPolicy.parameter.policy"></a>

- *Type:* aws-cdk-lib.RemovalPolicy

---

###### `options`<sup>Optional</sup> <a name="options" id="awscdk-resources-mongodbatlas.CfnApiKey.applyRemovalPolicy.parameter.options"></a>

- *Type:* aws-cdk-lib.RemovalPolicyOptions

---

##### `getAtt` <a name="getAtt" id="awscdk-resources-mongodbatlas.CfnApiKey.getAtt"></a>

```typescript
public getAtt(attributeName: string, typeHint?: ResolutionTypeHint): Reference
```

Returns a token for an runtime attribute of this resource.

Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
in case there is no generated attribute.

###### `attributeName`<sup>Required</sup> <a name="attributeName" id="awscdk-resources-mongodbatlas.CfnApiKey.getAtt.parameter.attributeName"></a>

- *Type:* string

The name of the attribute.

---

###### `typeHint`<sup>Optional</sup> <a name="typeHint" id="awscdk-resources-mongodbatlas.CfnApiKey.getAtt.parameter.typeHint"></a>

- *Type:* aws-cdk-lib.ResolutionTypeHint

---

##### `getMetadata` <a name="getMetadata" id="awscdk-resources-mongodbatlas.CfnApiKey.getMetadata"></a>

```typescript
public getMetadata(key: string): any
```

Retrieve a value value from the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnApiKey.getMetadata.parameter.key"></a>

- *Type:* string

---

##### `obtainDependencies` <a name="obtainDependencies" id="awscdk-resources-mongodbatlas.CfnApiKey.obtainDependencies"></a>

```typescript
public obtainDependencies(): Stack | CfnResource[]
```

Retrieves an array of resources this resource depends on.

This assembles dependencies on resources across stacks (including nested stacks)
automatically.

##### `obtainResourceDependencies` <a name="obtainResourceDependencies" id="awscdk-resources-mongodbatlas.CfnApiKey.obtainResourceDependencies"></a>

```typescript
public obtainResourceDependencies(): CfnResource[]
```

Get a shallow copy of dependencies between this resource and other resources in the same stack.

##### `removeDependency` <a name="removeDependency" id="awscdk-resources-mongodbatlas.CfnApiKey.removeDependency"></a>

```typescript
public removeDependency(target: CfnResource): void
```

Indicates that this resource no longer depends on another resource.

This can be used for resources across stacks (including nested stacks)
and the dependency will automatically be removed from the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnApiKey.removeDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `replaceDependency` <a name="replaceDependency" id="awscdk-resources-mongodbatlas.CfnApiKey.replaceDependency"></a>

```typescript
public replaceDependency(target: CfnResource, newTarget: CfnResource): void
```

Replaces one dependency with another.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnApiKey.replaceDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

The dependency to replace.

---

###### `newTarget`<sup>Required</sup> <a name="newTarget" id="awscdk-resources-mongodbatlas.CfnApiKey.replaceDependency.parameter.newTarget"></a>

- *Type:* aws-cdk-lib.CfnResource

The new dependency to add.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnApiKey.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnApiKey.isCfnElement">isCfnElement</a></code> | Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnApiKey.isCfnResource">isCfnResource</a></code> | Check whether the given construct is a CfnResource. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.CfnApiKey.isConstruct"></a>

```typescript
import { CfnApiKey } from 'awscdk-resources-mongodbatlas'

CfnApiKey.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnApiKey.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `isCfnElement` <a name="isCfnElement" id="awscdk-resources-mongodbatlas.CfnApiKey.isCfnElement"></a>

```typescript
import { CfnApiKey } from 'awscdk-resources-mongodbatlas'

CfnApiKey.isCfnElement(x: any)
```

Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).

Uses duck-typing instead of `instanceof` to allow stack elements from different
versions of this library to be included in the same stack.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnApiKey.isCfnElement.parameter.x"></a>

- *Type:* any

---

##### `isCfnResource` <a name="isCfnResource" id="awscdk-resources-mongodbatlas.CfnApiKey.isCfnResource"></a>

```typescript
import { CfnApiKey } from 'awscdk-resources-mongodbatlas'

CfnApiKey.isCfnResource(construct: IConstruct)
```

Check whether the given construct is a CfnResource.

###### `construct`<sup>Required</sup> <a name="construct" id="awscdk-resources-mongodbatlas.CfnApiKey.isCfnResource.parameter.construct"></a>

- *Type:* constructs.IConstruct

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnApiKey.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnApiKey.property.creationStack">creationStack</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnApiKey.property.logicalId">logicalId</a></code> | <code>string</code> | The logical ID for this CloudFormation stack element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnApiKey.property.stack">stack</a></code> | <code>aws-cdk-lib.Stack</code> | The stack in which this element is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnApiKey.property.ref">ref</a></code> | <code>string</code> | Return a string that will be resolved to a CloudFormation `{ Ref }` for this element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnApiKey.property.cfnOptions">cfnOptions</a></code> | <code>aws-cdk-lib.ICfnResourceOptions</code> | Options for this resource, such as condition, update policy etc. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnApiKey.property.cfnResourceType">cfnResourceType</a></code> | <code>string</code> | AWS resource type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnApiKey.property.attrAPIUserId">attrAPIUserId</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::APIKey.APIUserId`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnApiKey.property.attrAwsSecretArn">attrAwsSecretArn</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::APIKey.AwsSecretArn`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnApiKey.property.attrPrivateKey">attrPrivateKey</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::APIKey.PrivateKey`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnApiKey.property.attrPublicKey">attrPublicKey</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::APIKey.PublicKey`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnApiKey.property.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnApiKeyProps">CfnApiKeyProps</a></code> | Resource props. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.CfnApiKey.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `creationStack`<sup>Required</sup> <a name="creationStack" id="awscdk-resources-mongodbatlas.CfnApiKey.property.creationStack"></a>

```typescript
public readonly creationStack: string[];
```

- *Type:* string[]

---

##### `logicalId`<sup>Required</sup> <a name="logicalId" id="awscdk-resources-mongodbatlas.CfnApiKey.property.logicalId"></a>

```typescript
public readonly logicalId: string;
```

- *Type:* string

The logical ID for this CloudFormation stack element.

The logical ID of the element
is calculated from the path of the resource node in the construct tree.

To override this value, use `overrideLogicalId(newLogicalId)`.

---

##### `stack`<sup>Required</sup> <a name="stack" id="awscdk-resources-mongodbatlas.CfnApiKey.property.stack"></a>

```typescript
public readonly stack: Stack;
```

- *Type:* aws-cdk-lib.Stack

The stack in which this element is defined.

CfnElements must be defined within a stack scope (directly or indirectly).

---

##### `ref`<sup>Required</sup> <a name="ref" id="awscdk-resources-mongodbatlas.CfnApiKey.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.

If, by any chance, the intrinsic reference of a resource is not a string, you could
coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.

---

##### `cfnOptions`<sup>Required</sup> <a name="cfnOptions" id="awscdk-resources-mongodbatlas.CfnApiKey.property.cfnOptions"></a>

```typescript
public readonly cfnOptions: ICfnResourceOptions;
```

- *Type:* aws-cdk-lib.ICfnResourceOptions

Options for this resource, such as condition, update policy etc.

---

##### `cfnResourceType`<sup>Required</sup> <a name="cfnResourceType" id="awscdk-resources-mongodbatlas.CfnApiKey.property.cfnResourceType"></a>

```typescript
public readonly cfnResourceType: string;
```

- *Type:* string

AWS resource type.

---

##### `attrAPIUserId`<sup>Required</sup> <a name="attrAPIUserId" id="awscdk-resources-mongodbatlas.CfnApiKey.property.attrAPIUserId"></a>

```typescript
public readonly attrAPIUserId: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::APIKey.APIUserId`.

---

##### `attrAwsSecretArn`<sup>Required</sup> <a name="attrAwsSecretArn" id="awscdk-resources-mongodbatlas.CfnApiKey.property.attrAwsSecretArn"></a>

```typescript
public readonly attrAwsSecretArn: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::APIKey.AwsSecretArn`.

---

##### `attrPrivateKey`<sup>Required</sup> <a name="attrPrivateKey" id="awscdk-resources-mongodbatlas.CfnApiKey.property.attrPrivateKey"></a>

```typescript
public readonly attrPrivateKey: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::APIKey.PrivateKey`.

---

##### `attrPublicKey`<sup>Required</sup> <a name="attrPublicKey" id="awscdk-resources-mongodbatlas.CfnApiKey.property.attrPublicKey"></a>

```typescript
public readonly attrPublicKey: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::APIKey.PublicKey`.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnApiKey.property.props"></a>

```typescript
public readonly props: CfnApiKeyProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnApiKeyProps">CfnApiKeyProps</a>

Resource props.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnApiKey.property.CFN_RESOURCE_TYPE_NAME">CFN_RESOURCE_TYPE_NAME</a></code> | <code>string</code> | The CloudFormation resource type name for this resource class. |

---

##### `CFN_RESOURCE_TYPE_NAME`<sup>Required</sup> <a name="CFN_RESOURCE_TYPE_NAME" id="awscdk-resources-mongodbatlas.CfnApiKey.property.CFN_RESOURCE_TYPE_NAME"></a>

```typescript
public readonly CFN_RESOURCE_TYPE_NAME: string;
```

- *Type:* string

The CloudFormation resource type name for this resource class.

---

### CfnAuditing <a name="CfnAuditing" id="awscdk-resources-mongodbatlas.CfnAuditing"></a>

A CloudFormation `MongoDB::Atlas::Auditing`.

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.CfnAuditing.Initializer"></a>

```typescript
import { CfnAuditing } from 'awscdk-resources-mongodbatlas'

new CfnAuditing(scope: Construct, id: string, props: CfnAuditingProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAuditing.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - scope in which this resource is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAuditing.Initializer.parameter.id">id</a></code> | <code>string</code> | - scoped id of the resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAuditing.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnAuditingProps">CfnAuditingProps</a></code> | - resource properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.CfnAuditing.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

scope in which this resource is defined.

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnAuditing.Initializer.parameter.id"></a>

- *Type:* string

scoped id of the resource.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnAuditing.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnAuditingProps">CfnAuditingProps</a>

resource properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAuditing.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAuditing.overrideLogicalId">overrideLogicalId</a></code> | Overrides the auto-generated logical ID with a specific ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAuditing.addDeletionOverride">addDeletionOverride</a></code> | Syntactic sugar for `addOverride(path, undefined)`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAuditing.addDependency">addDependency</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAuditing.addDependsOn">addDependsOn</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAuditing.addMetadata">addMetadata</a></code> | Add a value to the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAuditing.addOverride">addOverride</a></code> | Adds an override to the synthesized CloudFormation resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAuditing.addPropertyDeletionOverride">addPropertyDeletionOverride</a></code> | Adds an override that deletes the value of a property from the resource definition. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAuditing.addPropertyOverride">addPropertyOverride</a></code> | Adds an override to a resource property. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAuditing.applyRemovalPolicy">applyRemovalPolicy</a></code> | Sets the deletion policy of the resource based on the removal policy specified. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAuditing.getAtt">getAtt</a></code> | Returns a token for an runtime attribute of this resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAuditing.getMetadata">getMetadata</a></code> | Retrieve a value value from the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAuditing.obtainDependencies">obtainDependencies</a></code> | Retrieves an array of resources this resource depends on. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAuditing.obtainResourceDependencies">obtainResourceDependencies</a></code> | Get a shallow copy of dependencies between this resource and other resources in the same stack. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAuditing.removeDependency">removeDependency</a></code> | Indicates that this resource no longer depends on another resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAuditing.replaceDependency">replaceDependency</a></code> | Replaces one dependency with another. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.CfnAuditing.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `overrideLogicalId` <a name="overrideLogicalId" id="awscdk-resources-mongodbatlas.CfnAuditing.overrideLogicalId"></a>

```typescript
public overrideLogicalId(newLogicalId: string): void
```

Overrides the auto-generated logical ID with a specific ID.

###### `newLogicalId`<sup>Required</sup> <a name="newLogicalId" id="awscdk-resources-mongodbatlas.CfnAuditing.overrideLogicalId.parameter.newLogicalId"></a>

- *Type:* string

The new logical ID to use for this stack element.

---

##### `addDeletionOverride` <a name="addDeletionOverride" id="awscdk-resources-mongodbatlas.CfnAuditing.addDeletionOverride"></a>

```typescript
public addDeletionOverride(path: string): void
```

Syntactic sugar for `addOverride(path, undefined)`.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnAuditing.addDeletionOverride.parameter.path"></a>

- *Type:* string

The path of the value to delete.

---

##### `addDependency` <a name="addDependency" id="awscdk-resources-mongodbatlas.CfnAuditing.addDependency"></a>

```typescript
public addDependency(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

This can be used for resources across stacks (or nested stack) boundaries
and the dependency will automatically be transferred to the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnAuditing.addDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### ~~`addDependsOn`~~ <a name="addDependsOn" id="awscdk-resources-mongodbatlas.CfnAuditing.addDependsOn"></a>

```typescript
public addDependsOn(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnAuditing.addDependsOn.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `addMetadata` <a name="addMetadata" id="awscdk-resources-mongodbatlas.CfnAuditing.addMetadata"></a>

```typescript
public addMetadata(key: string, value: any): void
```

Add a value to the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnAuditing.addMetadata.parameter.key"></a>

- *Type:* string

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnAuditing.addMetadata.parameter.value"></a>

- *Type:* any

---

##### `addOverride` <a name="addOverride" id="awscdk-resources-mongodbatlas.CfnAuditing.addOverride"></a>

```typescript
public addOverride(path: string, value: any): void
```

Adds an override to the synthesized CloudFormation resource.

To add a
property override, either use `addPropertyOverride` or prefix `path` with
"Properties." (i.e. `Properties.TopicName`).

If the override is nested, separate each nested level using a dot (.) in the path parameter.
If there is an array as part of the nesting, specify the index in the path.

To include a literal `.` in the property name, prefix with a `\`. In most
programming languages you will need to write this as `"\\."` because the
`\` itself will need to be escaped.

For example,
```typescript
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
```
would add the overrides
```json
"Properties": {
  "GlobalSecondaryIndexes": [
    {
      "Projection": {
        "NonKeyAttributes": [ "myattribute" ]
        ...
      }
      ...
    },
    {
      "ProjectionType": "INCLUDE"
      ...
    },
  ]
  ...
}
```

The `value` argument to `addOverride` will not be processed or translated
in any way. Pass raw JSON values in here with the correct capitalization
for CloudFormation. If you pass CDK classes or structs, they will be
rendered with lowercased key names, and CloudFormation will reject the
template.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnAuditing.addOverride.parameter.path"></a>

- *Type:* string

The path of the property, you can use dot notation to override values in complex types.

Any intermediate keys
will be created as needed.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnAuditing.addOverride.parameter.value"></a>

- *Type:* any

The value.

Could be primitive or complex.

---

##### `addPropertyDeletionOverride` <a name="addPropertyDeletionOverride" id="awscdk-resources-mongodbatlas.CfnAuditing.addPropertyDeletionOverride"></a>

```typescript
public addPropertyDeletionOverride(propertyPath: string): void
```

Adds an override that deletes the value of a property from the resource definition.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnAuditing.addPropertyDeletionOverride.parameter.propertyPath"></a>

- *Type:* string

The path to the property.

---

##### `addPropertyOverride` <a name="addPropertyOverride" id="awscdk-resources-mongodbatlas.CfnAuditing.addPropertyOverride"></a>

```typescript
public addPropertyOverride(propertyPath: string, value: any): void
```

Adds an override to a resource property.

Syntactic sugar for `addOverride("Properties.<...>", value)`.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnAuditing.addPropertyOverride.parameter.propertyPath"></a>

- *Type:* string

The path of the property.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnAuditing.addPropertyOverride.parameter.value"></a>

- *Type:* any

The value.

---

##### `applyRemovalPolicy` <a name="applyRemovalPolicy" id="awscdk-resources-mongodbatlas.CfnAuditing.applyRemovalPolicy"></a>

```typescript
public applyRemovalPolicy(policy?: RemovalPolicy, options?: RemovalPolicyOptions): void
```

Sets the deletion policy of the resource based on the removal policy specified.

The Removal Policy controls what happens to this resource when it stops
being managed by CloudFormation, either because you've removed it from the
CDK application or because you've made a change that requires the resource
to be replaced.

The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
cases, a snapshot can be taken of the resource prior to deletion
(`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
can be found in the following link:

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options)

###### `policy`<sup>Optional</sup> <a name="policy" id="awscdk-resources-mongodbatlas.CfnAuditing.applyRemovalPolicy.parameter.policy"></a>

- *Type:* aws-cdk-lib.RemovalPolicy

---

###### `options`<sup>Optional</sup> <a name="options" id="awscdk-resources-mongodbatlas.CfnAuditing.applyRemovalPolicy.parameter.options"></a>

- *Type:* aws-cdk-lib.RemovalPolicyOptions

---

##### `getAtt` <a name="getAtt" id="awscdk-resources-mongodbatlas.CfnAuditing.getAtt"></a>

```typescript
public getAtt(attributeName: string, typeHint?: ResolutionTypeHint): Reference
```

Returns a token for an runtime attribute of this resource.

Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
in case there is no generated attribute.

###### `attributeName`<sup>Required</sup> <a name="attributeName" id="awscdk-resources-mongodbatlas.CfnAuditing.getAtt.parameter.attributeName"></a>

- *Type:* string

The name of the attribute.

---

###### `typeHint`<sup>Optional</sup> <a name="typeHint" id="awscdk-resources-mongodbatlas.CfnAuditing.getAtt.parameter.typeHint"></a>

- *Type:* aws-cdk-lib.ResolutionTypeHint

---

##### `getMetadata` <a name="getMetadata" id="awscdk-resources-mongodbatlas.CfnAuditing.getMetadata"></a>

```typescript
public getMetadata(key: string): any
```

Retrieve a value value from the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnAuditing.getMetadata.parameter.key"></a>

- *Type:* string

---

##### `obtainDependencies` <a name="obtainDependencies" id="awscdk-resources-mongodbatlas.CfnAuditing.obtainDependencies"></a>

```typescript
public obtainDependencies(): Stack | CfnResource[]
```

Retrieves an array of resources this resource depends on.

This assembles dependencies on resources across stacks (including nested stacks)
automatically.

##### `obtainResourceDependencies` <a name="obtainResourceDependencies" id="awscdk-resources-mongodbatlas.CfnAuditing.obtainResourceDependencies"></a>

```typescript
public obtainResourceDependencies(): CfnResource[]
```

Get a shallow copy of dependencies between this resource and other resources in the same stack.

##### `removeDependency` <a name="removeDependency" id="awscdk-resources-mongodbatlas.CfnAuditing.removeDependency"></a>

```typescript
public removeDependency(target: CfnResource): void
```

Indicates that this resource no longer depends on another resource.

This can be used for resources across stacks (including nested stacks)
and the dependency will automatically be removed from the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnAuditing.removeDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `replaceDependency` <a name="replaceDependency" id="awscdk-resources-mongodbatlas.CfnAuditing.replaceDependency"></a>

```typescript
public replaceDependency(target: CfnResource, newTarget: CfnResource): void
```

Replaces one dependency with another.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnAuditing.replaceDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

The dependency to replace.

---

###### `newTarget`<sup>Required</sup> <a name="newTarget" id="awscdk-resources-mongodbatlas.CfnAuditing.replaceDependency.parameter.newTarget"></a>

- *Type:* aws-cdk-lib.CfnResource

The new dependency to add.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAuditing.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAuditing.isCfnElement">isCfnElement</a></code> | Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAuditing.isCfnResource">isCfnResource</a></code> | Check whether the given construct is a CfnResource. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.CfnAuditing.isConstruct"></a>

```typescript
import { CfnAuditing } from 'awscdk-resources-mongodbatlas'

CfnAuditing.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnAuditing.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `isCfnElement` <a name="isCfnElement" id="awscdk-resources-mongodbatlas.CfnAuditing.isCfnElement"></a>

```typescript
import { CfnAuditing } from 'awscdk-resources-mongodbatlas'

CfnAuditing.isCfnElement(x: any)
```

Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).

Uses duck-typing instead of `instanceof` to allow stack elements from different
versions of this library to be included in the same stack.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnAuditing.isCfnElement.parameter.x"></a>

- *Type:* any

---

##### `isCfnResource` <a name="isCfnResource" id="awscdk-resources-mongodbatlas.CfnAuditing.isCfnResource"></a>

```typescript
import { CfnAuditing } from 'awscdk-resources-mongodbatlas'

CfnAuditing.isCfnResource(construct: IConstruct)
```

Check whether the given construct is a CfnResource.

###### `construct`<sup>Required</sup> <a name="construct" id="awscdk-resources-mongodbatlas.CfnAuditing.isCfnResource.parameter.construct"></a>

- *Type:* constructs.IConstruct

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAuditing.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAuditing.property.creationStack">creationStack</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAuditing.property.logicalId">logicalId</a></code> | <code>string</code> | The logical ID for this CloudFormation stack element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAuditing.property.stack">stack</a></code> | <code>aws-cdk-lib.Stack</code> | The stack in which this element is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAuditing.property.ref">ref</a></code> | <code>string</code> | Return a string that will be resolved to a CloudFormation `{ Ref }` for this element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAuditing.property.cfnOptions">cfnOptions</a></code> | <code>aws-cdk-lib.ICfnResourceOptions</code> | Options for this resource, such as condition, update policy etc. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAuditing.property.cfnResourceType">cfnResourceType</a></code> | <code>string</code> | AWS resource type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAuditing.property.attrAuditAuthorizationSuccess">attrAuditAuthorizationSuccess</a></code> | <code>aws-cdk-lib.IResolvable</code> | Attribute `MongoDB::Atlas::Auditing.AuditAuthorizationSuccess`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAuditing.property.attrAuditFilter">attrAuditFilter</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::Auditing.AuditFilter`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAuditing.property.attrConfigurationType">attrConfigurationType</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::Auditing.ConfigurationType`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAuditing.property.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnAuditingProps">CfnAuditingProps</a></code> | Resource props. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.CfnAuditing.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `creationStack`<sup>Required</sup> <a name="creationStack" id="awscdk-resources-mongodbatlas.CfnAuditing.property.creationStack"></a>

```typescript
public readonly creationStack: string[];
```

- *Type:* string[]

---

##### `logicalId`<sup>Required</sup> <a name="logicalId" id="awscdk-resources-mongodbatlas.CfnAuditing.property.logicalId"></a>

```typescript
public readonly logicalId: string;
```

- *Type:* string

The logical ID for this CloudFormation stack element.

The logical ID of the element
is calculated from the path of the resource node in the construct tree.

To override this value, use `overrideLogicalId(newLogicalId)`.

---

##### `stack`<sup>Required</sup> <a name="stack" id="awscdk-resources-mongodbatlas.CfnAuditing.property.stack"></a>

```typescript
public readonly stack: Stack;
```

- *Type:* aws-cdk-lib.Stack

The stack in which this element is defined.

CfnElements must be defined within a stack scope (directly or indirectly).

---

##### `ref`<sup>Required</sup> <a name="ref" id="awscdk-resources-mongodbatlas.CfnAuditing.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.

If, by any chance, the intrinsic reference of a resource is not a string, you could
coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.

---

##### `cfnOptions`<sup>Required</sup> <a name="cfnOptions" id="awscdk-resources-mongodbatlas.CfnAuditing.property.cfnOptions"></a>

```typescript
public readonly cfnOptions: ICfnResourceOptions;
```

- *Type:* aws-cdk-lib.ICfnResourceOptions

Options for this resource, such as condition, update policy etc.

---

##### `cfnResourceType`<sup>Required</sup> <a name="cfnResourceType" id="awscdk-resources-mongodbatlas.CfnAuditing.property.cfnResourceType"></a>

```typescript
public readonly cfnResourceType: string;
```

- *Type:* string

AWS resource type.

---

##### `attrAuditAuthorizationSuccess`<sup>Required</sup> <a name="attrAuditAuthorizationSuccess" id="awscdk-resources-mongodbatlas.CfnAuditing.property.attrAuditAuthorizationSuccess"></a>

```typescript
public readonly attrAuditAuthorizationSuccess: IResolvable;
```

- *Type:* aws-cdk-lib.IResolvable

Attribute `MongoDB::Atlas::Auditing.AuditAuthorizationSuccess`.

---

##### `attrAuditFilter`<sup>Required</sup> <a name="attrAuditFilter" id="awscdk-resources-mongodbatlas.CfnAuditing.property.attrAuditFilter"></a>

```typescript
public readonly attrAuditFilter: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::Auditing.AuditFilter`.

---

##### `attrConfigurationType`<sup>Required</sup> <a name="attrConfigurationType" id="awscdk-resources-mongodbatlas.CfnAuditing.property.attrConfigurationType"></a>

```typescript
public readonly attrConfigurationType: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::Auditing.ConfigurationType`.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnAuditing.property.props"></a>

```typescript
public readonly props: CfnAuditingProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnAuditingProps">CfnAuditingProps</a>

Resource props.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAuditing.property.CFN_RESOURCE_TYPE_NAME">CFN_RESOURCE_TYPE_NAME</a></code> | <code>string</code> | The CloudFormation resource type name for this resource class. |

---

##### `CFN_RESOURCE_TYPE_NAME`<sup>Required</sup> <a name="CFN_RESOURCE_TYPE_NAME" id="awscdk-resources-mongodbatlas.CfnAuditing.property.CFN_RESOURCE_TYPE_NAME"></a>

```typescript
public readonly CFN_RESOURCE_TYPE_NAME: string;
```

- *Type:* string

The CloudFormation resource type name for this resource class.

---

### CfnCloudBackUpRestoreJobs <a name="CfnCloudBackUpRestoreJobs" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs"></a>

A CloudFormation `MongoDB::Atlas::CloudBackUpRestoreJobs`.

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.Initializer"></a>

```typescript
import { CfnCloudBackUpRestoreJobs } from 'awscdk-resources-mongodbatlas'

new CfnCloudBackUpRestoreJobs(scope: Construct, id: string, props: CfnCloudBackUpRestoreJobsProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - scope in which this resource is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.Initializer.parameter.id">id</a></code> | <code>string</code> | - scoped id of the resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsProps">CfnCloudBackUpRestoreJobsProps</a></code> | - resource properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

scope in which this resource is defined.

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.Initializer.parameter.id"></a>

- *Type:* string

scoped id of the resource.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsProps">CfnCloudBackUpRestoreJobsProps</a>

resource properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.overrideLogicalId">overrideLogicalId</a></code> | Overrides the auto-generated logical ID with a specific ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.addDeletionOverride">addDeletionOverride</a></code> | Syntactic sugar for `addOverride(path, undefined)`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.addDependency">addDependency</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.addDependsOn">addDependsOn</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.addMetadata">addMetadata</a></code> | Add a value to the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.addOverride">addOverride</a></code> | Adds an override to the synthesized CloudFormation resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.addPropertyDeletionOverride">addPropertyDeletionOverride</a></code> | Adds an override that deletes the value of a property from the resource definition. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.addPropertyOverride">addPropertyOverride</a></code> | Adds an override to a resource property. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.applyRemovalPolicy">applyRemovalPolicy</a></code> | Sets the deletion policy of the resource based on the removal policy specified. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.getAtt">getAtt</a></code> | Returns a token for an runtime attribute of this resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.getMetadata">getMetadata</a></code> | Retrieve a value value from the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.obtainDependencies">obtainDependencies</a></code> | Retrieves an array of resources this resource depends on. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.obtainResourceDependencies">obtainResourceDependencies</a></code> | Get a shallow copy of dependencies between this resource and other resources in the same stack. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.removeDependency">removeDependency</a></code> | Indicates that this resource no longer depends on another resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.replaceDependency">replaceDependency</a></code> | Replaces one dependency with another. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `overrideLogicalId` <a name="overrideLogicalId" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.overrideLogicalId"></a>

```typescript
public overrideLogicalId(newLogicalId: string): void
```

Overrides the auto-generated logical ID with a specific ID.

###### `newLogicalId`<sup>Required</sup> <a name="newLogicalId" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.overrideLogicalId.parameter.newLogicalId"></a>

- *Type:* string

The new logical ID to use for this stack element.

---

##### `addDeletionOverride` <a name="addDeletionOverride" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.addDeletionOverride"></a>

```typescript
public addDeletionOverride(path: string): void
```

Syntactic sugar for `addOverride(path, undefined)`.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.addDeletionOverride.parameter.path"></a>

- *Type:* string

The path of the value to delete.

---

##### `addDependency` <a name="addDependency" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.addDependency"></a>

```typescript
public addDependency(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

This can be used for resources across stacks (or nested stack) boundaries
and the dependency will automatically be transferred to the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.addDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### ~~`addDependsOn`~~ <a name="addDependsOn" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.addDependsOn"></a>

```typescript
public addDependsOn(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.addDependsOn.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `addMetadata` <a name="addMetadata" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.addMetadata"></a>

```typescript
public addMetadata(key: string, value: any): void
```

Add a value to the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.addMetadata.parameter.key"></a>

- *Type:* string

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.addMetadata.parameter.value"></a>

- *Type:* any

---

##### `addOverride` <a name="addOverride" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.addOverride"></a>

```typescript
public addOverride(path: string, value: any): void
```

Adds an override to the synthesized CloudFormation resource.

To add a
property override, either use `addPropertyOverride` or prefix `path` with
"Properties." (i.e. `Properties.TopicName`).

If the override is nested, separate each nested level using a dot (.) in the path parameter.
If there is an array as part of the nesting, specify the index in the path.

To include a literal `.` in the property name, prefix with a `\`. In most
programming languages you will need to write this as `"\\."` because the
`\` itself will need to be escaped.

For example,
```typescript
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
```
would add the overrides
```json
"Properties": {
  "GlobalSecondaryIndexes": [
    {
      "Projection": {
        "NonKeyAttributes": [ "myattribute" ]
        ...
      }
      ...
    },
    {
      "ProjectionType": "INCLUDE"
      ...
    },
  ]
  ...
}
```

The `value` argument to `addOverride` will not be processed or translated
in any way. Pass raw JSON values in here with the correct capitalization
for CloudFormation. If you pass CDK classes or structs, they will be
rendered with lowercased key names, and CloudFormation will reject the
template.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.addOverride.parameter.path"></a>

- *Type:* string

The path of the property, you can use dot notation to override values in complex types.

Any intermediate keys
will be created as needed.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.addOverride.parameter.value"></a>

- *Type:* any

The value.

Could be primitive or complex.

---

##### `addPropertyDeletionOverride` <a name="addPropertyDeletionOverride" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.addPropertyDeletionOverride"></a>

```typescript
public addPropertyDeletionOverride(propertyPath: string): void
```

Adds an override that deletes the value of a property from the resource definition.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.addPropertyDeletionOverride.parameter.propertyPath"></a>

- *Type:* string

The path to the property.

---

##### `addPropertyOverride` <a name="addPropertyOverride" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.addPropertyOverride"></a>

```typescript
public addPropertyOverride(propertyPath: string, value: any): void
```

Adds an override to a resource property.

Syntactic sugar for `addOverride("Properties.<...>", value)`.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.addPropertyOverride.parameter.propertyPath"></a>

- *Type:* string

The path of the property.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.addPropertyOverride.parameter.value"></a>

- *Type:* any

The value.

---

##### `applyRemovalPolicy` <a name="applyRemovalPolicy" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.applyRemovalPolicy"></a>

```typescript
public applyRemovalPolicy(policy?: RemovalPolicy, options?: RemovalPolicyOptions): void
```

Sets the deletion policy of the resource based on the removal policy specified.

The Removal Policy controls what happens to this resource when it stops
being managed by CloudFormation, either because you've removed it from the
CDK application or because you've made a change that requires the resource
to be replaced.

The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
cases, a snapshot can be taken of the resource prior to deletion
(`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
can be found in the following link:

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options)

###### `policy`<sup>Optional</sup> <a name="policy" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.applyRemovalPolicy.parameter.policy"></a>

- *Type:* aws-cdk-lib.RemovalPolicy

---

###### `options`<sup>Optional</sup> <a name="options" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.applyRemovalPolicy.parameter.options"></a>

- *Type:* aws-cdk-lib.RemovalPolicyOptions

---

##### `getAtt` <a name="getAtt" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.getAtt"></a>

```typescript
public getAtt(attributeName: string, typeHint?: ResolutionTypeHint): Reference
```

Returns a token for an runtime attribute of this resource.

Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
in case there is no generated attribute.

###### `attributeName`<sup>Required</sup> <a name="attributeName" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.getAtt.parameter.attributeName"></a>

- *Type:* string

The name of the attribute.

---

###### `typeHint`<sup>Optional</sup> <a name="typeHint" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.getAtt.parameter.typeHint"></a>

- *Type:* aws-cdk-lib.ResolutionTypeHint

---

##### `getMetadata` <a name="getMetadata" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.getMetadata"></a>

```typescript
public getMetadata(key: string): any
```

Retrieve a value value from the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.getMetadata.parameter.key"></a>

- *Type:* string

---

##### `obtainDependencies` <a name="obtainDependencies" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.obtainDependencies"></a>

```typescript
public obtainDependencies(): Stack | CfnResource[]
```

Retrieves an array of resources this resource depends on.

This assembles dependencies on resources across stacks (including nested stacks)
automatically.

##### `obtainResourceDependencies` <a name="obtainResourceDependencies" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.obtainResourceDependencies"></a>

```typescript
public obtainResourceDependencies(): CfnResource[]
```

Get a shallow copy of dependencies between this resource and other resources in the same stack.

##### `removeDependency` <a name="removeDependency" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.removeDependency"></a>

```typescript
public removeDependency(target: CfnResource): void
```

Indicates that this resource no longer depends on another resource.

This can be used for resources across stacks (including nested stacks)
and the dependency will automatically be removed from the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.removeDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `replaceDependency` <a name="replaceDependency" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.replaceDependency"></a>

```typescript
public replaceDependency(target: CfnResource, newTarget: CfnResource): void
```

Replaces one dependency with another.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.replaceDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

The dependency to replace.

---

###### `newTarget`<sup>Required</sup> <a name="newTarget" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.replaceDependency.parameter.newTarget"></a>

- *Type:* aws-cdk-lib.CfnResource

The new dependency to add.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.isCfnElement">isCfnElement</a></code> | Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.isCfnResource">isCfnResource</a></code> | Check whether the given construct is a CfnResource. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.isConstruct"></a>

```typescript
import { CfnCloudBackUpRestoreJobs } from 'awscdk-resources-mongodbatlas'

CfnCloudBackUpRestoreJobs.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `isCfnElement` <a name="isCfnElement" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.isCfnElement"></a>

```typescript
import { CfnCloudBackUpRestoreJobs } from 'awscdk-resources-mongodbatlas'

CfnCloudBackUpRestoreJobs.isCfnElement(x: any)
```

Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).

Uses duck-typing instead of `instanceof` to allow stack elements from different
versions of this library to be included in the same stack.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.isCfnElement.parameter.x"></a>

- *Type:* any

---

##### `isCfnResource` <a name="isCfnResource" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.isCfnResource"></a>

```typescript
import { CfnCloudBackUpRestoreJobs } from 'awscdk-resources-mongodbatlas'

CfnCloudBackUpRestoreJobs.isCfnResource(construct: IConstruct)
```

Check whether the given construct is a CfnResource.

###### `construct`<sup>Required</sup> <a name="construct" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.isCfnResource.parameter.construct"></a>

- *Type:* constructs.IConstruct

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.property.creationStack">creationStack</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.property.logicalId">logicalId</a></code> | <code>string</code> | The logical ID for this CloudFormation stack element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.property.stack">stack</a></code> | <code>aws-cdk-lib.Stack</code> | The stack in which this element is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.property.ref">ref</a></code> | <code>string</code> | Return a string that will be resolved to a CloudFormation `{ Ref }` for this element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.property.cfnOptions">cfnOptions</a></code> | <code>aws-cdk-lib.ICfnResourceOptions</code> | Options for this resource, such as condition, update policy etc. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.property.cfnResourceType">cfnResourceType</a></code> | <code>string</code> | AWS resource type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.property.attrDeliveryUrl">attrDeliveryUrl</a></code> | <code>string[]</code> | Attribute `MongoDB::Atlas::CloudBackUpRestoreJobs.DeliveryUrl`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.property.attrExpiresAt">attrExpiresAt</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::CloudBackUpRestoreJobs.ExpiresAt`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.property.attrFinishedAt">attrFinishedAt</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::CloudBackUpRestoreJobs.FinishedAt`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.property.attrId">attrId</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::CloudBackUpRestoreJobs.Id`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.property.attrTimestamp">attrTimestamp</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::CloudBackUpRestoreJobs.Timestamp`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.property.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsProps">CfnCloudBackUpRestoreJobsProps</a></code> | Resource props. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `creationStack`<sup>Required</sup> <a name="creationStack" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.property.creationStack"></a>

```typescript
public readonly creationStack: string[];
```

- *Type:* string[]

---

##### `logicalId`<sup>Required</sup> <a name="logicalId" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.property.logicalId"></a>

```typescript
public readonly logicalId: string;
```

- *Type:* string

The logical ID for this CloudFormation stack element.

The logical ID of the element
is calculated from the path of the resource node in the construct tree.

To override this value, use `overrideLogicalId(newLogicalId)`.

---

##### `stack`<sup>Required</sup> <a name="stack" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.property.stack"></a>

```typescript
public readonly stack: Stack;
```

- *Type:* aws-cdk-lib.Stack

The stack in which this element is defined.

CfnElements must be defined within a stack scope (directly or indirectly).

---

##### `ref`<sup>Required</sup> <a name="ref" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.

If, by any chance, the intrinsic reference of a resource is not a string, you could
coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.

---

##### `cfnOptions`<sup>Required</sup> <a name="cfnOptions" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.property.cfnOptions"></a>

```typescript
public readonly cfnOptions: ICfnResourceOptions;
```

- *Type:* aws-cdk-lib.ICfnResourceOptions

Options for this resource, such as condition, update policy etc.

---

##### `cfnResourceType`<sup>Required</sup> <a name="cfnResourceType" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.property.cfnResourceType"></a>

```typescript
public readonly cfnResourceType: string;
```

- *Type:* string

AWS resource type.

---

##### `attrDeliveryUrl`<sup>Required</sup> <a name="attrDeliveryUrl" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.property.attrDeliveryUrl"></a>

```typescript
public readonly attrDeliveryUrl: string[];
```

- *Type:* string[]

Attribute `MongoDB::Atlas::CloudBackUpRestoreJobs.DeliveryUrl`.

---

##### `attrExpiresAt`<sup>Required</sup> <a name="attrExpiresAt" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.property.attrExpiresAt"></a>

```typescript
public readonly attrExpiresAt: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::CloudBackUpRestoreJobs.ExpiresAt`.

---

##### `attrFinishedAt`<sup>Required</sup> <a name="attrFinishedAt" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.property.attrFinishedAt"></a>

```typescript
public readonly attrFinishedAt: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::CloudBackUpRestoreJobs.FinishedAt`.

---

##### `attrId`<sup>Required</sup> <a name="attrId" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.property.attrId"></a>

```typescript
public readonly attrId: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::CloudBackUpRestoreJobs.Id`.

---

##### `attrTimestamp`<sup>Required</sup> <a name="attrTimestamp" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.property.attrTimestamp"></a>

```typescript
public readonly attrTimestamp: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::CloudBackUpRestoreJobs.Timestamp`.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.property.props"></a>

```typescript
public readonly props: CfnCloudBackUpRestoreJobsProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsProps">CfnCloudBackUpRestoreJobsProps</a>

Resource props.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.property.CFN_RESOURCE_TYPE_NAME">CFN_RESOURCE_TYPE_NAME</a></code> | <code>string</code> | The CloudFormation resource type name for this resource class. |

---

##### `CFN_RESOURCE_TYPE_NAME`<sup>Required</sup> <a name="CFN_RESOURCE_TYPE_NAME" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobs.property.CFN_RESOURCE_TYPE_NAME"></a>

```typescript
public readonly CFN_RESOURCE_TYPE_NAME: string;
```

- *Type:* string

The CloudFormation resource type name for this resource class.

---

### CfnCloudBackupSchedule <a name="CfnCloudBackupSchedule" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule"></a>

A CloudFormation `MongoDB::Atlas::CloudBackupSchedule`.

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.Initializer"></a>

```typescript
import { CfnCloudBackupSchedule } from 'awscdk-resources-mongodbatlas'

new CfnCloudBackupSchedule(scope: Construct, id: string, props: CfnCloudBackupScheduleProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - scope in which this resource is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.Initializer.parameter.id">id</a></code> | <code>string</code> | - scoped id of the resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupScheduleProps">CfnCloudBackupScheduleProps</a></code> | - resource properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

scope in which this resource is defined.

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.Initializer.parameter.id"></a>

- *Type:* string

scoped id of the resource.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnCloudBackupScheduleProps">CfnCloudBackupScheduleProps</a>

resource properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.overrideLogicalId">overrideLogicalId</a></code> | Overrides the auto-generated logical ID with a specific ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.addDeletionOverride">addDeletionOverride</a></code> | Syntactic sugar for `addOverride(path, undefined)`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.addDependency">addDependency</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.addDependsOn">addDependsOn</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.addMetadata">addMetadata</a></code> | Add a value to the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.addOverride">addOverride</a></code> | Adds an override to the synthesized CloudFormation resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.addPropertyDeletionOverride">addPropertyDeletionOverride</a></code> | Adds an override that deletes the value of a property from the resource definition. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.addPropertyOverride">addPropertyOverride</a></code> | Adds an override to a resource property. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.applyRemovalPolicy">applyRemovalPolicy</a></code> | Sets the deletion policy of the resource based on the removal policy specified. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.getAtt">getAtt</a></code> | Returns a token for an runtime attribute of this resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.getMetadata">getMetadata</a></code> | Retrieve a value value from the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.obtainDependencies">obtainDependencies</a></code> | Retrieves an array of resources this resource depends on. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.obtainResourceDependencies">obtainResourceDependencies</a></code> | Get a shallow copy of dependencies between this resource and other resources in the same stack. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.removeDependency">removeDependency</a></code> | Indicates that this resource no longer depends on another resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.replaceDependency">replaceDependency</a></code> | Replaces one dependency with another. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `overrideLogicalId` <a name="overrideLogicalId" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.overrideLogicalId"></a>

```typescript
public overrideLogicalId(newLogicalId: string): void
```

Overrides the auto-generated logical ID with a specific ID.

###### `newLogicalId`<sup>Required</sup> <a name="newLogicalId" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.overrideLogicalId.parameter.newLogicalId"></a>

- *Type:* string

The new logical ID to use for this stack element.

---

##### `addDeletionOverride` <a name="addDeletionOverride" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.addDeletionOverride"></a>

```typescript
public addDeletionOverride(path: string): void
```

Syntactic sugar for `addOverride(path, undefined)`.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.addDeletionOverride.parameter.path"></a>

- *Type:* string

The path of the value to delete.

---

##### `addDependency` <a name="addDependency" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.addDependency"></a>

```typescript
public addDependency(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

This can be used for resources across stacks (or nested stack) boundaries
and the dependency will automatically be transferred to the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.addDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### ~~`addDependsOn`~~ <a name="addDependsOn" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.addDependsOn"></a>

```typescript
public addDependsOn(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.addDependsOn.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `addMetadata` <a name="addMetadata" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.addMetadata"></a>

```typescript
public addMetadata(key: string, value: any): void
```

Add a value to the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.addMetadata.parameter.key"></a>

- *Type:* string

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.addMetadata.parameter.value"></a>

- *Type:* any

---

##### `addOverride` <a name="addOverride" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.addOverride"></a>

```typescript
public addOverride(path: string, value: any): void
```

Adds an override to the synthesized CloudFormation resource.

To add a
property override, either use `addPropertyOverride` or prefix `path` with
"Properties." (i.e. `Properties.TopicName`).

If the override is nested, separate each nested level using a dot (.) in the path parameter.
If there is an array as part of the nesting, specify the index in the path.

To include a literal `.` in the property name, prefix with a `\`. In most
programming languages you will need to write this as `"\\."` because the
`\` itself will need to be escaped.

For example,
```typescript
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
```
would add the overrides
```json
"Properties": {
  "GlobalSecondaryIndexes": [
    {
      "Projection": {
        "NonKeyAttributes": [ "myattribute" ]
        ...
      }
      ...
    },
    {
      "ProjectionType": "INCLUDE"
      ...
    },
  ]
  ...
}
```

The `value` argument to `addOverride` will not be processed or translated
in any way. Pass raw JSON values in here with the correct capitalization
for CloudFormation. If you pass CDK classes or structs, they will be
rendered with lowercased key names, and CloudFormation will reject the
template.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.addOverride.parameter.path"></a>

- *Type:* string

The path of the property, you can use dot notation to override values in complex types.

Any intermediate keys
will be created as needed.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.addOverride.parameter.value"></a>

- *Type:* any

The value.

Could be primitive or complex.

---

##### `addPropertyDeletionOverride` <a name="addPropertyDeletionOverride" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.addPropertyDeletionOverride"></a>

```typescript
public addPropertyDeletionOverride(propertyPath: string): void
```

Adds an override that deletes the value of a property from the resource definition.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.addPropertyDeletionOverride.parameter.propertyPath"></a>

- *Type:* string

The path to the property.

---

##### `addPropertyOverride` <a name="addPropertyOverride" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.addPropertyOverride"></a>

```typescript
public addPropertyOverride(propertyPath: string, value: any): void
```

Adds an override to a resource property.

Syntactic sugar for `addOverride("Properties.<...>", value)`.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.addPropertyOverride.parameter.propertyPath"></a>

- *Type:* string

The path of the property.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.addPropertyOverride.parameter.value"></a>

- *Type:* any

The value.

---

##### `applyRemovalPolicy` <a name="applyRemovalPolicy" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.applyRemovalPolicy"></a>

```typescript
public applyRemovalPolicy(policy?: RemovalPolicy, options?: RemovalPolicyOptions): void
```

Sets the deletion policy of the resource based on the removal policy specified.

The Removal Policy controls what happens to this resource when it stops
being managed by CloudFormation, either because you've removed it from the
CDK application or because you've made a change that requires the resource
to be replaced.

The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
cases, a snapshot can be taken of the resource prior to deletion
(`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
can be found in the following link:

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options)

###### `policy`<sup>Optional</sup> <a name="policy" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.applyRemovalPolicy.parameter.policy"></a>

- *Type:* aws-cdk-lib.RemovalPolicy

---

###### `options`<sup>Optional</sup> <a name="options" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.applyRemovalPolicy.parameter.options"></a>

- *Type:* aws-cdk-lib.RemovalPolicyOptions

---

##### `getAtt` <a name="getAtt" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.getAtt"></a>

```typescript
public getAtt(attributeName: string, typeHint?: ResolutionTypeHint): Reference
```

Returns a token for an runtime attribute of this resource.

Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
in case there is no generated attribute.

###### `attributeName`<sup>Required</sup> <a name="attributeName" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.getAtt.parameter.attributeName"></a>

- *Type:* string

The name of the attribute.

---

###### `typeHint`<sup>Optional</sup> <a name="typeHint" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.getAtt.parameter.typeHint"></a>

- *Type:* aws-cdk-lib.ResolutionTypeHint

---

##### `getMetadata` <a name="getMetadata" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.getMetadata"></a>

```typescript
public getMetadata(key: string): any
```

Retrieve a value value from the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.getMetadata.parameter.key"></a>

- *Type:* string

---

##### `obtainDependencies` <a name="obtainDependencies" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.obtainDependencies"></a>

```typescript
public obtainDependencies(): Stack | CfnResource[]
```

Retrieves an array of resources this resource depends on.

This assembles dependencies on resources across stacks (including nested stacks)
automatically.

##### `obtainResourceDependencies` <a name="obtainResourceDependencies" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.obtainResourceDependencies"></a>

```typescript
public obtainResourceDependencies(): CfnResource[]
```

Get a shallow copy of dependencies between this resource and other resources in the same stack.

##### `removeDependency` <a name="removeDependency" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.removeDependency"></a>

```typescript
public removeDependency(target: CfnResource): void
```

Indicates that this resource no longer depends on another resource.

This can be used for resources across stacks (including nested stacks)
and the dependency will automatically be removed from the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.removeDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `replaceDependency` <a name="replaceDependency" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.replaceDependency"></a>

```typescript
public replaceDependency(target: CfnResource, newTarget: CfnResource): void
```

Replaces one dependency with another.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.replaceDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

The dependency to replace.

---

###### `newTarget`<sup>Required</sup> <a name="newTarget" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.replaceDependency.parameter.newTarget"></a>

- *Type:* aws-cdk-lib.CfnResource

The new dependency to add.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.isCfnElement">isCfnElement</a></code> | Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.isCfnResource">isCfnResource</a></code> | Check whether the given construct is a CfnResource. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.isConstruct"></a>

```typescript
import { CfnCloudBackupSchedule } from 'awscdk-resources-mongodbatlas'

CfnCloudBackupSchedule.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `isCfnElement` <a name="isCfnElement" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.isCfnElement"></a>

```typescript
import { CfnCloudBackupSchedule } from 'awscdk-resources-mongodbatlas'

CfnCloudBackupSchedule.isCfnElement(x: any)
```

Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).

Uses duck-typing instead of `instanceof` to allow stack elements from different
versions of this library to be included in the same stack.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.isCfnElement.parameter.x"></a>

- *Type:* any

---

##### `isCfnResource` <a name="isCfnResource" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.isCfnResource"></a>

```typescript
import { CfnCloudBackupSchedule } from 'awscdk-resources-mongodbatlas'

CfnCloudBackupSchedule.isCfnResource(construct: IConstruct)
```

Check whether the given construct is a CfnResource.

###### `construct`<sup>Required</sup> <a name="construct" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.isCfnResource.parameter.construct"></a>

- *Type:* constructs.IConstruct

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.property.creationStack">creationStack</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.property.logicalId">logicalId</a></code> | <code>string</code> | The logical ID for this CloudFormation stack element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.property.stack">stack</a></code> | <code>aws-cdk-lib.Stack</code> | The stack in which this element is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.property.ref">ref</a></code> | <code>string</code> | Return a string that will be resolved to a CloudFormation `{ Ref }` for this element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.property.cfnOptions">cfnOptions</a></code> | <code>aws-cdk-lib.ICfnResourceOptions</code> | Options for this resource, such as condition, update policy etc. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.property.cfnResourceType">cfnResourceType</a></code> | <code>string</code> | AWS resource type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.property.attrClusterId">attrClusterId</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::CloudBackupSchedule.ClusterId`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.property.attrNextSnapshot">attrNextSnapshot</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::CloudBackupSchedule.NextSnapshot`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.property.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupScheduleProps">CfnCloudBackupScheduleProps</a></code> | Resource props. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `creationStack`<sup>Required</sup> <a name="creationStack" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.property.creationStack"></a>

```typescript
public readonly creationStack: string[];
```

- *Type:* string[]

---

##### `logicalId`<sup>Required</sup> <a name="logicalId" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.property.logicalId"></a>

```typescript
public readonly logicalId: string;
```

- *Type:* string

The logical ID for this CloudFormation stack element.

The logical ID of the element
is calculated from the path of the resource node in the construct tree.

To override this value, use `overrideLogicalId(newLogicalId)`.

---

##### `stack`<sup>Required</sup> <a name="stack" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.property.stack"></a>

```typescript
public readonly stack: Stack;
```

- *Type:* aws-cdk-lib.Stack

The stack in which this element is defined.

CfnElements must be defined within a stack scope (directly or indirectly).

---

##### `ref`<sup>Required</sup> <a name="ref" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.

If, by any chance, the intrinsic reference of a resource is not a string, you could
coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.

---

##### `cfnOptions`<sup>Required</sup> <a name="cfnOptions" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.property.cfnOptions"></a>

```typescript
public readonly cfnOptions: ICfnResourceOptions;
```

- *Type:* aws-cdk-lib.ICfnResourceOptions

Options for this resource, such as condition, update policy etc.

---

##### `cfnResourceType`<sup>Required</sup> <a name="cfnResourceType" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.property.cfnResourceType"></a>

```typescript
public readonly cfnResourceType: string;
```

- *Type:* string

AWS resource type.

---

##### `attrClusterId`<sup>Required</sup> <a name="attrClusterId" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.property.attrClusterId"></a>

```typescript
public readonly attrClusterId: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::CloudBackupSchedule.ClusterId`.

---

##### `attrNextSnapshot`<sup>Required</sup> <a name="attrNextSnapshot" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.property.attrNextSnapshot"></a>

```typescript
public readonly attrNextSnapshot: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::CloudBackupSchedule.NextSnapshot`.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.property.props"></a>

```typescript
public readonly props: CfnCloudBackupScheduleProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnCloudBackupScheduleProps">CfnCloudBackupScheduleProps</a>

Resource props.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.property.CFN_RESOURCE_TYPE_NAME">CFN_RESOURCE_TYPE_NAME</a></code> | <code>string</code> | The CloudFormation resource type name for this resource class. |

---

##### `CFN_RESOURCE_TYPE_NAME`<sup>Required</sup> <a name="CFN_RESOURCE_TYPE_NAME" id="awscdk-resources-mongodbatlas.CfnCloudBackupSchedule.property.CFN_RESOURCE_TYPE_NAME"></a>

```typescript
public readonly CFN_RESOURCE_TYPE_NAME: string;
```

- *Type:* string

The CloudFormation resource type name for this resource class.

---

### CfnCloudBackupSnapshot <a name="CfnCloudBackupSnapshot" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot"></a>

A CloudFormation `MongoDB::Atlas::CloudBackupSnapshot`.

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.Initializer"></a>

```typescript
import { CfnCloudBackupSnapshot } from 'awscdk-resources-mongodbatlas'

new CfnCloudBackupSnapshot(scope: Construct, id: string, props: CfnCloudBackupSnapshotProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - scope in which this resource is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.Initializer.parameter.id">id</a></code> | <code>string</code> | - scoped id of the resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotProps">CfnCloudBackupSnapshotProps</a></code> | - resource properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

scope in which this resource is defined.

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.Initializer.parameter.id"></a>

- *Type:* string

scoped id of the resource.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotProps">CfnCloudBackupSnapshotProps</a>

resource properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.overrideLogicalId">overrideLogicalId</a></code> | Overrides the auto-generated logical ID with a specific ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.addDeletionOverride">addDeletionOverride</a></code> | Syntactic sugar for `addOverride(path, undefined)`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.addDependency">addDependency</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.addDependsOn">addDependsOn</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.addMetadata">addMetadata</a></code> | Add a value to the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.addOverride">addOverride</a></code> | Adds an override to the synthesized CloudFormation resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.addPropertyDeletionOverride">addPropertyDeletionOverride</a></code> | Adds an override that deletes the value of a property from the resource definition. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.addPropertyOverride">addPropertyOverride</a></code> | Adds an override to a resource property. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.applyRemovalPolicy">applyRemovalPolicy</a></code> | Sets the deletion policy of the resource based on the removal policy specified. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.getAtt">getAtt</a></code> | Returns a token for an runtime attribute of this resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.getMetadata">getMetadata</a></code> | Retrieve a value value from the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.obtainDependencies">obtainDependencies</a></code> | Retrieves an array of resources this resource depends on. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.obtainResourceDependencies">obtainResourceDependencies</a></code> | Get a shallow copy of dependencies between this resource and other resources in the same stack. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.removeDependency">removeDependency</a></code> | Indicates that this resource no longer depends on another resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.replaceDependency">replaceDependency</a></code> | Replaces one dependency with another. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `overrideLogicalId` <a name="overrideLogicalId" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.overrideLogicalId"></a>

```typescript
public overrideLogicalId(newLogicalId: string): void
```

Overrides the auto-generated logical ID with a specific ID.

###### `newLogicalId`<sup>Required</sup> <a name="newLogicalId" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.overrideLogicalId.parameter.newLogicalId"></a>

- *Type:* string

The new logical ID to use for this stack element.

---

##### `addDeletionOverride` <a name="addDeletionOverride" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.addDeletionOverride"></a>

```typescript
public addDeletionOverride(path: string): void
```

Syntactic sugar for `addOverride(path, undefined)`.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.addDeletionOverride.parameter.path"></a>

- *Type:* string

The path of the value to delete.

---

##### `addDependency` <a name="addDependency" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.addDependency"></a>

```typescript
public addDependency(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

This can be used for resources across stacks (or nested stack) boundaries
and the dependency will automatically be transferred to the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.addDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### ~~`addDependsOn`~~ <a name="addDependsOn" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.addDependsOn"></a>

```typescript
public addDependsOn(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.addDependsOn.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `addMetadata` <a name="addMetadata" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.addMetadata"></a>

```typescript
public addMetadata(key: string, value: any): void
```

Add a value to the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.addMetadata.parameter.key"></a>

- *Type:* string

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.addMetadata.parameter.value"></a>

- *Type:* any

---

##### `addOverride` <a name="addOverride" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.addOverride"></a>

```typescript
public addOverride(path: string, value: any): void
```

Adds an override to the synthesized CloudFormation resource.

To add a
property override, either use `addPropertyOverride` or prefix `path` with
"Properties." (i.e. `Properties.TopicName`).

If the override is nested, separate each nested level using a dot (.) in the path parameter.
If there is an array as part of the nesting, specify the index in the path.

To include a literal `.` in the property name, prefix with a `\`. In most
programming languages you will need to write this as `"\\."` because the
`\` itself will need to be escaped.

For example,
```typescript
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
```
would add the overrides
```json
"Properties": {
  "GlobalSecondaryIndexes": [
    {
      "Projection": {
        "NonKeyAttributes": [ "myattribute" ]
        ...
      }
      ...
    },
    {
      "ProjectionType": "INCLUDE"
      ...
    },
  ]
  ...
}
```

The `value` argument to `addOverride` will not be processed or translated
in any way. Pass raw JSON values in here with the correct capitalization
for CloudFormation. If you pass CDK classes or structs, they will be
rendered with lowercased key names, and CloudFormation will reject the
template.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.addOverride.parameter.path"></a>

- *Type:* string

The path of the property, you can use dot notation to override values in complex types.

Any intermediate keys
will be created as needed.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.addOverride.parameter.value"></a>

- *Type:* any

The value.

Could be primitive or complex.

---

##### `addPropertyDeletionOverride` <a name="addPropertyDeletionOverride" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.addPropertyDeletionOverride"></a>

```typescript
public addPropertyDeletionOverride(propertyPath: string): void
```

Adds an override that deletes the value of a property from the resource definition.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.addPropertyDeletionOverride.parameter.propertyPath"></a>

- *Type:* string

The path to the property.

---

##### `addPropertyOverride` <a name="addPropertyOverride" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.addPropertyOverride"></a>

```typescript
public addPropertyOverride(propertyPath: string, value: any): void
```

Adds an override to a resource property.

Syntactic sugar for `addOverride("Properties.<...>", value)`.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.addPropertyOverride.parameter.propertyPath"></a>

- *Type:* string

The path of the property.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.addPropertyOverride.parameter.value"></a>

- *Type:* any

The value.

---

##### `applyRemovalPolicy` <a name="applyRemovalPolicy" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.applyRemovalPolicy"></a>

```typescript
public applyRemovalPolicy(policy?: RemovalPolicy, options?: RemovalPolicyOptions): void
```

Sets the deletion policy of the resource based on the removal policy specified.

The Removal Policy controls what happens to this resource when it stops
being managed by CloudFormation, either because you've removed it from the
CDK application or because you've made a change that requires the resource
to be replaced.

The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
cases, a snapshot can be taken of the resource prior to deletion
(`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
can be found in the following link:

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options)

###### `policy`<sup>Optional</sup> <a name="policy" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.applyRemovalPolicy.parameter.policy"></a>

- *Type:* aws-cdk-lib.RemovalPolicy

---

###### `options`<sup>Optional</sup> <a name="options" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.applyRemovalPolicy.parameter.options"></a>

- *Type:* aws-cdk-lib.RemovalPolicyOptions

---

##### `getAtt` <a name="getAtt" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.getAtt"></a>

```typescript
public getAtt(attributeName: string, typeHint?: ResolutionTypeHint): Reference
```

Returns a token for an runtime attribute of this resource.

Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
in case there is no generated attribute.

###### `attributeName`<sup>Required</sup> <a name="attributeName" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.getAtt.parameter.attributeName"></a>

- *Type:* string

The name of the attribute.

---

###### `typeHint`<sup>Optional</sup> <a name="typeHint" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.getAtt.parameter.typeHint"></a>

- *Type:* aws-cdk-lib.ResolutionTypeHint

---

##### `getMetadata` <a name="getMetadata" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.getMetadata"></a>

```typescript
public getMetadata(key: string): any
```

Retrieve a value value from the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.getMetadata.parameter.key"></a>

- *Type:* string

---

##### `obtainDependencies` <a name="obtainDependencies" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.obtainDependencies"></a>

```typescript
public obtainDependencies(): Stack | CfnResource[]
```

Retrieves an array of resources this resource depends on.

This assembles dependencies on resources across stacks (including nested stacks)
automatically.

##### `obtainResourceDependencies` <a name="obtainResourceDependencies" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.obtainResourceDependencies"></a>

```typescript
public obtainResourceDependencies(): CfnResource[]
```

Get a shallow copy of dependencies between this resource and other resources in the same stack.

##### `removeDependency` <a name="removeDependency" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.removeDependency"></a>

```typescript
public removeDependency(target: CfnResource): void
```

Indicates that this resource no longer depends on another resource.

This can be used for resources across stacks (including nested stacks)
and the dependency will automatically be removed from the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.removeDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `replaceDependency` <a name="replaceDependency" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.replaceDependency"></a>

```typescript
public replaceDependency(target: CfnResource, newTarget: CfnResource): void
```

Replaces one dependency with another.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.replaceDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

The dependency to replace.

---

###### `newTarget`<sup>Required</sup> <a name="newTarget" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.replaceDependency.parameter.newTarget"></a>

- *Type:* aws-cdk-lib.CfnResource

The new dependency to add.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.isCfnElement">isCfnElement</a></code> | Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.isCfnResource">isCfnResource</a></code> | Check whether the given construct is a CfnResource. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.isConstruct"></a>

```typescript
import { CfnCloudBackupSnapshot } from 'awscdk-resources-mongodbatlas'

CfnCloudBackupSnapshot.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `isCfnElement` <a name="isCfnElement" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.isCfnElement"></a>

```typescript
import { CfnCloudBackupSnapshot } from 'awscdk-resources-mongodbatlas'

CfnCloudBackupSnapshot.isCfnElement(x: any)
```

Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).

Uses duck-typing instead of `instanceof` to allow stack elements from different
versions of this library to be included in the same stack.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.isCfnElement.parameter.x"></a>

- *Type:* any

---

##### `isCfnResource` <a name="isCfnResource" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.isCfnResource"></a>

```typescript
import { CfnCloudBackupSnapshot } from 'awscdk-resources-mongodbatlas'

CfnCloudBackupSnapshot.isCfnResource(construct: IConstruct)
```

Check whether the given construct is a CfnResource.

###### `construct`<sup>Required</sup> <a name="construct" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.isCfnResource.parameter.construct"></a>

- *Type:* constructs.IConstruct

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.property.creationStack">creationStack</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.property.logicalId">logicalId</a></code> | <code>string</code> | The logical ID for this CloudFormation stack element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.property.stack">stack</a></code> | <code>aws-cdk-lib.Stack</code> | The stack in which this element is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.property.ref">ref</a></code> | <code>string</code> | Return a string that will be resolved to a CloudFormation `{ Ref }` for this element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.property.cfnOptions">cfnOptions</a></code> | <code>aws-cdk-lib.ICfnResourceOptions</code> | Options for this resource, such as condition, update policy etc. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.property.cfnResourceType">cfnResourceType</a></code> | <code>string</code> | AWS resource type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.property.attrCloudProvider">attrCloudProvider</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::CloudBackupSnapshot.CloudProvider`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.property.attrCreatedAt">attrCreatedAt</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::CloudBackupSnapshot.CreatedAt`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.property.attrExpiresAt">attrExpiresAt</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::CloudBackupSnapshot.ExpiresAt`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.property.attrId">attrId</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::CloudBackupSnapshot.Id`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.property.attrMasterKeyUUID">attrMasterKeyUUID</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::CloudBackupSnapshot.MasterKeyUUID`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.property.attrMongodVersion">attrMongodVersion</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::CloudBackupSnapshot.MongodVersion`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.property.attrReplicaSetName">attrReplicaSetName</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::CloudBackupSnapshot.ReplicaSetName`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.property.attrSnapshotId">attrSnapshotId</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::CloudBackupSnapshot.SnapshotId`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.property.attrSnapshotIds">attrSnapshotIds</a></code> | <code>string[]</code> | Attribute `MongoDB::Atlas::CloudBackupSnapshot.SnapshotIds`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.property.attrStatus">attrStatus</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::CloudBackupSnapshot.Status`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.property.attrStorageSizeBytes">attrStorageSizeBytes</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::CloudBackupSnapshot.StorageSizeBytes`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.property.attrType">attrType</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::CloudBackupSnapshot.Type`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.property.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotProps">CfnCloudBackupSnapshotProps</a></code> | Resource props. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `creationStack`<sup>Required</sup> <a name="creationStack" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.property.creationStack"></a>

```typescript
public readonly creationStack: string[];
```

- *Type:* string[]

---

##### `logicalId`<sup>Required</sup> <a name="logicalId" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.property.logicalId"></a>

```typescript
public readonly logicalId: string;
```

- *Type:* string

The logical ID for this CloudFormation stack element.

The logical ID of the element
is calculated from the path of the resource node in the construct tree.

To override this value, use `overrideLogicalId(newLogicalId)`.

---

##### `stack`<sup>Required</sup> <a name="stack" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.property.stack"></a>

```typescript
public readonly stack: Stack;
```

- *Type:* aws-cdk-lib.Stack

The stack in which this element is defined.

CfnElements must be defined within a stack scope (directly or indirectly).

---

##### `ref`<sup>Required</sup> <a name="ref" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.

If, by any chance, the intrinsic reference of a resource is not a string, you could
coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.

---

##### `cfnOptions`<sup>Required</sup> <a name="cfnOptions" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.property.cfnOptions"></a>

```typescript
public readonly cfnOptions: ICfnResourceOptions;
```

- *Type:* aws-cdk-lib.ICfnResourceOptions

Options for this resource, such as condition, update policy etc.

---

##### `cfnResourceType`<sup>Required</sup> <a name="cfnResourceType" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.property.cfnResourceType"></a>

```typescript
public readonly cfnResourceType: string;
```

- *Type:* string

AWS resource type.

---

##### `attrCloudProvider`<sup>Required</sup> <a name="attrCloudProvider" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.property.attrCloudProvider"></a>

```typescript
public readonly attrCloudProvider: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::CloudBackupSnapshot.CloudProvider`.

---

##### `attrCreatedAt`<sup>Required</sup> <a name="attrCreatedAt" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.property.attrCreatedAt"></a>

```typescript
public readonly attrCreatedAt: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::CloudBackupSnapshot.CreatedAt`.

---

##### `attrExpiresAt`<sup>Required</sup> <a name="attrExpiresAt" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.property.attrExpiresAt"></a>

```typescript
public readonly attrExpiresAt: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::CloudBackupSnapshot.ExpiresAt`.

---

##### `attrId`<sup>Required</sup> <a name="attrId" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.property.attrId"></a>

```typescript
public readonly attrId: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::CloudBackupSnapshot.Id`.

---

##### `attrMasterKeyUUID`<sup>Required</sup> <a name="attrMasterKeyUUID" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.property.attrMasterKeyUUID"></a>

```typescript
public readonly attrMasterKeyUUID: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::CloudBackupSnapshot.MasterKeyUUID`.

---

##### `attrMongodVersion`<sup>Required</sup> <a name="attrMongodVersion" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.property.attrMongodVersion"></a>

```typescript
public readonly attrMongodVersion: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::CloudBackupSnapshot.MongodVersion`.

---

##### `attrReplicaSetName`<sup>Required</sup> <a name="attrReplicaSetName" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.property.attrReplicaSetName"></a>

```typescript
public readonly attrReplicaSetName: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::CloudBackupSnapshot.ReplicaSetName`.

---

##### `attrSnapshotId`<sup>Required</sup> <a name="attrSnapshotId" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.property.attrSnapshotId"></a>

```typescript
public readonly attrSnapshotId: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::CloudBackupSnapshot.SnapshotId`.

---

##### `attrSnapshotIds`<sup>Required</sup> <a name="attrSnapshotIds" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.property.attrSnapshotIds"></a>

```typescript
public readonly attrSnapshotIds: string[];
```

- *Type:* string[]

Attribute `MongoDB::Atlas::CloudBackupSnapshot.SnapshotIds`.

---

##### `attrStatus`<sup>Required</sup> <a name="attrStatus" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.property.attrStatus"></a>

```typescript
public readonly attrStatus: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::CloudBackupSnapshot.Status`.

---

##### `attrStorageSizeBytes`<sup>Required</sup> <a name="attrStorageSizeBytes" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.property.attrStorageSizeBytes"></a>

```typescript
public readonly attrStorageSizeBytes: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::CloudBackupSnapshot.StorageSizeBytes`.

---

##### `attrType`<sup>Required</sup> <a name="attrType" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.property.attrType"></a>

```typescript
public readonly attrType: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::CloudBackupSnapshot.Type`.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.property.props"></a>

```typescript
public readonly props: CfnCloudBackupSnapshotProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotProps">CfnCloudBackupSnapshotProps</a>

Resource props.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.property.CFN_RESOURCE_TYPE_NAME">CFN_RESOURCE_TYPE_NAME</a></code> | <code>string</code> | The CloudFormation resource type name for this resource class. |

---

##### `CFN_RESOURCE_TYPE_NAME`<sup>Required</sup> <a name="CFN_RESOURCE_TYPE_NAME" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshot.property.CFN_RESOURCE_TYPE_NAME"></a>

```typescript
public readonly CFN_RESOURCE_TYPE_NAME: string;
```

- *Type:* string

The CloudFormation resource type name for this resource class.

---

### CfnCloudBackupSnapshotExportBucket <a name="CfnCloudBackupSnapshotExportBucket" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket"></a>

A CloudFormation `MongoDB::Atlas::CloudBackupSnapshotExportBucket`.

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.Initializer"></a>

```typescript
import { CfnCloudBackupSnapshotExportBucket } from 'awscdk-resources-mongodbatlas'

new CfnCloudBackupSnapshotExportBucket(scope: Construct, id: string, props: CfnCloudBackupSnapshotExportBucketProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - scope in which this resource is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.Initializer.parameter.id">id</a></code> | <code>string</code> | - scoped id of the resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucketProps">CfnCloudBackupSnapshotExportBucketProps</a></code> | - resource properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

scope in which this resource is defined.

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.Initializer.parameter.id"></a>

- *Type:* string

scoped id of the resource.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucketProps">CfnCloudBackupSnapshotExportBucketProps</a>

resource properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.overrideLogicalId">overrideLogicalId</a></code> | Overrides the auto-generated logical ID with a specific ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.addDeletionOverride">addDeletionOverride</a></code> | Syntactic sugar for `addOverride(path, undefined)`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.addDependency">addDependency</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.addDependsOn">addDependsOn</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.addMetadata">addMetadata</a></code> | Add a value to the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.addOverride">addOverride</a></code> | Adds an override to the synthesized CloudFormation resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.addPropertyDeletionOverride">addPropertyDeletionOverride</a></code> | Adds an override that deletes the value of a property from the resource definition. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.addPropertyOverride">addPropertyOverride</a></code> | Adds an override to a resource property. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.applyRemovalPolicy">applyRemovalPolicy</a></code> | Sets the deletion policy of the resource based on the removal policy specified. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.getAtt">getAtt</a></code> | Returns a token for an runtime attribute of this resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.getMetadata">getMetadata</a></code> | Retrieve a value value from the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.obtainDependencies">obtainDependencies</a></code> | Retrieves an array of resources this resource depends on. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.obtainResourceDependencies">obtainResourceDependencies</a></code> | Get a shallow copy of dependencies between this resource and other resources in the same stack. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.removeDependency">removeDependency</a></code> | Indicates that this resource no longer depends on another resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.replaceDependency">replaceDependency</a></code> | Replaces one dependency with another. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `overrideLogicalId` <a name="overrideLogicalId" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.overrideLogicalId"></a>

```typescript
public overrideLogicalId(newLogicalId: string): void
```

Overrides the auto-generated logical ID with a specific ID.

###### `newLogicalId`<sup>Required</sup> <a name="newLogicalId" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.overrideLogicalId.parameter.newLogicalId"></a>

- *Type:* string

The new logical ID to use for this stack element.

---

##### `addDeletionOverride` <a name="addDeletionOverride" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.addDeletionOverride"></a>

```typescript
public addDeletionOverride(path: string): void
```

Syntactic sugar for `addOverride(path, undefined)`.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.addDeletionOverride.parameter.path"></a>

- *Type:* string

The path of the value to delete.

---

##### `addDependency` <a name="addDependency" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.addDependency"></a>

```typescript
public addDependency(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

This can be used for resources across stacks (or nested stack) boundaries
and the dependency will automatically be transferred to the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.addDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### ~~`addDependsOn`~~ <a name="addDependsOn" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.addDependsOn"></a>

```typescript
public addDependsOn(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.addDependsOn.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `addMetadata` <a name="addMetadata" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.addMetadata"></a>

```typescript
public addMetadata(key: string, value: any): void
```

Add a value to the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.addMetadata.parameter.key"></a>

- *Type:* string

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.addMetadata.parameter.value"></a>

- *Type:* any

---

##### `addOverride` <a name="addOverride" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.addOverride"></a>

```typescript
public addOverride(path: string, value: any): void
```

Adds an override to the synthesized CloudFormation resource.

To add a
property override, either use `addPropertyOverride` or prefix `path` with
"Properties." (i.e. `Properties.TopicName`).

If the override is nested, separate each nested level using a dot (.) in the path parameter.
If there is an array as part of the nesting, specify the index in the path.

To include a literal `.` in the property name, prefix with a `\`. In most
programming languages you will need to write this as `"\\."` because the
`\` itself will need to be escaped.

For example,
```typescript
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
```
would add the overrides
```json
"Properties": {
  "GlobalSecondaryIndexes": [
    {
      "Projection": {
        "NonKeyAttributes": [ "myattribute" ]
        ...
      }
      ...
    },
    {
      "ProjectionType": "INCLUDE"
      ...
    },
  ]
  ...
}
```

The `value` argument to `addOverride` will not be processed or translated
in any way. Pass raw JSON values in here with the correct capitalization
for CloudFormation. If you pass CDK classes or structs, they will be
rendered with lowercased key names, and CloudFormation will reject the
template.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.addOverride.parameter.path"></a>

- *Type:* string

The path of the property, you can use dot notation to override values in complex types.

Any intermediate keys
will be created as needed.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.addOverride.parameter.value"></a>

- *Type:* any

The value.

Could be primitive or complex.

---

##### `addPropertyDeletionOverride` <a name="addPropertyDeletionOverride" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.addPropertyDeletionOverride"></a>

```typescript
public addPropertyDeletionOverride(propertyPath: string): void
```

Adds an override that deletes the value of a property from the resource definition.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.addPropertyDeletionOverride.parameter.propertyPath"></a>

- *Type:* string

The path to the property.

---

##### `addPropertyOverride` <a name="addPropertyOverride" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.addPropertyOverride"></a>

```typescript
public addPropertyOverride(propertyPath: string, value: any): void
```

Adds an override to a resource property.

Syntactic sugar for `addOverride("Properties.<...>", value)`.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.addPropertyOverride.parameter.propertyPath"></a>

- *Type:* string

The path of the property.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.addPropertyOverride.parameter.value"></a>

- *Type:* any

The value.

---

##### `applyRemovalPolicy` <a name="applyRemovalPolicy" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.applyRemovalPolicy"></a>

```typescript
public applyRemovalPolicy(policy?: RemovalPolicy, options?: RemovalPolicyOptions): void
```

Sets the deletion policy of the resource based on the removal policy specified.

The Removal Policy controls what happens to this resource when it stops
being managed by CloudFormation, either because you've removed it from the
CDK application or because you've made a change that requires the resource
to be replaced.

The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
cases, a snapshot can be taken of the resource prior to deletion
(`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
can be found in the following link:

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options)

###### `policy`<sup>Optional</sup> <a name="policy" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.applyRemovalPolicy.parameter.policy"></a>

- *Type:* aws-cdk-lib.RemovalPolicy

---

###### `options`<sup>Optional</sup> <a name="options" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.applyRemovalPolicy.parameter.options"></a>

- *Type:* aws-cdk-lib.RemovalPolicyOptions

---

##### `getAtt` <a name="getAtt" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.getAtt"></a>

```typescript
public getAtt(attributeName: string, typeHint?: ResolutionTypeHint): Reference
```

Returns a token for an runtime attribute of this resource.

Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
in case there is no generated attribute.

###### `attributeName`<sup>Required</sup> <a name="attributeName" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.getAtt.parameter.attributeName"></a>

- *Type:* string

The name of the attribute.

---

###### `typeHint`<sup>Optional</sup> <a name="typeHint" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.getAtt.parameter.typeHint"></a>

- *Type:* aws-cdk-lib.ResolutionTypeHint

---

##### `getMetadata` <a name="getMetadata" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.getMetadata"></a>

```typescript
public getMetadata(key: string): any
```

Retrieve a value value from the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.getMetadata.parameter.key"></a>

- *Type:* string

---

##### `obtainDependencies` <a name="obtainDependencies" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.obtainDependencies"></a>

```typescript
public obtainDependencies(): Stack | CfnResource[]
```

Retrieves an array of resources this resource depends on.

This assembles dependencies on resources across stacks (including nested stacks)
automatically.

##### `obtainResourceDependencies` <a name="obtainResourceDependencies" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.obtainResourceDependencies"></a>

```typescript
public obtainResourceDependencies(): CfnResource[]
```

Get a shallow copy of dependencies between this resource and other resources in the same stack.

##### `removeDependency` <a name="removeDependency" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.removeDependency"></a>

```typescript
public removeDependency(target: CfnResource): void
```

Indicates that this resource no longer depends on another resource.

This can be used for resources across stacks (including nested stacks)
and the dependency will automatically be removed from the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.removeDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `replaceDependency` <a name="replaceDependency" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.replaceDependency"></a>

```typescript
public replaceDependency(target: CfnResource, newTarget: CfnResource): void
```

Replaces one dependency with another.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.replaceDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

The dependency to replace.

---

###### `newTarget`<sup>Required</sup> <a name="newTarget" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.replaceDependency.parameter.newTarget"></a>

- *Type:* aws-cdk-lib.CfnResource

The new dependency to add.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.isCfnElement">isCfnElement</a></code> | Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.isCfnResource">isCfnResource</a></code> | Check whether the given construct is a CfnResource. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.isConstruct"></a>

```typescript
import { CfnCloudBackupSnapshotExportBucket } from 'awscdk-resources-mongodbatlas'

CfnCloudBackupSnapshotExportBucket.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `isCfnElement` <a name="isCfnElement" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.isCfnElement"></a>

```typescript
import { CfnCloudBackupSnapshotExportBucket } from 'awscdk-resources-mongodbatlas'

CfnCloudBackupSnapshotExportBucket.isCfnElement(x: any)
```

Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).

Uses duck-typing instead of `instanceof` to allow stack elements from different
versions of this library to be included in the same stack.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.isCfnElement.parameter.x"></a>

- *Type:* any

---

##### `isCfnResource` <a name="isCfnResource" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.isCfnResource"></a>

```typescript
import { CfnCloudBackupSnapshotExportBucket } from 'awscdk-resources-mongodbatlas'

CfnCloudBackupSnapshotExportBucket.isCfnResource(construct: IConstruct)
```

Check whether the given construct is a CfnResource.

###### `construct`<sup>Required</sup> <a name="construct" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.isCfnResource.parameter.construct"></a>

- *Type:* constructs.IConstruct

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.property.creationStack">creationStack</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.property.logicalId">logicalId</a></code> | <code>string</code> | The logical ID for this CloudFormation stack element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.property.stack">stack</a></code> | <code>aws-cdk-lib.Stack</code> | The stack in which this element is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.property.ref">ref</a></code> | <code>string</code> | Return a string that will be resolved to a CloudFormation `{ Ref }` for this element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.property.cfnOptions">cfnOptions</a></code> | <code>aws-cdk-lib.ICfnResourceOptions</code> | Options for this resource, such as condition, update policy etc. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.property.cfnResourceType">cfnResourceType</a></code> | <code>string</code> | AWS resource type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.property.attrId">attrId</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::CloudBackupSnapshotExportBucket.Id`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.property.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucketProps">CfnCloudBackupSnapshotExportBucketProps</a></code> | Resource props. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `creationStack`<sup>Required</sup> <a name="creationStack" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.property.creationStack"></a>

```typescript
public readonly creationStack: string[];
```

- *Type:* string[]

---

##### `logicalId`<sup>Required</sup> <a name="logicalId" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.property.logicalId"></a>

```typescript
public readonly logicalId: string;
```

- *Type:* string

The logical ID for this CloudFormation stack element.

The logical ID of the element
is calculated from the path of the resource node in the construct tree.

To override this value, use `overrideLogicalId(newLogicalId)`.

---

##### `stack`<sup>Required</sup> <a name="stack" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.property.stack"></a>

```typescript
public readonly stack: Stack;
```

- *Type:* aws-cdk-lib.Stack

The stack in which this element is defined.

CfnElements must be defined within a stack scope (directly or indirectly).

---

##### `ref`<sup>Required</sup> <a name="ref" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.

If, by any chance, the intrinsic reference of a resource is not a string, you could
coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.

---

##### `cfnOptions`<sup>Required</sup> <a name="cfnOptions" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.property.cfnOptions"></a>

```typescript
public readonly cfnOptions: ICfnResourceOptions;
```

- *Type:* aws-cdk-lib.ICfnResourceOptions

Options for this resource, such as condition, update policy etc.

---

##### `cfnResourceType`<sup>Required</sup> <a name="cfnResourceType" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.property.cfnResourceType"></a>

```typescript
public readonly cfnResourceType: string;
```

- *Type:* string

AWS resource type.

---

##### `attrId`<sup>Required</sup> <a name="attrId" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.property.attrId"></a>

```typescript
public readonly attrId: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::CloudBackupSnapshotExportBucket.Id`.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.property.props"></a>

```typescript
public readonly props: CfnCloudBackupSnapshotExportBucketProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucketProps">CfnCloudBackupSnapshotExportBucketProps</a>

Resource props.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.property.CFN_RESOURCE_TYPE_NAME">CFN_RESOURCE_TYPE_NAME</a></code> | <code>string</code> | The CloudFormation resource type name for this resource class. |

---

##### `CFN_RESOURCE_TYPE_NAME`<sup>Required</sup> <a name="CFN_RESOURCE_TYPE_NAME" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucket.property.CFN_RESOURCE_TYPE_NAME"></a>

```typescript
public readonly CFN_RESOURCE_TYPE_NAME: string;
```

- *Type:* string

The CloudFormation resource type name for this resource class.

---

### CfnCluster <a name="CfnCluster" id="awscdk-resources-mongodbatlas.CfnCluster"></a>

A CloudFormation `MongoDB::Atlas::Cluster`.

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.CfnCluster.Initializer"></a>

```typescript
import { CfnCluster } from 'awscdk-resources-mongodbatlas'

new CfnCluster(scope: Construct, id: string, props: CfnClusterProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCluster.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - scope in which this resource is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCluster.Initializer.parameter.id">id</a></code> | <code>string</code> | - scoped id of the resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCluster.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnClusterProps">CfnClusterProps</a></code> | - resource properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.CfnCluster.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

scope in which this resource is defined.

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnCluster.Initializer.parameter.id"></a>

- *Type:* string

scoped id of the resource.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnCluster.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnClusterProps">CfnClusterProps</a>

resource properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCluster.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCluster.overrideLogicalId">overrideLogicalId</a></code> | Overrides the auto-generated logical ID with a specific ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCluster.addDeletionOverride">addDeletionOverride</a></code> | Syntactic sugar for `addOverride(path, undefined)`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCluster.addDependency">addDependency</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCluster.addDependsOn">addDependsOn</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCluster.addMetadata">addMetadata</a></code> | Add a value to the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCluster.addOverride">addOverride</a></code> | Adds an override to the synthesized CloudFormation resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCluster.addPropertyDeletionOverride">addPropertyDeletionOverride</a></code> | Adds an override that deletes the value of a property from the resource definition. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCluster.addPropertyOverride">addPropertyOverride</a></code> | Adds an override to a resource property. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCluster.applyRemovalPolicy">applyRemovalPolicy</a></code> | Sets the deletion policy of the resource based on the removal policy specified. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCluster.getAtt">getAtt</a></code> | Returns a token for an runtime attribute of this resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCluster.getMetadata">getMetadata</a></code> | Retrieve a value value from the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCluster.obtainDependencies">obtainDependencies</a></code> | Retrieves an array of resources this resource depends on. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCluster.obtainResourceDependencies">obtainResourceDependencies</a></code> | Get a shallow copy of dependencies between this resource and other resources in the same stack. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCluster.removeDependency">removeDependency</a></code> | Indicates that this resource no longer depends on another resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCluster.replaceDependency">replaceDependency</a></code> | Replaces one dependency with another. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.CfnCluster.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `overrideLogicalId` <a name="overrideLogicalId" id="awscdk-resources-mongodbatlas.CfnCluster.overrideLogicalId"></a>

```typescript
public overrideLogicalId(newLogicalId: string): void
```

Overrides the auto-generated logical ID with a specific ID.

###### `newLogicalId`<sup>Required</sup> <a name="newLogicalId" id="awscdk-resources-mongodbatlas.CfnCluster.overrideLogicalId.parameter.newLogicalId"></a>

- *Type:* string

The new logical ID to use for this stack element.

---

##### `addDeletionOverride` <a name="addDeletionOverride" id="awscdk-resources-mongodbatlas.CfnCluster.addDeletionOverride"></a>

```typescript
public addDeletionOverride(path: string): void
```

Syntactic sugar for `addOverride(path, undefined)`.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnCluster.addDeletionOverride.parameter.path"></a>

- *Type:* string

The path of the value to delete.

---

##### `addDependency` <a name="addDependency" id="awscdk-resources-mongodbatlas.CfnCluster.addDependency"></a>

```typescript
public addDependency(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

This can be used for resources across stacks (or nested stack) boundaries
and the dependency will automatically be transferred to the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnCluster.addDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### ~~`addDependsOn`~~ <a name="addDependsOn" id="awscdk-resources-mongodbatlas.CfnCluster.addDependsOn"></a>

```typescript
public addDependsOn(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnCluster.addDependsOn.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `addMetadata` <a name="addMetadata" id="awscdk-resources-mongodbatlas.CfnCluster.addMetadata"></a>

```typescript
public addMetadata(key: string, value: any): void
```

Add a value to the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnCluster.addMetadata.parameter.key"></a>

- *Type:* string

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnCluster.addMetadata.parameter.value"></a>

- *Type:* any

---

##### `addOverride` <a name="addOverride" id="awscdk-resources-mongodbatlas.CfnCluster.addOverride"></a>

```typescript
public addOverride(path: string, value: any): void
```

Adds an override to the synthesized CloudFormation resource.

To add a
property override, either use `addPropertyOverride` or prefix `path` with
"Properties." (i.e. `Properties.TopicName`).

If the override is nested, separate each nested level using a dot (.) in the path parameter.
If there is an array as part of the nesting, specify the index in the path.

To include a literal `.` in the property name, prefix with a `\`. In most
programming languages you will need to write this as `"\\."` because the
`\` itself will need to be escaped.

For example,
```typescript
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
```
would add the overrides
```json
"Properties": {
  "GlobalSecondaryIndexes": [
    {
      "Projection": {
        "NonKeyAttributes": [ "myattribute" ]
        ...
      }
      ...
    },
    {
      "ProjectionType": "INCLUDE"
      ...
    },
  ]
  ...
}
```

The `value` argument to `addOverride` will not be processed or translated
in any way. Pass raw JSON values in here with the correct capitalization
for CloudFormation. If you pass CDK classes or structs, they will be
rendered with lowercased key names, and CloudFormation will reject the
template.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnCluster.addOverride.parameter.path"></a>

- *Type:* string

The path of the property, you can use dot notation to override values in complex types.

Any intermediate keys
will be created as needed.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnCluster.addOverride.parameter.value"></a>

- *Type:* any

The value.

Could be primitive or complex.

---

##### `addPropertyDeletionOverride` <a name="addPropertyDeletionOverride" id="awscdk-resources-mongodbatlas.CfnCluster.addPropertyDeletionOverride"></a>

```typescript
public addPropertyDeletionOverride(propertyPath: string): void
```

Adds an override that deletes the value of a property from the resource definition.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnCluster.addPropertyDeletionOverride.parameter.propertyPath"></a>

- *Type:* string

The path to the property.

---

##### `addPropertyOverride` <a name="addPropertyOverride" id="awscdk-resources-mongodbatlas.CfnCluster.addPropertyOverride"></a>

```typescript
public addPropertyOverride(propertyPath: string, value: any): void
```

Adds an override to a resource property.

Syntactic sugar for `addOverride("Properties.<...>", value)`.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnCluster.addPropertyOverride.parameter.propertyPath"></a>

- *Type:* string

The path of the property.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnCluster.addPropertyOverride.parameter.value"></a>

- *Type:* any

The value.

---

##### `applyRemovalPolicy` <a name="applyRemovalPolicy" id="awscdk-resources-mongodbatlas.CfnCluster.applyRemovalPolicy"></a>

```typescript
public applyRemovalPolicy(policy?: RemovalPolicy, options?: RemovalPolicyOptions): void
```

Sets the deletion policy of the resource based on the removal policy specified.

The Removal Policy controls what happens to this resource when it stops
being managed by CloudFormation, either because you've removed it from the
CDK application or because you've made a change that requires the resource
to be replaced.

The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
cases, a snapshot can be taken of the resource prior to deletion
(`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
can be found in the following link:

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options)

###### `policy`<sup>Optional</sup> <a name="policy" id="awscdk-resources-mongodbatlas.CfnCluster.applyRemovalPolicy.parameter.policy"></a>

- *Type:* aws-cdk-lib.RemovalPolicy

---

###### `options`<sup>Optional</sup> <a name="options" id="awscdk-resources-mongodbatlas.CfnCluster.applyRemovalPolicy.parameter.options"></a>

- *Type:* aws-cdk-lib.RemovalPolicyOptions

---

##### `getAtt` <a name="getAtt" id="awscdk-resources-mongodbatlas.CfnCluster.getAtt"></a>

```typescript
public getAtt(attributeName: string, typeHint?: ResolutionTypeHint): Reference
```

Returns a token for an runtime attribute of this resource.

Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
in case there is no generated attribute.

###### `attributeName`<sup>Required</sup> <a name="attributeName" id="awscdk-resources-mongodbatlas.CfnCluster.getAtt.parameter.attributeName"></a>

- *Type:* string

The name of the attribute.

---

###### `typeHint`<sup>Optional</sup> <a name="typeHint" id="awscdk-resources-mongodbatlas.CfnCluster.getAtt.parameter.typeHint"></a>

- *Type:* aws-cdk-lib.ResolutionTypeHint

---

##### `getMetadata` <a name="getMetadata" id="awscdk-resources-mongodbatlas.CfnCluster.getMetadata"></a>

```typescript
public getMetadata(key: string): any
```

Retrieve a value value from the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnCluster.getMetadata.parameter.key"></a>

- *Type:* string

---

##### `obtainDependencies` <a name="obtainDependencies" id="awscdk-resources-mongodbatlas.CfnCluster.obtainDependencies"></a>

```typescript
public obtainDependencies(): Stack | CfnResource[]
```

Retrieves an array of resources this resource depends on.

This assembles dependencies on resources across stacks (including nested stacks)
automatically.

##### `obtainResourceDependencies` <a name="obtainResourceDependencies" id="awscdk-resources-mongodbatlas.CfnCluster.obtainResourceDependencies"></a>

```typescript
public obtainResourceDependencies(): CfnResource[]
```

Get a shallow copy of dependencies between this resource and other resources in the same stack.

##### `removeDependency` <a name="removeDependency" id="awscdk-resources-mongodbatlas.CfnCluster.removeDependency"></a>

```typescript
public removeDependency(target: CfnResource): void
```

Indicates that this resource no longer depends on another resource.

This can be used for resources across stacks (including nested stacks)
and the dependency will automatically be removed from the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnCluster.removeDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `replaceDependency` <a name="replaceDependency" id="awscdk-resources-mongodbatlas.CfnCluster.replaceDependency"></a>

```typescript
public replaceDependency(target: CfnResource, newTarget: CfnResource): void
```

Replaces one dependency with another.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnCluster.replaceDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

The dependency to replace.

---

###### `newTarget`<sup>Required</sup> <a name="newTarget" id="awscdk-resources-mongodbatlas.CfnCluster.replaceDependency.parameter.newTarget"></a>

- *Type:* aws-cdk-lib.CfnResource

The new dependency to add.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCluster.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCluster.isCfnElement">isCfnElement</a></code> | Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCluster.isCfnResource">isCfnResource</a></code> | Check whether the given construct is a CfnResource. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.CfnCluster.isConstruct"></a>

```typescript
import { CfnCluster } from 'awscdk-resources-mongodbatlas'

CfnCluster.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnCluster.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `isCfnElement` <a name="isCfnElement" id="awscdk-resources-mongodbatlas.CfnCluster.isCfnElement"></a>

```typescript
import { CfnCluster } from 'awscdk-resources-mongodbatlas'

CfnCluster.isCfnElement(x: any)
```

Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).

Uses duck-typing instead of `instanceof` to allow stack elements from different
versions of this library to be included in the same stack.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnCluster.isCfnElement.parameter.x"></a>

- *Type:* any

---

##### `isCfnResource` <a name="isCfnResource" id="awscdk-resources-mongodbatlas.CfnCluster.isCfnResource"></a>

```typescript
import { CfnCluster } from 'awscdk-resources-mongodbatlas'

CfnCluster.isCfnResource(construct: IConstruct)
```

Check whether the given construct is a CfnResource.

###### `construct`<sup>Required</sup> <a name="construct" id="awscdk-resources-mongodbatlas.CfnCluster.isCfnResource.parameter.construct"></a>

- *Type:* constructs.IConstruct

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCluster.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCluster.property.creationStack">creationStack</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCluster.property.logicalId">logicalId</a></code> | <code>string</code> | The logical ID for this CloudFormation stack element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCluster.property.stack">stack</a></code> | <code>aws-cdk-lib.Stack</code> | The stack in which this element is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCluster.property.ref">ref</a></code> | <code>string</code> | Return a string that will be resolved to a CloudFormation `{ Ref }` for this element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCluster.property.cfnOptions">cfnOptions</a></code> | <code>aws-cdk-lib.ICfnResourceOptions</code> | Options for this resource, such as condition, update policy etc. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCluster.property.cfnResourceType">cfnResourceType</a></code> | <code>string</code> | AWS resource type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCluster.property.attrCreatedDate">attrCreatedDate</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::Cluster.CreatedDate`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCluster.property.attrId">attrId</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::Cluster.Id`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCluster.property.attrMongoDBVersion">attrMongoDBVersion</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::Cluster.MongoDBVersion`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCluster.property.attrStateName">attrStateName</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::Cluster.StateName`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCluster.property.connectionStrings">connectionStrings</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ConnectionStrings">ConnectionStrings</a></code> | Attribute `MongoDB::Atlas::Cluster.ConnectionStrings`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCluster.property.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnClusterProps">CfnClusterProps</a></code> | Resource props. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.CfnCluster.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `creationStack`<sup>Required</sup> <a name="creationStack" id="awscdk-resources-mongodbatlas.CfnCluster.property.creationStack"></a>

```typescript
public readonly creationStack: string[];
```

- *Type:* string[]

---

##### `logicalId`<sup>Required</sup> <a name="logicalId" id="awscdk-resources-mongodbatlas.CfnCluster.property.logicalId"></a>

```typescript
public readonly logicalId: string;
```

- *Type:* string

The logical ID for this CloudFormation stack element.

The logical ID of the element
is calculated from the path of the resource node in the construct tree.

To override this value, use `overrideLogicalId(newLogicalId)`.

---

##### `stack`<sup>Required</sup> <a name="stack" id="awscdk-resources-mongodbatlas.CfnCluster.property.stack"></a>

```typescript
public readonly stack: Stack;
```

- *Type:* aws-cdk-lib.Stack

The stack in which this element is defined.

CfnElements must be defined within a stack scope (directly or indirectly).

---

##### `ref`<sup>Required</sup> <a name="ref" id="awscdk-resources-mongodbatlas.CfnCluster.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.

If, by any chance, the intrinsic reference of a resource is not a string, you could
coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.

---

##### `cfnOptions`<sup>Required</sup> <a name="cfnOptions" id="awscdk-resources-mongodbatlas.CfnCluster.property.cfnOptions"></a>

```typescript
public readonly cfnOptions: ICfnResourceOptions;
```

- *Type:* aws-cdk-lib.ICfnResourceOptions

Options for this resource, such as condition, update policy etc.

---

##### `cfnResourceType`<sup>Required</sup> <a name="cfnResourceType" id="awscdk-resources-mongodbatlas.CfnCluster.property.cfnResourceType"></a>

```typescript
public readonly cfnResourceType: string;
```

- *Type:* string

AWS resource type.

---

##### `attrCreatedDate`<sup>Required</sup> <a name="attrCreatedDate" id="awscdk-resources-mongodbatlas.CfnCluster.property.attrCreatedDate"></a>

```typescript
public readonly attrCreatedDate: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::Cluster.CreatedDate`.

---

##### `attrId`<sup>Required</sup> <a name="attrId" id="awscdk-resources-mongodbatlas.CfnCluster.property.attrId"></a>

```typescript
public readonly attrId: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::Cluster.Id`.

---

##### `attrMongoDBVersion`<sup>Required</sup> <a name="attrMongoDBVersion" id="awscdk-resources-mongodbatlas.CfnCluster.property.attrMongoDBVersion"></a>

```typescript
public readonly attrMongoDBVersion: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::Cluster.MongoDBVersion`.

---

##### `attrStateName`<sup>Required</sup> <a name="attrStateName" id="awscdk-resources-mongodbatlas.CfnCluster.property.attrStateName"></a>

```typescript
public readonly attrStateName: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::Cluster.StateName`.

---

##### `connectionStrings`<sup>Required</sup> <a name="connectionStrings" id="awscdk-resources-mongodbatlas.CfnCluster.property.connectionStrings"></a>

```typescript
public readonly connectionStrings: ConnectionStrings;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ConnectionStrings">ConnectionStrings</a>

Attribute `MongoDB::Atlas::Cluster.ConnectionStrings`.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnCluster.property.props"></a>

```typescript
public readonly props: CfnClusterProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnClusterProps">CfnClusterProps</a>

Resource props.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCluster.property.CFN_RESOURCE_TYPE_NAME">CFN_RESOURCE_TYPE_NAME</a></code> | <code>string</code> | The CloudFormation resource type name for this resource class. |

---

##### `CFN_RESOURCE_TYPE_NAME`<sup>Required</sup> <a name="CFN_RESOURCE_TYPE_NAME" id="awscdk-resources-mongodbatlas.CfnCluster.property.CFN_RESOURCE_TYPE_NAME"></a>

```typescript
public readonly CFN_RESOURCE_TYPE_NAME: string;
```

- *Type:* string

The CloudFormation resource type name for this resource class.

---

### CfnClusterOutageSimulation <a name="CfnClusterOutageSimulation" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation"></a>

A CloudFormation `MongoDB::Atlas::ClusterOutageSimulation`.

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.Initializer"></a>

```typescript
import { CfnClusterOutageSimulation } from 'awscdk-resources-mongodbatlas'

new CfnClusterOutageSimulation(scope: Construct, id: string, props: CfnClusterOutageSimulationProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - scope in which this resource is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.Initializer.parameter.id">id</a></code> | <code>string</code> | - scoped id of the resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnClusterOutageSimulationProps">CfnClusterOutageSimulationProps</a></code> | - resource properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

scope in which this resource is defined.

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.Initializer.parameter.id"></a>

- *Type:* string

scoped id of the resource.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnClusterOutageSimulationProps">CfnClusterOutageSimulationProps</a>

resource properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.overrideLogicalId">overrideLogicalId</a></code> | Overrides the auto-generated logical ID with a specific ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.addDeletionOverride">addDeletionOverride</a></code> | Syntactic sugar for `addOverride(path, undefined)`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.addDependency">addDependency</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.addDependsOn">addDependsOn</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.addMetadata">addMetadata</a></code> | Add a value to the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.addOverride">addOverride</a></code> | Adds an override to the synthesized CloudFormation resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.addPropertyDeletionOverride">addPropertyDeletionOverride</a></code> | Adds an override that deletes the value of a property from the resource definition. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.addPropertyOverride">addPropertyOverride</a></code> | Adds an override to a resource property. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.applyRemovalPolicy">applyRemovalPolicy</a></code> | Sets the deletion policy of the resource based on the removal policy specified. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.getAtt">getAtt</a></code> | Returns a token for an runtime attribute of this resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.getMetadata">getMetadata</a></code> | Retrieve a value value from the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.obtainDependencies">obtainDependencies</a></code> | Retrieves an array of resources this resource depends on. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.obtainResourceDependencies">obtainResourceDependencies</a></code> | Get a shallow copy of dependencies between this resource and other resources in the same stack. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.removeDependency">removeDependency</a></code> | Indicates that this resource no longer depends on another resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.replaceDependency">replaceDependency</a></code> | Replaces one dependency with another. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `overrideLogicalId` <a name="overrideLogicalId" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.overrideLogicalId"></a>

```typescript
public overrideLogicalId(newLogicalId: string): void
```

Overrides the auto-generated logical ID with a specific ID.

###### `newLogicalId`<sup>Required</sup> <a name="newLogicalId" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.overrideLogicalId.parameter.newLogicalId"></a>

- *Type:* string

The new logical ID to use for this stack element.

---

##### `addDeletionOverride` <a name="addDeletionOverride" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.addDeletionOverride"></a>

```typescript
public addDeletionOverride(path: string): void
```

Syntactic sugar for `addOverride(path, undefined)`.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.addDeletionOverride.parameter.path"></a>

- *Type:* string

The path of the value to delete.

---

##### `addDependency` <a name="addDependency" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.addDependency"></a>

```typescript
public addDependency(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

This can be used for resources across stacks (or nested stack) boundaries
and the dependency will automatically be transferred to the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.addDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### ~~`addDependsOn`~~ <a name="addDependsOn" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.addDependsOn"></a>

```typescript
public addDependsOn(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.addDependsOn.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `addMetadata` <a name="addMetadata" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.addMetadata"></a>

```typescript
public addMetadata(key: string, value: any): void
```

Add a value to the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.addMetadata.parameter.key"></a>

- *Type:* string

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.addMetadata.parameter.value"></a>

- *Type:* any

---

##### `addOverride` <a name="addOverride" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.addOverride"></a>

```typescript
public addOverride(path: string, value: any): void
```

Adds an override to the synthesized CloudFormation resource.

To add a
property override, either use `addPropertyOverride` or prefix `path` with
"Properties." (i.e. `Properties.TopicName`).

If the override is nested, separate each nested level using a dot (.) in the path parameter.
If there is an array as part of the nesting, specify the index in the path.

To include a literal `.` in the property name, prefix with a `\`. In most
programming languages you will need to write this as `"\\."` because the
`\` itself will need to be escaped.

For example,
```typescript
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
```
would add the overrides
```json
"Properties": {
  "GlobalSecondaryIndexes": [
    {
      "Projection": {
        "NonKeyAttributes": [ "myattribute" ]
        ...
      }
      ...
    },
    {
      "ProjectionType": "INCLUDE"
      ...
    },
  ]
  ...
}
```

The `value` argument to `addOverride` will not be processed or translated
in any way. Pass raw JSON values in here with the correct capitalization
for CloudFormation. If you pass CDK classes or structs, they will be
rendered with lowercased key names, and CloudFormation will reject the
template.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.addOverride.parameter.path"></a>

- *Type:* string

The path of the property, you can use dot notation to override values in complex types.

Any intermediate keys
will be created as needed.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.addOverride.parameter.value"></a>

- *Type:* any

The value.

Could be primitive or complex.

---

##### `addPropertyDeletionOverride` <a name="addPropertyDeletionOverride" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.addPropertyDeletionOverride"></a>

```typescript
public addPropertyDeletionOverride(propertyPath: string): void
```

Adds an override that deletes the value of a property from the resource definition.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.addPropertyDeletionOverride.parameter.propertyPath"></a>

- *Type:* string

The path to the property.

---

##### `addPropertyOverride` <a name="addPropertyOverride" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.addPropertyOverride"></a>

```typescript
public addPropertyOverride(propertyPath: string, value: any): void
```

Adds an override to a resource property.

Syntactic sugar for `addOverride("Properties.<...>", value)`.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.addPropertyOverride.parameter.propertyPath"></a>

- *Type:* string

The path of the property.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.addPropertyOverride.parameter.value"></a>

- *Type:* any

The value.

---

##### `applyRemovalPolicy` <a name="applyRemovalPolicy" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.applyRemovalPolicy"></a>

```typescript
public applyRemovalPolicy(policy?: RemovalPolicy, options?: RemovalPolicyOptions): void
```

Sets the deletion policy of the resource based on the removal policy specified.

The Removal Policy controls what happens to this resource when it stops
being managed by CloudFormation, either because you've removed it from the
CDK application or because you've made a change that requires the resource
to be replaced.

The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
cases, a snapshot can be taken of the resource prior to deletion
(`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
can be found in the following link:

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options)

###### `policy`<sup>Optional</sup> <a name="policy" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.applyRemovalPolicy.parameter.policy"></a>

- *Type:* aws-cdk-lib.RemovalPolicy

---

###### `options`<sup>Optional</sup> <a name="options" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.applyRemovalPolicy.parameter.options"></a>

- *Type:* aws-cdk-lib.RemovalPolicyOptions

---

##### `getAtt` <a name="getAtt" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.getAtt"></a>

```typescript
public getAtt(attributeName: string, typeHint?: ResolutionTypeHint): Reference
```

Returns a token for an runtime attribute of this resource.

Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
in case there is no generated attribute.

###### `attributeName`<sup>Required</sup> <a name="attributeName" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.getAtt.parameter.attributeName"></a>

- *Type:* string

The name of the attribute.

---

###### `typeHint`<sup>Optional</sup> <a name="typeHint" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.getAtt.parameter.typeHint"></a>

- *Type:* aws-cdk-lib.ResolutionTypeHint

---

##### `getMetadata` <a name="getMetadata" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.getMetadata"></a>

```typescript
public getMetadata(key: string): any
```

Retrieve a value value from the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.getMetadata.parameter.key"></a>

- *Type:* string

---

##### `obtainDependencies` <a name="obtainDependencies" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.obtainDependencies"></a>

```typescript
public obtainDependencies(): Stack | CfnResource[]
```

Retrieves an array of resources this resource depends on.

This assembles dependencies on resources across stacks (including nested stacks)
automatically.

##### `obtainResourceDependencies` <a name="obtainResourceDependencies" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.obtainResourceDependencies"></a>

```typescript
public obtainResourceDependencies(): CfnResource[]
```

Get a shallow copy of dependencies between this resource and other resources in the same stack.

##### `removeDependency` <a name="removeDependency" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.removeDependency"></a>

```typescript
public removeDependency(target: CfnResource): void
```

Indicates that this resource no longer depends on another resource.

This can be used for resources across stacks (including nested stacks)
and the dependency will automatically be removed from the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.removeDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `replaceDependency` <a name="replaceDependency" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.replaceDependency"></a>

```typescript
public replaceDependency(target: CfnResource, newTarget: CfnResource): void
```

Replaces one dependency with another.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.replaceDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

The dependency to replace.

---

###### `newTarget`<sup>Required</sup> <a name="newTarget" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.replaceDependency.parameter.newTarget"></a>

- *Type:* aws-cdk-lib.CfnResource

The new dependency to add.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.isCfnElement">isCfnElement</a></code> | Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.isCfnResource">isCfnResource</a></code> | Check whether the given construct is a CfnResource. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.isConstruct"></a>

```typescript
import { CfnClusterOutageSimulation } from 'awscdk-resources-mongodbatlas'

CfnClusterOutageSimulation.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `isCfnElement` <a name="isCfnElement" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.isCfnElement"></a>

```typescript
import { CfnClusterOutageSimulation } from 'awscdk-resources-mongodbatlas'

CfnClusterOutageSimulation.isCfnElement(x: any)
```

Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).

Uses duck-typing instead of `instanceof` to allow stack elements from different
versions of this library to be included in the same stack.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.isCfnElement.parameter.x"></a>

- *Type:* any

---

##### `isCfnResource` <a name="isCfnResource" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.isCfnResource"></a>

```typescript
import { CfnClusterOutageSimulation } from 'awscdk-resources-mongodbatlas'

CfnClusterOutageSimulation.isCfnResource(construct: IConstruct)
```

Check whether the given construct is a CfnResource.

###### `construct`<sup>Required</sup> <a name="construct" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.isCfnResource.parameter.construct"></a>

- *Type:* constructs.IConstruct

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.property.creationStack">creationStack</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.property.logicalId">logicalId</a></code> | <code>string</code> | The logical ID for this CloudFormation stack element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.property.stack">stack</a></code> | <code>aws-cdk-lib.Stack</code> | The stack in which this element is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.property.ref">ref</a></code> | <code>string</code> | Return a string that will be resolved to a CloudFormation `{ Ref }` for this element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.property.cfnOptions">cfnOptions</a></code> | <code>aws-cdk-lib.ICfnResourceOptions</code> | Options for this resource, such as condition, update policy etc. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.property.cfnResourceType">cfnResourceType</a></code> | <code>string</code> | AWS resource type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.property.attrSimulationId">attrSimulationId</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::ClusterOutageSimulation.SimulationId`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.property.attrStartRequestDate">attrStartRequestDate</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::ClusterOutageSimulation.StartRequestDate`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.property.attrState">attrState</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::ClusterOutageSimulation.State`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.property.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnClusterOutageSimulationProps">CfnClusterOutageSimulationProps</a></code> | Resource props. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `creationStack`<sup>Required</sup> <a name="creationStack" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.property.creationStack"></a>

```typescript
public readonly creationStack: string[];
```

- *Type:* string[]

---

##### `logicalId`<sup>Required</sup> <a name="logicalId" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.property.logicalId"></a>

```typescript
public readonly logicalId: string;
```

- *Type:* string

The logical ID for this CloudFormation stack element.

The logical ID of the element
is calculated from the path of the resource node in the construct tree.

To override this value, use `overrideLogicalId(newLogicalId)`.

---

##### `stack`<sup>Required</sup> <a name="stack" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.property.stack"></a>

```typescript
public readonly stack: Stack;
```

- *Type:* aws-cdk-lib.Stack

The stack in which this element is defined.

CfnElements must be defined within a stack scope (directly or indirectly).

---

##### `ref`<sup>Required</sup> <a name="ref" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.

If, by any chance, the intrinsic reference of a resource is not a string, you could
coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.

---

##### `cfnOptions`<sup>Required</sup> <a name="cfnOptions" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.property.cfnOptions"></a>

```typescript
public readonly cfnOptions: ICfnResourceOptions;
```

- *Type:* aws-cdk-lib.ICfnResourceOptions

Options for this resource, such as condition, update policy etc.

---

##### `cfnResourceType`<sup>Required</sup> <a name="cfnResourceType" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.property.cfnResourceType"></a>

```typescript
public readonly cfnResourceType: string;
```

- *Type:* string

AWS resource type.

---

##### `attrSimulationId`<sup>Required</sup> <a name="attrSimulationId" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.property.attrSimulationId"></a>

```typescript
public readonly attrSimulationId: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::ClusterOutageSimulation.SimulationId`.

---

##### `attrStartRequestDate`<sup>Required</sup> <a name="attrStartRequestDate" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.property.attrStartRequestDate"></a>

```typescript
public readonly attrStartRequestDate: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::ClusterOutageSimulation.StartRequestDate`.

---

##### `attrState`<sup>Required</sup> <a name="attrState" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.property.attrState"></a>

```typescript
public readonly attrState: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::ClusterOutageSimulation.State`.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.property.props"></a>

```typescript
public readonly props: CfnClusterOutageSimulationProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnClusterOutageSimulationProps">CfnClusterOutageSimulationProps</a>

Resource props.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.property.CFN_RESOURCE_TYPE_NAME">CFN_RESOURCE_TYPE_NAME</a></code> | <code>string</code> | The CloudFormation resource type name for this resource class. |

---

##### `CFN_RESOURCE_TYPE_NAME`<sup>Required</sup> <a name="CFN_RESOURCE_TYPE_NAME" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulation.property.CFN_RESOURCE_TYPE_NAME"></a>

```typescript
public readonly CFN_RESOURCE_TYPE_NAME: string;
```

- *Type:* string

The CloudFormation resource type name for this resource class.

---

### CfnCustomDbRole <a name="CfnCustomDbRole" id="awscdk-resources-mongodbatlas.CfnCustomDbRole"></a>

A CloudFormation `MongoDB::Atlas::CustomDBRole`.

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.Initializer"></a>

```typescript
import { CfnCustomDbRole } from 'awscdk-resources-mongodbatlas'

new CfnCustomDbRole(scope: Construct, id: string, props: CfnCustomDbRoleProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDbRole.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - scope in which this resource is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDbRole.Initializer.parameter.id">id</a></code> | <code>string</code> | - scoped id of the resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDbRole.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDbRoleProps">CfnCustomDbRoleProps</a></code> | - resource properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

scope in which this resource is defined.

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.Initializer.parameter.id"></a>

- *Type:* string

scoped id of the resource.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnCustomDbRoleProps">CfnCustomDbRoleProps</a>

resource properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDbRole.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDbRole.overrideLogicalId">overrideLogicalId</a></code> | Overrides the auto-generated logical ID with a specific ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDbRole.addDeletionOverride">addDeletionOverride</a></code> | Syntactic sugar for `addOverride(path, undefined)`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDbRole.addDependency">addDependency</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDbRole.addDependsOn">addDependsOn</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDbRole.addMetadata">addMetadata</a></code> | Add a value to the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDbRole.addOverride">addOverride</a></code> | Adds an override to the synthesized CloudFormation resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDbRole.addPropertyDeletionOverride">addPropertyDeletionOverride</a></code> | Adds an override that deletes the value of a property from the resource definition. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDbRole.addPropertyOverride">addPropertyOverride</a></code> | Adds an override to a resource property. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDbRole.applyRemovalPolicy">applyRemovalPolicy</a></code> | Sets the deletion policy of the resource based on the removal policy specified. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDbRole.getAtt">getAtt</a></code> | Returns a token for an runtime attribute of this resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDbRole.getMetadata">getMetadata</a></code> | Retrieve a value value from the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDbRole.obtainDependencies">obtainDependencies</a></code> | Retrieves an array of resources this resource depends on. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDbRole.obtainResourceDependencies">obtainResourceDependencies</a></code> | Get a shallow copy of dependencies between this resource and other resources in the same stack. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDbRole.removeDependency">removeDependency</a></code> | Indicates that this resource no longer depends on another resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDbRole.replaceDependency">replaceDependency</a></code> | Replaces one dependency with another. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `overrideLogicalId` <a name="overrideLogicalId" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.overrideLogicalId"></a>

```typescript
public overrideLogicalId(newLogicalId: string): void
```

Overrides the auto-generated logical ID with a specific ID.

###### `newLogicalId`<sup>Required</sup> <a name="newLogicalId" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.overrideLogicalId.parameter.newLogicalId"></a>

- *Type:* string

The new logical ID to use for this stack element.

---

##### `addDeletionOverride` <a name="addDeletionOverride" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.addDeletionOverride"></a>

```typescript
public addDeletionOverride(path: string): void
```

Syntactic sugar for `addOverride(path, undefined)`.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.addDeletionOverride.parameter.path"></a>

- *Type:* string

The path of the value to delete.

---

##### `addDependency` <a name="addDependency" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.addDependency"></a>

```typescript
public addDependency(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

This can be used for resources across stacks (or nested stack) boundaries
and the dependency will automatically be transferred to the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.addDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### ~~`addDependsOn`~~ <a name="addDependsOn" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.addDependsOn"></a>

```typescript
public addDependsOn(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.addDependsOn.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `addMetadata` <a name="addMetadata" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.addMetadata"></a>

```typescript
public addMetadata(key: string, value: any): void
```

Add a value to the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.addMetadata.parameter.key"></a>

- *Type:* string

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.addMetadata.parameter.value"></a>

- *Type:* any

---

##### `addOverride` <a name="addOverride" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.addOverride"></a>

```typescript
public addOverride(path: string, value: any): void
```

Adds an override to the synthesized CloudFormation resource.

To add a
property override, either use `addPropertyOverride` or prefix `path` with
"Properties." (i.e. `Properties.TopicName`).

If the override is nested, separate each nested level using a dot (.) in the path parameter.
If there is an array as part of the nesting, specify the index in the path.

To include a literal `.` in the property name, prefix with a `\`. In most
programming languages you will need to write this as `"\\."` because the
`\` itself will need to be escaped.

For example,
```typescript
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
```
would add the overrides
```json
"Properties": {
  "GlobalSecondaryIndexes": [
    {
      "Projection": {
        "NonKeyAttributes": [ "myattribute" ]
        ...
      }
      ...
    },
    {
      "ProjectionType": "INCLUDE"
      ...
    },
  ]
  ...
}
```

The `value` argument to `addOverride` will not be processed or translated
in any way. Pass raw JSON values in here with the correct capitalization
for CloudFormation. If you pass CDK classes or structs, they will be
rendered with lowercased key names, and CloudFormation will reject the
template.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.addOverride.parameter.path"></a>

- *Type:* string

The path of the property, you can use dot notation to override values in complex types.

Any intermediate keys
will be created as needed.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.addOverride.parameter.value"></a>

- *Type:* any

The value.

Could be primitive or complex.

---

##### `addPropertyDeletionOverride` <a name="addPropertyDeletionOverride" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.addPropertyDeletionOverride"></a>

```typescript
public addPropertyDeletionOverride(propertyPath: string): void
```

Adds an override that deletes the value of a property from the resource definition.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.addPropertyDeletionOverride.parameter.propertyPath"></a>

- *Type:* string

The path to the property.

---

##### `addPropertyOverride` <a name="addPropertyOverride" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.addPropertyOverride"></a>

```typescript
public addPropertyOverride(propertyPath: string, value: any): void
```

Adds an override to a resource property.

Syntactic sugar for `addOverride("Properties.<...>", value)`.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.addPropertyOverride.parameter.propertyPath"></a>

- *Type:* string

The path of the property.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.addPropertyOverride.parameter.value"></a>

- *Type:* any

The value.

---

##### `applyRemovalPolicy` <a name="applyRemovalPolicy" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.applyRemovalPolicy"></a>

```typescript
public applyRemovalPolicy(policy?: RemovalPolicy, options?: RemovalPolicyOptions): void
```

Sets the deletion policy of the resource based on the removal policy specified.

The Removal Policy controls what happens to this resource when it stops
being managed by CloudFormation, either because you've removed it from the
CDK application or because you've made a change that requires the resource
to be replaced.

The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
cases, a snapshot can be taken of the resource prior to deletion
(`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
can be found in the following link:

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options)

###### `policy`<sup>Optional</sup> <a name="policy" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.applyRemovalPolicy.parameter.policy"></a>

- *Type:* aws-cdk-lib.RemovalPolicy

---

###### `options`<sup>Optional</sup> <a name="options" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.applyRemovalPolicy.parameter.options"></a>

- *Type:* aws-cdk-lib.RemovalPolicyOptions

---

##### `getAtt` <a name="getAtt" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.getAtt"></a>

```typescript
public getAtt(attributeName: string, typeHint?: ResolutionTypeHint): Reference
```

Returns a token for an runtime attribute of this resource.

Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
in case there is no generated attribute.

###### `attributeName`<sup>Required</sup> <a name="attributeName" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.getAtt.parameter.attributeName"></a>

- *Type:* string

The name of the attribute.

---

###### `typeHint`<sup>Optional</sup> <a name="typeHint" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.getAtt.parameter.typeHint"></a>

- *Type:* aws-cdk-lib.ResolutionTypeHint

---

##### `getMetadata` <a name="getMetadata" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.getMetadata"></a>

```typescript
public getMetadata(key: string): any
```

Retrieve a value value from the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.getMetadata.parameter.key"></a>

- *Type:* string

---

##### `obtainDependencies` <a name="obtainDependencies" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.obtainDependencies"></a>

```typescript
public obtainDependencies(): Stack | CfnResource[]
```

Retrieves an array of resources this resource depends on.

This assembles dependencies on resources across stacks (including nested stacks)
automatically.

##### `obtainResourceDependencies` <a name="obtainResourceDependencies" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.obtainResourceDependencies"></a>

```typescript
public obtainResourceDependencies(): CfnResource[]
```

Get a shallow copy of dependencies between this resource and other resources in the same stack.

##### `removeDependency` <a name="removeDependency" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.removeDependency"></a>

```typescript
public removeDependency(target: CfnResource): void
```

Indicates that this resource no longer depends on another resource.

This can be used for resources across stacks (including nested stacks)
and the dependency will automatically be removed from the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.removeDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `replaceDependency` <a name="replaceDependency" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.replaceDependency"></a>

```typescript
public replaceDependency(target: CfnResource, newTarget: CfnResource): void
```

Replaces one dependency with another.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.replaceDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

The dependency to replace.

---

###### `newTarget`<sup>Required</sup> <a name="newTarget" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.replaceDependency.parameter.newTarget"></a>

- *Type:* aws-cdk-lib.CfnResource

The new dependency to add.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDbRole.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDbRole.isCfnElement">isCfnElement</a></code> | Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDbRole.isCfnResource">isCfnResource</a></code> | Check whether the given construct is a CfnResource. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.isConstruct"></a>

```typescript
import { CfnCustomDbRole } from 'awscdk-resources-mongodbatlas'

CfnCustomDbRole.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `isCfnElement` <a name="isCfnElement" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.isCfnElement"></a>

```typescript
import { CfnCustomDbRole } from 'awscdk-resources-mongodbatlas'

CfnCustomDbRole.isCfnElement(x: any)
```

Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).

Uses duck-typing instead of `instanceof` to allow stack elements from different
versions of this library to be included in the same stack.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.isCfnElement.parameter.x"></a>

- *Type:* any

---

##### `isCfnResource` <a name="isCfnResource" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.isCfnResource"></a>

```typescript
import { CfnCustomDbRole } from 'awscdk-resources-mongodbatlas'

CfnCustomDbRole.isCfnResource(construct: IConstruct)
```

Check whether the given construct is a CfnResource.

###### `construct`<sup>Required</sup> <a name="construct" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.isCfnResource.parameter.construct"></a>

- *Type:* constructs.IConstruct

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDbRole.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDbRole.property.creationStack">creationStack</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDbRole.property.logicalId">logicalId</a></code> | <code>string</code> | The logical ID for this CloudFormation stack element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDbRole.property.stack">stack</a></code> | <code>aws-cdk-lib.Stack</code> | The stack in which this element is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDbRole.property.ref">ref</a></code> | <code>string</code> | Return a string that will be resolved to a CloudFormation `{ Ref }` for this element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDbRole.property.cfnOptions">cfnOptions</a></code> | <code>aws-cdk-lib.ICfnResourceOptions</code> | Options for this resource, such as condition, update policy etc. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDbRole.property.cfnResourceType">cfnResourceType</a></code> | <code>string</code> | AWS resource type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDbRole.property.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDbRoleProps">CfnCustomDbRoleProps</a></code> | Resource props. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `creationStack`<sup>Required</sup> <a name="creationStack" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.property.creationStack"></a>

```typescript
public readonly creationStack: string[];
```

- *Type:* string[]

---

##### `logicalId`<sup>Required</sup> <a name="logicalId" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.property.logicalId"></a>

```typescript
public readonly logicalId: string;
```

- *Type:* string

The logical ID for this CloudFormation stack element.

The logical ID of the element
is calculated from the path of the resource node in the construct tree.

To override this value, use `overrideLogicalId(newLogicalId)`.

---

##### `stack`<sup>Required</sup> <a name="stack" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.property.stack"></a>

```typescript
public readonly stack: Stack;
```

- *Type:* aws-cdk-lib.Stack

The stack in which this element is defined.

CfnElements must be defined within a stack scope (directly or indirectly).

---

##### `ref`<sup>Required</sup> <a name="ref" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.

If, by any chance, the intrinsic reference of a resource is not a string, you could
coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.

---

##### `cfnOptions`<sup>Required</sup> <a name="cfnOptions" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.property.cfnOptions"></a>

```typescript
public readonly cfnOptions: ICfnResourceOptions;
```

- *Type:* aws-cdk-lib.ICfnResourceOptions

Options for this resource, such as condition, update policy etc.

---

##### `cfnResourceType`<sup>Required</sup> <a name="cfnResourceType" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.property.cfnResourceType"></a>

```typescript
public readonly cfnResourceType: string;
```

- *Type:* string

AWS resource type.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.property.props"></a>

```typescript
public readonly props: CfnCustomDbRoleProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnCustomDbRoleProps">CfnCustomDbRoleProps</a>

Resource props.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDbRole.property.CFN_RESOURCE_TYPE_NAME">CFN_RESOURCE_TYPE_NAME</a></code> | <code>string</code> | The CloudFormation resource type name for this resource class. |

---

##### `CFN_RESOURCE_TYPE_NAME`<sup>Required</sup> <a name="CFN_RESOURCE_TYPE_NAME" id="awscdk-resources-mongodbatlas.CfnCustomDbRole.property.CFN_RESOURCE_TYPE_NAME"></a>

```typescript
public readonly CFN_RESOURCE_TYPE_NAME: string;
```

- *Type:* string

The CloudFormation resource type name for this resource class.

---

### CfnCustomDnsConfigurationClusterAws <a name="CfnCustomDnsConfigurationClusterAws" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws"></a>

A CloudFormation `MongoDB::Atlas::CustomDnsConfigurationClusterAws`.

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.Initializer"></a>

```typescript
import { CfnCustomDnsConfigurationClusterAws } from 'awscdk-resources-mongodbatlas'

new CfnCustomDnsConfigurationClusterAws(scope: Construct, id: string, props: CfnCustomDnsConfigurationClusterAwsProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - scope in which this resource is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.Initializer.parameter.id">id</a></code> | <code>string</code> | - scoped id of the resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAwsProps">CfnCustomDnsConfigurationClusterAwsProps</a></code> | - resource properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

scope in which this resource is defined.

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.Initializer.parameter.id"></a>

- *Type:* string

scoped id of the resource.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAwsProps">CfnCustomDnsConfigurationClusterAwsProps</a>

resource properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.overrideLogicalId">overrideLogicalId</a></code> | Overrides the auto-generated logical ID with a specific ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.addDeletionOverride">addDeletionOverride</a></code> | Syntactic sugar for `addOverride(path, undefined)`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.addDependency">addDependency</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.addDependsOn">addDependsOn</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.addMetadata">addMetadata</a></code> | Add a value to the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.addOverride">addOverride</a></code> | Adds an override to the synthesized CloudFormation resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.addPropertyDeletionOverride">addPropertyDeletionOverride</a></code> | Adds an override that deletes the value of a property from the resource definition. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.addPropertyOverride">addPropertyOverride</a></code> | Adds an override to a resource property. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.applyRemovalPolicy">applyRemovalPolicy</a></code> | Sets the deletion policy of the resource based on the removal policy specified. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.getAtt">getAtt</a></code> | Returns a token for an runtime attribute of this resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.getMetadata">getMetadata</a></code> | Retrieve a value value from the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.obtainDependencies">obtainDependencies</a></code> | Retrieves an array of resources this resource depends on. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.obtainResourceDependencies">obtainResourceDependencies</a></code> | Get a shallow copy of dependencies between this resource and other resources in the same stack. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.removeDependency">removeDependency</a></code> | Indicates that this resource no longer depends on another resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.replaceDependency">replaceDependency</a></code> | Replaces one dependency with another. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `overrideLogicalId` <a name="overrideLogicalId" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.overrideLogicalId"></a>

```typescript
public overrideLogicalId(newLogicalId: string): void
```

Overrides the auto-generated logical ID with a specific ID.

###### `newLogicalId`<sup>Required</sup> <a name="newLogicalId" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.overrideLogicalId.parameter.newLogicalId"></a>

- *Type:* string

The new logical ID to use for this stack element.

---

##### `addDeletionOverride` <a name="addDeletionOverride" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.addDeletionOverride"></a>

```typescript
public addDeletionOverride(path: string): void
```

Syntactic sugar for `addOverride(path, undefined)`.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.addDeletionOverride.parameter.path"></a>

- *Type:* string

The path of the value to delete.

---

##### `addDependency` <a name="addDependency" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.addDependency"></a>

```typescript
public addDependency(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

This can be used for resources across stacks (or nested stack) boundaries
and the dependency will automatically be transferred to the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.addDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### ~~`addDependsOn`~~ <a name="addDependsOn" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.addDependsOn"></a>

```typescript
public addDependsOn(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.addDependsOn.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `addMetadata` <a name="addMetadata" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.addMetadata"></a>

```typescript
public addMetadata(key: string, value: any): void
```

Add a value to the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.addMetadata.parameter.key"></a>

- *Type:* string

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.addMetadata.parameter.value"></a>

- *Type:* any

---

##### `addOverride` <a name="addOverride" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.addOverride"></a>

```typescript
public addOverride(path: string, value: any): void
```

Adds an override to the synthesized CloudFormation resource.

To add a
property override, either use `addPropertyOverride` or prefix `path` with
"Properties." (i.e. `Properties.TopicName`).

If the override is nested, separate each nested level using a dot (.) in the path parameter.
If there is an array as part of the nesting, specify the index in the path.

To include a literal `.` in the property name, prefix with a `\`. In most
programming languages you will need to write this as `"\\."` because the
`\` itself will need to be escaped.

For example,
```typescript
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
```
would add the overrides
```json
"Properties": {
  "GlobalSecondaryIndexes": [
    {
      "Projection": {
        "NonKeyAttributes": [ "myattribute" ]
        ...
      }
      ...
    },
    {
      "ProjectionType": "INCLUDE"
      ...
    },
  ]
  ...
}
```

The `value` argument to `addOverride` will not be processed or translated
in any way. Pass raw JSON values in here with the correct capitalization
for CloudFormation. If you pass CDK classes or structs, they will be
rendered with lowercased key names, and CloudFormation will reject the
template.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.addOverride.parameter.path"></a>

- *Type:* string

The path of the property, you can use dot notation to override values in complex types.

Any intermediate keys
will be created as needed.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.addOverride.parameter.value"></a>

- *Type:* any

The value.

Could be primitive or complex.

---

##### `addPropertyDeletionOverride` <a name="addPropertyDeletionOverride" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.addPropertyDeletionOverride"></a>

```typescript
public addPropertyDeletionOverride(propertyPath: string): void
```

Adds an override that deletes the value of a property from the resource definition.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.addPropertyDeletionOverride.parameter.propertyPath"></a>

- *Type:* string

The path to the property.

---

##### `addPropertyOverride` <a name="addPropertyOverride" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.addPropertyOverride"></a>

```typescript
public addPropertyOverride(propertyPath: string, value: any): void
```

Adds an override to a resource property.

Syntactic sugar for `addOverride("Properties.<...>", value)`.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.addPropertyOverride.parameter.propertyPath"></a>

- *Type:* string

The path of the property.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.addPropertyOverride.parameter.value"></a>

- *Type:* any

The value.

---

##### `applyRemovalPolicy` <a name="applyRemovalPolicy" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.applyRemovalPolicy"></a>

```typescript
public applyRemovalPolicy(policy?: RemovalPolicy, options?: RemovalPolicyOptions): void
```

Sets the deletion policy of the resource based on the removal policy specified.

The Removal Policy controls what happens to this resource when it stops
being managed by CloudFormation, either because you've removed it from the
CDK application or because you've made a change that requires the resource
to be replaced.

The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
cases, a snapshot can be taken of the resource prior to deletion
(`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
can be found in the following link:

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options)

###### `policy`<sup>Optional</sup> <a name="policy" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.applyRemovalPolicy.parameter.policy"></a>

- *Type:* aws-cdk-lib.RemovalPolicy

---

###### `options`<sup>Optional</sup> <a name="options" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.applyRemovalPolicy.parameter.options"></a>

- *Type:* aws-cdk-lib.RemovalPolicyOptions

---

##### `getAtt` <a name="getAtt" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.getAtt"></a>

```typescript
public getAtt(attributeName: string, typeHint?: ResolutionTypeHint): Reference
```

Returns a token for an runtime attribute of this resource.

Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
in case there is no generated attribute.

###### `attributeName`<sup>Required</sup> <a name="attributeName" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.getAtt.parameter.attributeName"></a>

- *Type:* string

The name of the attribute.

---

###### `typeHint`<sup>Optional</sup> <a name="typeHint" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.getAtt.parameter.typeHint"></a>

- *Type:* aws-cdk-lib.ResolutionTypeHint

---

##### `getMetadata` <a name="getMetadata" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.getMetadata"></a>

```typescript
public getMetadata(key: string): any
```

Retrieve a value value from the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.getMetadata.parameter.key"></a>

- *Type:* string

---

##### `obtainDependencies` <a name="obtainDependencies" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.obtainDependencies"></a>

```typescript
public obtainDependencies(): Stack | CfnResource[]
```

Retrieves an array of resources this resource depends on.

This assembles dependencies on resources across stacks (including nested stacks)
automatically.

##### `obtainResourceDependencies` <a name="obtainResourceDependencies" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.obtainResourceDependencies"></a>

```typescript
public obtainResourceDependencies(): CfnResource[]
```

Get a shallow copy of dependencies between this resource and other resources in the same stack.

##### `removeDependency` <a name="removeDependency" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.removeDependency"></a>

```typescript
public removeDependency(target: CfnResource): void
```

Indicates that this resource no longer depends on another resource.

This can be used for resources across stacks (including nested stacks)
and the dependency will automatically be removed from the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.removeDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `replaceDependency` <a name="replaceDependency" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.replaceDependency"></a>

```typescript
public replaceDependency(target: CfnResource, newTarget: CfnResource): void
```

Replaces one dependency with another.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.replaceDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

The dependency to replace.

---

###### `newTarget`<sup>Required</sup> <a name="newTarget" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.replaceDependency.parameter.newTarget"></a>

- *Type:* aws-cdk-lib.CfnResource

The new dependency to add.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.isCfnElement">isCfnElement</a></code> | Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.isCfnResource">isCfnResource</a></code> | Check whether the given construct is a CfnResource. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.isConstruct"></a>

```typescript
import { CfnCustomDnsConfigurationClusterAws } from 'awscdk-resources-mongodbatlas'

CfnCustomDnsConfigurationClusterAws.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `isCfnElement` <a name="isCfnElement" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.isCfnElement"></a>

```typescript
import { CfnCustomDnsConfigurationClusterAws } from 'awscdk-resources-mongodbatlas'

CfnCustomDnsConfigurationClusterAws.isCfnElement(x: any)
```

Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).

Uses duck-typing instead of `instanceof` to allow stack elements from different
versions of this library to be included in the same stack.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.isCfnElement.parameter.x"></a>

- *Type:* any

---

##### `isCfnResource` <a name="isCfnResource" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.isCfnResource"></a>

```typescript
import { CfnCustomDnsConfigurationClusterAws } from 'awscdk-resources-mongodbatlas'

CfnCustomDnsConfigurationClusterAws.isCfnResource(construct: IConstruct)
```

Check whether the given construct is a CfnResource.

###### `construct`<sup>Required</sup> <a name="construct" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.isCfnResource.parameter.construct"></a>

- *Type:* constructs.IConstruct

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.property.creationStack">creationStack</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.property.logicalId">logicalId</a></code> | <code>string</code> | The logical ID for this CloudFormation stack element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.property.stack">stack</a></code> | <code>aws-cdk-lib.Stack</code> | The stack in which this element is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.property.ref">ref</a></code> | <code>string</code> | Return a string that will be resolved to a CloudFormation `{ Ref }` for this element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.property.cfnOptions">cfnOptions</a></code> | <code>aws-cdk-lib.ICfnResourceOptions</code> | Options for this resource, such as condition, update policy etc. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.property.cfnResourceType">cfnResourceType</a></code> | <code>string</code> | AWS resource type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.property.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAwsProps">CfnCustomDnsConfigurationClusterAwsProps</a></code> | Resource props. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `creationStack`<sup>Required</sup> <a name="creationStack" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.property.creationStack"></a>

```typescript
public readonly creationStack: string[];
```

- *Type:* string[]

---

##### `logicalId`<sup>Required</sup> <a name="logicalId" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.property.logicalId"></a>

```typescript
public readonly logicalId: string;
```

- *Type:* string

The logical ID for this CloudFormation stack element.

The logical ID of the element
is calculated from the path of the resource node in the construct tree.

To override this value, use `overrideLogicalId(newLogicalId)`.

---

##### `stack`<sup>Required</sup> <a name="stack" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.property.stack"></a>

```typescript
public readonly stack: Stack;
```

- *Type:* aws-cdk-lib.Stack

The stack in which this element is defined.

CfnElements must be defined within a stack scope (directly or indirectly).

---

##### `ref`<sup>Required</sup> <a name="ref" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.

If, by any chance, the intrinsic reference of a resource is not a string, you could
coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.

---

##### `cfnOptions`<sup>Required</sup> <a name="cfnOptions" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.property.cfnOptions"></a>

```typescript
public readonly cfnOptions: ICfnResourceOptions;
```

- *Type:* aws-cdk-lib.ICfnResourceOptions

Options for this resource, such as condition, update policy etc.

---

##### `cfnResourceType`<sup>Required</sup> <a name="cfnResourceType" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.property.cfnResourceType"></a>

```typescript
public readonly cfnResourceType: string;
```

- *Type:* string

AWS resource type.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.property.props"></a>

```typescript
public readonly props: CfnCustomDnsConfigurationClusterAwsProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAwsProps">CfnCustomDnsConfigurationClusterAwsProps</a>

Resource props.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.property.CFN_RESOURCE_TYPE_NAME">CFN_RESOURCE_TYPE_NAME</a></code> | <code>string</code> | The CloudFormation resource type name for this resource class. |

---

##### `CFN_RESOURCE_TYPE_NAME`<sup>Required</sup> <a name="CFN_RESOURCE_TYPE_NAME" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAws.property.CFN_RESOURCE_TYPE_NAME"></a>

```typescript
public readonly CFN_RESOURCE_TYPE_NAME: string;
```

- *Type:* string

The CloudFormation resource type name for this resource class.

---

### CfnDatabaseUser <a name="CfnDatabaseUser" id="awscdk-resources-mongodbatlas.CfnDatabaseUser"></a>

A CloudFormation `MongoDB::Atlas::DatabaseUser`.

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.Initializer"></a>

```typescript
import { CfnDatabaseUser } from 'awscdk-resources-mongodbatlas'

new CfnDatabaseUser(scope: Construct, id: string, props: CfnDatabaseUserProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUser.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - scope in which this resource is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUser.Initializer.parameter.id">id</a></code> | <code>string</code> | - scoped id of the resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUser.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUserProps">CfnDatabaseUserProps</a></code> | - resource properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

scope in which this resource is defined.

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.Initializer.parameter.id"></a>

- *Type:* string

scoped id of the resource.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnDatabaseUserProps">CfnDatabaseUserProps</a>

resource properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUser.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUser.overrideLogicalId">overrideLogicalId</a></code> | Overrides the auto-generated logical ID with a specific ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUser.addDeletionOverride">addDeletionOverride</a></code> | Syntactic sugar for `addOverride(path, undefined)`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUser.addDependency">addDependency</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUser.addDependsOn">addDependsOn</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUser.addMetadata">addMetadata</a></code> | Add a value to the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUser.addOverride">addOverride</a></code> | Adds an override to the synthesized CloudFormation resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUser.addPropertyDeletionOverride">addPropertyDeletionOverride</a></code> | Adds an override that deletes the value of a property from the resource definition. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUser.addPropertyOverride">addPropertyOverride</a></code> | Adds an override to a resource property. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUser.applyRemovalPolicy">applyRemovalPolicy</a></code> | Sets the deletion policy of the resource based on the removal policy specified. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUser.getAtt">getAtt</a></code> | Returns a token for an runtime attribute of this resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUser.getMetadata">getMetadata</a></code> | Retrieve a value value from the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUser.obtainDependencies">obtainDependencies</a></code> | Retrieves an array of resources this resource depends on. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUser.obtainResourceDependencies">obtainResourceDependencies</a></code> | Get a shallow copy of dependencies between this resource and other resources in the same stack. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUser.removeDependency">removeDependency</a></code> | Indicates that this resource no longer depends on another resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUser.replaceDependency">replaceDependency</a></code> | Replaces one dependency with another. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `overrideLogicalId` <a name="overrideLogicalId" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.overrideLogicalId"></a>

```typescript
public overrideLogicalId(newLogicalId: string): void
```

Overrides the auto-generated logical ID with a specific ID.

###### `newLogicalId`<sup>Required</sup> <a name="newLogicalId" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.overrideLogicalId.parameter.newLogicalId"></a>

- *Type:* string

The new logical ID to use for this stack element.

---

##### `addDeletionOverride` <a name="addDeletionOverride" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.addDeletionOverride"></a>

```typescript
public addDeletionOverride(path: string): void
```

Syntactic sugar for `addOverride(path, undefined)`.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.addDeletionOverride.parameter.path"></a>

- *Type:* string

The path of the value to delete.

---

##### `addDependency` <a name="addDependency" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.addDependency"></a>

```typescript
public addDependency(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

This can be used for resources across stacks (or nested stack) boundaries
and the dependency will automatically be transferred to the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.addDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### ~~`addDependsOn`~~ <a name="addDependsOn" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.addDependsOn"></a>

```typescript
public addDependsOn(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.addDependsOn.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `addMetadata` <a name="addMetadata" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.addMetadata"></a>

```typescript
public addMetadata(key: string, value: any): void
```

Add a value to the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.addMetadata.parameter.key"></a>

- *Type:* string

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.addMetadata.parameter.value"></a>

- *Type:* any

---

##### `addOverride` <a name="addOverride" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.addOverride"></a>

```typescript
public addOverride(path: string, value: any): void
```

Adds an override to the synthesized CloudFormation resource.

To add a
property override, either use `addPropertyOverride` or prefix `path` with
"Properties." (i.e. `Properties.TopicName`).

If the override is nested, separate each nested level using a dot (.) in the path parameter.
If there is an array as part of the nesting, specify the index in the path.

To include a literal `.` in the property name, prefix with a `\`. In most
programming languages you will need to write this as `"\\."` because the
`\` itself will need to be escaped.

For example,
```typescript
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
```
would add the overrides
```json
"Properties": {
  "GlobalSecondaryIndexes": [
    {
      "Projection": {
        "NonKeyAttributes": [ "myattribute" ]
        ...
      }
      ...
    },
    {
      "ProjectionType": "INCLUDE"
      ...
    },
  ]
  ...
}
```

The `value` argument to `addOverride` will not be processed or translated
in any way. Pass raw JSON values in here with the correct capitalization
for CloudFormation. If you pass CDK classes or structs, they will be
rendered with lowercased key names, and CloudFormation will reject the
template.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.addOverride.parameter.path"></a>

- *Type:* string

The path of the property, you can use dot notation to override values in complex types.

Any intermediate keys
will be created as needed.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.addOverride.parameter.value"></a>

- *Type:* any

The value.

Could be primitive or complex.

---

##### `addPropertyDeletionOverride` <a name="addPropertyDeletionOverride" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.addPropertyDeletionOverride"></a>

```typescript
public addPropertyDeletionOverride(propertyPath: string): void
```

Adds an override that deletes the value of a property from the resource definition.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.addPropertyDeletionOverride.parameter.propertyPath"></a>

- *Type:* string

The path to the property.

---

##### `addPropertyOverride` <a name="addPropertyOverride" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.addPropertyOverride"></a>

```typescript
public addPropertyOverride(propertyPath: string, value: any): void
```

Adds an override to a resource property.

Syntactic sugar for `addOverride("Properties.<...>", value)`.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.addPropertyOverride.parameter.propertyPath"></a>

- *Type:* string

The path of the property.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.addPropertyOverride.parameter.value"></a>

- *Type:* any

The value.

---

##### `applyRemovalPolicy` <a name="applyRemovalPolicy" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.applyRemovalPolicy"></a>

```typescript
public applyRemovalPolicy(policy?: RemovalPolicy, options?: RemovalPolicyOptions): void
```

Sets the deletion policy of the resource based on the removal policy specified.

The Removal Policy controls what happens to this resource when it stops
being managed by CloudFormation, either because you've removed it from the
CDK application or because you've made a change that requires the resource
to be replaced.

The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
cases, a snapshot can be taken of the resource prior to deletion
(`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
can be found in the following link:

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options)

###### `policy`<sup>Optional</sup> <a name="policy" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.applyRemovalPolicy.parameter.policy"></a>

- *Type:* aws-cdk-lib.RemovalPolicy

---

###### `options`<sup>Optional</sup> <a name="options" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.applyRemovalPolicy.parameter.options"></a>

- *Type:* aws-cdk-lib.RemovalPolicyOptions

---

##### `getAtt` <a name="getAtt" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.getAtt"></a>

```typescript
public getAtt(attributeName: string, typeHint?: ResolutionTypeHint): Reference
```

Returns a token for an runtime attribute of this resource.

Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
in case there is no generated attribute.

###### `attributeName`<sup>Required</sup> <a name="attributeName" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.getAtt.parameter.attributeName"></a>

- *Type:* string

The name of the attribute.

---

###### `typeHint`<sup>Optional</sup> <a name="typeHint" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.getAtt.parameter.typeHint"></a>

- *Type:* aws-cdk-lib.ResolutionTypeHint

---

##### `getMetadata` <a name="getMetadata" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.getMetadata"></a>

```typescript
public getMetadata(key: string): any
```

Retrieve a value value from the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.getMetadata.parameter.key"></a>

- *Type:* string

---

##### `obtainDependencies` <a name="obtainDependencies" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.obtainDependencies"></a>

```typescript
public obtainDependencies(): Stack | CfnResource[]
```

Retrieves an array of resources this resource depends on.

This assembles dependencies on resources across stacks (including nested stacks)
automatically.

##### `obtainResourceDependencies` <a name="obtainResourceDependencies" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.obtainResourceDependencies"></a>

```typescript
public obtainResourceDependencies(): CfnResource[]
```

Get a shallow copy of dependencies between this resource and other resources in the same stack.

##### `removeDependency` <a name="removeDependency" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.removeDependency"></a>

```typescript
public removeDependency(target: CfnResource): void
```

Indicates that this resource no longer depends on another resource.

This can be used for resources across stacks (including nested stacks)
and the dependency will automatically be removed from the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.removeDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `replaceDependency` <a name="replaceDependency" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.replaceDependency"></a>

```typescript
public replaceDependency(target: CfnResource, newTarget: CfnResource): void
```

Replaces one dependency with another.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.replaceDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

The dependency to replace.

---

###### `newTarget`<sup>Required</sup> <a name="newTarget" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.replaceDependency.parameter.newTarget"></a>

- *Type:* aws-cdk-lib.CfnResource

The new dependency to add.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUser.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUser.isCfnElement">isCfnElement</a></code> | Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUser.isCfnResource">isCfnResource</a></code> | Check whether the given construct is a CfnResource. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.isConstruct"></a>

```typescript
import { CfnDatabaseUser } from 'awscdk-resources-mongodbatlas'

CfnDatabaseUser.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `isCfnElement` <a name="isCfnElement" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.isCfnElement"></a>

```typescript
import { CfnDatabaseUser } from 'awscdk-resources-mongodbatlas'

CfnDatabaseUser.isCfnElement(x: any)
```

Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).

Uses duck-typing instead of `instanceof` to allow stack elements from different
versions of this library to be included in the same stack.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.isCfnElement.parameter.x"></a>

- *Type:* any

---

##### `isCfnResource` <a name="isCfnResource" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.isCfnResource"></a>

```typescript
import { CfnDatabaseUser } from 'awscdk-resources-mongodbatlas'

CfnDatabaseUser.isCfnResource(construct: IConstruct)
```

Check whether the given construct is a CfnResource.

###### `construct`<sup>Required</sup> <a name="construct" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.isCfnResource.parameter.construct"></a>

- *Type:* constructs.IConstruct

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUser.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUser.property.creationStack">creationStack</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUser.property.logicalId">logicalId</a></code> | <code>string</code> | The logical ID for this CloudFormation stack element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUser.property.stack">stack</a></code> | <code>aws-cdk-lib.Stack</code> | The stack in which this element is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUser.property.ref">ref</a></code> | <code>string</code> | Return a string that will be resolved to a CloudFormation `{ Ref }` for this element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUser.property.cfnOptions">cfnOptions</a></code> | <code>aws-cdk-lib.ICfnResourceOptions</code> | Options for this resource, such as condition, update policy etc. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUser.property.cfnResourceType">cfnResourceType</a></code> | <code>string</code> | AWS resource type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUser.property.attrUserCFNIdentifier">attrUserCFNIdentifier</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::DatabaseUser.UserCFNIdentifier`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUser.property.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUserProps">CfnDatabaseUserProps</a></code> | Resource props. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `creationStack`<sup>Required</sup> <a name="creationStack" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.property.creationStack"></a>

```typescript
public readonly creationStack: string[];
```

- *Type:* string[]

---

##### `logicalId`<sup>Required</sup> <a name="logicalId" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.property.logicalId"></a>

```typescript
public readonly logicalId: string;
```

- *Type:* string

The logical ID for this CloudFormation stack element.

The logical ID of the element
is calculated from the path of the resource node in the construct tree.

To override this value, use `overrideLogicalId(newLogicalId)`.

---

##### `stack`<sup>Required</sup> <a name="stack" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.property.stack"></a>

```typescript
public readonly stack: Stack;
```

- *Type:* aws-cdk-lib.Stack

The stack in which this element is defined.

CfnElements must be defined within a stack scope (directly or indirectly).

---

##### `ref`<sup>Required</sup> <a name="ref" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.

If, by any chance, the intrinsic reference of a resource is not a string, you could
coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.

---

##### `cfnOptions`<sup>Required</sup> <a name="cfnOptions" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.property.cfnOptions"></a>

```typescript
public readonly cfnOptions: ICfnResourceOptions;
```

- *Type:* aws-cdk-lib.ICfnResourceOptions

Options for this resource, such as condition, update policy etc.

---

##### `cfnResourceType`<sup>Required</sup> <a name="cfnResourceType" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.property.cfnResourceType"></a>

```typescript
public readonly cfnResourceType: string;
```

- *Type:* string

AWS resource type.

---

##### `attrUserCFNIdentifier`<sup>Required</sup> <a name="attrUserCFNIdentifier" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.property.attrUserCFNIdentifier"></a>

```typescript
public readonly attrUserCFNIdentifier: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::DatabaseUser.UserCFNIdentifier`.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.property.props"></a>

```typescript
public readonly props: CfnDatabaseUserProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnDatabaseUserProps">CfnDatabaseUserProps</a>

Resource props.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUser.property.CFN_RESOURCE_TYPE_NAME">CFN_RESOURCE_TYPE_NAME</a></code> | <code>string</code> | The CloudFormation resource type name for this resource class. |

---

##### `CFN_RESOURCE_TYPE_NAME`<sup>Required</sup> <a name="CFN_RESOURCE_TYPE_NAME" id="awscdk-resources-mongodbatlas.CfnDatabaseUser.property.CFN_RESOURCE_TYPE_NAME"></a>

```typescript
public readonly CFN_RESOURCE_TYPE_NAME: string;
```

- *Type:* string

The CloudFormation resource type name for this resource class.

---

### CfnDataLakePipeline <a name="CfnDataLakePipeline" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline"></a>

A CloudFormation `MongoDB::Atlas::DataLakePipeline`.

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.Initializer"></a>

```typescript
import { CfnDataLakePipeline } from 'awscdk-resources-mongodbatlas'

new CfnDataLakePipeline(scope: Construct, id: string, props: CfnDataLakePipelineProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakePipeline.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - scope in which this resource is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakePipeline.Initializer.parameter.id">id</a></code> | <code>string</code> | - scoped id of the resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakePipeline.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakePipelineProps">CfnDataLakePipelineProps</a></code> | - resource properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

scope in which this resource is defined.

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.Initializer.parameter.id"></a>

- *Type:* string

scoped id of the resource.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnDataLakePipelineProps">CfnDataLakePipelineProps</a>

resource properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakePipeline.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakePipeline.overrideLogicalId">overrideLogicalId</a></code> | Overrides the auto-generated logical ID with a specific ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakePipeline.addDeletionOverride">addDeletionOverride</a></code> | Syntactic sugar for `addOverride(path, undefined)`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakePipeline.addDependency">addDependency</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakePipeline.addDependsOn">addDependsOn</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakePipeline.addMetadata">addMetadata</a></code> | Add a value to the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakePipeline.addOverride">addOverride</a></code> | Adds an override to the synthesized CloudFormation resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakePipeline.addPropertyDeletionOverride">addPropertyDeletionOverride</a></code> | Adds an override that deletes the value of a property from the resource definition. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakePipeline.addPropertyOverride">addPropertyOverride</a></code> | Adds an override to a resource property. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakePipeline.applyRemovalPolicy">applyRemovalPolicy</a></code> | Sets the deletion policy of the resource based on the removal policy specified. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakePipeline.getAtt">getAtt</a></code> | Returns a token for an runtime attribute of this resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakePipeline.getMetadata">getMetadata</a></code> | Retrieve a value value from the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakePipeline.obtainDependencies">obtainDependencies</a></code> | Retrieves an array of resources this resource depends on. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakePipeline.obtainResourceDependencies">obtainResourceDependencies</a></code> | Get a shallow copy of dependencies between this resource and other resources in the same stack. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakePipeline.removeDependency">removeDependency</a></code> | Indicates that this resource no longer depends on another resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakePipeline.replaceDependency">replaceDependency</a></code> | Replaces one dependency with another. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `overrideLogicalId` <a name="overrideLogicalId" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.overrideLogicalId"></a>

```typescript
public overrideLogicalId(newLogicalId: string): void
```

Overrides the auto-generated logical ID with a specific ID.

###### `newLogicalId`<sup>Required</sup> <a name="newLogicalId" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.overrideLogicalId.parameter.newLogicalId"></a>

- *Type:* string

The new logical ID to use for this stack element.

---

##### `addDeletionOverride` <a name="addDeletionOverride" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.addDeletionOverride"></a>

```typescript
public addDeletionOverride(path: string): void
```

Syntactic sugar for `addOverride(path, undefined)`.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.addDeletionOverride.parameter.path"></a>

- *Type:* string

The path of the value to delete.

---

##### `addDependency` <a name="addDependency" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.addDependency"></a>

```typescript
public addDependency(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

This can be used for resources across stacks (or nested stack) boundaries
and the dependency will automatically be transferred to the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.addDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### ~~`addDependsOn`~~ <a name="addDependsOn" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.addDependsOn"></a>

```typescript
public addDependsOn(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.addDependsOn.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `addMetadata` <a name="addMetadata" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.addMetadata"></a>

```typescript
public addMetadata(key: string, value: any): void
```

Add a value to the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.addMetadata.parameter.key"></a>

- *Type:* string

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.addMetadata.parameter.value"></a>

- *Type:* any

---

##### `addOverride` <a name="addOverride" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.addOverride"></a>

```typescript
public addOverride(path: string, value: any): void
```

Adds an override to the synthesized CloudFormation resource.

To add a
property override, either use `addPropertyOverride` or prefix `path` with
"Properties." (i.e. `Properties.TopicName`).

If the override is nested, separate each nested level using a dot (.) in the path parameter.
If there is an array as part of the nesting, specify the index in the path.

To include a literal `.` in the property name, prefix with a `\`. In most
programming languages you will need to write this as `"\\."` because the
`\` itself will need to be escaped.

For example,
```typescript
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
```
would add the overrides
```json
"Properties": {
  "GlobalSecondaryIndexes": [
    {
      "Projection": {
        "NonKeyAttributes": [ "myattribute" ]
        ...
      }
      ...
    },
    {
      "ProjectionType": "INCLUDE"
      ...
    },
  ]
  ...
}
```

The `value` argument to `addOverride` will not be processed or translated
in any way. Pass raw JSON values in here with the correct capitalization
for CloudFormation. If you pass CDK classes or structs, they will be
rendered with lowercased key names, and CloudFormation will reject the
template.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.addOverride.parameter.path"></a>

- *Type:* string

The path of the property, you can use dot notation to override values in complex types.

Any intermediate keys
will be created as needed.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.addOverride.parameter.value"></a>

- *Type:* any

The value.

Could be primitive or complex.

---

##### `addPropertyDeletionOverride` <a name="addPropertyDeletionOverride" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.addPropertyDeletionOverride"></a>

```typescript
public addPropertyDeletionOverride(propertyPath: string): void
```

Adds an override that deletes the value of a property from the resource definition.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.addPropertyDeletionOverride.parameter.propertyPath"></a>

- *Type:* string

The path to the property.

---

##### `addPropertyOverride` <a name="addPropertyOverride" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.addPropertyOverride"></a>

```typescript
public addPropertyOverride(propertyPath: string, value: any): void
```

Adds an override to a resource property.

Syntactic sugar for `addOverride("Properties.<...>", value)`.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.addPropertyOverride.parameter.propertyPath"></a>

- *Type:* string

The path of the property.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.addPropertyOverride.parameter.value"></a>

- *Type:* any

The value.

---

##### `applyRemovalPolicy` <a name="applyRemovalPolicy" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.applyRemovalPolicy"></a>

```typescript
public applyRemovalPolicy(policy?: RemovalPolicy, options?: RemovalPolicyOptions): void
```

Sets the deletion policy of the resource based on the removal policy specified.

The Removal Policy controls what happens to this resource when it stops
being managed by CloudFormation, either because you've removed it from the
CDK application or because you've made a change that requires the resource
to be replaced.

The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
cases, a snapshot can be taken of the resource prior to deletion
(`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
can be found in the following link:

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options)

###### `policy`<sup>Optional</sup> <a name="policy" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.applyRemovalPolicy.parameter.policy"></a>

- *Type:* aws-cdk-lib.RemovalPolicy

---

###### `options`<sup>Optional</sup> <a name="options" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.applyRemovalPolicy.parameter.options"></a>

- *Type:* aws-cdk-lib.RemovalPolicyOptions

---

##### `getAtt` <a name="getAtt" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.getAtt"></a>

```typescript
public getAtt(attributeName: string, typeHint?: ResolutionTypeHint): Reference
```

Returns a token for an runtime attribute of this resource.

Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
in case there is no generated attribute.

###### `attributeName`<sup>Required</sup> <a name="attributeName" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.getAtt.parameter.attributeName"></a>

- *Type:* string

The name of the attribute.

---

###### `typeHint`<sup>Optional</sup> <a name="typeHint" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.getAtt.parameter.typeHint"></a>

- *Type:* aws-cdk-lib.ResolutionTypeHint

---

##### `getMetadata` <a name="getMetadata" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.getMetadata"></a>

```typescript
public getMetadata(key: string): any
```

Retrieve a value value from the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.getMetadata.parameter.key"></a>

- *Type:* string

---

##### `obtainDependencies` <a name="obtainDependencies" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.obtainDependencies"></a>

```typescript
public obtainDependencies(): Stack | CfnResource[]
```

Retrieves an array of resources this resource depends on.

This assembles dependencies on resources across stacks (including nested stacks)
automatically.

##### `obtainResourceDependencies` <a name="obtainResourceDependencies" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.obtainResourceDependencies"></a>

```typescript
public obtainResourceDependencies(): CfnResource[]
```

Get a shallow copy of dependencies between this resource and other resources in the same stack.

##### `removeDependency` <a name="removeDependency" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.removeDependency"></a>

```typescript
public removeDependency(target: CfnResource): void
```

Indicates that this resource no longer depends on another resource.

This can be used for resources across stacks (including nested stacks)
and the dependency will automatically be removed from the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.removeDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `replaceDependency` <a name="replaceDependency" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.replaceDependency"></a>

```typescript
public replaceDependency(target: CfnResource, newTarget: CfnResource): void
```

Replaces one dependency with another.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.replaceDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

The dependency to replace.

---

###### `newTarget`<sup>Required</sup> <a name="newTarget" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.replaceDependency.parameter.newTarget"></a>

- *Type:* aws-cdk-lib.CfnResource

The new dependency to add.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakePipeline.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakePipeline.isCfnElement">isCfnElement</a></code> | Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakePipeline.isCfnResource">isCfnResource</a></code> | Check whether the given construct is a CfnResource. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.isConstruct"></a>

```typescript
import { CfnDataLakePipeline } from 'awscdk-resources-mongodbatlas'

CfnDataLakePipeline.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `isCfnElement` <a name="isCfnElement" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.isCfnElement"></a>

```typescript
import { CfnDataLakePipeline } from 'awscdk-resources-mongodbatlas'

CfnDataLakePipeline.isCfnElement(x: any)
```

Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).

Uses duck-typing instead of `instanceof` to allow stack elements from different
versions of this library to be included in the same stack.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.isCfnElement.parameter.x"></a>

- *Type:* any

---

##### `isCfnResource` <a name="isCfnResource" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.isCfnResource"></a>

```typescript
import { CfnDataLakePipeline } from 'awscdk-resources-mongodbatlas'

CfnDataLakePipeline.isCfnResource(construct: IConstruct)
```

Check whether the given construct is a CfnResource.

###### `construct`<sup>Required</sup> <a name="construct" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.isCfnResource.parameter.construct"></a>

- *Type:* constructs.IConstruct

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakePipeline.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakePipeline.property.creationStack">creationStack</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakePipeline.property.logicalId">logicalId</a></code> | <code>string</code> | The logical ID for this CloudFormation stack element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakePipeline.property.stack">stack</a></code> | <code>aws-cdk-lib.Stack</code> | The stack in which this element is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakePipeline.property.ref">ref</a></code> | <code>string</code> | Return a string that will be resolved to a CloudFormation `{ Ref }` for this element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakePipeline.property.cfnOptions">cfnOptions</a></code> | <code>aws-cdk-lib.ICfnResourceOptions</code> | Options for this resource, such as condition, update policy etc. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakePipeline.property.cfnResourceType">cfnResourceType</a></code> | <code>string</code> | AWS resource type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakePipeline.property.attrCreatedDate">attrCreatedDate</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::DataLakePipeline.CreatedDate`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakePipeline.property.attrId">attrId</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::DataLakePipeline.Id`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakePipeline.property.attrLastUpdatedDate">attrLastUpdatedDate</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::DataLakePipeline.LastUpdatedDate`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakePipeline.property.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakePipelineProps">CfnDataLakePipelineProps</a></code> | Resource props. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `creationStack`<sup>Required</sup> <a name="creationStack" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.property.creationStack"></a>

```typescript
public readonly creationStack: string[];
```

- *Type:* string[]

---

##### `logicalId`<sup>Required</sup> <a name="logicalId" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.property.logicalId"></a>

```typescript
public readonly logicalId: string;
```

- *Type:* string

The logical ID for this CloudFormation stack element.

The logical ID of the element
is calculated from the path of the resource node in the construct tree.

To override this value, use `overrideLogicalId(newLogicalId)`.

---

##### `stack`<sup>Required</sup> <a name="stack" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.property.stack"></a>

```typescript
public readonly stack: Stack;
```

- *Type:* aws-cdk-lib.Stack

The stack in which this element is defined.

CfnElements must be defined within a stack scope (directly or indirectly).

---

##### `ref`<sup>Required</sup> <a name="ref" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.

If, by any chance, the intrinsic reference of a resource is not a string, you could
coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.

---

##### `cfnOptions`<sup>Required</sup> <a name="cfnOptions" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.property.cfnOptions"></a>

```typescript
public readonly cfnOptions: ICfnResourceOptions;
```

- *Type:* aws-cdk-lib.ICfnResourceOptions

Options for this resource, such as condition, update policy etc.

---

##### `cfnResourceType`<sup>Required</sup> <a name="cfnResourceType" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.property.cfnResourceType"></a>

```typescript
public readonly cfnResourceType: string;
```

- *Type:* string

AWS resource type.

---

##### `attrCreatedDate`<sup>Required</sup> <a name="attrCreatedDate" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.property.attrCreatedDate"></a>

```typescript
public readonly attrCreatedDate: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::DataLakePipeline.CreatedDate`.

---

##### `attrId`<sup>Required</sup> <a name="attrId" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.property.attrId"></a>

```typescript
public readonly attrId: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::DataLakePipeline.Id`.

---

##### `attrLastUpdatedDate`<sup>Required</sup> <a name="attrLastUpdatedDate" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.property.attrLastUpdatedDate"></a>

```typescript
public readonly attrLastUpdatedDate: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::DataLakePipeline.LastUpdatedDate`.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.property.props"></a>

```typescript
public readonly props: CfnDataLakePipelineProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnDataLakePipelineProps">CfnDataLakePipelineProps</a>

Resource props.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakePipeline.property.CFN_RESOURCE_TYPE_NAME">CFN_RESOURCE_TYPE_NAME</a></code> | <code>string</code> | The CloudFormation resource type name for this resource class. |

---

##### `CFN_RESOURCE_TYPE_NAME`<sup>Required</sup> <a name="CFN_RESOURCE_TYPE_NAME" id="awscdk-resources-mongodbatlas.CfnDataLakePipeline.property.CFN_RESOURCE_TYPE_NAME"></a>

```typescript
public readonly CFN_RESOURCE_TYPE_NAME: string;
```

- *Type:* string

The CloudFormation resource type name for this resource class.

---

### CfnDataLakes <a name="CfnDataLakes" id="awscdk-resources-mongodbatlas.CfnDataLakes"></a>

A CloudFormation `MongoDB::Atlas::DataLakes`.

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.CfnDataLakes.Initializer"></a>

```typescript
import { CfnDataLakes } from 'awscdk-resources-mongodbatlas'

new CfnDataLakes(scope: Construct, id: string, props: CfnDataLakesProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakes.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - scope in which this resource is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakes.Initializer.parameter.id">id</a></code> | <code>string</code> | - scoped id of the resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakes.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakesProps">CfnDataLakesProps</a></code> | - resource properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.CfnDataLakes.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

scope in which this resource is defined.

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnDataLakes.Initializer.parameter.id"></a>

- *Type:* string

scoped id of the resource.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnDataLakes.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnDataLakesProps">CfnDataLakesProps</a>

resource properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakes.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakes.overrideLogicalId">overrideLogicalId</a></code> | Overrides the auto-generated logical ID with a specific ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakes.addDeletionOverride">addDeletionOverride</a></code> | Syntactic sugar for `addOverride(path, undefined)`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakes.addDependency">addDependency</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakes.addDependsOn">addDependsOn</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakes.addMetadata">addMetadata</a></code> | Add a value to the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakes.addOverride">addOverride</a></code> | Adds an override to the synthesized CloudFormation resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakes.addPropertyDeletionOverride">addPropertyDeletionOverride</a></code> | Adds an override that deletes the value of a property from the resource definition. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakes.addPropertyOverride">addPropertyOverride</a></code> | Adds an override to a resource property. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakes.applyRemovalPolicy">applyRemovalPolicy</a></code> | Sets the deletion policy of the resource based on the removal policy specified. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakes.getAtt">getAtt</a></code> | Returns a token for an runtime attribute of this resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakes.getMetadata">getMetadata</a></code> | Retrieve a value value from the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakes.obtainDependencies">obtainDependencies</a></code> | Retrieves an array of resources this resource depends on. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakes.obtainResourceDependencies">obtainResourceDependencies</a></code> | Get a shallow copy of dependencies between this resource and other resources in the same stack. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakes.removeDependency">removeDependency</a></code> | Indicates that this resource no longer depends on another resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakes.replaceDependency">replaceDependency</a></code> | Replaces one dependency with another. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.CfnDataLakes.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `overrideLogicalId` <a name="overrideLogicalId" id="awscdk-resources-mongodbatlas.CfnDataLakes.overrideLogicalId"></a>

```typescript
public overrideLogicalId(newLogicalId: string): void
```

Overrides the auto-generated logical ID with a specific ID.

###### `newLogicalId`<sup>Required</sup> <a name="newLogicalId" id="awscdk-resources-mongodbatlas.CfnDataLakes.overrideLogicalId.parameter.newLogicalId"></a>

- *Type:* string

The new logical ID to use for this stack element.

---

##### `addDeletionOverride` <a name="addDeletionOverride" id="awscdk-resources-mongodbatlas.CfnDataLakes.addDeletionOverride"></a>

```typescript
public addDeletionOverride(path: string): void
```

Syntactic sugar for `addOverride(path, undefined)`.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnDataLakes.addDeletionOverride.parameter.path"></a>

- *Type:* string

The path of the value to delete.

---

##### `addDependency` <a name="addDependency" id="awscdk-resources-mongodbatlas.CfnDataLakes.addDependency"></a>

```typescript
public addDependency(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

This can be used for resources across stacks (or nested stack) boundaries
and the dependency will automatically be transferred to the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnDataLakes.addDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### ~~`addDependsOn`~~ <a name="addDependsOn" id="awscdk-resources-mongodbatlas.CfnDataLakes.addDependsOn"></a>

```typescript
public addDependsOn(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnDataLakes.addDependsOn.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `addMetadata` <a name="addMetadata" id="awscdk-resources-mongodbatlas.CfnDataLakes.addMetadata"></a>

```typescript
public addMetadata(key: string, value: any): void
```

Add a value to the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnDataLakes.addMetadata.parameter.key"></a>

- *Type:* string

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnDataLakes.addMetadata.parameter.value"></a>

- *Type:* any

---

##### `addOverride` <a name="addOverride" id="awscdk-resources-mongodbatlas.CfnDataLakes.addOverride"></a>

```typescript
public addOverride(path: string, value: any): void
```

Adds an override to the synthesized CloudFormation resource.

To add a
property override, either use `addPropertyOverride` or prefix `path` with
"Properties." (i.e. `Properties.TopicName`).

If the override is nested, separate each nested level using a dot (.) in the path parameter.
If there is an array as part of the nesting, specify the index in the path.

To include a literal `.` in the property name, prefix with a `\`. In most
programming languages you will need to write this as `"\\."` because the
`\` itself will need to be escaped.

For example,
```typescript
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
```
would add the overrides
```json
"Properties": {
  "GlobalSecondaryIndexes": [
    {
      "Projection": {
        "NonKeyAttributes": [ "myattribute" ]
        ...
      }
      ...
    },
    {
      "ProjectionType": "INCLUDE"
      ...
    },
  ]
  ...
}
```

The `value` argument to `addOverride` will not be processed or translated
in any way. Pass raw JSON values in here with the correct capitalization
for CloudFormation. If you pass CDK classes or structs, they will be
rendered with lowercased key names, and CloudFormation will reject the
template.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnDataLakes.addOverride.parameter.path"></a>

- *Type:* string

The path of the property, you can use dot notation to override values in complex types.

Any intermediate keys
will be created as needed.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnDataLakes.addOverride.parameter.value"></a>

- *Type:* any

The value.

Could be primitive or complex.

---

##### `addPropertyDeletionOverride` <a name="addPropertyDeletionOverride" id="awscdk-resources-mongodbatlas.CfnDataLakes.addPropertyDeletionOverride"></a>

```typescript
public addPropertyDeletionOverride(propertyPath: string): void
```

Adds an override that deletes the value of a property from the resource definition.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnDataLakes.addPropertyDeletionOverride.parameter.propertyPath"></a>

- *Type:* string

The path to the property.

---

##### `addPropertyOverride` <a name="addPropertyOverride" id="awscdk-resources-mongodbatlas.CfnDataLakes.addPropertyOverride"></a>

```typescript
public addPropertyOverride(propertyPath: string, value: any): void
```

Adds an override to a resource property.

Syntactic sugar for `addOverride("Properties.<...>", value)`.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnDataLakes.addPropertyOverride.parameter.propertyPath"></a>

- *Type:* string

The path of the property.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnDataLakes.addPropertyOverride.parameter.value"></a>

- *Type:* any

The value.

---

##### `applyRemovalPolicy` <a name="applyRemovalPolicy" id="awscdk-resources-mongodbatlas.CfnDataLakes.applyRemovalPolicy"></a>

```typescript
public applyRemovalPolicy(policy?: RemovalPolicy, options?: RemovalPolicyOptions): void
```

Sets the deletion policy of the resource based on the removal policy specified.

The Removal Policy controls what happens to this resource when it stops
being managed by CloudFormation, either because you've removed it from the
CDK application or because you've made a change that requires the resource
to be replaced.

The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
cases, a snapshot can be taken of the resource prior to deletion
(`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
can be found in the following link:

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options)

###### `policy`<sup>Optional</sup> <a name="policy" id="awscdk-resources-mongodbatlas.CfnDataLakes.applyRemovalPolicy.parameter.policy"></a>

- *Type:* aws-cdk-lib.RemovalPolicy

---

###### `options`<sup>Optional</sup> <a name="options" id="awscdk-resources-mongodbatlas.CfnDataLakes.applyRemovalPolicy.parameter.options"></a>

- *Type:* aws-cdk-lib.RemovalPolicyOptions

---

##### `getAtt` <a name="getAtt" id="awscdk-resources-mongodbatlas.CfnDataLakes.getAtt"></a>

```typescript
public getAtt(attributeName: string, typeHint?: ResolutionTypeHint): Reference
```

Returns a token for an runtime attribute of this resource.

Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
in case there is no generated attribute.

###### `attributeName`<sup>Required</sup> <a name="attributeName" id="awscdk-resources-mongodbatlas.CfnDataLakes.getAtt.parameter.attributeName"></a>

- *Type:* string

The name of the attribute.

---

###### `typeHint`<sup>Optional</sup> <a name="typeHint" id="awscdk-resources-mongodbatlas.CfnDataLakes.getAtt.parameter.typeHint"></a>

- *Type:* aws-cdk-lib.ResolutionTypeHint

---

##### `getMetadata` <a name="getMetadata" id="awscdk-resources-mongodbatlas.CfnDataLakes.getMetadata"></a>

```typescript
public getMetadata(key: string): any
```

Retrieve a value value from the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnDataLakes.getMetadata.parameter.key"></a>

- *Type:* string

---

##### `obtainDependencies` <a name="obtainDependencies" id="awscdk-resources-mongodbatlas.CfnDataLakes.obtainDependencies"></a>

```typescript
public obtainDependencies(): Stack | CfnResource[]
```

Retrieves an array of resources this resource depends on.

This assembles dependencies on resources across stacks (including nested stacks)
automatically.

##### `obtainResourceDependencies` <a name="obtainResourceDependencies" id="awscdk-resources-mongodbatlas.CfnDataLakes.obtainResourceDependencies"></a>

```typescript
public obtainResourceDependencies(): CfnResource[]
```

Get a shallow copy of dependencies between this resource and other resources in the same stack.

##### `removeDependency` <a name="removeDependency" id="awscdk-resources-mongodbatlas.CfnDataLakes.removeDependency"></a>

```typescript
public removeDependency(target: CfnResource): void
```

Indicates that this resource no longer depends on another resource.

This can be used for resources across stacks (including nested stacks)
and the dependency will automatically be removed from the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnDataLakes.removeDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `replaceDependency` <a name="replaceDependency" id="awscdk-resources-mongodbatlas.CfnDataLakes.replaceDependency"></a>

```typescript
public replaceDependency(target: CfnResource, newTarget: CfnResource): void
```

Replaces one dependency with another.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnDataLakes.replaceDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

The dependency to replace.

---

###### `newTarget`<sup>Required</sup> <a name="newTarget" id="awscdk-resources-mongodbatlas.CfnDataLakes.replaceDependency.parameter.newTarget"></a>

- *Type:* aws-cdk-lib.CfnResource

The new dependency to add.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakes.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakes.isCfnElement">isCfnElement</a></code> | Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakes.isCfnResource">isCfnResource</a></code> | Check whether the given construct is a CfnResource. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.CfnDataLakes.isConstruct"></a>

```typescript
import { CfnDataLakes } from 'awscdk-resources-mongodbatlas'

CfnDataLakes.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnDataLakes.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `isCfnElement` <a name="isCfnElement" id="awscdk-resources-mongodbatlas.CfnDataLakes.isCfnElement"></a>

```typescript
import { CfnDataLakes } from 'awscdk-resources-mongodbatlas'

CfnDataLakes.isCfnElement(x: any)
```

Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).

Uses duck-typing instead of `instanceof` to allow stack elements from different
versions of this library to be included in the same stack.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnDataLakes.isCfnElement.parameter.x"></a>

- *Type:* any

---

##### `isCfnResource` <a name="isCfnResource" id="awscdk-resources-mongodbatlas.CfnDataLakes.isCfnResource"></a>

```typescript
import { CfnDataLakes } from 'awscdk-resources-mongodbatlas'

CfnDataLakes.isCfnResource(construct: IConstruct)
```

Check whether the given construct is a CfnResource.

###### `construct`<sup>Required</sup> <a name="construct" id="awscdk-resources-mongodbatlas.CfnDataLakes.isCfnResource.parameter.construct"></a>

- *Type:* constructs.IConstruct

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakes.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakes.property.creationStack">creationStack</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakes.property.logicalId">logicalId</a></code> | <code>string</code> | The logical ID for this CloudFormation stack element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakes.property.stack">stack</a></code> | <code>aws-cdk-lib.Stack</code> | The stack in which this element is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakes.property.ref">ref</a></code> | <code>string</code> | Return a string that will be resolved to a CloudFormation `{ Ref }` for this element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakes.property.cfnOptions">cfnOptions</a></code> | <code>aws-cdk-lib.ICfnResourceOptions</code> | Options for this resource, such as condition, update policy etc. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakes.property.cfnResourceType">cfnResourceType</a></code> | <code>string</code> | AWS resource type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakes.property.attrHostnames">attrHostnames</a></code> | <code>string[]</code> | Attribute `MongoDB::Atlas::DataLakes.Hostnames`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakes.property.attrStartDate">attrStartDate</a></code> | <code>number</code> | Attribute `MongoDB::Atlas::DataLakes.StartDate`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakes.property.attrState">attrState</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::DataLakes.State`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakes.property.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakesProps">CfnDataLakesProps</a></code> | Resource props. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.CfnDataLakes.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `creationStack`<sup>Required</sup> <a name="creationStack" id="awscdk-resources-mongodbatlas.CfnDataLakes.property.creationStack"></a>

```typescript
public readonly creationStack: string[];
```

- *Type:* string[]

---

##### `logicalId`<sup>Required</sup> <a name="logicalId" id="awscdk-resources-mongodbatlas.CfnDataLakes.property.logicalId"></a>

```typescript
public readonly logicalId: string;
```

- *Type:* string

The logical ID for this CloudFormation stack element.

The logical ID of the element
is calculated from the path of the resource node in the construct tree.

To override this value, use `overrideLogicalId(newLogicalId)`.

---

##### `stack`<sup>Required</sup> <a name="stack" id="awscdk-resources-mongodbatlas.CfnDataLakes.property.stack"></a>

```typescript
public readonly stack: Stack;
```

- *Type:* aws-cdk-lib.Stack

The stack in which this element is defined.

CfnElements must be defined within a stack scope (directly or indirectly).

---

##### `ref`<sup>Required</sup> <a name="ref" id="awscdk-resources-mongodbatlas.CfnDataLakes.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.

If, by any chance, the intrinsic reference of a resource is not a string, you could
coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.

---

##### `cfnOptions`<sup>Required</sup> <a name="cfnOptions" id="awscdk-resources-mongodbatlas.CfnDataLakes.property.cfnOptions"></a>

```typescript
public readonly cfnOptions: ICfnResourceOptions;
```

- *Type:* aws-cdk-lib.ICfnResourceOptions

Options for this resource, such as condition, update policy etc.

---

##### `cfnResourceType`<sup>Required</sup> <a name="cfnResourceType" id="awscdk-resources-mongodbatlas.CfnDataLakes.property.cfnResourceType"></a>

```typescript
public readonly cfnResourceType: string;
```

- *Type:* string

AWS resource type.

---

##### `attrHostnames`<sup>Required</sup> <a name="attrHostnames" id="awscdk-resources-mongodbatlas.CfnDataLakes.property.attrHostnames"></a>

```typescript
public readonly attrHostnames: string[];
```

- *Type:* string[]

Attribute `MongoDB::Atlas::DataLakes.Hostnames`.

---

##### `attrStartDate`<sup>Required</sup> <a name="attrStartDate" id="awscdk-resources-mongodbatlas.CfnDataLakes.property.attrStartDate"></a>

```typescript
public readonly attrStartDate: number;
```

- *Type:* number

Attribute `MongoDB::Atlas::DataLakes.StartDate`.

---

##### `attrState`<sup>Required</sup> <a name="attrState" id="awscdk-resources-mongodbatlas.CfnDataLakes.property.attrState"></a>

```typescript
public readonly attrState: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::DataLakes.State`.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnDataLakes.property.props"></a>

```typescript
public readonly props: CfnDataLakesProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnDataLakesProps">CfnDataLakesProps</a>

Resource props.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakes.property.CFN_RESOURCE_TYPE_NAME">CFN_RESOURCE_TYPE_NAME</a></code> | <code>string</code> | The CloudFormation resource type name for this resource class. |

---

##### `CFN_RESOURCE_TYPE_NAME`<sup>Required</sup> <a name="CFN_RESOURCE_TYPE_NAME" id="awscdk-resources-mongodbatlas.CfnDataLakes.property.CFN_RESOURCE_TYPE_NAME"></a>

```typescript
public readonly CFN_RESOURCE_TYPE_NAME: string;
```

- *Type:* string

The CloudFormation resource type name for this resource class.

---

### CfnEncryptionAtRest <a name="CfnEncryptionAtRest" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest"></a>

A CloudFormation `MongoDB::Atlas::EncryptionAtRest`.

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.Initializer"></a>

```typescript
import { CfnEncryptionAtRest } from 'awscdk-resources-mongodbatlas'

new CfnEncryptionAtRest(scope: Construct, id: string, props: CfnEncryptionAtRestProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnEncryptionAtRest.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - scope in which this resource is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnEncryptionAtRest.Initializer.parameter.id">id</a></code> | <code>string</code> | - scoped id of the resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnEncryptionAtRest.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnEncryptionAtRestProps">CfnEncryptionAtRestProps</a></code> | - resource properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

scope in which this resource is defined.

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.Initializer.parameter.id"></a>

- *Type:* string

scoped id of the resource.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnEncryptionAtRestProps">CfnEncryptionAtRestProps</a>

resource properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnEncryptionAtRest.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnEncryptionAtRest.overrideLogicalId">overrideLogicalId</a></code> | Overrides the auto-generated logical ID with a specific ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnEncryptionAtRest.addDeletionOverride">addDeletionOverride</a></code> | Syntactic sugar for `addOverride(path, undefined)`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnEncryptionAtRest.addDependency">addDependency</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnEncryptionAtRest.addDependsOn">addDependsOn</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnEncryptionAtRest.addMetadata">addMetadata</a></code> | Add a value to the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnEncryptionAtRest.addOverride">addOverride</a></code> | Adds an override to the synthesized CloudFormation resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnEncryptionAtRest.addPropertyDeletionOverride">addPropertyDeletionOverride</a></code> | Adds an override that deletes the value of a property from the resource definition. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnEncryptionAtRest.addPropertyOverride">addPropertyOverride</a></code> | Adds an override to a resource property. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnEncryptionAtRest.applyRemovalPolicy">applyRemovalPolicy</a></code> | Sets the deletion policy of the resource based on the removal policy specified. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnEncryptionAtRest.getAtt">getAtt</a></code> | Returns a token for an runtime attribute of this resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnEncryptionAtRest.getMetadata">getMetadata</a></code> | Retrieve a value value from the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnEncryptionAtRest.obtainDependencies">obtainDependencies</a></code> | Retrieves an array of resources this resource depends on. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnEncryptionAtRest.obtainResourceDependencies">obtainResourceDependencies</a></code> | Get a shallow copy of dependencies between this resource and other resources in the same stack. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnEncryptionAtRest.removeDependency">removeDependency</a></code> | Indicates that this resource no longer depends on another resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnEncryptionAtRest.replaceDependency">replaceDependency</a></code> | Replaces one dependency with another. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `overrideLogicalId` <a name="overrideLogicalId" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.overrideLogicalId"></a>

```typescript
public overrideLogicalId(newLogicalId: string): void
```

Overrides the auto-generated logical ID with a specific ID.

###### `newLogicalId`<sup>Required</sup> <a name="newLogicalId" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.overrideLogicalId.parameter.newLogicalId"></a>

- *Type:* string

The new logical ID to use for this stack element.

---

##### `addDeletionOverride` <a name="addDeletionOverride" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.addDeletionOverride"></a>

```typescript
public addDeletionOverride(path: string): void
```

Syntactic sugar for `addOverride(path, undefined)`.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.addDeletionOverride.parameter.path"></a>

- *Type:* string

The path of the value to delete.

---

##### `addDependency` <a name="addDependency" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.addDependency"></a>

```typescript
public addDependency(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

This can be used for resources across stacks (or nested stack) boundaries
and the dependency will automatically be transferred to the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.addDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### ~~`addDependsOn`~~ <a name="addDependsOn" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.addDependsOn"></a>

```typescript
public addDependsOn(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.addDependsOn.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `addMetadata` <a name="addMetadata" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.addMetadata"></a>

```typescript
public addMetadata(key: string, value: any): void
```

Add a value to the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.addMetadata.parameter.key"></a>

- *Type:* string

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.addMetadata.parameter.value"></a>

- *Type:* any

---

##### `addOverride` <a name="addOverride" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.addOverride"></a>

```typescript
public addOverride(path: string, value: any): void
```

Adds an override to the synthesized CloudFormation resource.

To add a
property override, either use `addPropertyOverride` or prefix `path` with
"Properties." (i.e. `Properties.TopicName`).

If the override is nested, separate each nested level using a dot (.) in the path parameter.
If there is an array as part of the nesting, specify the index in the path.

To include a literal `.` in the property name, prefix with a `\`. In most
programming languages you will need to write this as `"\\."` because the
`\` itself will need to be escaped.

For example,
```typescript
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
```
would add the overrides
```json
"Properties": {
  "GlobalSecondaryIndexes": [
    {
      "Projection": {
        "NonKeyAttributes": [ "myattribute" ]
        ...
      }
      ...
    },
    {
      "ProjectionType": "INCLUDE"
      ...
    },
  ]
  ...
}
```

The `value` argument to `addOverride` will not be processed or translated
in any way. Pass raw JSON values in here with the correct capitalization
for CloudFormation. If you pass CDK classes or structs, they will be
rendered with lowercased key names, and CloudFormation will reject the
template.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.addOverride.parameter.path"></a>

- *Type:* string

The path of the property, you can use dot notation to override values in complex types.

Any intermediate keys
will be created as needed.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.addOverride.parameter.value"></a>

- *Type:* any

The value.

Could be primitive or complex.

---

##### `addPropertyDeletionOverride` <a name="addPropertyDeletionOverride" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.addPropertyDeletionOverride"></a>

```typescript
public addPropertyDeletionOverride(propertyPath: string): void
```

Adds an override that deletes the value of a property from the resource definition.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.addPropertyDeletionOverride.parameter.propertyPath"></a>

- *Type:* string

The path to the property.

---

##### `addPropertyOverride` <a name="addPropertyOverride" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.addPropertyOverride"></a>

```typescript
public addPropertyOverride(propertyPath: string, value: any): void
```

Adds an override to a resource property.

Syntactic sugar for `addOverride("Properties.<...>", value)`.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.addPropertyOverride.parameter.propertyPath"></a>

- *Type:* string

The path of the property.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.addPropertyOverride.parameter.value"></a>

- *Type:* any

The value.

---

##### `applyRemovalPolicy` <a name="applyRemovalPolicy" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.applyRemovalPolicy"></a>

```typescript
public applyRemovalPolicy(policy?: RemovalPolicy, options?: RemovalPolicyOptions): void
```

Sets the deletion policy of the resource based on the removal policy specified.

The Removal Policy controls what happens to this resource when it stops
being managed by CloudFormation, either because you've removed it from the
CDK application or because you've made a change that requires the resource
to be replaced.

The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
cases, a snapshot can be taken of the resource prior to deletion
(`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
can be found in the following link:

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options)

###### `policy`<sup>Optional</sup> <a name="policy" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.applyRemovalPolicy.parameter.policy"></a>

- *Type:* aws-cdk-lib.RemovalPolicy

---

###### `options`<sup>Optional</sup> <a name="options" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.applyRemovalPolicy.parameter.options"></a>

- *Type:* aws-cdk-lib.RemovalPolicyOptions

---

##### `getAtt` <a name="getAtt" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.getAtt"></a>

```typescript
public getAtt(attributeName: string, typeHint?: ResolutionTypeHint): Reference
```

Returns a token for an runtime attribute of this resource.

Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
in case there is no generated attribute.

###### `attributeName`<sup>Required</sup> <a name="attributeName" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.getAtt.parameter.attributeName"></a>

- *Type:* string

The name of the attribute.

---

###### `typeHint`<sup>Optional</sup> <a name="typeHint" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.getAtt.parameter.typeHint"></a>

- *Type:* aws-cdk-lib.ResolutionTypeHint

---

##### `getMetadata` <a name="getMetadata" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.getMetadata"></a>

```typescript
public getMetadata(key: string): any
```

Retrieve a value value from the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.getMetadata.parameter.key"></a>

- *Type:* string

---

##### `obtainDependencies` <a name="obtainDependencies" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.obtainDependencies"></a>

```typescript
public obtainDependencies(): Stack | CfnResource[]
```

Retrieves an array of resources this resource depends on.

This assembles dependencies on resources across stacks (including nested stacks)
automatically.

##### `obtainResourceDependencies` <a name="obtainResourceDependencies" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.obtainResourceDependencies"></a>

```typescript
public obtainResourceDependencies(): CfnResource[]
```

Get a shallow copy of dependencies between this resource and other resources in the same stack.

##### `removeDependency` <a name="removeDependency" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.removeDependency"></a>

```typescript
public removeDependency(target: CfnResource): void
```

Indicates that this resource no longer depends on another resource.

This can be used for resources across stacks (including nested stacks)
and the dependency will automatically be removed from the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.removeDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `replaceDependency` <a name="replaceDependency" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.replaceDependency"></a>

```typescript
public replaceDependency(target: CfnResource, newTarget: CfnResource): void
```

Replaces one dependency with another.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.replaceDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

The dependency to replace.

---

###### `newTarget`<sup>Required</sup> <a name="newTarget" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.replaceDependency.parameter.newTarget"></a>

- *Type:* aws-cdk-lib.CfnResource

The new dependency to add.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnEncryptionAtRest.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnEncryptionAtRest.isCfnElement">isCfnElement</a></code> | Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnEncryptionAtRest.isCfnResource">isCfnResource</a></code> | Check whether the given construct is a CfnResource. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.isConstruct"></a>

```typescript
import { CfnEncryptionAtRest } from 'awscdk-resources-mongodbatlas'

CfnEncryptionAtRest.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `isCfnElement` <a name="isCfnElement" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.isCfnElement"></a>

```typescript
import { CfnEncryptionAtRest } from 'awscdk-resources-mongodbatlas'

CfnEncryptionAtRest.isCfnElement(x: any)
```

Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).

Uses duck-typing instead of `instanceof` to allow stack elements from different
versions of this library to be included in the same stack.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.isCfnElement.parameter.x"></a>

- *Type:* any

---

##### `isCfnResource` <a name="isCfnResource" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.isCfnResource"></a>

```typescript
import { CfnEncryptionAtRest } from 'awscdk-resources-mongodbatlas'

CfnEncryptionAtRest.isCfnResource(construct: IConstruct)
```

Check whether the given construct is a CfnResource.

###### `construct`<sup>Required</sup> <a name="construct" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.isCfnResource.parameter.construct"></a>

- *Type:* constructs.IConstruct

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnEncryptionAtRest.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnEncryptionAtRest.property.creationStack">creationStack</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnEncryptionAtRest.property.logicalId">logicalId</a></code> | <code>string</code> | The logical ID for this CloudFormation stack element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnEncryptionAtRest.property.stack">stack</a></code> | <code>aws-cdk-lib.Stack</code> | The stack in which this element is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnEncryptionAtRest.property.ref">ref</a></code> | <code>string</code> | Return a string that will be resolved to a CloudFormation `{ Ref }` for this element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnEncryptionAtRest.property.cfnOptions">cfnOptions</a></code> | <code>aws-cdk-lib.ICfnResourceOptions</code> | Options for this resource, such as condition, update policy etc. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnEncryptionAtRest.property.cfnResourceType">cfnResourceType</a></code> | <code>string</code> | AWS resource type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnEncryptionAtRest.property.attrId">attrId</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::EncryptionAtRest.Id`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnEncryptionAtRest.property.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnEncryptionAtRestProps">CfnEncryptionAtRestProps</a></code> | Resource props. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `creationStack`<sup>Required</sup> <a name="creationStack" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.property.creationStack"></a>

```typescript
public readonly creationStack: string[];
```

- *Type:* string[]

---

##### `logicalId`<sup>Required</sup> <a name="logicalId" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.property.logicalId"></a>

```typescript
public readonly logicalId: string;
```

- *Type:* string

The logical ID for this CloudFormation stack element.

The logical ID of the element
is calculated from the path of the resource node in the construct tree.

To override this value, use `overrideLogicalId(newLogicalId)`.

---

##### `stack`<sup>Required</sup> <a name="stack" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.property.stack"></a>

```typescript
public readonly stack: Stack;
```

- *Type:* aws-cdk-lib.Stack

The stack in which this element is defined.

CfnElements must be defined within a stack scope (directly or indirectly).

---

##### `ref`<sup>Required</sup> <a name="ref" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.

If, by any chance, the intrinsic reference of a resource is not a string, you could
coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.

---

##### `cfnOptions`<sup>Required</sup> <a name="cfnOptions" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.property.cfnOptions"></a>

```typescript
public readonly cfnOptions: ICfnResourceOptions;
```

- *Type:* aws-cdk-lib.ICfnResourceOptions

Options for this resource, such as condition, update policy etc.

---

##### `cfnResourceType`<sup>Required</sup> <a name="cfnResourceType" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.property.cfnResourceType"></a>

```typescript
public readonly cfnResourceType: string;
```

- *Type:* string

AWS resource type.

---

##### `attrId`<sup>Required</sup> <a name="attrId" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.property.attrId"></a>

```typescript
public readonly attrId: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::EncryptionAtRest.Id`.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.property.props"></a>

```typescript
public readonly props: CfnEncryptionAtRestProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnEncryptionAtRestProps">CfnEncryptionAtRestProps</a>

Resource props.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnEncryptionAtRest.property.CFN_RESOURCE_TYPE_NAME">CFN_RESOURCE_TYPE_NAME</a></code> | <code>string</code> | The CloudFormation resource type name for this resource class. |

---

##### `CFN_RESOURCE_TYPE_NAME`<sup>Required</sup> <a name="CFN_RESOURCE_TYPE_NAME" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRest.property.CFN_RESOURCE_TYPE_NAME"></a>

```typescript
public readonly CFN_RESOURCE_TYPE_NAME: string;
```

- *Type:* string

The CloudFormation resource type name for this resource class.

---

### CfnFederatedDatabaseInstance <a name="CfnFederatedDatabaseInstance" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance"></a>

A CloudFormation `MongoDB::Atlas::FederatedDatabaseInstance`.

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.Initializer"></a>

```typescript
import { CfnFederatedDatabaseInstance } from 'awscdk-resources-mongodbatlas'

new CfnFederatedDatabaseInstance(scope: Construct, id: string, props: CfnFederatedDatabaseInstanceProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - scope in which this resource is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.Initializer.parameter.id">id</a></code> | <code>string</code> | - scoped id of the resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstanceProps">CfnFederatedDatabaseInstanceProps</a></code> | - resource properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

scope in which this resource is defined.

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.Initializer.parameter.id"></a>

- *Type:* string

scoped id of the resource.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstanceProps">CfnFederatedDatabaseInstanceProps</a>

resource properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.overrideLogicalId">overrideLogicalId</a></code> | Overrides the auto-generated logical ID with a specific ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.addDeletionOverride">addDeletionOverride</a></code> | Syntactic sugar for `addOverride(path, undefined)`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.addDependency">addDependency</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.addDependsOn">addDependsOn</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.addMetadata">addMetadata</a></code> | Add a value to the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.addOverride">addOverride</a></code> | Adds an override to the synthesized CloudFormation resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.addPropertyDeletionOverride">addPropertyDeletionOverride</a></code> | Adds an override that deletes the value of a property from the resource definition. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.addPropertyOverride">addPropertyOverride</a></code> | Adds an override to a resource property. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.applyRemovalPolicy">applyRemovalPolicy</a></code> | Sets the deletion policy of the resource based on the removal policy specified. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.getAtt">getAtt</a></code> | Returns a token for an runtime attribute of this resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.getMetadata">getMetadata</a></code> | Retrieve a value value from the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.obtainDependencies">obtainDependencies</a></code> | Retrieves an array of resources this resource depends on. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.obtainResourceDependencies">obtainResourceDependencies</a></code> | Get a shallow copy of dependencies between this resource and other resources in the same stack. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.removeDependency">removeDependency</a></code> | Indicates that this resource no longer depends on another resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.replaceDependency">replaceDependency</a></code> | Replaces one dependency with another. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `overrideLogicalId` <a name="overrideLogicalId" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.overrideLogicalId"></a>

```typescript
public overrideLogicalId(newLogicalId: string): void
```

Overrides the auto-generated logical ID with a specific ID.

###### `newLogicalId`<sup>Required</sup> <a name="newLogicalId" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.overrideLogicalId.parameter.newLogicalId"></a>

- *Type:* string

The new logical ID to use for this stack element.

---

##### `addDeletionOverride` <a name="addDeletionOverride" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.addDeletionOverride"></a>

```typescript
public addDeletionOverride(path: string): void
```

Syntactic sugar for `addOverride(path, undefined)`.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.addDeletionOverride.parameter.path"></a>

- *Type:* string

The path of the value to delete.

---

##### `addDependency` <a name="addDependency" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.addDependency"></a>

```typescript
public addDependency(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

This can be used for resources across stacks (or nested stack) boundaries
and the dependency will automatically be transferred to the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.addDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### ~~`addDependsOn`~~ <a name="addDependsOn" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.addDependsOn"></a>

```typescript
public addDependsOn(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.addDependsOn.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `addMetadata` <a name="addMetadata" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.addMetadata"></a>

```typescript
public addMetadata(key: string, value: any): void
```

Add a value to the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.addMetadata.parameter.key"></a>

- *Type:* string

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.addMetadata.parameter.value"></a>

- *Type:* any

---

##### `addOverride` <a name="addOverride" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.addOverride"></a>

```typescript
public addOverride(path: string, value: any): void
```

Adds an override to the synthesized CloudFormation resource.

To add a
property override, either use `addPropertyOverride` or prefix `path` with
"Properties." (i.e. `Properties.TopicName`).

If the override is nested, separate each nested level using a dot (.) in the path parameter.
If there is an array as part of the nesting, specify the index in the path.

To include a literal `.` in the property name, prefix with a `\`. In most
programming languages you will need to write this as `"\\."` because the
`\` itself will need to be escaped.

For example,
```typescript
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
```
would add the overrides
```json
"Properties": {
  "GlobalSecondaryIndexes": [
    {
      "Projection": {
        "NonKeyAttributes": [ "myattribute" ]
        ...
      }
      ...
    },
    {
      "ProjectionType": "INCLUDE"
      ...
    },
  ]
  ...
}
```

The `value` argument to `addOverride` will not be processed or translated
in any way. Pass raw JSON values in here with the correct capitalization
for CloudFormation. If you pass CDK classes or structs, they will be
rendered with lowercased key names, and CloudFormation will reject the
template.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.addOverride.parameter.path"></a>

- *Type:* string

The path of the property, you can use dot notation to override values in complex types.

Any intermediate keys
will be created as needed.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.addOverride.parameter.value"></a>

- *Type:* any

The value.

Could be primitive or complex.

---

##### `addPropertyDeletionOverride` <a name="addPropertyDeletionOverride" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.addPropertyDeletionOverride"></a>

```typescript
public addPropertyDeletionOverride(propertyPath: string): void
```

Adds an override that deletes the value of a property from the resource definition.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.addPropertyDeletionOverride.parameter.propertyPath"></a>

- *Type:* string

The path to the property.

---

##### `addPropertyOverride` <a name="addPropertyOverride" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.addPropertyOverride"></a>

```typescript
public addPropertyOverride(propertyPath: string, value: any): void
```

Adds an override to a resource property.

Syntactic sugar for `addOverride("Properties.<...>", value)`.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.addPropertyOverride.parameter.propertyPath"></a>

- *Type:* string

The path of the property.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.addPropertyOverride.parameter.value"></a>

- *Type:* any

The value.

---

##### `applyRemovalPolicy` <a name="applyRemovalPolicy" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.applyRemovalPolicy"></a>

```typescript
public applyRemovalPolicy(policy?: RemovalPolicy, options?: RemovalPolicyOptions): void
```

Sets the deletion policy of the resource based on the removal policy specified.

The Removal Policy controls what happens to this resource when it stops
being managed by CloudFormation, either because you've removed it from the
CDK application or because you've made a change that requires the resource
to be replaced.

The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
cases, a snapshot can be taken of the resource prior to deletion
(`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
can be found in the following link:

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options)

###### `policy`<sup>Optional</sup> <a name="policy" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.applyRemovalPolicy.parameter.policy"></a>

- *Type:* aws-cdk-lib.RemovalPolicy

---

###### `options`<sup>Optional</sup> <a name="options" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.applyRemovalPolicy.parameter.options"></a>

- *Type:* aws-cdk-lib.RemovalPolicyOptions

---

##### `getAtt` <a name="getAtt" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.getAtt"></a>

```typescript
public getAtt(attributeName: string, typeHint?: ResolutionTypeHint): Reference
```

Returns a token for an runtime attribute of this resource.

Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
in case there is no generated attribute.

###### `attributeName`<sup>Required</sup> <a name="attributeName" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.getAtt.parameter.attributeName"></a>

- *Type:* string

The name of the attribute.

---

###### `typeHint`<sup>Optional</sup> <a name="typeHint" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.getAtt.parameter.typeHint"></a>

- *Type:* aws-cdk-lib.ResolutionTypeHint

---

##### `getMetadata` <a name="getMetadata" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.getMetadata"></a>

```typescript
public getMetadata(key: string): any
```

Retrieve a value value from the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.getMetadata.parameter.key"></a>

- *Type:* string

---

##### `obtainDependencies` <a name="obtainDependencies" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.obtainDependencies"></a>

```typescript
public obtainDependencies(): Stack | CfnResource[]
```

Retrieves an array of resources this resource depends on.

This assembles dependencies on resources across stacks (including nested stacks)
automatically.

##### `obtainResourceDependencies` <a name="obtainResourceDependencies" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.obtainResourceDependencies"></a>

```typescript
public obtainResourceDependencies(): CfnResource[]
```

Get a shallow copy of dependencies between this resource and other resources in the same stack.

##### `removeDependency` <a name="removeDependency" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.removeDependency"></a>

```typescript
public removeDependency(target: CfnResource): void
```

Indicates that this resource no longer depends on another resource.

This can be used for resources across stacks (including nested stacks)
and the dependency will automatically be removed from the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.removeDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `replaceDependency` <a name="replaceDependency" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.replaceDependency"></a>

```typescript
public replaceDependency(target: CfnResource, newTarget: CfnResource): void
```

Replaces one dependency with another.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.replaceDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

The dependency to replace.

---

###### `newTarget`<sup>Required</sup> <a name="newTarget" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.replaceDependency.parameter.newTarget"></a>

- *Type:* aws-cdk-lib.CfnResource

The new dependency to add.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.isCfnElement">isCfnElement</a></code> | Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.isCfnResource">isCfnResource</a></code> | Check whether the given construct is a CfnResource. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.isConstruct"></a>

```typescript
import { CfnFederatedDatabaseInstance } from 'awscdk-resources-mongodbatlas'

CfnFederatedDatabaseInstance.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `isCfnElement` <a name="isCfnElement" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.isCfnElement"></a>

```typescript
import { CfnFederatedDatabaseInstance } from 'awscdk-resources-mongodbatlas'

CfnFederatedDatabaseInstance.isCfnElement(x: any)
```

Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).

Uses duck-typing instead of `instanceof` to allow stack elements from different
versions of this library to be included in the same stack.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.isCfnElement.parameter.x"></a>

- *Type:* any

---

##### `isCfnResource` <a name="isCfnResource" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.isCfnResource"></a>

```typescript
import { CfnFederatedDatabaseInstance } from 'awscdk-resources-mongodbatlas'

CfnFederatedDatabaseInstance.isCfnResource(construct: IConstruct)
```

Check whether the given construct is a CfnResource.

###### `construct`<sup>Required</sup> <a name="construct" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.isCfnResource.parameter.construct"></a>

- *Type:* constructs.IConstruct

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.property.creationStack">creationStack</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.property.logicalId">logicalId</a></code> | <code>string</code> | The logical ID for this CloudFormation stack element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.property.stack">stack</a></code> | <code>aws-cdk-lib.Stack</code> | The stack in which this element is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.property.ref">ref</a></code> | <code>string</code> | Return a string that will be resolved to a CloudFormation `{ Ref }` for this element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.property.cfnOptions">cfnOptions</a></code> | <code>aws-cdk-lib.ICfnResourceOptions</code> | Options for this resource, such as condition, update policy etc. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.property.cfnResourceType">cfnResourceType</a></code> | <code>string</code> | AWS resource type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.property.attrExternalId">attrExternalId</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::FederatedDatabaseInstance.CloudProviderConfig.ExternalId`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.property.attrHostNames">attrHostNames</a></code> | <code>string[]</code> | Attribute `MongoDB::Atlas::FederatedDatabaseInstance.HostNames`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.property.attrIamAssumedRoleARNN">attrIamAssumedRoleARNN</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::FederatedDatabaseInstance.CloudProviderConfig.IamAssumedRoleARN`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.property.attrIamUserARN">attrIamUserARN</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::FederatedDatabaseInstance.CloudProviderConfig.IamUserARN`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.property.attrState">attrState</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::FederatedDatabaseInstance.State`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.property.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstanceProps">CfnFederatedDatabaseInstanceProps</a></code> | Resource props. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `creationStack`<sup>Required</sup> <a name="creationStack" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.property.creationStack"></a>

```typescript
public readonly creationStack: string[];
```

- *Type:* string[]

---

##### `logicalId`<sup>Required</sup> <a name="logicalId" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.property.logicalId"></a>

```typescript
public readonly logicalId: string;
```

- *Type:* string

The logical ID for this CloudFormation stack element.

The logical ID of the element
is calculated from the path of the resource node in the construct tree.

To override this value, use `overrideLogicalId(newLogicalId)`.

---

##### `stack`<sup>Required</sup> <a name="stack" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.property.stack"></a>

```typescript
public readonly stack: Stack;
```

- *Type:* aws-cdk-lib.Stack

The stack in which this element is defined.

CfnElements must be defined within a stack scope (directly or indirectly).

---

##### `ref`<sup>Required</sup> <a name="ref" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.

If, by any chance, the intrinsic reference of a resource is not a string, you could
coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.

---

##### `cfnOptions`<sup>Required</sup> <a name="cfnOptions" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.property.cfnOptions"></a>

```typescript
public readonly cfnOptions: ICfnResourceOptions;
```

- *Type:* aws-cdk-lib.ICfnResourceOptions

Options for this resource, such as condition, update policy etc.

---

##### `cfnResourceType`<sup>Required</sup> <a name="cfnResourceType" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.property.cfnResourceType"></a>

```typescript
public readonly cfnResourceType: string;
```

- *Type:* string

AWS resource type.

---

##### `attrExternalId`<sup>Required</sup> <a name="attrExternalId" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.property.attrExternalId"></a>

```typescript
public readonly attrExternalId: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::FederatedDatabaseInstance.CloudProviderConfig.ExternalId`.

---

##### `attrHostNames`<sup>Required</sup> <a name="attrHostNames" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.property.attrHostNames"></a>

```typescript
public readonly attrHostNames: string[];
```

- *Type:* string[]

Attribute `MongoDB::Atlas::FederatedDatabaseInstance.HostNames`.

---

##### `attrIamAssumedRoleARNN`<sup>Required</sup> <a name="attrIamAssumedRoleARNN" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.property.attrIamAssumedRoleARNN"></a>

```typescript
public readonly attrIamAssumedRoleARNN: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::FederatedDatabaseInstance.CloudProviderConfig.IamAssumedRoleARN`.

---

##### `attrIamUserARN`<sup>Required</sup> <a name="attrIamUserARN" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.property.attrIamUserARN"></a>

```typescript
public readonly attrIamUserARN: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::FederatedDatabaseInstance.CloudProviderConfig.IamUserARN`.

---

##### `attrState`<sup>Required</sup> <a name="attrState" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.property.attrState"></a>

```typescript
public readonly attrState: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::FederatedDatabaseInstance.State`.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.property.props"></a>

```typescript
public readonly props: CfnFederatedDatabaseInstanceProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstanceProps">CfnFederatedDatabaseInstanceProps</a>

Resource props.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.property.CFN_RESOURCE_TYPE_NAME">CFN_RESOURCE_TYPE_NAME</a></code> | <code>string</code> | The CloudFormation resource type name for this resource class. |

---

##### `CFN_RESOURCE_TYPE_NAME`<sup>Required</sup> <a name="CFN_RESOURCE_TYPE_NAME" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstance.property.CFN_RESOURCE_TYPE_NAME"></a>

```typescript
public readonly CFN_RESOURCE_TYPE_NAME: string;
```

- *Type:* string

The CloudFormation resource type name for this resource class.

---

### CfnFederatedQueryLimit <a name="CfnFederatedQueryLimit" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit"></a>

A CloudFormation `MongoDB::Atlas::FederatedQueryLimit`.

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.Initializer"></a>

```typescript
import { CfnFederatedQueryLimit } from 'awscdk-resources-mongodbatlas'

new CfnFederatedQueryLimit(scope: Construct, id: string, props: CfnFederatedQueryLimitProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - scope in which this resource is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.Initializer.parameter.id">id</a></code> | <code>string</code> | - scoped id of the resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimitProps">CfnFederatedQueryLimitProps</a></code> | - resource properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

scope in which this resource is defined.

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.Initializer.parameter.id"></a>

- *Type:* string

scoped id of the resource.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimitProps">CfnFederatedQueryLimitProps</a>

resource properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.overrideLogicalId">overrideLogicalId</a></code> | Overrides the auto-generated logical ID with a specific ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.addDeletionOverride">addDeletionOverride</a></code> | Syntactic sugar for `addOverride(path, undefined)`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.addDependency">addDependency</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.addDependsOn">addDependsOn</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.addMetadata">addMetadata</a></code> | Add a value to the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.addOverride">addOverride</a></code> | Adds an override to the synthesized CloudFormation resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.addPropertyDeletionOverride">addPropertyDeletionOverride</a></code> | Adds an override that deletes the value of a property from the resource definition. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.addPropertyOverride">addPropertyOverride</a></code> | Adds an override to a resource property. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.applyRemovalPolicy">applyRemovalPolicy</a></code> | Sets the deletion policy of the resource based on the removal policy specified. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.getAtt">getAtt</a></code> | Returns a token for an runtime attribute of this resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.getMetadata">getMetadata</a></code> | Retrieve a value value from the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.obtainDependencies">obtainDependencies</a></code> | Retrieves an array of resources this resource depends on. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.obtainResourceDependencies">obtainResourceDependencies</a></code> | Get a shallow copy of dependencies between this resource and other resources in the same stack. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.removeDependency">removeDependency</a></code> | Indicates that this resource no longer depends on another resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.replaceDependency">replaceDependency</a></code> | Replaces one dependency with another. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `overrideLogicalId` <a name="overrideLogicalId" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.overrideLogicalId"></a>

```typescript
public overrideLogicalId(newLogicalId: string): void
```

Overrides the auto-generated logical ID with a specific ID.

###### `newLogicalId`<sup>Required</sup> <a name="newLogicalId" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.overrideLogicalId.parameter.newLogicalId"></a>

- *Type:* string

The new logical ID to use for this stack element.

---

##### `addDeletionOverride` <a name="addDeletionOverride" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.addDeletionOverride"></a>

```typescript
public addDeletionOverride(path: string): void
```

Syntactic sugar for `addOverride(path, undefined)`.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.addDeletionOverride.parameter.path"></a>

- *Type:* string

The path of the value to delete.

---

##### `addDependency` <a name="addDependency" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.addDependency"></a>

```typescript
public addDependency(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

This can be used for resources across stacks (or nested stack) boundaries
and the dependency will automatically be transferred to the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.addDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### ~~`addDependsOn`~~ <a name="addDependsOn" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.addDependsOn"></a>

```typescript
public addDependsOn(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.addDependsOn.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `addMetadata` <a name="addMetadata" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.addMetadata"></a>

```typescript
public addMetadata(key: string, value: any): void
```

Add a value to the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.addMetadata.parameter.key"></a>

- *Type:* string

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.addMetadata.parameter.value"></a>

- *Type:* any

---

##### `addOverride` <a name="addOverride" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.addOverride"></a>

```typescript
public addOverride(path: string, value: any): void
```

Adds an override to the synthesized CloudFormation resource.

To add a
property override, either use `addPropertyOverride` or prefix `path` with
"Properties." (i.e. `Properties.TopicName`).

If the override is nested, separate each nested level using a dot (.) in the path parameter.
If there is an array as part of the nesting, specify the index in the path.

To include a literal `.` in the property name, prefix with a `\`. In most
programming languages you will need to write this as `"\\."` because the
`\` itself will need to be escaped.

For example,
```typescript
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
```
would add the overrides
```json
"Properties": {
  "GlobalSecondaryIndexes": [
    {
      "Projection": {
        "NonKeyAttributes": [ "myattribute" ]
        ...
      }
      ...
    },
    {
      "ProjectionType": "INCLUDE"
      ...
    },
  ]
  ...
}
```

The `value` argument to `addOverride` will not be processed or translated
in any way. Pass raw JSON values in here with the correct capitalization
for CloudFormation. If you pass CDK classes or structs, they will be
rendered with lowercased key names, and CloudFormation will reject the
template.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.addOverride.parameter.path"></a>

- *Type:* string

The path of the property, you can use dot notation to override values in complex types.

Any intermediate keys
will be created as needed.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.addOverride.parameter.value"></a>

- *Type:* any

The value.

Could be primitive or complex.

---

##### `addPropertyDeletionOverride` <a name="addPropertyDeletionOverride" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.addPropertyDeletionOverride"></a>

```typescript
public addPropertyDeletionOverride(propertyPath: string): void
```

Adds an override that deletes the value of a property from the resource definition.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.addPropertyDeletionOverride.parameter.propertyPath"></a>

- *Type:* string

The path to the property.

---

##### `addPropertyOverride` <a name="addPropertyOverride" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.addPropertyOverride"></a>

```typescript
public addPropertyOverride(propertyPath: string, value: any): void
```

Adds an override to a resource property.

Syntactic sugar for `addOverride("Properties.<...>", value)`.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.addPropertyOverride.parameter.propertyPath"></a>

- *Type:* string

The path of the property.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.addPropertyOverride.parameter.value"></a>

- *Type:* any

The value.

---

##### `applyRemovalPolicy` <a name="applyRemovalPolicy" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.applyRemovalPolicy"></a>

```typescript
public applyRemovalPolicy(policy?: RemovalPolicy, options?: RemovalPolicyOptions): void
```

Sets the deletion policy of the resource based on the removal policy specified.

The Removal Policy controls what happens to this resource when it stops
being managed by CloudFormation, either because you've removed it from the
CDK application or because you've made a change that requires the resource
to be replaced.

The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
cases, a snapshot can be taken of the resource prior to deletion
(`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
can be found in the following link:

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options)

###### `policy`<sup>Optional</sup> <a name="policy" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.applyRemovalPolicy.parameter.policy"></a>

- *Type:* aws-cdk-lib.RemovalPolicy

---

###### `options`<sup>Optional</sup> <a name="options" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.applyRemovalPolicy.parameter.options"></a>

- *Type:* aws-cdk-lib.RemovalPolicyOptions

---

##### `getAtt` <a name="getAtt" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.getAtt"></a>

```typescript
public getAtt(attributeName: string, typeHint?: ResolutionTypeHint): Reference
```

Returns a token for an runtime attribute of this resource.

Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
in case there is no generated attribute.

###### `attributeName`<sup>Required</sup> <a name="attributeName" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.getAtt.parameter.attributeName"></a>

- *Type:* string

The name of the attribute.

---

###### `typeHint`<sup>Optional</sup> <a name="typeHint" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.getAtt.parameter.typeHint"></a>

- *Type:* aws-cdk-lib.ResolutionTypeHint

---

##### `getMetadata` <a name="getMetadata" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.getMetadata"></a>

```typescript
public getMetadata(key: string): any
```

Retrieve a value value from the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.getMetadata.parameter.key"></a>

- *Type:* string

---

##### `obtainDependencies` <a name="obtainDependencies" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.obtainDependencies"></a>

```typescript
public obtainDependencies(): Stack | CfnResource[]
```

Retrieves an array of resources this resource depends on.

This assembles dependencies on resources across stacks (including nested stacks)
automatically.

##### `obtainResourceDependencies` <a name="obtainResourceDependencies" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.obtainResourceDependencies"></a>

```typescript
public obtainResourceDependencies(): CfnResource[]
```

Get a shallow copy of dependencies between this resource and other resources in the same stack.

##### `removeDependency` <a name="removeDependency" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.removeDependency"></a>

```typescript
public removeDependency(target: CfnResource): void
```

Indicates that this resource no longer depends on another resource.

This can be used for resources across stacks (including nested stacks)
and the dependency will automatically be removed from the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.removeDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `replaceDependency` <a name="replaceDependency" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.replaceDependency"></a>

```typescript
public replaceDependency(target: CfnResource, newTarget: CfnResource): void
```

Replaces one dependency with another.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.replaceDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

The dependency to replace.

---

###### `newTarget`<sup>Required</sup> <a name="newTarget" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.replaceDependency.parameter.newTarget"></a>

- *Type:* aws-cdk-lib.CfnResource

The new dependency to add.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.isCfnElement">isCfnElement</a></code> | Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.isCfnResource">isCfnResource</a></code> | Check whether the given construct is a CfnResource. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.isConstruct"></a>

```typescript
import { CfnFederatedQueryLimit } from 'awscdk-resources-mongodbatlas'

CfnFederatedQueryLimit.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `isCfnElement` <a name="isCfnElement" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.isCfnElement"></a>

```typescript
import { CfnFederatedQueryLimit } from 'awscdk-resources-mongodbatlas'

CfnFederatedQueryLimit.isCfnElement(x: any)
```

Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).

Uses duck-typing instead of `instanceof` to allow stack elements from different
versions of this library to be included in the same stack.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.isCfnElement.parameter.x"></a>

- *Type:* any

---

##### `isCfnResource` <a name="isCfnResource" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.isCfnResource"></a>

```typescript
import { CfnFederatedQueryLimit } from 'awscdk-resources-mongodbatlas'

CfnFederatedQueryLimit.isCfnResource(construct: IConstruct)
```

Check whether the given construct is a CfnResource.

###### `construct`<sup>Required</sup> <a name="construct" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.isCfnResource.parameter.construct"></a>

- *Type:* constructs.IConstruct

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.property.creationStack">creationStack</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.property.logicalId">logicalId</a></code> | <code>string</code> | The logical ID for this CloudFormation stack element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.property.stack">stack</a></code> | <code>aws-cdk-lib.Stack</code> | The stack in which this element is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.property.ref">ref</a></code> | <code>string</code> | Return a string that will be resolved to a CloudFormation `{ Ref }` for this element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.property.cfnOptions">cfnOptions</a></code> | <code>aws-cdk-lib.ICfnResourceOptions</code> | Options for this resource, such as condition, update policy etc. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.property.cfnResourceType">cfnResourceType</a></code> | <code>string</code> | AWS resource type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.property.attrCurrentUsage">attrCurrentUsage</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::FederatedQueryLimit.CurrentUsage`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.property.attrDefaultLimit">attrDefaultLimit</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::FederatedQueryLimit.DefaultLimit`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.property.attrLastModifiedDate">attrLastModifiedDate</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::FederatedQueryLimit.LastModifiedDate`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.property.attrMaximumLimit">attrMaximumLimit</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::FederatedQueryLimit.MaximumLimit`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.property.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimitProps">CfnFederatedQueryLimitProps</a></code> | Resource props. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `creationStack`<sup>Required</sup> <a name="creationStack" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.property.creationStack"></a>

```typescript
public readonly creationStack: string[];
```

- *Type:* string[]

---

##### `logicalId`<sup>Required</sup> <a name="logicalId" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.property.logicalId"></a>

```typescript
public readonly logicalId: string;
```

- *Type:* string

The logical ID for this CloudFormation stack element.

The logical ID of the element
is calculated from the path of the resource node in the construct tree.

To override this value, use `overrideLogicalId(newLogicalId)`.

---

##### `stack`<sup>Required</sup> <a name="stack" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.property.stack"></a>

```typescript
public readonly stack: Stack;
```

- *Type:* aws-cdk-lib.Stack

The stack in which this element is defined.

CfnElements must be defined within a stack scope (directly or indirectly).

---

##### `ref`<sup>Required</sup> <a name="ref" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.

If, by any chance, the intrinsic reference of a resource is not a string, you could
coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.

---

##### `cfnOptions`<sup>Required</sup> <a name="cfnOptions" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.property.cfnOptions"></a>

```typescript
public readonly cfnOptions: ICfnResourceOptions;
```

- *Type:* aws-cdk-lib.ICfnResourceOptions

Options for this resource, such as condition, update policy etc.

---

##### `cfnResourceType`<sup>Required</sup> <a name="cfnResourceType" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.property.cfnResourceType"></a>

```typescript
public readonly cfnResourceType: string;
```

- *Type:* string

AWS resource type.

---

##### `attrCurrentUsage`<sup>Required</sup> <a name="attrCurrentUsage" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.property.attrCurrentUsage"></a>

```typescript
public readonly attrCurrentUsage: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::FederatedQueryLimit.CurrentUsage`.

---

##### `attrDefaultLimit`<sup>Required</sup> <a name="attrDefaultLimit" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.property.attrDefaultLimit"></a>

```typescript
public readonly attrDefaultLimit: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::FederatedQueryLimit.DefaultLimit`.

---

##### `attrLastModifiedDate`<sup>Required</sup> <a name="attrLastModifiedDate" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.property.attrLastModifiedDate"></a>

```typescript
public readonly attrLastModifiedDate: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::FederatedQueryLimit.LastModifiedDate`.

---

##### `attrMaximumLimit`<sup>Required</sup> <a name="attrMaximumLimit" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.property.attrMaximumLimit"></a>

```typescript
public readonly attrMaximumLimit: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::FederatedQueryLimit.MaximumLimit`.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.property.props"></a>

```typescript
public readonly props: CfnFederatedQueryLimitProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimitProps">CfnFederatedQueryLimitProps</a>

Resource props.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.property.CFN_RESOURCE_TYPE_NAME">CFN_RESOURCE_TYPE_NAME</a></code> | <code>string</code> | The CloudFormation resource type name for this resource class. |

---

##### `CFN_RESOURCE_TYPE_NAME`<sup>Required</sup> <a name="CFN_RESOURCE_TYPE_NAME" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimit.property.CFN_RESOURCE_TYPE_NAME"></a>

```typescript
public readonly CFN_RESOURCE_TYPE_NAME: string;
```

- *Type:* string

The CloudFormation resource type name for this resource class.

---

### CfnFederatedSettingsOrgRoleMapping <a name="CfnFederatedSettingsOrgRoleMapping" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping"></a>

A CloudFormation `MongoDB::Atlas::FederatedSettingsOrgRoleMapping`.

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.Initializer"></a>

```typescript
import { CfnFederatedSettingsOrgRoleMapping } from 'awscdk-resources-mongodbatlas'

new CfnFederatedSettingsOrgRoleMapping(scope: Construct, id: string, props: CfnFederatedSettingsOrgRoleMappingProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - scope in which this resource is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.Initializer.parameter.id">id</a></code> | <code>string</code> | - scoped id of the resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMappingProps">CfnFederatedSettingsOrgRoleMappingProps</a></code> | - resource properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

scope in which this resource is defined.

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.Initializer.parameter.id"></a>

- *Type:* string

scoped id of the resource.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMappingProps">CfnFederatedSettingsOrgRoleMappingProps</a>

resource properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.overrideLogicalId">overrideLogicalId</a></code> | Overrides the auto-generated logical ID with a specific ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.addDeletionOverride">addDeletionOverride</a></code> | Syntactic sugar for `addOverride(path, undefined)`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.addDependency">addDependency</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.addDependsOn">addDependsOn</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.addMetadata">addMetadata</a></code> | Add a value to the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.addOverride">addOverride</a></code> | Adds an override to the synthesized CloudFormation resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.addPropertyDeletionOverride">addPropertyDeletionOverride</a></code> | Adds an override that deletes the value of a property from the resource definition. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.addPropertyOverride">addPropertyOverride</a></code> | Adds an override to a resource property. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.applyRemovalPolicy">applyRemovalPolicy</a></code> | Sets the deletion policy of the resource based on the removal policy specified. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.getAtt">getAtt</a></code> | Returns a token for an runtime attribute of this resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.getMetadata">getMetadata</a></code> | Retrieve a value value from the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.obtainDependencies">obtainDependencies</a></code> | Retrieves an array of resources this resource depends on. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.obtainResourceDependencies">obtainResourceDependencies</a></code> | Get a shallow copy of dependencies between this resource and other resources in the same stack. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.removeDependency">removeDependency</a></code> | Indicates that this resource no longer depends on another resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.replaceDependency">replaceDependency</a></code> | Replaces one dependency with another. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `overrideLogicalId` <a name="overrideLogicalId" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.overrideLogicalId"></a>

```typescript
public overrideLogicalId(newLogicalId: string): void
```

Overrides the auto-generated logical ID with a specific ID.

###### `newLogicalId`<sup>Required</sup> <a name="newLogicalId" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.overrideLogicalId.parameter.newLogicalId"></a>

- *Type:* string

The new logical ID to use for this stack element.

---

##### `addDeletionOverride` <a name="addDeletionOverride" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.addDeletionOverride"></a>

```typescript
public addDeletionOverride(path: string): void
```

Syntactic sugar for `addOverride(path, undefined)`.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.addDeletionOverride.parameter.path"></a>

- *Type:* string

The path of the value to delete.

---

##### `addDependency` <a name="addDependency" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.addDependency"></a>

```typescript
public addDependency(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

This can be used for resources across stacks (or nested stack) boundaries
and the dependency will automatically be transferred to the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.addDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### ~~`addDependsOn`~~ <a name="addDependsOn" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.addDependsOn"></a>

```typescript
public addDependsOn(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.addDependsOn.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `addMetadata` <a name="addMetadata" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.addMetadata"></a>

```typescript
public addMetadata(key: string, value: any): void
```

Add a value to the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.addMetadata.parameter.key"></a>

- *Type:* string

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.addMetadata.parameter.value"></a>

- *Type:* any

---

##### `addOverride` <a name="addOverride" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.addOverride"></a>

```typescript
public addOverride(path: string, value: any): void
```

Adds an override to the synthesized CloudFormation resource.

To add a
property override, either use `addPropertyOverride` or prefix `path` with
"Properties." (i.e. `Properties.TopicName`).

If the override is nested, separate each nested level using a dot (.) in the path parameter.
If there is an array as part of the nesting, specify the index in the path.

To include a literal `.` in the property name, prefix with a `\`. In most
programming languages you will need to write this as `"\\."` because the
`\` itself will need to be escaped.

For example,
```typescript
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
```
would add the overrides
```json
"Properties": {
  "GlobalSecondaryIndexes": [
    {
      "Projection": {
        "NonKeyAttributes": [ "myattribute" ]
        ...
      }
      ...
    },
    {
      "ProjectionType": "INCLUDE"
      ...
    },
  ]
  ...
}
```

The `value` argument to `addOverride` will not be processed or translated
in any way. Pass raw JSON values in here with the correct capitalization
for CloudFormation. If you pass CDK classes or structs, they will be
rendered with lowercased key names, and CloudFormation will reject the
template.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.addOverride.parameter.path"></a>

- *Type:* string

The path of the property, you can use dot notation to override values in complex types.

Any intermediate keys
will be created as needed.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.addOverride.parameter.value"></a>

- *Type:* any

The value.

Could be primitive or complex.

---

##### `addPropertyDeletionOverride` <a name="addPropertyDeletionOverride" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.addPropertyDeletionOverride"></a>

```typescript
public addPropertyDeletionOverride(propertyPath: string): void
```

Adds an override that deletes the value of a property from the resource definition.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.addPropertyDeletionOverride.parameter.propertyPath"></a>

- *Type:* string

The path to the property.

---

##### `addPropertyOverride` <a name="addPropertyOverride" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.addPropertyOverride"></a>

```typescript
public addPropertyOverride(propertyPath: string, value: any): void
```

Adds an override to a resource property.

Syntactic sugar for `addOverride("Properties.<...>", value)`.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.addPropertyOverride.parameter.propertyPath"></a>

- *Type:* string

The path of the property.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.addPropertyOverride.parameter.value"></a>

- *Type:* any

The value.

---

##### `applyRemovalPolicy` <a name="applyRemovalPolicy" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.applyRemovalPolicy"></a>

```typescript
public applyRemovalPolicy(policy?: RemovalPolicy, options?: RemovalPolicyOptions): void
```

Sets the deletion policy of the resource based on the removal policy specified.

The Removal Policy controls what happens to this resource when it stops
being managed by CloudFormation, either because you've removed it from the
CDK application or because you've made a change that requires the resource
to be replaced.

The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
cases, a snapshot can be taken of the resource prior to deletion
(`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
can be found in the following link:

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options)

###### `policy`<sup>Optional</sup> <a name="policy" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.applyRemovalPolicy.parameter.policy"></a>

- *Type:* aws-cdk-lib.RemovalPolicy

---

###### `options`<sup>Optional</sup> <a name="options" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.applyRemovalPolicy.parameter.options"></a>

- *Type:* aws-cdk-lib.RemovalPolicyOptions

---

##### `getAtt` <a name="getAtt" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.getAtt"></a>

```typescript
public getAtt(attributeName: string, typeHint?: ResolutionTypeHint): Reference
```

Returns a token for an runtime attribute of this resource.

Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
in case there is no generated attribute.

###### `attributeName`<sup>Required</sup> <a name="attributeName" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.getAtt.parameter.attributeName"></a>

- *Type:* string

The name of the attribute.

---

###### `typeHint`<sup>Optional</sup> <a name="typeHint" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.getAtt.parameter.typeHint"></a>

- *Type:* aws-cdk-lib.ResolutionTypeHint

---

##### `getMetadata` <a name="getMetadata" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.getMetadata"></a>

```typescript
public getMetadata(key: string): any
```

Retrieve a value value from the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.getMetadata.parameter.key"></a>

- *Type:* string

---

##### `obtainDependencies` <a name="obtainDependencies" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.obtainDependencies"></a>

```typescript
public obtainDependencies(): Stack | CfnResource[]
```

Retrieves an array of resources this resource depends on.

This assembles dependencies on resources across stacks (including nested stacks)
automatically.

##### `obtainResourceDependencies` <a name="obtainResourceDependencies" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.obtainResourceDependencies"></a>

```typescript
public obtainResourceDependencies(): CfnResource[]
```

Get a shallow copy of dependencies between this resource and other resources in the same stack.

##### `removeDependency` <a name="removeDependency" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.removeDependency"></a>

```typescript
public removeDependency(target: CfnResource): void
```

Indicates that this resource no longer depends on another resource.

This can be used for resources across stacks (including nested stacks)
and the dependency will automatically be removed from the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.removeDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `replaceDependency` <a name="replaceDependency" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.replaceDependency"></a>

```typescript
public replaceDependency(target: CfnResource, newTarget: CfnResource): void
```

Replaces one dependency with another.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.replaceDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

The dependency to replace.

---

###### `newTarget`<sup>Required</sup> <a name="newTarget" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.replaceDependency.parameter.newTarget"></a>

- *Type:* aws-cdk-lib.CfnResource

The new dependency to add.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.isCfnElement">isCfnElement</a></code> | Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.isCfnResource">isCfnResource</a></code> | Check whether the given construct is a CfnResource. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.isConstruct"></a>

```typescript
import { CfnFederatedSettingsOrgRoleMapping } from 'awscdk-resources-mongodbatlas'

CfnFederatedSettingsOrgRoleMapping.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `isCfnElement` <a name="isCfnElement" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.isCfnElement"></a>

```typescript
import { CfnFederatedSettingsOrgRoleMapping } from 'awscdk-resources-mongodbatlas'

CfnFederatedSettingsOrgRoleMapping.isCfnElement(x: any)
```

Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).

Uses duck-typing instead of `instanceof` to allow stack elements from different
versions of this library to be included in the same stack.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.isCfnElement.parameter.x"></a>

- *Type:* any

---

##### `isCfnResource` <a name="isCfnResource" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.isCfnResource"></a>

```typescript
import { CfnFederatedSettingsOrgRoleMapping } from 'awscdk-resources-mongodbatlas'

CfnFederatedSettingsOrgRoleMapping.isCfnResource(construct: IConstruct)
```

Check whether the given construct is a CfnResource.

###### `construct`<sup>Required</sup> <a name="construct" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.isCfnResource.parameter.construct"></a>

- *Type:* constructs.IConstruct

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.property.creationStack">creationStack</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.property.logicalId">logicalId</a></code> | <code>string</code> | The logical ID for this CloudFormation stack element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.property.stack">stack</a></code> | <code>aws-cdk-lib.Stack</code> | The stack in which this element is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.property.ref">ref</a></code> | <code>string</code> | Return a string that will be resolved to a CloudFormation `{ Ref }` for this element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.property.cfnOptions">cfnOptions</a></code> | <code>aws-cdk-lib.ICfnResourceOptions</code> | Options for this resource, such as condition, update policy etc. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.property.cfnResourceType">cfnResourceType</a></code> | <code>string</code> | AWS resource type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.property.attrId">attrId</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::FederatedSettingsOrgRoleMapping.Id`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.property.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMappingProps">CfnFederatedSettingsOrgRoleMappingProps</a></code> | Resource props. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `creationStack`<sup>Required</sup> <a name="creationStack" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.property.creationStack"></a>

```typescript
public readonly creationStack: string[];
```

- *Type:* string[]

---

##### `logicalId`<sup>Required</sup> <a name="logicalId" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.property.logicalId"></a>

```typescript
public readonly logicalId: string;
```

- *Type:* string

The logical ID for this CloudFormation stack element.

The logical ID of the element
is calculated from the path of the resource node in the construct tree.

To override this value, use `overrideLogicalId(newLogicalId)`.

---

##### `stack`<sup>Required</sup> <a name="stack" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.property.stack"></a>

```typescript
public readonly stack: Stack;
```

- *Type:* aws-cdk-lib.Stack

The stack in which this element is defined.

CfnElements must be defined within a stack scope (directly or indirectly).

---

##### `ref`<sup>Required</sup> <a name="ref" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.

If, by any chance, the intrinsic reference of a resource is not a string, you could
coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.

---

##### `cfnOptions`<sup>Required</sup> <a name="cfnOptions" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.property.cfnOptions"></a>

```typescript
public readonly cfnOptions: ICfnResourceOptions;
```

- *Type:* aws-cdk-lib.ICfnResourceOptions

Options for this resource, such as condition, update policy etc.

---

##### `cfnResourceType`<sup>Required</sup> <a name="cfnResourceType" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.property.cfnResourceType"></a>

```typescript
public readonly cfnResourceType: string;
```

- *Type:* string

AWS resource type.

---

##### `attrId`<sup>Required</sup> <a name="attrId" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.property.attrId"></a>

```typescript
public readonly attrId: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::FederatedSettingsOrgRoleMapping.Id`.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.property.props"></a>

```typescript
public readonly props: CfnFederatedSettingsOrgRoleMappingProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMappingProps">CfnFederatedSettingsOrgRoleMappingProps</a>

Resource props.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.property.CFN_RESOURCE_TYPE_NAME">CFN_RESOURCE_TYPE_NAME</a></code> | <code>string</code> | The CloudFormation resource type name for this resource class. |

---

##### `CFN_RESOURCE_TYPE_NAME`<sup>Required</sup> <a name="CFN_RESOURCE_TYPE_NAME" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMapping.property.CFN_RESOURCE_TYPE_NAME"></a>

```typescript
public readonly CFN_RESOURCE_TYPE_NAME: string;
```

- *Type:* string

The CloudFormation resource type name for this resource class.

---

### CfnGlobalClusterConfig <a name="CfnGlobalClusterConfig" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig"></a>

A CloudFormation `MongoDB::Atlas::GlobalClusterConfig`.

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.Initializer"></a>

```typescript
import { CfnGlobalClusterConfig } from 'awscdk-resources-mongodbatlas'

new CfnGlobalClusterConfig(scope: Construct, id: string, props: CfnGlobalClusterConfigProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - scope in which this resource is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.Initializer.parameter.id">id</a></code> | <code>string</code> | - scoped id of the resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnGlobalClusterConfigProps">CfnGlobalClusterConfigProps</a></code> | - resource properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

scope in which this resource is defined.

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.Initializer.parameter.id"></a>

- *Type:* string

scoped id of the resource.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnGlobalClusterConfigProps">CfnGlobalClusterConfigProps</a>

resource properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.overrideLogicalId">overrideLogicalId</a></code> | Overrides the auto-generated logical ID with a specific ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.addDeletionOverride">addDeletionOverride</a></code> | Syntactic sugar for `addOverride(path, undefined)`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.addDependency">addDependency</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.addDependsOn">addDependsOn</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.addMetadata">addMetadata</a></code> | Add a value to the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.addOverride">addOverride</a></code> | Adds an override to the synthesized CloudFormation resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.addPropertyDeletionOverride">addPropertyDeletionOverride</a></code> | Adds an override that deletes the value of a property from the resource definition. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.addPropertyOverride">addPropertyOverride</a></code> | Adds an override to a resource property. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.applyRemovalPolicy">applyRemovalPolicy</a></code> | Sets the deletion policy of the resource based on the removal policy specified. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.getAtt">getAtt</a></code> | Returns a token for an runtime attribute of this resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.getMetadata">getMetadata</a></code> | Retrieve a value value from the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.obtainDependencies">obtainDependencies</a></code> | Retrieves an array of resources this resource depends on. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.obtainResourceDependencies">obtainResourceDependencies</a></code> | Get a shallow copy of dependencies between this resource and other resources in the same stack. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.removeDependency">removeDependency</a></code> | Indicates that this resource no longer depends on another resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.replaceDependency">replaceDependency</a></code> | Replaces one dependency with another. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `overrideLogicalId` <a name="overrideLogicalId" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.overrideLogicalId"></a>

```typescript
public overrideLogicalId(newLogicalId: string): void
```

Overrides the auto-generated logical ID with a specific ID.

###### `newLogicalId`<sup>Required</sup> <a name="newLogicalId" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.overrideLogicalId.parameter.newLogicalId"></a>

- *Type:* string

The new logical ID to use for this stack element.

---

##### `addDeletionOverride` <a name="addDeletionOverride" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.addDeletionOverride"></a>

```typescript
public addDeletionOverride(path: string): void
```

Syntactic sugar for `addOverride(path, undefined)`.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.addDeletionOverride.parameter.path"></a>

- *Type:* string

The path of the value to delete.

---

##### `addDependency` <a name="addDependency" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.addDependency"></a>

```typescript
public addDependency(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

This can be used for resources across stacks (or nested stack) boundaries
and the dependency will automatically be transferred to the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.addDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### ~~`addDependsOn`~~ <a name="addDependsOn" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.addDependsOn"></a>

```typescript
public addDependsOn(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.addDependsOn.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `addMetadata` <a name="addMetadata" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.addMetadata"></a>

```typescript
public addMetadata(key: string, value: any): void
```

Add a value to the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.addMetadata.parameter.key"></a>

- *Type:* string

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.addMetadata.parameter.value"></a>

- *Type:* any

---

##### `addOverride` <a name="addOverride" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.addOverride"></a>

```typescript
public addOverride(path: string, value: any): void
```

Adds an override to the synthesized CloudFormation resource.

To add a
property override, either use `addPropertyOverride` or prefix `path` with
"Properties." (i.e. `Properties.TopicName`).

If the override is nested, separate each nested level using a dot (.) in the path parameter.
If there is an array as part of the nesting, specify the index in the path.

To include a literal `.` in the property name, prefix with a `\`. In most
programming languages you will need to write this as `"\\."` because the
`\` itself will need to be escaped.

For example,
```typescript
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
```
would add the overrides
```json
"Properties": {
  "GlobalSecondaryIndexes": [
    {
      "Projection": {
        "NonKeyAttributes": [ "myattribute" ]
        ...
      }
      ...
    },
    {
      "ProjectionType": "INCLUDE"
      ...
    },
  ]
  ...
}
```

The `value` argument to `addOverride` will not be processed or translated
in any way. Pass raw JSON values in here with the correct capitalization
for CloudFormation. If you pass CDK classes or structs, they will be
rendered with lowercased key names, and CloudFormation will reject the
template.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.addOverride.parameter.path"></a>

- *Type:* string

The path of the property, you can use dot notation to override values in complex types.

Any intermediate keys
will be created as needed.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.addOverride.parameter.value"></a>

- *Type:* any

The value.

Could be primitive or complex.

---

##### `addPropertyDeletionOverride` <a name="addPropertyDeletionOverride" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.addPropertyDeletionOverride"></a>

```typescript
public addPropertyDeletionOverride(propertyPath: string): void
```

Adds an override that deletes the value of a property from the resource definition.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.addPropertyDeletionOverride.parameter.propertyPath"></a>

- *Type:* string

The path to the property.

---

##### `addPropertyOverride` <a name="addPropertyOverride" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.addPropertyOverride"></a>

```typescript
public addPropertyOverride(propertyPath: string, value: any): void
```

Adds an override to a resource property.

Syntactic sugar for `addOverride("Properties.<...>", value)`.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.addPropertyOverride.parameter.propertyPath"></a>

- *Type:* string

The path of the property.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.addPropertyOverride.parameter.value"></a>

- *Type:* any

The value.

---

##### `applyRemovalPolicy` <a name="applyRemovalPolicy" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.applyRemovalPolicy"></a>

```typescript
public applyRemovalPolicy(policy?: RemovalPolicy, options?: RemovalPolicyOptions): void
```

Sets the deletion policy of the resource based on the removal policy specified.

The Removal Policy controls what happens to this resource when it stops
being managed by CloudFormation, either because you've removed it from the
CDK application or because you've made a change that requires the resource
to be replaced.

The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
cases, a snapshot can be taken of the resource prior to deletion
(`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
can be found in the following link:

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options)

###### `policy`<sup>Optional</sup> <a name="policy" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.applyRemovalPolicy.parameter.policy"></a>

- *Type:* aws-cdk-lib.RemovalPolicy

---

###### `options`<sup>Optional</sup> <a name="options" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.applyRemovalPolicy.parameter.options"></a>

- *Type:* aws-cdk-lib.RemovalPolicyOptions

---

##### `getAtt` <a name="getAtt" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.getAtt"></a>

```typescript
public getAtt(attributeName: string, typeHint?: ResolutionTypeHint): Reference
```

Returns a token for an runtime attribute of this resource.

Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
in case there is no generated attribute.

###### `attributeName`<sup>Required</sup> <a name="attributeName" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.getAtt.parameter.attributeName"></a>

- *Type:* string

The name of the attribute.

---

###### `typeHint`<sup>Optional</sup> <a name="typeHint" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.getAtt.parameter.typeHint"></a>

- *Type:* aws-cdk-lib.ResolutionTypeHint

---

##### `getMetadata` <a name="getMetadata" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.getMetadata"></a>

```typescript
public getMetadata(key: string): any
```

Retrieve a value value from the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.getMetadata.parameter.key"></a>

- *Type:* string

---

##### `obtainDependencies` <a name="obtainDependencies" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.obtainDependencies"></a>

```typescript
public obtainDependencies(): Stack | CfnResource[]
```

Retrieves an array of resources this resource depends on.

This assembles dependencies on resources across stacks (including nested stacks)
automatically.

##### `obtainResourceDependencies` <a name="obtainResourceDependencies" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.obtainResourceDependencies"></a>

```typescript
public obtainResourceDependencies(): CfnResource[]
```

Get a shallow copy of dependencies between this resource and other resources in the same stack.

##### `removeDependency` <a name="removeDependency" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.removeDependency"></a>

```typescript
public removeDependency(target: CfnResource): void
```

Indicates that this resource no longer depends on another resource.

This can be used for resources across stacks (including nested stacks)
and the dependency will automatically be removed from the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.removeDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `replaceDependency` <a name="replaceDependency" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.replaceDependency"></a>

```typescript
public replaceDependency(target: CfnResource, newTarget: CfnResource): void
```

Replaces one dependency with another.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.replaceDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

The dependency to replace.

---

###### `newTarget`<sup>Required</sup> <a name="newTarget" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.replaceDependency.parameter.newTarget"></a>

- *Type:* aws-cdk-lib.CfnResource

The new dependency to add.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.isCfnElement">isCfnElement</a></code> | Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.isCfnResource">isCfnResource</a></code> | Check whether the given construct is a CfnResource. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.isConstruct"></a>

```typescript
import { CfnGlobalClusterConfig } from 'awscdk-resources-mongodbatlas'

CfnGlobalClusterConfig.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `isCfnElement` <a name="isCfnElement" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.isCfnElement"></a>

```typescript
import { CfnGlobalClusterConfig } from 'awscdk-resources-mongodbatlas'

CfnGlobalClusterConfig.isCfnElement(x: any)
```

Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).

Uses duck-typing instead of `instanceof` to allow stack elements from different
versions of this library to be included in the same stack.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.isCfnElement.parameter.x"></a>

- *Type:* any

---

##### `isCfnResource` <a name="isCfnResource" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.isCfnResource"></a>

```typescript
import { CfnGlobalClusterConfig } from 'awscdk-resources-mongodbatlas'

CfnGlobalClusterConfig.isCfnResource(construct: IConstruct)
```

Check whether the given construct is a CfnResource.

###### `construct`<sup>Required</sup> <a name="construct" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.isCfnResource.parameter.construct"></a>

- *Type:* constructs.IConstruct

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.property.creationStack">creationStack</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.property.logicalId">logicalId</a></code> | <code>string</code> | The logical ID for this CloudFormation stack element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.property.stack">stack</a></code> | <code>aws-cdk-lib.Stack</code> | The stack in which this element is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.property.ref">ref</a></code> | <code>string</code> | Return a string that will be resolved to a CloudFormation `{ Ref }` for this element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.property.cfnOptions">cfnOptions</a></code> | <code>aws-cdk-lib.ICfnResourceOptions</code> | Options for this resource, such as condition, update policy etc. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.property.cfnResourceType">cfnResourceType</a></code> | <code>string</code> | AWS resource type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.property.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnGlobalClusterConfigProps">CfnGlobalClusterConfigProps</a></code> | Resource props. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `creationStack`<sup>Required</sup> <a name="creationStack" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.property.creationStack"></a>

```typescript
public readonly creationStack: string[];
```

- *Type:* string[]

---

##### `logicalId`<sup>Required</sup> <a name="logicalId" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.property.logicalId"></a>

```typescript
public readonly logicalId: string;
```

- *Type:* string

The logical ID for this CloudFormation stack element.

The logical ID of the element
is calculated from the path of the resource node in the construct tree.

To override this value, use `overrideLogicalId(newLogicalId)`.

---

##### `stack`<sup>Required</sup> <a name="stack" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.property.stack"></a>

```typescript
public readonly stack: Stack;
```

- *Type:* aws-cdk-lib.Stack

The stack in which this element is defined.

CfnElements must be defined within a stack scope (directly or indirectly).

---

##### `ref`<sup>Required</sup> <a name="ref" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.

If, by any chance, the intrinsic reference of a resource is not a string, you could
coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.

---

##### `cfnOptions`<sup>Required</sup> <a name="cfnOptions" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.property.cfnOptions"></a>

```typescript
public readonly cfnOptions: ICfnResourceOptions;
```

- *Type:* aws-cdk-lib.ICfnResourceOptions

Options for this resource, such as condition, update policy etc.

---

##### `cfnResourceType`<sup>Required</sup> <a name="cfnResourceType" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.property.cfnResourceType"></a>

```typescript
public readonly cfnResourceType: string;
```

- *Type:* string

AWS resource type.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.property.props"></a>

```typescript
public readonly props: CfnGlobalClusterConfigProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnGlobalClusterConfigProps">CfnGlobalClusterConfigProps</a>

Resource props.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.property.CFN_RESOURCE_TYPE_NAME">CFN_RESOURCE_TYPE_NAME</a></code> | <code>string</code> | The CloudFormation resource type name for this resource class. |

---

##### `CFN_RESOURCE_TYPE_NAME`<sup>Required</sup> <a name="CFN_RESOURCE_TYPE_NAME" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfig.property.CFN_RESOURCE_TYPE_NAME"></a>

```typescript
public readonly CFN_RESOURCE_TYPE_NAME: string;
```

- *Type:* string

The CloudFormation resource type name for this resource class.

---

### CfnLdapConfiguration <a name="CfnLdapConfiguration" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration"></a>

A CloudFormation `MongoDB::Atlas::LDAPConfiguration`.

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.Initializer"></a>

```typescript
import { CfnLdapConfiguration } from 'awscdk-resources-mongodbatlas'

new CfnLdapConfiguration(scope: Construct, id: string, props: CfnLdapConfigurationProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapConfiguration.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - scope in which this resource is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapConfiguration.Initializer.parameter.id">id</a></code> | <code>string</code> | - scoped id of the resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapConfiguration.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnLdapConfigurationProps">CfnLdapConfigurationProps</a></code> | - resource properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

scope in which this resource is defined.

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.Initializer.parameter.id"></a>

- *Type:* string

scoped id of the resource.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnLdapConfigurationProps">CfnLdapConfigurationProps</a>

resource properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapConfiguration.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapConfiguration.overrideLogicalId">overrideLogicalId</a></code> | Overrides the auto-generated logical ID with a specific ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapConfiguration.addDeletionOverride">addDeletionOverride</a></code> | Syntactic sugar for `addOverride(path, undefined)`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapConfiguration.addDependency">addDependency</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapConfiguration.addDependsOn">addDependsOn</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapConfiguration.addMetadata">addMetadata</a></code> | Add a value to the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapConfiguration.addOverride">addOverride</a></code> | Adds an override to the synthesized CloudFormation resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapConfiguration.addPropertyDeletionOverride">addPropertyDeletionOverride</a></code> | Adds an override that deletes the value of a property from the resource definition. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapConfiguration.addPropertyOverride">addPropertyOverride</a></code> | Adds an override to a resource property. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapConfiguration.applyRemovalPolicy">applyRemovalPolicy</a></code> | Sets the deletion policy of the resource based on the removal policy specified. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapConfiguration.getAtt">getAtt</a></code> | Returns a token for an runtime attribute of this resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapConfiguration.getMetadata">getMetadata</a></code> | Retrieve a value value from the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapConfiguration.obtainDependencies">obtainDependencies</a></code> | Retrieves an array of resources this resource depends on. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapConfiguration.obtainResourceDependencies">obtainResourceDependencies</a></code> | Get a shallow copy of dependencies between this resource and other resources in the same stack. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapConfiguration.removeDependency">removeDependency</a></code> | Indicates that this resource no longer depends on another resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapConfiguration.replaceDependency">replaceDependency</a></code> | Replaces one dependency with another. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `overrideLogicalId` <a name="overrideLogicalId" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.overrideLogicalId"></a>

```typescript
public overrideLogicalId(newLogicalId: string): void
```

Overrides the auto-generated logical ID with a specific ID.

###### `newLogicalId`<sup>Required</sup> <a name="newLogicalId" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.overrideLogicalId.parameter.newLogicalId"></a>

- *Type:* string

The new logical ID to use for this stack element.

---

##### `addDeletionOverride` <a name="addDeletionOverride" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.addDeletionOverride"></a>

```typescript
public addDeletionOverride(path: string): void
```

Syntactic sugar for `addOverride(path, undefined)`.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.addDeletionOverride.parameter.path"></a>

- *Type:* string

The path of the value to delete.

---

##### `addDependency` <a name="addDependency" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.addDependency"></a>

```typescript
public addDependency(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

This can be used for resources across stacks (or nested stack) boundaries
and the dependency will automatically be transferred to the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.addDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### ~~`addDependsOn`~~ <a name="addDependsOn" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.addDependsOn"></a>

```typescript
public addDependsOn(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.addDependsOn.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `addMetadata` <a name="addMetadata" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.addMetadata"></a>

```typescript
public addMetadata(key: string, value: any): void
```

Add a value to the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.addMetadata.parameter.key"></a>

- *Type:* string

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.addMetadata.parameter.value"></a>

- *Type:* any

---

##### `addOverride` <a name="addOverride" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.addOverride"></a>

```typescript
public addOverride(path: string, value: any): void
```

Adds an override to the synthesized CloudFormation resource.

To add a
property override, either use `addPropertyOverride` or prefix `path` with
"Properties." (i.e. `Properties.TopicName`).

If the override is nested, separate each nested level using a dot (.) in the path parameter.
If there is an array as part of the nesting, specify the index in the path.

To include a literal `.` in the property name, prefix with a `\`. In most
programming languages you will need to write this as `"\\."` because the
`\` itself will need to be escaped.

For example,
```typescript
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
```
would add the overrides
```json
"Properties": {
  "GlobalSecondaryIndexes": [
    {
      "Projection": {
        "NonKeyAttributes": [ "myattribute" ]
        ...
      }
      ...
    },
    {
      "ProjectionType": "INCLUDE"
      ...
    },
  ]
  ...
}
```

The `value` argument to `addOverride` will not be processed or translated
in any way. Pass raw JSON values in here with the correct capitalization
for CloudFormation. If you pass CDK classes or structs, they will be
rendered with lowercased key names, and CloudFormation will reject the
template.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.addOverride.parameter.path"></a>

- *Type:* string

The path of the property, you can use dot notation to override values in complex types.

Any intermediate keys
will be created as needed.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.addOverride.parameter.value"></a>

- *Type:* any

The value.

Could be primitive or complex.

---

##### `addPropertyDeletionOverride` <a name="addPropertyDeletionOverride" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.addPropertyDeletionOverride"></a>

```typescript
public addPropertyDeletionOverride(propertyPath: string): void
```

Adds an override that deletes the value of a property from the resource definition.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.addPropertyDeletionOverride.parameter.propertyPath"></a>

- *Type:* string

The path to the property.

---

##### `addPropertyOverride` <a name="addPropertyOverride" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.addPropertyOverride"></a>

```typescript
public addPropertyOverride(propertyPath: string, value: any): void
```

Adds an override to a resource property.

Syntactic sugar for `addOverride("Properties.<...>", value)`.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.addPropertyOverride.parameter.propertyPath"></a>

- *Type:* string

The path of the property.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.addPropertyOverride.parameter.value"></a>

- *Type:* any

The value.

---

##### `applyRemovalPolicy` <a name="applyRemovalPolicy" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.applyRemovalPolicy"></a>

```typescript
public applyRemovalPolicy(policy?: RemovalPolicy, options?: RemovalPolicyOptions): void
```

Sets the deletion policy of the resource based on the removal policy specified.

The Removal Policy controls what happens to this resource when it stops
being managed by CloudFormation, either because you've removed it from the
CDK application or because you've made a change that requires the resource
to be replaced.

The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
cases, a snapshot can be taken of the resource prior to deletion
(`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
can be found in the following link:

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options)

###### `policy`<sup>Optional</sup> <a name="policy" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.applyRemovalPolicy.parameter.policy"></a>

- *Type:* aws-cdk-lib.RemovalPolicy

---

###### `options`<sup>Optional</sup> <a name="options" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.applyRemovalPolicy.parameter.options"></a>

- *Type:* aws-cdk-lib.RemovalPolicyOptions

---

##### `getAtt` <a name="getAtt" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.getAtt"></a>

```typescript
public getAtt(attributeName: string, typeHint?: ResolutionTypeHint): Reference
```

Returns a token for an runtime attribute of this resource.

Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
in case there is no generated attribute.

###### `attributeName`<sup>Required</sup> <a name="attributeName" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.getAtt.parameter.attributeName"></a>

- *Type:* string

The name of the attribute.

---

###### `typeHint`<sup>Optional</sup> <a name="typeHint" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.getAtt.parameter.typeHint"></a>

- *Type:* aws-cdk-lib.ResolutionTypeHint

---

##### `getMetadata` <a name="getMetadata" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.getMetadata"></a>

```typescript
public getMetadata(key: string): any
```

Retrieve a value value from the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.getMetadata.parameter.key"></a>

- *Type:* string

---

##### `obtainDependencies` <a name="obtainDependencies" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.obtainDependencies"></a>

```typescript
public obtainDependencies(): Stack | CfnResource[]
```

Retrieves an array of resources this resource depends on.

This assembles dependencies on resources across stacks (including nested stacks)
automatically.

##### `obtainResourceDependencies` <a name="obtainResourceDependencies" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.obtainResourceDependencies"></a>

```typescript
public obtainResourceDependencies(): CfnResource[]
```

Get a shallow copy of dependencies between this resource and other resources in the same stack.

##### `removeDependency` <a name="removeDependency" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.removeDependency"></a>

```typescript
public removeDependency(target: CfnResource): void
```

Indicates that this resource no longer depends on another resource.

This can be used for resources across stacks (including nested stacks)
and the dependency will automatically be removed from the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.removeDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `replaceDependency` <a name="replaceDependency" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.replaceDependency"></a>

```typescript
public replaceDependency(target: CfnResource, newTarget: CfnResource): void
```

Replaces one dependency with another.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.replaceDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

The dependency to replace.

---

###### `newTarget`<sup>Required</sup> <a name="newTarget" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.replaceDependency.parameter.newTarget"></a>

- *Type:* aws-cdk-lib.CfnResource

The new dependency to add.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapConfiguration.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapConfiguration.isCfnElement">isCfnElement</a></code> | Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapConfiguration.isCfnResource">isCfnResource</a></code> | Check whether the given construct is a CfnResource. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.isConstruct"></a>

```typescript
import { CfnLdapConfiguration } from 'awscdk-resources-mongodbatlas'

CfnLdapConfiguration.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `isCfnElement` <a name="isCfnElement" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.isCfnElement"></a>

```typescript
import { CfnLdapConfiguration } from 'awscdk-resources-mongodbatlas'

CfnLdapConfiguration.isCfnElement(x: any)
```

Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).

Uses duck-typing instead of `instanceof` to allow stack elements from different
versions of this library to be included in the same stack.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.isCfnElement.parameter.x"></a>

- *Type:* any

---

##### `isCfnResource` <a name="isCfnResource" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.isCfnResource"></a>

```typescript
import { CfnLdapConfiguration } from 'awscdk-resources-mongodbatlas'

CfnLdapConfiguration.isCfnResource(construct: IConstruct)
```

Check whether the given construct is a CfnResource.

###### `construct`<sup>Required</sup> <a name="construct" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.isCfnResource.parameter.construct"></a>

- *Type:* constructs.IConstruct

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapConfiguration.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapConfiguration.property.creationStack">creationStack</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapConfiguration.property.logicalId">logicalId</a></code> | <code>string</code> | The logical ID for this CloudFormation stack element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapConfiguration.property.stack">stack</a></code> | <code>aws-cdk-lib.Stack</code> | The stack in which this element is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapConfiguration.property.ref">ref</a></code> | <code>string</code> | Return a string that will be resolved to a CloudFormation `{ Ref }` for this element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapConfiguration.property.cfnOptions">cfnOptions</a></code> | <code>aws-cdk-lib.ICfnResourceOptions</code> | Options for this resource, such as condition, update policy etc. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapConfiguration.property.cfnResourceType">cfnResourceType</a></code> | <code>string</code> | AWS resource type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapConfiguration.property.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnLdapConfigurationProps">CfnLdapConfigurationProps</a></code> | Resource props. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `creationStack`<sup>Required</sup> <a name="creationStack" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.property.creationStack"></a>

```typescript
public readonly creationStack: string[];
```

- *Type:* string[]

---

##### `logicalId`<sup>Required</sup> <a name="logicalId" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.property.logicalId"></a>

```typescript
public readonly logicalId: string;
```

- *Type:* string

The logical ID for this CloudFormation stack element.

The logical ID of the element
is calculated from the path of the resource node in the construct tree.

To override this value, use `overrideLogicalId(newLogicalId)`.

---

##### `stack`<sup>Required</sup> <a name="stack" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.property.stack"></a>

```typescript
public readonly stack: Stack;
```

- *Type:* aws-cdk-lib.Stack

The stack in which this element is defined.

CfnElements must be defined within a stack scope (directly or indirectly).

---

##### `ref`<sup>Required</sup> <a name="ref" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.

If, by any chance, the intrinsic reference of a resource is not a string, you could
coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.

---

##### `cfnOptions`<sup>Required</sup> <a name="cfnOptions" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.property.cfnOptions"></a>

```typescript
public readonly cfnOptions: ICfnResourceOptions;
```

- *Type:* aws-cdk-lib.ICfnResourceOptions

Options for this resource, such as condition, update policy etc.

---

##### `cfnResourceType`<sup>Required</sup> <a name="cfnResourceType" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.property.cfnResourceType"></a>

```typescript
public readonly cfnResourceType: string;
```

- *Type:* string

AWS resource type.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.property.props"></a>

```typescript
public readonly props: CfnLdapConfigurationProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnLdapConfigurationProps">CfnLdapConfigurationProps</a>

Resource props.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapConfiguration.property.CFN_RESOURCE_TYPE_NAME">CFN_RESOURCE_TYPE_NAME</a></code> | <code>string</code> | The CloudFormation resource type name for this resource class. |

---

##### `CFN_RESOURCE_TYPE_NAME`<sup>Required</sup> <a name="CFN_RESOURCE_TYPE_NAME" id="awscdk-resources-mongodbatlas.CfnLdapConfiguration.property.CFN_RESOURCE_TYPE_NAME"></a>

```typescript
public readonly CFN_RESOURCE_TYPE_NAME: string;
```

- *Type:* string

The CloudFormation resource type name for this resource class.

---

### CfnLdapVerify <a name="CfnLdapVerify" id="awscdk-resources-mongodbatlas.CfnLdapVerify"></a>

A CloudFormation `MongoDB::Atlas::LDAPVerify`.

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.CfnLdapVerify.Initializer"></a>

```typescript
import { CfnLdapVerify } from 'awscdk-resources-mongodbatlas'

new CfnLdapVerify(scope: Construct, id: string, props: CfnLdapVerifyProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapVerify.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - scope in which this resource is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapVerify.Initializer.parameter.id">id</a></code> | <code>string</code> | - scoped id of the resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapVerify.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnLdapVerifyProps">CfnLdapVerifyProps</a></code> | - resource properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.CfnLdapVerify.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

scope in which this resource is defined.

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnLdapVerify.Initializer.parameter.id"></a>

- *Type:* string

scoped id of the resource.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnLdapVerify.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnLdapVerifyProps">CfnLdapVerifyProps</a>

resource properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapVerify.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapVerify.overrideLogicalId">overrideLogicalId</a></code> | Overrides the auto-generated logical ID with a specific ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapVerify.addDeletionOverride">addDeletionOverride</a></code> | Syntactic sugar for `addOverride(path, undefined)`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapVerify.addDependency">addDependency</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapVerify.addDependsOn">addDependsOn</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapVerify.addMetadata">addMetadata</a></code> | Add a value to the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapVerify.addOverride">addOverride</a></code> | Adds an override to the synthesized CloudFormation resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapVerify.addPropertyDeletionOverride">addPropertyDeletionOverride</a></code> | Adds an override that deletes the value of a property from the resource definition. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapVerify.addPropertyOverride">addPropertyOverride</a></code> | Adds an override to a resource property. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapVerify.applyRemovalPolicy">applyRemovalPolicy</a></code> | Sets the deletion policy of the resource based on the removal policy specified. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapVerify.getAtt">getAtt</a></code> | Returns a token for an runtime attribute of this resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapVerify.getMetadata">getMetadata</a></code> | Retrieve a value value from the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapVerify.obtainDependencies">obtainDependencies</a></code> | Retrieves an array of resources this resource depends on. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapVerify.obtainResourceDependencies">obtainResourceDependencies</a></code> | Get a shallow copy of dependencies between this resource and other resources in the same stack. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapVerify.removeDependency">removeDependency</a></code> | Indicates that this resource no longer depends on another resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapVerify.replaceDependency">replaceDependency</a></code> | Replaces one dependency with another. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.CfnLdapVerify.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `overrideLogicalId` <a name="overrideLogicalId" id="awscdk-resources-mongodbatlas.CfnLdapVerify.overrideLogicalId"></a>

```typescript
public overrideLogicalId(newLogicalId: string): void
```

Overrides the auto-generated logical ID with a specific ID.

###### `newLogicalId`<sup>Required</sup> <a name="newLogicalId" id="awscdk-resources-mongodbatlas.CfnLdapVerify.overrideLogicalId.parameter.newLogicalId"></a>

- *Type:* string

The new logical ID to use for this stack element.

---

##### `addDeletionOverride` <a name="addDeletionOverride" id="awscdk-resources-mongodbatlas.CfnLdapVerify.addDeletionOverride"></a>

```typescript
public addDeletionOverride(path: string): void
```

Syntactic sugar for `addOverride(path, undefined)`.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnLdapVerify.addDeletionOverride.parameter.path"></a>

- *Type:* string

The path of the value to delete.

---

##### `addDependency` <a name="addDependency" id="awscdk-resources-mongodbatlas.CfnLdapVerify.addDependency"></a>

```typescript
public addDependency(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

This can be used for resources across stacks (or nested stack) boundaries
and the dependency will automatically be transferred to the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnLdapVerify.addDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### ~~`addDependsOn`~~ <a name="addDependsOn" id="awscdk-resources-mongodbatlas.CfnLdapVerify.addDependsOn"></a>

```typescript
public addDependsOn(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnLdapVerify.addDependsOn.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `addMetadata` <a name="addMetadata" id="awscdk-resources-mongodbatlas.CfnLdapVerify.addMetadata"></a>

```typescript
public addMetadata(key: string, value: any): void
```

Add a value to the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnLdapVerify.addMetadata.parameter.key"></a>

- *Type:* string

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnLdapVerify.addMetadata.parameter.value"></a>

- *Type:* any

---

##### `addOverride` <a name="addOverride" id="awscdk-resources-mongodbatlas.CfnLdapVerify.addOverride"></a>

```typescript
public addOverride(path: string, value: any): void
```

Adds an override to the synthesized CloudFormation resource.

To add a
property override, either use `addPropertyOverride` or prefix `path` with
"Properties." (i.e. `Properties.TopicName`).

If the override is nested, separate each nested level using a dot (.) in the path parameter.
If there is an array as part of the nesting, specify the index in the path.

To include a literal `.` in the property name, prefix with a `\`. In most
programming languages you will need to write this as `"\\."` because the
`\` itself will need to be escaped.

For example,
```typescript
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
```
would add the overrides
```json
"Properties": {
  "GlobalSecondaryIndexes": [
    {
      "Projection": {
        "NonKeyAttributes": [ "myattribute" ]
        ...
      }
      ...
    },
    {
      "ProjectionType": "INCLUDE"
      ...
    },
  ]
  ...
}
```

The `value` argument to `addOverride` will not be processed or translated
in any way. Pass raw JSON values in here with the correct capitalization
for CloudFormation. If you pass CDK classes or structs, they will be
rendered with lowercased key names, and CloudFormation will reject the
template.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnLdapVerify.addOverride.parameter.path"></a>

- *Type:* string

The path of the property, you can use dot notation to override values in complex types.

Any intermediate keys
will be created as needed.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnLdapVerify.addOverride.parameter.value"></a>

- *Type:* any

The value.

Could be primitive or complex.

---

##### `addPropertyDeletionOverride` <a name="addPropertyDeletionOverride" id="awscdk-resources-mongodbatlas.CfnLdapVerify.addPropertyDeletionOverride"></a>

```typescript
public addPropertyDeletionOverride(propertyPath: string): void
```

Adds an override that deletes the value of a property from the resource definition.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnLdapVerify.addPropertyDeletionOverride.parameter.propertyPath"></a>

- *Type:* string

The path to the property.

---

##### `addPropertyOverride` <a name="addPropertyOverride" id="awscdk-resources-mongodbatlas.CfnLdapVerify.addPropertyOverride"></a>

```typescript
public addPropertyOverride(propertyPath: string, value: any): void
```

Adds an override to a resource property.

Syntactic sugar for `addOverride("Properties.<...>", value)`.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnLdapVerify.addPropertyOverride.parameter.propertyPath"></a>

- *Type:* string

The path of the property.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnLdapVerify.addPropertyOverride.parameter.value"></a>

- *Type:* any

The value.

---

##### `applyRemovalPolicy` <a name="applyRemovalPolicy" id="awscdk-resources-mongodbatlas.CfnLdapVerify.applyRemovalPolicy"></a>

```typescript
public applyRemovalPolicy(policy?: RemovalPolicy, options?: RemovalPolicyOptions): void
```

Sets the deletion policy of the resource based on the removal policy specified.

The Removal Policy controls what happens to this resource when it stops
being managed by CloudFormation, either because you've removed it from the
CDK application or because you've made a change that requires the resource
to be replaced.

The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
cases, a snapshot can be taken of the resource prior to deletion
(`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
can be found in the following link:

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options)

###### `policy`<sup>Optional</sup> <a name="policy" id="awscdk-resources-mongodbatlas.CfnLdapVerify.applyRemovalPolicy.parameter.policy"></a>

- *Type:* aws-cdk-lib.RemovalPolicy

---

###### `options`<sup>Optional</sup> <a name="options" id="awscdk-resources-mongodbatlas.CfnLdapVerify.applyRemovalPolicy.parameter.options"></a>

- *Type:* aws-cdk-lib.RemovalPolicyOptions

---

##### `getAtt` <a name="getAtt" id="awscdk-resources-mongodbatlas.CfnLdapVerify.getAtt"></a>

```typescript
public getAtt(attributeName: string, typeHint?: ResolutionTypeHint): Reference
```

Returns a token for an runtime attribute of this resource.

Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
in case there is no generated attribute.

###### `attributeName`<sup>Required</sup> <a name="attributeName" id="awscdk-resources-mongodbatlas.CfnLdapVerify.getAtt.parameter.attributeName"></a>

- *Type:* string

The name of the attribute.

---

###### `typeHint`<sup>Optional</sup> <a name="typeHint" id="awscdk-resources-mongodbatlas.CfnLdapVerify.getAtt.parameter.typeHint"></a>

- *Type:* aws-cdk-lib.ResolutionTypeHint

---

##### `getMetadata` <a name="getMetadata" id="awscdk-resources-mongodbatlas.CfnLdapVerify.getMetadata"></a>

```typescript
public getMetadata(key: string): any
```

Retrieve a value value from the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnLdapVerify.getMetadata.parameter.key"></a>

- *Type:* string

---

##### `obtainDependencies` <a name="obtainDependencies" id="awscdk-resources-mongodbatlas.CfnLdapVerify.obtainDependencies"></a>

```typescript
public obtainDependencies(): Stack | CfnResource[]
```

Retrieves an array of resources this resource depends on.

This assembles dependencies on resources across stacks (including nested stacks)
automatically.

##### `obtainResourceDependencies` <a name="obtainResourceDependencies" id="awscdk-resources-mongodbatlas.CfnLdapVerify.obtainResourceDependencies"></a>

```typescript
public obtainResourceDependencies(): CfnResource[]
```

Get a shallow copy of dependencies between this resource and other resources in the same stack.

##### `removeDependency` <a name="removeDependency" id="awscdk-resources-mongodbatlas.CfnLdapVerify.removeDependency"></a>

```typescript
public removeDependency(target: CfnResource): void
```

Indicates that this resource no longer depends on another resource.

This can be used for resources across stacks (including nested stacks)
and the dependency will automatically be removed from the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnLdapVerify.removeDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `replaceDependency` <a name="replaceDependency" id="awscdk-resources-mongodbatlas.CfnLdapVerify.replaceDependency"></a>

```typescript
public replaceDependency(target: CfnResource, newTarget: CfnResource): void
```

Replaces one dependency with another.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnLdapVerify.replaceDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

The dependency to replace.

---

###### `newTarget`<sup>Required</sup> <a name="newTarget" id="awscdk-resources-mongodbatlas.CfnLdapVerify.replaceDependency.parameter.newTarget"></a>

- *Type:* aws-cdk-lib.CfnResource

The new dependency to add.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapVerify.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapVerify.isCfnElement">isCfnElement</a></code> | Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapVerify.isCfnResource">isCfnResource</a></code> | Check whether the given construct is a CfnResource. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.CfnLdapVerify.isConstruct"></a>

```typescript
import { CfnLdapVerify } from 'awscdk-resources-mongodbatlas'

CfnLdapVerify.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnLdapVerify.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `isCfnElement` <a name="isCfnElement" id="awscdk-resources-mongodbatlas.CfnLdapVerify.isCfnElement"></a>

```typescript
import { CfnLdapVerify } from 'awscdk-resources-mongodbatlas'

CfnLdapVerify.isCfnElement(x: any)
```

Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).

Uses duck-typing instead of `instanceof` to allow stack elements from different
versions of this library to be included in the same stack.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnLdapVerify.isCfnElement.parameter.x"></a>

- *Type:* any

---

##### `isCfnResource` <a name="isCfnResource" id="awscdk-resources-mongodbatlas.CfnLdapVerify.isCfnResource"></a>

```typescript
import { CfnLdapVerify } from 'awscdk-resources-mongodbatlas'

CfnLdapVerify.isCfnResource(construct: IConstruct)
```

Check whether the given construct is a CfnResource.

###### `construct`<sup>Required</sup> <a name="construct" id="awscdk-resources-mongodbatlas.CfnLdapVerify.isCfnResource.parameter.construct"></a>

- *Type:* constructs.IConstruct

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapVerify.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapVerify.property.creationStack">creationStack</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapVerify.property.logicalId">logicalId</a></code> | <code>string</code> | The logical ID for this CloudFormation stack element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapVerify.property.stack">stack</a></code> | <code>aws-cdk-lib.Stack</code> | The stack in which this element is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapVerify.property.ref">ref</a></code> | <code>string</code> | Return a string that will be resolved to a CloudFormation `{ Ref }` for this element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapVerify.property.cfnOptions">cfnOptions</a></code> | <code>aws-cdk-lib.ICfnResourceOptions</code> | Options for this resource, such as condition, update policy etc. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapVerify.property.cfnResourceType">cfnResourceType</a></code> | <code>string</code> | AWS resource type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapVerify.property.attrRequestId">attrRequestId</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::LDAPVerify.RequestId`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapVerify.property.attrStatus">attrStatus</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::LDAPVerify.Status`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapVerify.property.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnLdapVerifyProps">CfnLdapVerifyProps</a></code> | Resource props. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.CfnLdapVerify.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `creationStack`<sup>Required</sup> <a name="creationStack" id="awscdk-resources-mongodbatlas.CfnLdapVerify.property.creationStack"></a>

```typescript
public readonly creationStack: string[];
```

- *Type:* string[]

---

##### `logicalId`<sup>Required</sup> <a name="logicalId" id="awscdk-resources-mongodbatlas.CfnLdapVerify.property.logicalId"></a>

```typescript
public readonly logicalId: string;
```

- *Type:* string

The logical ID for this CloudFormation stack element.

The logical ID of the element
is calculated from the path of the resource node in the construct tree.

To override this value, use `overrideLogicalId(newLogicalId)`.

---

##### `stack`<sup>Required</sup> <a name="stack" id="awscdk-resources-mongodbatlas.CfnLdapVerify.property.stack"></a>

```typescript
public readonly stack: Stack;
```

- *Type:* aws-cdk-lib.Stack

The stack in which this element is defined.

CfnElements must be defined within a stack scope (directly or indirectly).

---

##### `ref`<sup>Required</sup> <a name="ref" id="awscdk-resources-mongodbatlas.CfnLdapVerify.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.

If, by any chance, the intrinsic reference of a resource is not a string, you could
coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.

---

##### `cfnOptions`<sup>Required</sup> <a name="cfnOptions" id="awscdk-resources-mongodbatlas.CfnLdapVerify.property.cfnOptions"></a>

```typescript
public readonly cfnOptions: ICfnResourceOptions;
```

- *Type:* aws-cdk-lib.ICfnResourceOptions

Options for this resource, such as condition, update policy etc.

---

##### `cfnResourceType`<sup>Required</sup> <a name="cfnResourceType" id="awscdk-resources-mongodbatlas.CfnLdapVerify.property.cfnResourceType"></a>

```typescript
public readonly cfnResourceType: string;
```

- *Type:* string

AWS resource type.

---

##### `attrRequestId`<sup>Required</sup> <a name="attrRequestId" id="awscdk-resources-mongodbatlas.CfnLdapVerify.property.attrRequestId"></a>

```typescript
public readonly attrRequestId: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::LDAPVerify.RequestId`.

---

##### `attrStatus`<sup>Required</sup> <a name="attrStatus" id="awscdk-resources-mongodbatlas.CfnLdapVerify.property.attrStatus"></a>

```typescript
public readonly attrStatus: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::LDAPVerify.Status`.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnLdapVerify.property.props"></a>

```typescript
public readonly props: CfnLdapVerifyProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnLdapVerifyProps">CfnLdapVerifyProps</a>

Resource props.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapVerify.property.CFN_RESOURCE_TYPE_NAME">CFN_RESOURCE_TYPE_NAME</a></code> | <code>string</code> | The CloudFormation resource type name for this resource class. |

---

##### `CFN_RESOURCE_TYPE_NAME`<sup>Required</sup> <a name="CFN_RESOURCE_TYPE_NAME" id="awscdk-resources-mongodbatlas.CfnLdapVerify.property.CFN_RESOURCE_TYPE_NAME"></a>

```typescript
public readonly CFN_RESOURCE_TYPE_NAME: string;
```

- *Type:* string

The CloudFormation resource type name for this resource class.

---

### CfnMaintenanceWindow <a name="CfnMaintenanceWindow" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow"></a>

A CloudFormation `MongoDB::Atlas::MaintenanceWindow`.

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.Initializer"></a>

```typescript
import { CfnMaintenanceWindow } from 'awscdk-resources-mongodbatlas'

new CfnMaintenanceWindow(scope: Construct, id: string, props: CfnMaintenanceWindowProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnMaintenanceWindow.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - scope in which this resource is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnMaintenanceWindow.Initializer.parameter.id">id</a></code> | <code>string</code> | - scoped id of the resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnMaintenanceWindow.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnMaintenanceWindowProps">CfnMaintenanceWindowProps</a></code> | - resource properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

scope in which this resource is defined.

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.Initializer.parameter.id"></a>

- *Type:* string

scoped id of the resource.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnMaintenanceWindowProps">CfnMaintenanceWindowProps</a>

resource properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnMaintenanceWindow.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnMaintenanceWindow.overrideLogicalId">overrideLogicalId</a></code> | Overrides the auto-generated logical ID with a specific ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnMaintenanceWindow.addDeletionOverride">addDeletionOverride</a></code> | Syntactic sugar for `addOverride(path, undefined)`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnMaintenanceWindow.addDependency">addDependency</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnMaintenanceWindow.addDependsOn">addDependsOn</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnMaintenanceWindow.addMetadata">addMetadata</a></code> | Add a value to the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnMaintenanceWindow.addOverride">addOverride</a></code> | Adds an override to the synthesized CloudFormation resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnMaintenanceWindow.addPropertyDeletionOverride">addPropertyDeletionOverride</a></code> | Adds an override that deletes the value of a property from the resource definition. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnMaintenanceWindow.addPropertyOverride">addPropertyOverride</a></code> | Adds an override to a resource property. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnMaintenanceWindow.applyRemovalPolicy">applyRemovalPolicy</a></code> | Sets the deletion policy of the resource based on the removal policy specified. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnMaintenanceWindow.getAtt">getAtt</a></code> | Returns a token for an runtime attribute of this resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnMaintenanceWindow.getMetadata">getMetadata</a></code> | Retrieve a value value from the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnMaintenanceWindow.obtainDependencies">obtainDependencies</a></code> | Retrieves an array of resources this resource depends on. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnMaintenanceWindow.obtainResourceDependencies">obtainResourceDependencies</a></code> | Get a shallow copy of dependencies between this resource and other resources in the same stack. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnMaintenanceWindow.removeDependency">removeDependency</a></code> | Indicates that this resource no longer depends on another resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnMaintenanceWindow.replaceDependency">replaceDependency</a></code> | Replaces one dependency with another. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `overrideLogicalId` <a name="overrideLogicalId" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.overrideLogicalId"></a>

```typescript
public overrideLogicalId(newLogicalId: string): void
```

Overrides the auto-generated logical ID with a specific ID.

###### `newLogicalId`<sup>Required</sup> <a name="newLogicalId" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.overrideLogicalId.parameter.newLogicalId"></a>

- *Type:* string

The new logical ID to use for this stack element.

---

##### `addDeletionOverride` <a name="addDeletionOverride" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.addDeletionOverride"></a>

```typescript
public addDeletionOverride(path: string): void
```

Syntactic sugar for `addOverride(path, undefined)`.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.addDeletionOverride.parameter.path"></a>

- *Type:* string

The path of the value to delete.

---

##### `addDependency` <a name="addDependency" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.addDependency"></a>

```typescript
public addDependency(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

This can be used for resources across stacks (or nested stack) boundaries
and the dependency will automatically be transferred to the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.addDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### ~~`addDependsOn`~~ <a name="addDependsOn" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.addDependsOn"></a>

```typescript
public addDependsOn(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.addDependsOn.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `addMetadata` <a name="addMetadata" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.addMetadata"></a>

```typescript
public addMetadata(key: string, value: any): void
```

Add a value to the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.addMetadata.parameter.key"></a>

- *Type:* string

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.addMetadata.parameter.value"></a>

- *Type:* any

---

##### `addOverride` <a name="addOverride" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.addOverride"></a>

```typescript
public addOverride(path: string, value: any): void
```

Adds an override to the synthesized CloudFormation resource.

To add a
property override, either use `addPropertyOverride` or prefix `path` with
"Properties." (i.e. `Properties.TopicName`).

If the override is nested, separate each nested level using a dot (.) in the path parameter.
If there is an array as part of the nesting, specify the index in the path.

To include a literal `.` in the property name, prefix with a `\`. In most
programming languages you will need to write this as `"\\."` because the
`\` itself will need to be escaped.

For example,
```typescript
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
```
would add the overrides
```json
"Properties": {
  "GlobalSecondaryIndexes": [
    {
      "Projection": {
        "NonKeyAttributes": [ "myattribute" ]
        ...
      }
      ...
    },
    {
      "ProjectionType": "INCLUDE"
      ...
    },
  ]
  ...
}
```

The `value` argument to `addOverride` will not be processed or translated
in any way. Pass raw JSON values in here with the correct capitalization
for CloudFormation. If you pass CDK classes or structs, they will be
rendered with lowercased key names, and CloudFormation will reject the
template.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.addOverride.parameter.path"></a>

- *Type:* string

The path of the property, you can use dot notation to override values in complex types.

Any intermediate keys
will be created as needed.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.addOverride.parameter.value"></a>

- *Type:* any

The value.

Could be primitive or complex.

---

##### `addPropertyDeletionOverride` <a name="addPropertyDeletionOverride" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.addPropertyDeletionOverride"></a>

```typescript
public addPropertyDeletionOverride(propertyPath: string): void
```

Adds an override that deletes the value of a property from the resource definition.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.addPropertyDeletionOverride.parameter.propertyPath"></a>

- *Type:* string

The path to the property.

---

##### `addPropertyOverride` <a name="addPropertyOverride" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.addPropertyOverride"></a>

```typescript
public addPropertyOverride(propertyPath: string, value: any): void
```

Adds an override to a resource property.

Syntactic sugar for `addOverride("Properties.<...>", value)`.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.addPropertyOverride.parameter.propertyPath"></a>

- *Type:* string

The path of the property.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.addPropertyOverride.parameter.value"></a>

- *Type:* any

The value.

---

##### `applyRemovalPolicy` <a name="applyRemovalPolicy" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.applyRemovalPolicy"></a>

```typescript
public applyRemovalPolicy(policy?: RemovalPolicy, options?: RemovalPolicyOptions): void
```

Sets the deletion policy of the resource based on the removal policy specified.

The Removal Policy controls what happens to this resource when it stops
being managed by CloudFormation, either because you've removed it from the
CDK application or because you've made a change that requires the resource
to be replaced.

The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
cases, a snapshot can be taken of the resource prior to deletion
(`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
can be found in the following link:

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options)

###### `policy`<sup>Optional</sup> <a name="policy" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.applyRemovalPolicy.parameter.policy"></a>

- *Type:* aws-cdk-lib.RemovalPolicy

---

###### `options`<sup>Optional</sup> <a name="options" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.applyRemovalPolicy.parameter.options"></a>

- *Type:* aws-cdk-lib.RemovalPolicyOptions

---

##### `getAtt` <a name="getAtt" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.getAtt"></a>

```typescript
public getAtt(attributeName: string, typeHint?: ResolutionTypeHint): Reference
```

Returns a token for an runtime attribute of this resource.

Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
in case there is no generated attribute.

###### `attributeName`<sup>Required</sup> <a name="attributeName" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.getAtt.parameter.attributeName"></a>

- *Type:* string

The name of the attribute.

---

###### `typeHint`<sup>Optional</sup> <a name="typeHint" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.getAtt.parameter.typeHint"></a>

- *Type:* aws-cdk-lib.ResolutionTypeHint

---

##### `getMetadata` <a name="getMetadata" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.getMetadata"></a>

```typescript
public getMetadata(key: string): any
```

Retrieve a value value from the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.getMetadata.parameter.key"></a>

- *Type:* string

---

##### `obtainDependencies` <a name="obtainDependencies" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.obtainDependencies"></a>

```typescript
public obtainDependencies(): Stack | CfnResource[]
```

Retrieves an array of resources this resource depends on.

This assembles dependencies on resources across stacks (including nested stacks)
automatically.

##### `obtainResourceDependencies` <a name="obtainResourceDependencies" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.obtainResourceDependencies"></a>

```typescript
public obtainResourceDependencies(): CfnResource[]
```

Get a shallow copy of dependencies between this resource and other resources in the same stack.

##### `removeDependency` <a name="removeDependency" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.removeDependency"></a>

```typescript
public removeDependency(target: CfnResource): void
```

Indicates that this resource no longer depends on another resource.

This can be used for resources across stacks (including nested stacks)
and the dependency will automatically be removed from the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.removeDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `replaceDependency` <a name="replaceDependency" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.replaceDependency"></a>

```typescript
public replaceDependency(target: CfnResource, newTarget: CfnResource): void
```

Replaces one dependency with another.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.replaceDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

The dependency to replace.

---

###### `newTarget`<sup>Required</sup> <a name="newTarget" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.replaceDependency.parameter.newTarget"></a>

- *Type:* aws-cdk-lib.CfnResource

The new dependency to add.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnMaintenanceWindow.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnMaintenanceWindow.isCfnElement">isCfnElement</a></code> | Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnMaintenanceWindow.isCfnResource">isCfnResource</a></code> | Check whether the given construct is a CfnResource. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.isConstruct"></a>

```typescript
import { CfnMaintenanceWindow } from 'awscdk-resources-mongodbatlas'

CfnMaintenanceWindow.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `isCfnElement` <a name="isCfnElement" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.isCfnElement"></a>

```typescript
import { CfnMaintenanceWindow } from 'awscdk-resources-mongodbatlas'

CfnMaintenanceWindow.isCfnElement(x: any)
```

Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).

Uses duck-typing instead of `instanceof` to allow stack elements from different
versions of this library to be included in the same stack.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.isCfnElement.parameter.x"></a>

- *Type:* any

---

##### `isCfnResource` <a name="isCfnResource" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.isCfnResource"></a>

```typescript
import { CfnMaintenanceWindow } from 'awscdk-resources-mongodbatlas'

CfnMaintenanceWindow.isCfnResource(construct: IConstruct)
```

Check whether the given construct is a CfnResource.

###### `construct`<sup>Required</sup> <a name="construct" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.isCfnResource.parameter.construct"></a>

- *Type:* constructs.IConstruct

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnMaintenanceWindow.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnMaintenanceWindow.property.creationStack">creationStack</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnMaintenanceWindow.property.logicalId">logicalId</a></code> | <code>string</code> | The logical ID for this CloudFormation stack element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnMaintenanceWindow.property.stack">stack</a></code> | <code>aws-cdk-lib.Stack</code> | The stack in which this element is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnMaintenanceWindow.property.ref">ref</a></code> | <code>string</code> | Return a string that will be resolved to a CloudFormation `{ Ref }` for this element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnMaintenanceWindow.property.cfnOptions">cfnOptions</a></code> | <code>aws-cdk-lib.ICfnResourceOptions</code> | Options for this resource, such as condition, update policy etc. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnMaintenanceWindow.property.cfnResourceType">cfnResourceType</a></code> | <code>string</code> | AWS resource type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnMaintenanceWindow.property.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnMaintenanceWindowProps">CfnMaintenanceWindowProps</a></code> | Resource props. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `creationStack`<sup>Required</sup> <a name="creationStack" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.property.creationStack"></a>

```typescript
public readonly creationStack: string[];
```

- *Type:* string[]

---

##### `logicalId`<sup>Required</sup> <a name="logicalId" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.property.logicalId"></a>

```typescript
public readonly logicalId: string;
```

- *Type:* string

The logical ID for this CloudFormation stack element.

The logical ID of the element
is calculated from the path of the resource node in the construct tree.

To override this value, use `overrideLogicalId(newLogicalId)`.

---

##### `stack`<sup>Required</sup> <a name="stack" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.property.stack"></a>

```typescript
public readonly stack: Stack;
```

- *Type:* aws-cdk-lib.Stack

The stack in which this element is defined.

CfnElements must be defined within a stack scope (directly or indirectly).

---

##### `ref`<sup>Required</sup> <a name="ref" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.

If, by any chance, the intrinsic reference of a resource is not a string, you could
coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.

---

##### `cfnOptions`<sup>Required</sup> <a name="cfnOptions" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.property.cfnOptions"></a>

```typescript
public readonly cfnOptions: ICfnResourceOptions;
```

- *Type:* aws-cdk-lib.ICfnResourceOptions

Options for this resource, such as condition, update policy etc.

---

##### `cfnResourceType`<sup>Required</sup> <a name="cfnResourceType" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.property.cfnResourceType"></a>

```typescript
public readonly cfnResourceType: string;
```

- *Type:* string

AWS resource type.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.property.props"></a>

```typescript
public readonly props: CfnMaintenanceWindowProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnMaintenanceWindowProps">CfnMaintenanceWindowProps</a>

Resource props.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnMaintenanceWindow.property.CFN_RESOURCE_TYPE_NAME">CFN_RESOURCE_TYPE_NAME</a></code> | <code>string</code> | The CloudFormation resource type name for this resource class. |

---

##### `CFN_RESOURCE_TYPE_NAME`<sup>Required</sup> <a name="CFN_RESOURCE_TYPE_NAME" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindow.property.CFN_RESOURCE_TYPE_NAME"></a>

```typescript
public readonly CFN_RESOURCE_TYPE_NAME: string;
```

- *Type:* string

The CloudFormation resource type name for this resource class.

---

### CfnNetworkContainer <a name="CfnNetworkContainer" id="awscdk-resources-mongodbatlas.CfnNetworkContainer"></a>

A CloudFormation `MongoDB::Atlas::NetworkContainer`.

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.Initializer"></a>

```typescript
import { CfnNetworkContainer } from 'awscdk-resources-mongodbatlas'

new CfnNetworkContainer(scope: Construct, id: string, props: CfnNetworkContainerProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkContainer.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - scope in which this resource is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkContainer.Initializer.parameter.id">id</a></code> | <code>string</code> | - scoped id of the resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkContainer.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkContainerProps">CfnNetworkContainerProps</a></code> | - resource properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

scope in which this resource is defined.

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.Initializer.parameter.id"></a>

- *Type:* string

scoped id of the resource.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnNetworkContainerProps">CfnNetworkContainerProps</a>

resource properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkContainer.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkContainer.overrideLogicalId">overrideLogicalId</a></code> | Overrides the auto-generated logical ID with a specific ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkContainer.addDeletionOverride">addDeletionOverride</a></code> | Syntactic sugar for `addOverride(path, undefined)`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkContainer.addDependency">addDependency</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkContainer.addDependsOn">addDependsOn</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkContainer.addMetadata">addMetadata</a></code> | Add a value to the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkContainer.addOverride">addOverride</a></code> | Adds an override to the synthesized CloudFormation resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkContainer.addPropertyDeletionOverride">addPropertyDeletionOverride</a></code> | Adds an override that deletes the value of a property from the resource definition. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkContainer.addPropertyOverride">addPropertyOverride</a></code> | Adds an override to a resource property. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkContainer.applyRemovalPolicy">applyRemovalPolicy</a></code> | Sets the deletion policy of the resource based on the removal policy specified. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkContainer.getAtt">getAtt</a></code> | Returns a token for an runtime attribute of this resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkContainer.getMetadata">getMetadata</a></code> | Retrieve a value value from the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkContainer.obtainDependencies">obtainDependencies</a></code> | Retrieves an array of resources this resource depends on. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkContainer.obtainResourceDependencies">obtainResourceDependencies</a></code> | Get a shallow copy of dependencies between this resource and other resources in the same stack. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkContainer.removeDependency">removeDependency</a></code> | Indicates that this resource no longer depends on another resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkContainer.replaceDependency">replaceDependency</a></code> | Replaces one dependency with another. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `overrideLogicalId` <a name="overrideLogicalId" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.overrideLogicalId"></a>

```typescript
public overrideLogicalId(newLogicalId: string): void
```

Overrides the auto-generated logical ID with a specific ID.

###### `newLogicalId`<sup>Required</sup> <a name="newLogicalId" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.overrideLogicalId.parameter.newLogicalId"></a>

- *Type:* string

The new logical ID to use for this stack element.

---

##### `addDeletionOverride` <a name="addDeletionOverride" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.addDeletionOverride"></a>

```typescript
public addDeletionOverride(path: string): void
```

Syntactic sugar for `addOverride(path, undefined)`.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.addDeletionOverride.parameter.path"></a>

- *Type:* string

The path of the value to delete.

---

##### `addDependency` <a name="addDependency" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.addDependency"></a>

```typescript
public addDependency(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

This can be used for resources across stacks (or nested stack) boundaries
and the dependency will automatically be transferred to the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.addDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### ~~`addDependsOn`~~ <a name="addDependsOn" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.addDependsOn"></a>

```typescript
public addDependsOn(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.addDependsOn.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `addMetadata` <a name="addMetadata" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.addMetadata"></a>

```typescript
public addMetadata(key: string, value: any): void
```

Add a value to the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.addMetadata.parameter.key"></a>

- *Type:* string

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.addMetadata.parameter.value"></a>

- *Type:* any

---

##### `addOverride` <a name="addOverride" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.addOverride"></a>

```typescript
public addOverride(path: string, value: any): void
```

Adds an override to the synthesized CloudFormation resource.

To add a
property override, either use `addPropertyOverride` or prefix `path` with
"Properties." (i.e. `Properties.TopicName`).

If the override is nested, separate each nested level using a dot (.) in the path parameter.
If there is an array as part of the nesting, specify the index in the path.

To include a literal `.` in the property name, prefix with a `\`. In most
programming languages you will need to write this as `"\\."` because the
`\` itself will need to be escaped.

For example,
```typescript
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
```
would add the overrides
```json
"Properties": {
  "GlobalSecondaryIndexes": [
    {
      "Projection": {
        "NonKeyAttributes": [ "myattribute" ]
        ...
      }
      ...
    },
    {
      "ProjectionType": "INCLUDE"
      ...
    },
  ]
  ...
}
```

The `value` argument to `addOverride` will not be processed or translated
in any way. Pass raw JSON values in here with the correct capitalization
for CloudFormation. If you pass CDK classes or structs, they will be
rendered with lowercased key names, and CloudFormation will reject the
template.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.addOverride.parameter.path"></a>

- *Type:* string

The path of the property, you can use dot notation to override values in complex types.

Any intermediate keys
will be created as needed.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.addOverride.parameter.value"></a>

- *Type:* any

The value.

Could be primitive or complex.

---

##### `addPropertyDeletionOverride` <a name="addPropertyDeletionOverride" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.addPropertyDeletionOverride"></a>

```typescript
public addPropertyDeletionOverride(propertyPath: string): void
```

Adds an override that deletes the value of a property from the resource definition.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.addPropertyDeletionOverride.parameter.propertyPath"></a>

- *Type:* string

The path to the property.

---

##### `addPropertyOverride` <a name="addPropertyOverride" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.addPropertyOverride"></a>

```typescript
public addPropertyOverride(propertyPath: string, value: any): void
```

Adds an override to a resource property.

Syntactic sugar for `addOverride("Properties.<...>", value)`.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.addPropertyOverride.parameter.propertyPath"></a>

- *Type:* string

The path of the property.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.addPropertyOverride.parameter.value"></a>

- *Type:* any

The value.

---

##### `applyRemovalPolicy` <a name="applyRemovalPolicy" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.applyRemovalPolicy"></a>

```typescript
public applyRemovalPolicy(policy?: RemovalPolicy, options?: RemovalPolicyOptions): void
```

Sets the deletion policy of the resource based on the removal policy specified.

The Removal Policy controls what happens to this resource when it stops
being managed by CloudFormation, either because you've removed it from the
CDK application or because you've made a change that requires the resource
to be replaced.

The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
cases, a snapshot can be taken of the resource prior to deletion
(`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
can be found in the following link:

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options)

###### `policy`<sup>Optional</sup> <a name="policy" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.applyRemovalPolicy.parameter.policy"></a>

- *Type:* aws-cdk-lib.RemovalPolicy

---

###### `options`<sup>Optional</sup> <a name="options" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.applyRemovalPolicy.parameter.options"></a>

- *Type:* aws-cdk-lib.RemovalPolicyOptions

---

##### `getAtt` <a name="getAtt" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.getAtt"></a>

```typescript
public getAtt(attributeName: string, typeHint?: ResolutionTypeHint): Reference
```

Returns a token for an runtime attribute of this resource.

Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
in case there is no generated attribute.

###### `attributeName`<sup>Required</sup> <a name="attributeName" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.getAtt.parameter.attributeName"></a>

- *Type:* string

The name of the attribute.

---

###### `typeHint`<sup>Optional</sup> <a name="typeHint" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.getAtt.parameter.typeHint"></a>

- *Type:* aws-cdk-lib.ResolutionTypeHint

---

##### `getMetadata` <a name="getMetadata" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.getMetadata"></a>

```typescript
public getMetadata(key: string): any
```

Retrieve a value value from the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.getMetadata.parameter.key"></a>

- *Type:* string

---

##### `obtainDependencies` <a name="obtainDependencies" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.obtainDependencies"></a>

```typescript
public obtainDependencies(): Stack | CfnResource[]
```

Retrieves an array of resources this resource depends on.

This assembles dependencies on resources across stacks (including nested stacks)
automatically.

##### `obtainResourceDependencies` <a name="obtainResourceDependencies" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.obtainResourceDependencies"></a>

```typescript
public obtainResourceDependencies(): CfnResource[]
```

Get a shallow copy of dependencies between this resource and other resources in the same stack.

##### `removeDependency` <a name="removeDependency" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.removeDependency"></a>

```typescript
public removeDependency(target: CfnResource): void
```

Indicates that this resource no longer depends on another resource.

This can be used for resources across stacks (including nested stacks)
and the dependency will automatically be removed from the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.removeDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `replaceDependency` <a name="replaceDependency" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.replaceDependency"></a>

```typescript
public replaceDependency(target: CfnResource, newTarget: CfnResource): void
```

Replaces one dependency with another.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.replaceDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

The dependency to replace.

---

###### `newTarget`<sup>Required</sup> <a name="newTarget" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.replaceDependency.parameter.newTarget"></a>

- *Type:* aws-cdk-lib.CfnResource

The new dependency to add.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkContainer.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkContainer.isCfnElement">isCfnElement</a></code> | Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkContainer.isCfnResource">isCfnResource</a></code> | Check whether the given construct is a CfnResource. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.isConstruct"></a>

```typescript
import { CfnNetworkContainer } from 'awscdk-resources-mongodbatlas'

CfnNetworkContainer.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `isCfnElement` <a name="isCfnElement" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.isCfnElement"></a>

```typescript
import { CfnNetworkContainer } from 'awscdk-resources-mongodbatlas'

CfnNetworkContainer.isCfnElement(x: any)
```

Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).

Uses duck-typing instead of `instanceof` to allow stack elements from different
versions of this library to be included in the same stack.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.isCfnElement.parameter.x"></a>

- *Type:* any

---

##### `isCfnResource` <a name="isCfnResource" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.isCfnResource"></a>

```typescript
import { CfnNetworkContainer } from 'awscdk-resources-mongodbatlas'

CfnNetworkContainer.isCfnResource(construct: IConstruct)
```

Check whether the given construct is a CfnResource.

###### `construct`<sup>Required</sup> <a name="construct" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.isCfnResource.parameter.construct"></a>

- *Type:* constructs.IConstruct

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkContainer.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkContainer.property.creationStack">creationStack</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkContainer.property.logicalId">logicalId</a></code> | <code>string</code> | The logical ID for this CloudFormation stack element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkContainer.property.stack">stack</a></code> | <code>aws-cdk-lib.Stack</code> | The stack in which this element is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkContainer.property.ref">ref</a></code> | <code>string</code> | Return a string that will be resolved to a CloudFormation `{ Ref }` for this element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkContainer.property.cfnOptions">cfnOptions</a></code> | <code>aws-cdk-lib.ICfnResourceOptions</code> | Options for this resource, such as condition, update policy etc. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkContainer.property.cfnResourceType">cfnResourceType</a></code> | <code>string</code> | AWS resource type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkContainer.property.attrId">attrId</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::NetworkContainer.Id`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkContainer.property.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkContainerProps">CfnNetworkContainerProps</a></code> | Resource props. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `creationStack`<sup>Required</sup> <a name="creationStack" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.property.creationStack"></a>

```typescript
public readonly creationStack: string[];
```

- *Type:* string[]

---

##### `logicalId`<sup>Required</sup> <a name="logicalId" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.property.logicalId"></a>

```typescript
public readonly logicalId: string;
```

- *Type:* string

The logical ID for this CloudFormation stack element.

The logical ID of the element
is calculated from the path of the resource node in the construct tree.

To override this value, use `overrideLogicalId(newLogicalId)`.

---

##### `stack`<sup>Required</sup> <a name="stack" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.property.stack"></a>

```typescript
public readonly stack: Stack;
```

- *Type:* aws-cdk-lib.Stack

The stack in which this element is defined.

CfnElements must be defined within a stack scope (directly or indirectly).

---

##### `ref`<sup>Required</sup> <a name="ref" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.

If, by any chance, the intrinsic reference of a resource is not a string, you could
coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.

---

##### `cfnOptions`<sup>Required</sup> <a name="cfnOptions" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.property.cfnOptions"></a>

```typescript
public readonly cfnOptions: ICfnResourceOptions;
```

- *Type:* aws-cdk-lib.ICfnResourceOptions

Options for this resource, such as condition, update policy etc.

---

##### `cfnResourceType`<sup>Required</sup> <a name="cfnResourceType" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.property.cfnResourceType"></a>

```typescript
public readonly cfnResourceType: string;
```

- *Type:* string

AWS resource type.

---

##### `attrId`<sup>Required</sup> <a name="attrId" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.property.attrId"></a>

```typescript
public readonly attrId: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::NetworkContainer.Id`.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.property.props"></a>

```typescript
public readonly props: CfnNetworkContainerProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnNetworkContainerProps">CfnNetworkContainerProps</a>

Resource props.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkContainer.property.CFN_RESOURCE_TYPE_NAME">CFN_RESOURCE_TYPE_NAME</a></code> | <code>string</code> | The CloudFormation resource type name for this resource class. |

---

##### `CFN_RESOURCE_TYPE_NAME`<sup>Required</sup> <a name="CFN_RESOURCE_TYPE_NAME" id="awscdk-resources-mongodbatlas.CfnNetworkContainer.property.CFN_RESOURCE_TYPE_NAME"></a>

```typescript
public readonly CFN_RESOURCE_TYPE_NAME: string;
```

- *Type:* string

The CloudFormation resource type name for this resource class.

---

### CfnNetworkPeering <a name="CfnNetworkPeering" id="awscdk-resources-mongodbatlas.CfnNetworkPeering"></a>

A CloudFormation `MongoDB::Atlas::NetworkPeering`.

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.Initializer"></a>

```typescript
import { CfnNetworkPeering } from 'awscdk-resources-mongodbatlas'

new CfnNetworkPeering(scope: Construct, id: string, props: CfnNetworkPeeringProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkPeering.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - scope in which this resource is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkPeering.Initializer.parameter.id">id</a></code> | <code>string</code> | - scoped id of the resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkPeering.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkPeeringProps">CfnNetworkPeeringProps</a></code> | - resource properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

scope in which this resource is defined.

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.Initializer.parameter.id"></a>

- *Type:* string

scoped id of the resource.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnNetworkPeeringProps">CfnNetworkPeeringProps</a>

resource properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkPeering.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkPeering.overrideLogicalId">overrideLogicalId</a></code> | Overrides the auto-generated logical ID with a specific ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkPeering.addDeletionOverride">addDeletionOverride</a></code> | Syntactic sugar for `addOverride(path, undefined)`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkPeering.addDependency">addDependency</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkPeering.addDependsOn">addDependsOn</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkPeering.addMetadata">addMetadata</a></code> | Add a value to the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkPeering.addOverride">addOverride</a></code> | Adds an override to the synthesized CloudFormation resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkPeering.addPropertyDeletionOverride">addPropertyDeletionOverride</a></code> | Adds an override that deletes the value of a property from the resource definition. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkPeering.addPropertyOverride">addPropertyOverride</a></code> | Adds an override to a resource property. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkPeering.applyRemovalPolicy">applyRemovalPolicy</a></code> | Sets the deletion policy of the resource based on the removal policy specified. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkPeering.getAtt">getAtt</a></code> | Returns a token for an runtime attribute of this resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkPeering.getMetadata">getMetadata</a></code> | Retrieve a value value from the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkPeering.obtainDependencies">obtainDependencies</a></code> | Retrieves an array of resources this resource depends on. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkPeering.obtainResourceDependencies">obtainResourceDependencies</a></code> | Get a shallow copy of dependencies between this resource and other resources in the same stack. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkPeering.removeDependency">removeDependency</a></code> | Indicates that this resource no longer depends on another resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkPeering.replaceDependency">replaceDependency</a></code> | Replaces one dependency with another. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `overrideLogicalId` <a name="overrideLogicalId" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.overrideLogicalId"></a>

```typescript
public overrideLogicalId(newLogicalId: string): void
```

Overrides the auto-generated logical ID with a specific ID.

###### `newLogicalId`<sup>Required</sup> <a name="newLogicalId" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.overrideLogicalId.parameter.newLogicalId"></a>

- *Type:* string

The new logical ID to use for this stack element.

---

##### `addDeletionOverride` <a name="addDeletionOverride" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.addDeletionOverride"></a>

```typescript
public addDeletionOverride(path: string): void
```

Syntactic sugar for `addOverride(path, undefined)`.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.addDeletionOverride.parameter.path"></a>

- *Type:* string

The path of the value to delete.

---

##### `addDependency` <a name="addDependency" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.addDependency"></a>

```typescript
public addDependency(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

This can be used for resources across stacks (or nested stack) boundaries
and the dependency will automatically be transferred to the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.addDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### ~~`addDependsOn`~~ <a name="addDependsOn" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.addDependsOn"></a>

```typescript
public addDependsOn(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.addDependsOn.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `addMetadata` <a name="addMetadata" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.addMetadata"></a>

```typescript
public addMetadata(key: string, value: any): void
```

Add a value to the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.addMetadata.parameter.key"></a>

- *Type:* string

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.addMetadata.parameter.value"></a>

- *Type:* any

---

##### `addOverride` <a name="addOverride" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.addOverride"></a>

```typescript
public addOverride(path: string, value: any): void
```

Adds an override to the synthesized CloudFormation resource.

To add a
property override, either use `addPropertyOverride` or prefix `path` with
"Properties." (i.e. `Properties.TopicName`).

If the override is nested, separate each nested level using a dot (.) in the path parameter.
If there is an array as part of the nesting, specify the index in the path.

To include a literal `.` in the property name, prefix with a `\`. In most
programming languages you will need to write this as `"\\."` because the
`\` itself will need to be escaped.

For example,
```typescript
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
```
would add the overrides
```json
"Properties": {
  "GlobalSecondaryIndexes": [
    {
      "Projection": {
        "NonKeyAttributes": [ "myattribute" ]
        ...
      }
      ...
    },
    {
      "ProjectionType": "INCLUDE"
      ...
    },
  ]
  ...
}
```

The `value` argument to `addOverride` will not be processed or translated
in any way. Pass raw JSON values in here with the correct capitalization
for CloudFormation. If you pass CDK classes or structs, they will be
rendered with lowercased key names, and CloudFormation will reject the
template.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.addOverride.parameter.path"></a>

- *Type:* string

The path of the property, you can use dot notation to override values in complex types.

Any intermediate keys
will be created as needed.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.addOverride.parameter.value"></a>

- *Type:* any

The value.

Could be primitive or complex.

---

##### `addPropertyDeletionOverride` <a name="addPropertyDeletionOverride" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.addPropertyDeletionOverride"></a>

```typescript
public addPropertyDeletionOverride(propertyPath: string): void
```

Adds an override that deletes the value of a property from the resource definition.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.addPropertyDeletionOverride.parameter.propertyPath"></a>

- *Type:* string

The path to the property.

---

##### `addPropertyOverride` <a name="addPropertyOverride" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.addPropertyOverride"></a>

```typescript
public addPropertyOverride(propertyPath: string, value: any): void
```

Adds an override to a resource property.

Syntactic sugar for `addOverride("Properties.<...>", value)`.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.addPropertyOverride.parameter.propertyPath"></a>

- *Type:* string

The path of the property.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.addPropertyOverride.parameter.value"></a>

- *Type:* any

The value.

---

##### `applyRemovalPolicy` <a name="applyRemovalPolicy" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.applyRemovalPolicy"></a>

```typescript
public applyRemovalPolicy(policy?: RemovalPolicy, options?: RemovalPolicyOptions): void
```

Sets the deletion policy of the resource based on the removal policy specified.

The Removal Policy controls what happens to this resource when it stops
being managed by CloudFormation, either because you've removed it from the
CDK application or because you've made a change that requires the resource
to be replaced.

The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
cases, a snapshot can be taken of the resource prior to deletion
(`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
can be found in the following link:

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options)

###### `policy`<sup>Optional</sup> <a name="policy" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.applyRemovalPolicy.parameter.policy"></a>

- *Type:* aws-cdk-lib.RemovalPolicy

---

###### `options`<sup>Optional</sup> <a name="options" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.applyRemovalPolicy.parameter.options"></a>

- *Type:* aws-cdk-lib.RemovalPolicyOptions

---

##### `getAtt` <a name="getAtt" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.getAtt"></a>

```typescript
public getAtt(attributeName: string, typeHint?: ResolutionTypeHint): Reference
```

Returns a token for an runtime attribute of this resource.

Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
in case there is no generated attribute.

###### `attributeName`<sup>Required</sup> <a name="attributeName" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.getAtt.parameter.attributeName"></a>

- *Type:* string

The name of the attribute.

---

###### `typeHint`<sup>Optional</sup> <a name="typeHint" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.getAtt.parameter.typeHint"></a>

- *Type:* aws-cdk-lib.ResolutionTypeHint

---

##### `getMetadata` <a name="getMetadata" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.getMetadata"></a>

```typescript
public getMetadata(key: string): any
```

Retrieve a value value from the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.getMetadata.parameter.key"></a>

- *Type:* string

---

##### `obtainDependencies` <a name="obtainDependencies" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.obtainDependencies"></a>

```typescript
public obtainDependencies(): Stack | CfnResource[]
```

Retrieves an array of resources this resource depends on.

This assembles dependencies on resources across stacks (including nested stacks)
automatically.

##### `obtainResourceDependencies` <a name="obtainResourceDependencies" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.obtainResourceDependencies"></a>

```typescript
public obtainResourceDependencies(): CfnResource[]
```

Get a shallow copy of dependencies between this resource and other resources in the same stack.

##### `removeDependency` <a name="removeDependency" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.removeDependency"></a>

```typescript
public removeDependency(target: CfnResource): void
```

Indicates that this resource no longer depends on another resource.

This can be used for resources across stacks (including nested stacks)
and the dependency will automatically be removed from the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.removeDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `replaceDependency` <a name="replaceDependency" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.replaceDependency"></a>

```typescript
public replaceDependency(target: CfnResource, newTarget: CfnResource): void
```

Replaces one dependency with another.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.replaceDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

The dependency to replace.

---

###### `newTarget`<sup>Required</sup> <a name="newTarget" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.replaceDependency.parameter.newTarget"></a>

- *Type:* aws-cdk-lib.CfnResource

The new dependency to add.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkPeering.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkPeering.isCfnElement">isCfnElement</a></code> | Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkPeering.isCfnResource">isCfnResource</a></code> | Check whether the given construct is a CfnResource. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.isConstruct"></a>

```typescript
import { CfnNetworkPeering } from 'awscdk-resources-mongodbatlas'

CfnNetworkPeering.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `isCfnElement` <a name="isCfnElement" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.isCfnElement"></a>

```typescript
import { CfnNetworkPeering } from 'awscdk-resources-mongodbatlas'

CfnNetworkPeering.isCfnElement(x: any)
```

Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).

Uses duck-typing instead of `instanceof` to allow stack elements from different
versions of this library to be included in the same stack.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.isCfnElement.parameter.x"></a>

- *Type:* any

---

##### `isCfnResource` <a name="isCfnResource" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.isCfnResource"></a>

```typescript
import { CfnNetworkPeering } from 'awscdk-resources-mongodbatlas'

CfnNetworkPeering.isCfnResource(construct: IConstruct)
```

Check whether the given construct is a CfnResource.

###### `construct`<sup>Required</sup> <a name="construct" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.isCfnResource.parameter.construct"></a>

- *Type:* constructs.IConstruct

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkPeering.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkPeering.property.creationStack">creationStack</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkPeering.property.logicalId">logicalId</a></code> | <code>string</code> | The logical ID for this CloudFormation stack element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkPeering.property.stack">stack</a></code> | <code>aws-cdk-lib.Stack</code> | The stack in which this element is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkPeering.property.ref">ref</a></code> | <code>string</code> | Return a string that will be resolved to a CloudFormation `{ Ref }` for this element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkPeering.property.cfnOptions">cfnOptions</a></code> | <code>aws-cdk-lib.ICfnResourceOptions</code> | Options for this resource, such as condition, update policy etc. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkPeering.property.cfnResourceType">cfnResourceType</a></code> | <code>string</code> | AWS resource type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkPeering.property.attrConnectionId">attrConnectionId</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::NetworkPeering.ConnectionId`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkPeering.property.attrErrorStateName">attrErrorStateName</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::NetworkPeering.ErrorStateName`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkPeering.property.attrId">attrId</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::NetworkPeering.Id`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkPeering.property.attrStatusName">attrStatusName</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::NetworkPeering.StatusName`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkPeering.property.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkPeeringProps">CfnNetworkPeeringProps</a></code> | Resource props. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `creationStack`<sup>Required</sup> <a name="creationStack" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.property.creationStack"></a>

```typescript
public readonly creationStack: string[];
```

- *Type:* string[]

---

##### `logicalId`<sup>Required</sup> <a name="logicalId" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.property.logicalId"></a>

```typescript
public readonly logicalId: string;
```

- *Type:* string

The logical ID for this CloudFormation stack element.

The logical ID of the element
is calculated from the path of the resource node in the construct tree.

To override this value, use `overrideLogicalId(newLogicalId)`.

---

##### `stack`<sup>Required</sup> <a name="stack" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.property.stack"></a>

```typescript
public readonly stack: Stack;
```

- *Type:* aws-cdk-lib.Stack

The stack in which this element is defined.

CfnElements must be defined within a stack scope (directly or indirectly).

---

##### `ref`<sup>Required</sup> <a name="ref" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.

If, by any chance, the intrinsic reference of a resource is not a string, you could
coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.

---

##### `cfnOptions`<sup>Required</sup> <a name="cfnOptions" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.property.cfnOptions"></a>

```typescript
public readonly cfnOptions: ICfnResourceOptions;
```

- *Type:* aws-cdk-lib.ICfnResourceOptions

Options for this resource, such as condition, update policy etc.

---

##### `cfnResourceType`<sup>Required</sup> <a name="cfnResourceType" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.property.cfnResourceType"></a>

```typescript
public readonly cfnResourceType: string;
```

- *Type:* string

AWS resource type.

---

##### `attrConnectionId`<sup>Required</sup> <a name="attrConnectionId" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.property.attrConnectionId"></a>

```typescript
public readonly attrConnectionId: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::NetworkPeering.ConnectionId`.

---

##### `attrErrorStateName`<sup>Required</sup> <a name="attrErrorStateName" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.property.attrErrorStateName"></a>

```typescript
public readonly attrErrorStateName: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::NetworkPeering.ErrorStateName`.

---

##### `attrId`<sup>Required</sup> <a name="attrId" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.property.attrId"></a>

```typescript
public readonly attrId: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::NetworkPeering.Id`.

---

##### `attrStatusName`<sup>Required</sup> <a name="attrStatusName" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.property.attrStatusName"></a>

```typescript
public readonly attrStatusName: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::NetworkPeering.StatusName`.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.property.props"></a>

```typescript
public readonly props: CfnNetworkPeeringProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnNetworkPeeringProps">CfnNetworkPeeringProps</a>

Resource props.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkPeering.property.CFN_RESOURCE_TYPE_NAME">CFN_RESOURCE_TYPE_NAME</a></code> | <code>string</code> | The CloudFormation resource type name for this resource class. |

---

##### `CFN_RESOURCE_TYPE_NAME`<sup>Required</sup> <a name="CFN_RESOURCE_TYPE_NAME" id="awscdk-resources-mongodbatlas.CfnNetworkPeering.property.CFN_RESOURCE_TYPE_NAME"></a>

```typescript
public readonly CFN_RESOURCE_TYPE_NAME: string;
```

- *Type:* string

The CloudFormation resource type name for this resource class.

---

### CfnOnlineArchive <a name="CfnOnlineArchive" id="awscdk-resources-mongodbatlas.CfnOnlineArchive"></a>

A CloudFormation `MongoDB::Atlas::OnlineArchive`.

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.Initializer"></a>

```typescript
import { CfnOnlineArchive } from 'awscdk-resources-mongodbatlas'

new CfnOnlineArchive(scope: Construct, id: string, props: CfnOnlineArchiveProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchive.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - scope in which this resource is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchive.Initializer.parameter.id">id</a></code> | <code>string</code> | - scoped id of the resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchive.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchiveProps">CfnOnlineArchiveProps</a></code> | - resource properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

scope in which this resource is defined.

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.Initializer.parameter.id"></a>

- *Type:* string

scoped id of the resource.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnOnlineArchiveProps">CfnOnlineArchiveProps</a>

resource properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchive.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchive.overrideLogicalId">overrideLogicalId</a></code> | Overrides the auto-generated logical ID with a specific ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchive.addDeletionOverride">addDeletionOverride</a></code> | Syntactic sugar for `addOverride(path, undefined)`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchive.addDependency">addDependency</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchive.addDependsOn">addDependsOn</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchive.addMetadata">addMetadata</a></code> | Add a value to the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchive.addOverride">addOverride</a></code> | Adds an override to the synthesized CloudFormation resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchive.addPropertyDeletionOverride">addPropertyDeletionOverride</a></code> | Adds an override that deletes the value of a property from the resource definition. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchive.addPropertyOverride">addPropertyOverride</a></code> | Adds an override to a resource property. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchive.applyRemovalPolicy">applyRemovalPolicy</a></code> | Sets the deletion policy of the resource based on the removal policy specified. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchive.getAtt">getAtt</a></code> | Returns a token for an runtime attribute of this resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchive.getMetadata">getMetadata</a></code> | Retrieve a value value from the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchive.obtainDependencies">obtainDependencies</a></code> | Retrieves an array of resources this resource depends on. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchive.obtainResourceDependencies">obtainResourceDependencies</a></code> | Get a shallow copy of dependencies between this resource and other resources in the same stack. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchive.removeDependency">removeDependency</a></code> | Indicates that this resource no longer depends on another resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchive.replaceDependency">replaceDependency</a></code> | Replaces one dependency with another. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `overrideLogicalId` <a name="overrideLogicalId" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.overrideLogicalId"></a>

```typescript
public overrideLogicalId(newLogicalId: string): void
```

Overrides the auto-generated logical ID with a specific ID.

###### `newLogicalId`<sup>Required</sup> <a name="newLogicalId" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.overrideLogicalId.parameter.newLogicalId"></a>

- *Type:* string

The new logical ID to use for this stack element.

---

##### `addDeletionOverride` <a name="addDeletionOverride" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.addDeletionOverride"></a>

```typescript
public addDeletionOverride(path: string): void
```

Syntactic sugar for `addOverride(path, undefined)`.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.addDeletionOverride.parameter.path"></a>

- *Type:* string

The path of the value to delete.

---

##### `addDependency` <a name="addDependency" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.addDependency"></a>

```typescript
public addDependency(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

This can be used for resources across stacks (or nested stack) boundaries
and the dependency will automatically be transferred to the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.addDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### ~~`addDependsOn`~~ <a name="addDependsOn" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.addDependsOn"></a>

```typescript
public addDependsOn(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.addDependsOn.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `addMetadata` <a name="addMetadata" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.addMetadata"></a>

```typescript
public addMetadata(key: string, value: any): void
```

Add a value to the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.addMetadata.parameter.key"></a>

- *Type:* string

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.addMetadata.parameter.value"></a>

- *Type:* any

---

##### `addOverride` <a name="addOverride" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.addOverride"></a>

```typescript
public addOverride(path: string, value: any): void
```

Adds an override to the synthesized CloudFormation resource.

To add a
property override, either use `addPropertyOverride` or prefix `path` with
"Properties." (i.e. `Properties.TopicName`).

If the override is nested, separate each nested level using a dot (.) in the path parameter.
If there is an array as part of the nesting, specify the index in the path.

To include a literal `.` in the property name, prefix with a `\`. In most
programming languages you will need to write this as `"\\."` because the
`\` itself will need to be escaped.

For example,
```typescript
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
```
would add the overrides
```json
"Properties": {
  "GlobalSecondaryIndexes": [
    {
      "Projection": {
        "NonKeyAttributes": [ "myattribute" ]
        ...
      }
      ...
    },
    {
      "ProjectionType": "INCLUDE"
      ...
    },
  ]
  ...
}
```

The `value` argument to `addOverride` will not be processed or translated
in any way. Pass raw JSON values in here with the correct capitalization
for CloudFormation. If you pass CDK classes or structs, they will be
rendered with lowercased key names, and CloudFormation will reject the
template.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.addOverride.parameter.path"></a>

- *Type:* string

The path of the property, you can use dot notation to override values in complex types.

Any intermediate keys
will be created as needed.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.addOverride.parameter.value"></a>

- *Type:* any

The value.

Could be primitive or complex.

---

##### `addPropertyDeletionOverride` <a name="addPropertyDeletionOverride" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.addPropertyDeletionOverride"></a>

```typescript
public addPropertyDeletionOverride(propertyPath: string): void
```

Adds an override that deletes the value of a property from the resource definition.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.addPropertyDeletionOverride.parameter.propertyPath"></a>

- *Type:* string

The path to the property.

---

##### `addPropertyOverride` <a name="addPropertyOverride" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.addPropertyOverride"></a>

```typescript
public addPropertyOverride(propertyPath: string, value: any): void
```

Adds an override to a resource property.

Syntactic sugar for `addOverride("Properties.<...>", value)`.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.addPropertyOverride.parameter.propertyPath"></a>

- *Type:* string

The path of the property.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.addPropertyOverride.parameter.value"></a>

- *Type:* any

The value.

---

##### `applyRemovalPolicy` <a name="applyRemovalPolicy" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.applyRemovalPolicy"></a>

```typescript
public applyRemovalPolicy(policy?: RemovalPolicy, options?: RemovalPolicyOptions): void
```

Sets the deletion policy of the resource based on the removal policy specified.

The Removal Policy controls what happens to this resource when it stops
being managed by CloudFormation, either because you've removed it from the
CDK application or because you've made a change that requires the resource
to be replaced.

The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
cases, a snapshot can be taken of the resource prior to deletion
(`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
can be found in the following link:

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options)

###### `policy`<sup>Optional</sup> <a name="policy" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.applyRemovalPolicy.parameter.policy"></a>

- *Type:* aws-cdk-lib.RemovalPolicy

---

###### `options`<sup>Optional</sup> <a name="options" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.applyRemovalPolicy.parameter.options"></a>

- *Type:* aws-cdk-lib.RemovalPolicyOptions

---

##### `getAtt` <a name="getAtt" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.getAtt"></a>

```typescript
public getAtt(attributeName: string, typeHint?: ResolutionTypeHint): Reference
```

Returns a token for an runtime attribute of this resource.

Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
in case there is no generated attribute.

###### `attributeName`<sup>Required</sup> <a name="attributeName" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.getAtt.parameter.attributeName"></a>

- *Type:* string

The name of the attribute.

---

###### `typeHint`<sup>Optional</sup> <a name="typeHint" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.getAtt.parameter.typeHint"></a>

- *Type:* aws-cdk-lib.ResolutionTypeHint

---

##### `getMetadata` <a name="getMetadata" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.getMetadata"></a>

```typescript
public getMetadata(key: string): any
```

Retrieve a value value from the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.getMetadata.parameter.key"></a>

- *Type:* string

---

##### `obtainDependencies` <a name="obtainDependencies" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.obtainDependencies"></a>

```typescript
public obtainDependencies(): Stack | CfnResource[]
```

Retrieves an array of resources this resource depends on.

This assembles dependencies on resources across stacks (including nested stacks)
automatically.

##### `obtainResourceDependencies` <a name="obtainResourceDependencies" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.obtainResourceDependencies"></a>

```typescript
public obtainResourceDependencies(): CfnResource[]
```

Get a shallow copy of dependencies between this resource and other resources in the same stack.

##### `removeDependency` <a name="removeDependency" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.removeDependency"></a>

```typescript
public removeDependency(target: CfnResource): void
```

Indicates that this resource no longer depends on another resource.

This can be used for resources across stacks (including nested stacks)
and the dependency will automatically be removed from the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.removeDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `replaceDependency` <a name="replaceDependency" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.replaceDependency"></a>

```typescript
public replaceDependency(target: CfnResource, newTarget: CfnResource): void
```

Replaces one dependency with another.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.replaceDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

The dependency to replace.

---

###### `newTarget`<sup>Required</sup> <a name="newTarget" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.replaceDependency.parameter.newTarget"></a>

- *Type:* aws-cdk-lib.CfnResource

The new dependency to add.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchive.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchive.isCfnElement">isCfnElement</a></code> | Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchive.isCfnResource">isCfnResource</a></code> | Check whether the given construct is a CfnResource. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.isConstruct"></a>

```typescript
import { CfnOnlineArchive } from 'awscdk-resources-mongodbatlas'

CfnOnlineArchive.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `isCfnElement` <a name="isCfnElement" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.isCfnElement"></a>

```typescript
import { CfnOnlineArchive } from 'awscdk-resources-mongodbatlas'

CfnOnlineArchive.isCfnElement(x: any)
```

Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).

Uses duck-typing instead of `instanceof` to allow stack elements from different
versions of this library to be included in the same stack.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.isCfnElement.parameter.x"></a>

- *Type:* any

---

##### `isCfnResource` <a name="isCfnResource" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.isCfnResource"></a>

```typescript
import { CfnOnlineArchive } from 'awscdk-resources-mongodbatlas'

CfnOnlineArchive.isCfnResource(construct: IConstruct)
```

Check whether the given construct is a CfnResource.

###### `construct`<sup>Required</sup> <a name="construct" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.isCfnResource.parameter.construct"></a>

- *Type:* constructs.IConstruct

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchive.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchive.property.creationStack">creationStack</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchive.property.logicalId">logicalId</a></code> | <code>string</code> | The logical ID for this CloudFormation stack element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchive.property.stack">stack</a></code> | <code>aws-cdk-lib.Stack</code> | The stack in which this element is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchive.property.ref">ref</a></code> | <code>string</code> | Return a string that will be resolved to a CloudFormation `{ Ref }` for this element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchive.property.cfnOptions">cfnOptions</a></code> | <code>aws-cdk-lib.ICfnResourceOptions</code> | Options for this resource, such as condition, update policy etc. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchive.property.cfnResourceType">cfnResourceType</a></code> | <code>string</code> | AWS resource type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchive.property.attrArchiveId">attrArchiveId</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::OnlineArchive.ArchiveId`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchive.property.attrState">attrState</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::OnlineArchive.State`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchive.property.attrTotalCount">attrTotalCount</a></code> | <code>number</code> | Attribute `MongoDB::Atlas::OnlineArchive.TotalCount`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchive.property.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchiveProps">CfnOnlineArchiveProps</a></code> | Resource props. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `creationStack`<sup>Required</sup> <a name="creationStack" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.property.creationStack"></a>

```typescript
public readonly creationStack: string[];
```

- *Type:* string[]

---

##### `logicalId`<sup>Required</sup> <a name="logicalId" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.property.logicalId"></a>

```typescript
public readonly logicalId: string;
```

- *Type:* string

The logical ID for this CloudFormation stack element.

The logical ID of the element
is calculated from the path of the resource node in the construct tree.

To override this value, use `overrideLogicalId(newLogicalId)`.

---

##### `stack`<sup>Required</sup> <a name="stack" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.property.stack"></a>

```typescript
public readonly stack: Stack;
```

- *Type:* aws-cdk-lib.Stack

The stack in which this element is defined.

CfnElements must be defined within a stack scope (directly or indirectly).

---

##### `ref`<sup>Required</sup> <a name="ref" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.

If, by any chance, the intrinsic reference of a resource is not a string, you could
coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.

---

##### `cfnOptions`<sup>Required</sup> <a name="cfnOptions" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.property.cfnOptions"></a>

```typescript
public readonly cfnOptions: ICfnResourceOptions;
```

- *Type:* aws-cdk-lib.ICfnResourceOptions

Options for this resource, such as condition, update policy etc.

---

##### `cfnResourceType`<sup>Required</sup> <a name="cfnResourceType" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.property.cfnResourceType"></a>

```typescript
public readonly cfnResourceType: string;
```

- *Type:* string

AWS resource type.

---

##### `attrArchiveId`<sup>Required</sup> <a name="attrArchiveId" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.property.attrArchiveId"></a>

```typescript
public readonly attrArchiveId: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::OnlineArchive.ArchiveId`.

---

##### `attrState`<sup>Required</sup> <a name="attrState" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.property.attrState"></a>

```typescript
public readonly attrState: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::OnlineArchive.State`.

---

##### `attrTotalCount`<sup>Required</sup> <a name="attrTotalCount" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.property.attrTotalCount"></a>

```typescript
public readonly attrTotalCount: number;
```

- *Type:* number

Attribute `MongoDB::Atlas::OnlineArchive.TotalCount`.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.property.props"></a>

```typescript
public readonly props: CfnOnlineArchiveProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnOnlineArchiveProps">CfnOnlineArchiveProps</a>

Resource props.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchive.property.CFN_RESOURCE_TYPE_NAME">CFN_RESOURCE_TYPE_NAME</a></code> | <code>string</code> | The CloudFormation resource type name for this resource class. |

---

##### `CFN_RESOURCE_TYPE_NAME`<sup>Required</sup> <a name="CFN_RESOURCE_TYPE_NAME" id="awscdk-resources-mongodbatlas.CfnOnlineArchive.property.CFN_RESOURCE_TYPE_NAME"></a>

```typescript
public readonly CFN_RESOURCE_TYPE_NAME: string;
```

- *Type:* string

The CloudFormation resource type name for this resource class.

---

### CfnOrganization <a name="CfnOrganization" id="awscdk-resources-mongodbatlas.CfnOrganization"></a>

A CloudFormation `MongoDB::Atlas::Organization`.

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.CfnOrganization.Initializer"></a>

```typescript
import { CfnOrganization } from 'awscdk-resources-mongodbatlas'

new CfnOrganization(scope: Construct, id: string, props: CfnOrganizationProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrganization.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - scope in which this resource is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrganization.Initializer.parameter.id">id</a></code> | <code>string</code> | - scoped id of the resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrganization.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnOrganizationProps">CfnOrganizationProps</a></code> | - resource properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.CfnOrganization.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

scope in which this resource is defined.

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnOrganization.Initializer.parameter.id"></a>

- *Type:* string

scoped id of the resource.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnOrganization.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnOrganizationProps">CfnOrganizationProps</a>

resource properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrganization.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrganization.overrideLogicalId">overrideLogicalId</a></code> | Overrides the auto-generated logical ID with a specific ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrganization.addDeletionOverride">addDeletionOverride</a></code> | Syntactic sugar for `addOverride(path, undefined)`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrganization.addDependency">addDependency</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrganization.addDependsOn">addDependsOn</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrganization.addMetadata">addMetadata</a></code> | Add a value to the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrganization.addOverride">addOverride</a></code> | Adds an override to the synthesized CloudFormation resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrganization.addPropertyDeletionOverride">addPropertyDeletionOverride</a></code> | Adds an override that deletes the value of a property from the resource definition. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrganization.addPropertyOverride">addPropertyOverride</a></code> | Adds an override to a resource property. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrganization.applyRemovalPolicy">applyRemovalPolicy</a></code> | Sets the deletion policy of the resource based on the removal policy specified. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrganization.getAtt">getAtt</a></code> | Returns a token for an runtime attribute of this resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrganization.getMetadata">getMetadata</a></code> | Retrieve a value value from the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrganization.obtainDependencies">obtainDependencies</a></code> | Retrieves an array of resources this resource depends on. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrganization.obtainResourceDependencies">obtainResourceDependencies</a></code> | Get a shallow copy of dependencies between this resource and other resources in the same stack. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrganization.removeDependency">removeDependency</a></code> | Indicates that this resource no longer depends on another resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrganization.replaceDependency">replaceDependency</a></code> | Replaces one dependency with another. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.CfnOrganization.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `overrideLogicalId` <a name="overrideLogicalId" id="awscdk-resources-mongodbatlas.CfnOrganization.overrideLogicalId"></a>

```typescript
public overrideLogicalId(newLogicalId: string): void
```

Overrides the auto-generated logical ID with a specific ID.

###### `newLogicalId`<sup>Required</sup> <a name="newLogicalId" id="awscdk-resources-mongodbatlas.CfnOrganization.overrideLogicalId.parameter.newLogicalId"></a>

- *Type:* string

The new logical ID to use for this stack element.

---

##### `addDeletionOverride` <a name="addDeletionOverride" id="awscdk-resources-mongodbatlas.CfnOrganization.addDeletionOverride"></a>

```typescript
public addDeletionOverride(path: string): void
```

Syntactic sugar for `addOverride(path, undefined)`.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnOrganization.addDeletionOverride.parameter.path"></a>

- *Type:* string

The path of the value to delete.

---

##### `addDependency` <a name="addDependency" id="awscdk-resources-mongodbatlas.CfnOrganization.addDependency"></a>

```typescript
public addDependency(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

This can be used for resources across stacks (or nested stack) boundaries
and the dependency will automatically be transferred to the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnOrganization.addDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### ~~`addDependsOn`~~ <a name="addDependsOn" id="awscdk-resources-mongodbatlas.CfnOrganization.addDependsOn"></a>

```typescript
public addDependsOn(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnOrganization.addDependsOn.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `addMetadata` <a name="addMetadata" id="awscdk-resources-mongodbatlas.CfnOrganization.addMetadata"></a>

```typescript
public addMetadata(key: string, value: any): void
```

Add a value to the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnOrganization.addMetadata.parameter.key"></a>

- *Type:* string

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnOrganization.addMetadata.parameter.value"></a>

- *Type:* any

---

##### `addOverride` <a name="addOverride" id="awscdk-resources-mongodbatlas.CfnOrganization.addOverride"></a>

```typescript
public addOverride(path: string, value: any): void
```

Adds an override to the synthesized CloudFormation resource.

To add a
property override, either use `addPropertyOverride` or prefix `path` with
"Properties." (i.e. `Properties.TopicName`).

If the override is nested, separate each nested level using a dot (.) in the path parameter.
If there is an array as part of the nesting, specify the index in the path.

To include a literal `.` in the property name, prefix with a `\`. In most
programming languages you will need to write this as `"\\."` because the
`\` itself will need to be escaped.

For example,
```typescript
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
```
would add the overrides
```json
"Properties": {
  "GlobalSecondaryIndexes": [
    {
      "Projection": {
        "NonKeyAttributes": [ "myattribute" ]
        ...
      }
      ...
    },
    {
      "ProjectionType": "INCLUDE"
      ...
    },
  ]
  ...
}
```

The `value` argument to `addOverride` will not be processed or translated
in any way. Pass raw JSON values in here with the correct capitalization
for CloudFormation. If you pass CDK classes or structs, they will be
rendered with lowercased key names, and CloudFormation will reject the
template.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnOrganization.addOverride.parameter.path"></a>

- *Type:* string

The path of the property, you can use dot notation to override values in complex types.

Any intermediate keys
will be created as needed.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnOrganization.addOverride.parameter.value"></a>

- *Type:* any

The value.

Could be primitive or complex.

---

##### `addPropertyDeletionOverride` <a name="addPropertyDeletionOverride" id="awscdk-resources-mongodbatlas.CfnOrganization.addPropertyDeletionOverride"></a>

```typescript
public addPropertyDeletionOverride(propertyPath: string): void
```

Adds an override that deletes the value of a property from the resource definition.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnOrganization.addPropertyDeletionOverride.parameter.propertyPath"></a>

- *Type:* string

The path to the property.

---

##### `addPropertyOverride` <a name="addPropertyOverride" id="awscdk-resources-mongodbatlas.CfnOrganization.addPropertyOverride"></a>

```typescript
public addPropertyOverride(propertyPath: string, value: any): void
```

Adds an override to a resource property.

Syntactic sugar for `addOverride("Properties.<...>", value)`.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnOrganization.addPropertyOverride.parameter.propertyPath"></a>

- *Type:* string

The path of the property.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnOrganization.addPropertyOverride.parameter.value"></a>

- *Type:* any

The value.

---

##### `applyRemovalPolicy` <a name="applyRemovalPolicy" id="awscdk-resources-mongodbatlas.CfnOrganization.applyRemovalPolicy"></a>

```typescript
public applyRemovalPolicy(policy?: RemovalPolicy, options?: RemovalPolicyOptions): void
```

Sets the deletion policy of the resource based on the removal policy specified.

The Removal Policy controls what happens to this resource when it stops
being managed by CloudFormation, either because you've removed it from the
CDK application or because you've made a change that requires the resource
to be replaced.

The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
cases, a snapshot can be taken of the resource prior to deletion
(`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
can be found in the following link:

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options)

###### `policy`<sup>Optional</sup> <a name="policy" id="awscdk-resources-mongodbatlas.CfnOrganization.applyRemovalPolicy.parameter.policy"></a>

- *Type:* aws-cdk-lib.RemovalPolicy

---

###### `options`<sup>Optional</sup> <a name="options" id="awscdk-resources-mongodbatlas.CfnOrganization.applyRemovalPolicy.parameter.options"></a>

- *Type:* aws-cdk-lib.RemovalPolicyOptions

---

##### `getAtt` <a name="getAtt" id="awscdk-resources-mongodbatlas.CfnOrganization.getAtt"></a>

```typescript
public getAtt(attributeName: string, typeHint?: ResolutionTypeHint): Reference
```

Returns a token for an runtime attribute of this resource.

Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
in case there is no generated attribute.

###### `attributeName`<sup>Required</sup> <a name="attributeName" id="awscdk-resources-mongodbatlas.CfnOrganization.getAtt.parameter.attributeName"></a>

- *Type:* string

The name of the attribute.

---

###### `typeHint`<sup>Optional</sup> <a name="typeHint" id="awscdk-resources-mongodbatlas.CfnOrganization.getAtt.parameter.typeHint"></a>

- *Type:* aws-cdk-lib.ResolutionTypeHint

---

##### `getMetadata` <a name="getMetadata" id="awscdk-resources-mongodbatlas.CfnOrganization.getMetadata"></a>

```typescript
public getMetadata(key: string): any
```

Retrieve a value value from the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnOrganization.getMetadata.parameter.key"></a>

- *Type:* string

---

##### `obtainDependencies` <a name="obtainDependencies" id="awscdk-resources-mongodbatlas.CfnOrganization.obtainDependencies"></a>

```typescript
public obtainDependencies(): Stack | CfnResource[]
```

Retrieves an array of resources this resource depends on.

This assembles dependencies on resources across stacks (including nested stacks)
automatically.

##### `obtainResourceDependencies` <a name="obtainResourceDependencies" id="awscdk-resources-mongodbatlas.CfnOrganization.obtainResourceDependencies"></a>

```typescript
public obtainResourceDependencies(): CfnResource[]
```

Get a shallow copy of dependencies between this resource and other resources in the same stack.

##### `removeDependency` <a name="removeDependency" id="awscdk-resources-mongodbatlas.CfnOrganization.removeDependency"></a>

```typescript
public removeDependency(target: CfnResource): void
```

Indicates that this resource no longer depends on another resource.

This can be used for resources across stacks (including nested stacks)
and the dependency will automatically be removed from the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnOrganization.removeDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `replaceDependency` <a name="replaceDependency" id="awscdk-resources-mongodbatlas.CfnOrganization.replaceDependency"></a>

```typescript
public replaceDependency(target: CfnResource, newTarget: CfnResource): void
```

Replaces one dependency with another.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnOrganization.replaceDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

The dependency to replace.

---

###### `newTarget`<sup>Required</sup> <a name="newTarget" id="awscdk-resources-mongodbatlas.CfnOrganization.replaceDependency.parameter.newTarget"></a>

- *Type:* aws-cdk-lib.CfnResource

The new dependency to add.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrganization.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrganization.isCfnElement">isCfnElement</a></code> | Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrganization.isCfnResource">isCfnResource</a></code> | Check whether the given construct is a CfnResource. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.CfnOrganization.isConstruct"></a>

```typescript
import { CfnOrganization } from 'awscdk-resources-mongodbatlas'

CfnOrganization.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnOrganization.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `isCfnElement` <a name="isCfnElement" id="awscdk-resources-mongodbatlas.CfnOrganization.isCfnElement"></a>

```typescript
import { CfnOrganization } from 'awscdk-resources-mongodbatlas'

CfnOrganization.isCfnElement(x: any)
```

Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).

Uses duck-typing instead of `instanceof` to allow stack elements from different
versions of this library to be included in the same stack.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnOrganization.isCfnElement.parameter.x"></a>

- *Type:* any

---

##### `isCfnResource` <a name="isCfnResource" id="awscdk-resources-mongodbatlas.CfnOrganization.isCfnResource"></a>

```typescript
import { CfnOrganization } from 'awscdk-resources-mongodbatlas'

CfnOrganization.isCfnResource(construct: IConstruct)
```

Check whether the given construct is a CfnResource.

###### `construct`<sup>Required</sup> <a name="construct" id="awscdk-resources-mongodbatlas.CfnOrganization.isCfnResource.parameter.construct"></a>

- *Type:* constructs.IConstruct

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrganization.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrganization.property.creationStack">creationStack</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrganization.property.logicalId">logicalId</a></code> | <code>string</code> | The logical ID for this CloudFormation stack element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrganization.property.stack">stack</a></code> | <code>aws-cdk-lib.Stack</code> | The stack in which this element is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrganization.property.ref">ref</a></code> | <code>string</code> | Return a string that will be resolved to a CloudFormation `{ Ref }` for this element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrganization.property.cfnOptions">cfnOptions</a></code> | <code>aws-cdk-lib.ICfnResourceOptions</code> | Options for this resource, such as condition, update policy etc. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrganization.property.cfnResourceType">cfnResourceType</a></code> | <code>string</code> | AWS resource type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrganization.property.attrOrgId">attrOrgId</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::Organization.OrgId`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrganization.property.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnOrganizationProps">CfnOrganizationProps</a></code> | Resource props. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.CfnOrganization.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `creationStack`<sup>Required</sup> <a name="creationStack" id="awscdk-resources-mongodbatlas.CfnOrganization.property.creationStack"></a>

```typescript
public readonly creationStack: string[];
```

- *Type:* string[]

---

##### `logicalId`<sup>Required</sup> <a name="logicalId" id="awscdk-resources-mongodbatlas.CfnOrganization.property.logicalId"></a>

```typescript
public readonly logicalId: string;
```

- *Type:* string

The logical ID for this CloudFormation stack element.

The logical ID of the element
is calculated from the path of the resource node in the construct tree.

To override this value, use `overrideLogicalId(newLogicalId)`.

---

##### `stack`<sup>Required</sup> <a name="stack" id="awscdk-resources-mongodbatlas.CfnOrganization.property.stack"></a>

```typescript
public readonly stack: Stack;
```

- *Type:* aws-cdk-lib.Stack

The stack in which this element is defined.

CfnElements must be defined within a stack scope (directly or indirectly).

---

##### `ref`<sup>Required</sup> <a name="ref" id="awscdk-resources-mongodbatlas.CfnOrganization.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.

If, by any chance, the intrinsic reference of a resource is not a string, you could
coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.

---

##### `cfnOptions`<sup>Required</sup> <a name="cfnOptions" id="awscdk-resources-mongodbatlas.CfnOrganization.property.cfnOptions"></a>

```typescript
public readonly cfnOptions: ICfnResourceOptions;
```

- *Type:* aws-cdk-lib.ICfnResourceOptions

Options for this resource, such as condition, update policy etc.

---

##### `cfnResourceType`<sup>Required</sup> <a name="cfnResourceType" id="awscdk-resources-mongodbatlas.CfnOrganization.property.cfnResourceType"></a>

```typescript
public readonly cfnResourceType: string;
```

- *Type:* string

AWS resource type.

---

##### `attrOrgId`<sup>Required</sup> <a name="attrOrgId" id="awscdk-resources-mongodbatlas.CfnOrganization.property.attrOrgId"></a>

```typescript
public readonly attrOrgId: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::Organization.OrgId`.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnOrganization.property.props"></a>

```typescript
public readonly props: CfnOrganizationProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnOrganizationProps">CfnOrganizationProps</a>

Resource props.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrganization.property.CFN_RESOURCE_TYPE_NAME">CFN_RESOURCE_TYPE_NAME</a></code> | <code>string</code> | The CloudFormation resource type name for this resource class. |

---

##### `CFN_RESOURCE_TYPE_NAME`<sup>Required</sup> <a name="CFN_RESOURCE_TYPE_NAME" id="awscdk-resources-mongodbatlas.CfnOrganization.property.CFN_RESOURCE_TYPE_NAME"></a>

```typescript
public readonly CFN_RESOURCE_TYPE_NAME: string;
```

- *Type:* string

The CloudFormation resource type name for this resource class.

---

### CfnOrgInvitation <a name="CfnOrgInvitation" id="awscdk-resources-mongodbatlas.CfnOrgInvitation"></a>

A CloudFormation `MongoDB::Atlas::OrgInvitation`.

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.Initializer"></a>

```typescript
import { CfnOrgInvitation } from 'awscdk-resources-mongodbatlas'

new CfnOrgInvitation(scope: Construct, id: string, props: CfnOrgInvitationProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitation.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - scope in which this resource is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitation.Initializer.parameter.id">id</a></code> | <code>string</code> | - scoped id of the resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitation.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitationProps">CfnOrgInvitationProps</a></code> | - resource properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

scope in which this resource is defined.

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.Initializer.parameter.id"></a>

- *Type:* string

scoped id of the resource.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnOrgInvitationProps">CfnOrgInvitationProps</a>

resource properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitation.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitation.overrideLogicalId">overrideLogicalId</a></code> | Overrides the auto-generated logical ID with a specific ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitation.addDeletionOverride">addDeletionOverride</a></code> | Syntactic sugar for `addOverride(path, undefined)`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitation.addDependency">addDependency</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitation.addDependsOn">addDependsOn</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitation.addMetadata">addMetadata</a></code> | Add a value to the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitation.addOverride">addOverride</a></code> | Adds an override to the synthesized CloudFormation resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitation.addPropertyDeletionOverride">addPropertyDeletionOverride</a></code> | Adds an override that deletes the value of a property from the resource definition. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitation.addPropertyOverride">addPropertyOverride</a></code> | Adds an override to a resource property. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitation.applyRemovalPolicy">applyRemovalPolicy</a></code> | Sets the deletion policy of the resource based on the removal policy specified. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitation.getAtt">getAtt</a></code> | Returns a token for an runtime attribute of this resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitation.getMetadata">getMetadata</a></code> | Retrieve a value value from the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitation.obtainDependencies">obtainDependencies</a></code> | Retrieves an array of resources this resource depends on. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitation.obtainResourceDependencies">obtainResourceDependencies</a></code> | Get a shallow copy of dependencies between this resource and other resources in the same stack. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitation.removeDependency">removeDependency</a></code> | Indicates that this resource no longer depends on another resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitation.replaceDependency">replaceDependency</a></code> | Replaces one dependency with another. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `overrideLogicalId` <a name="overrideLogicalId" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.overrideLogicalId"></a>

```typescript
public overrideLogicalId(newLogicalId: string): void
```

Overrides the auto-generated logical ID with a specific ID.

###### `newLogicalId`<sup>Required</sup> <a name="newLogicalId" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.overrideLogicalId.parameter.newLogicalId"></a>

- *Type:* string

The new logical ID to use for this stack element.

---

##### `addDeletionOverride` <a name="addDeletionOverride" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.addDeletionOverride"></a>

```typescript
public addDeletionOverride(path: string): void
```

Syntactic sugar for `addOverride(path, undefined)`.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.addDeletionOverride.parameter.path"></a>

- *Type:* string

The path of the value to delete.

---

##### `addDependency` <a name="addDependency" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.addDependency"></a>

```typescript
public addDependency(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

This can be used for resources across stacks (or nested stack) boundaries
and the dependency will automatically be transferred to the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.addDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### ~~`addDependsOn`~~ <a name="addDependsOn" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.addDependsOn"></a>

```typescript
public addDependsOn(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.addDependsOn.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `addMetadata` <a name="addMetadata" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.addMetadata"></a>

```typescript
public addMetadata(key: string, value: any): void
```

Add a value to the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.addMetadata.parameter.key"></a>

- *Type:* string

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.addMetadata.parameter.value"></a>

- *Type:* any

---

##### `addOverride` <a name="addOverride" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.addOverride"></a>

```typescript
public addOverride(path: string, value: any): void
```

Adds an override to the synthesized CloudFormation resource.

To add a
property override, either use `addPropertyOverride` or prefix `path` with
"Properties." (i.e. `Properties.TopicName`).

If the override is nested, separate each nested level using a dot (.) in the path parameter.
If there is an array as part of the nesting, specify the index in the path.

To include a literal `.` in the property name, prefix with a `\`. In most
programming languages you will need to write this as `"\\."` because the
`\` itself will need to be escaped.

For example,
```typescript
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
```
would add the overrides
```json
"Properties": {
  "GlobalSecondaryIndexes": [
    {
      "Projection": {
        "NonKeyAttributes": [ "myattribute" ]
        ...
      }
      ...
    },
    {
      "ProjectionType": "INCLUDE"
      ...
    },
  ]
  ...
}
```

The `value` argument to `addOverride` will not be processed or translated
in any way. Pass raw JSON values in here with the correct capitalization
for CloudFormation. If you pass CDK classes or structs, they will be
rendered with lowercased key names, and CloudFormation will reject the
template.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.addOverride.parameter.path"></a>

- *Type:* string

The path of the property, you can use dot notation to override values in complex types.

Any intermediate keys
will be created as needed.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.addOverride.parameter.value"></a>

- *Type:* any

The value.

Could be primitive or complex.

---

##### `addPropertyDeletionOverride` <a name="addPropertyDeletionOverride" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.addPropertyDeletionOverride"></a>

```typescript
public addPropertyDeletionOverride(propertyPath: string): void
```

Adds an override that deletes the value of a property from the resource definition.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.addPropertyDeletionOverride.parameter.propertyPath"></a>

- *Type:* string

The path to the property.

---

##### `addPropertyOverride` <a name="addPropertyOverride" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.addPropertyOverride"></a>

```typescript
public addPropertyOverride(propertyPath: string, value: any): void
```

Adds an override to a resource property.

Syntactic sugar for `addOverride("Properties.<...>", value)`.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.addPropertyOverride.parameter.propertyPath"></a>

- *Type:* string

The path of the property.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.addPropertyOverride.parameter.value"></a>

- *Type:* any

The value.

---

##### `applyRemovalPolicy` <a name="applyRemovalPolicy" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.applyRemovalPolicy"></a>

```typescript
public applyRemovalPolicy(policy?: RemovalPolicy, options?: RemovalPolicyOptions): void
```

Sets the deletion policy of the resource based on the removal policy specified.

The Removal Policy controls what happens to this resource when it stops
being managed by CloudFormation, either because you've removed it from the
CDK application or because you've made a change that requires the resource
to be replaced.

The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
cases, a snapshot can be taken of the resource prior to deletion
(`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
can be found in the following link:

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options)

###### `policy`<sup>Optional</sup> <a name="policy" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.applyRemovalPolicy.parameter.policy"></a>

- *Type:* aws-cdk-lib.RemovalPolicy

---

###### `options`<sup>Optional</sup> <a name="options" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.applyRemovalPolicy.parameter.options"></a>

- *Type:* aws-cdk-lib.RemovalPolicyOptions

---

##### `getAtt` <a name="getAtt" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.getAtt"></a>

```typescript
public getAtt(attributeName: string, typeHint?: ResolutionTypeHint): Reference
```

Returns a token for an runtime attribute of this resource.

Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
in case there is no generated attribute.

###### `attributeName`<sup>Required</sup> <a name="attributeName" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.getAtt.parameter.attributeName"></a>

- *Type:* string

The name of the attribute.

---

###### `typeHint`<sup>Optional</sup> <a name="typeHint" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.getAtt.parameter.typeHint"></a>

- *Type:* aws-cdk-lib.ResolutionTypeHint

---

##### `getMetadata` <a name="getMetadata" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.getMetadata"></a>

```typescript
public getMetadata(key: string): any
```

Retrieve a value value from the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.getMetadata.parameter.key"></a>

- *Type:* string

---

##### `obtainDependencies` <a name="obtainDependencies" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.obtainDependencies"></a>

```typescript
public obtainDependencies(): Stack | CfnResource[]
```

Retrieves an array of resources this resource depends on.

This assembles dependencies on resources across stacks (including nested stacks)
automatically.

##### `obtainResourceDependencies` <a name="obtainResourceDependencies" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.obtainResourceDependencies"></a>

```typescript
public obtainResourceDependencies(): CfnResource[]
```

Get a shallow copy of dependencies between this resource and other resources in the same stack.

##### `removeDependency` <a name="removeDependency" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.removeDependency"></a>

```typescript
public removeDependency(target: CfnResource): void
```

Indicates that this resource no longer depends on another resource.

This can be used for resources across stacks (including nested stacks)
and the dependency will automatically be removed from the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.removeDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `replaceDependency` <a name="replaceDependency" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.replaceDependency"></a>

```typescript
public replaceDependency(target: CfnResource, newTarget: CfnResource): void
```

Replaces one dependency with another.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.replaceDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

The dependency to replace.

---

###### `newTarget`<sup>Required</sup> <a name="newTarget" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.replaceDependency.parameter.newTarget"></a>

- *Type:* aws-cdk-lib.CfnResource

The new dependency to add.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitation.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitation.isCfnElement">isCfnElement</a></code> | Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitation.isCfnResource">isCfnResource</a></code> | Check whether the given construct is a CfnResource. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.isConstruct"></a>

```typescript
import { CfnOrgInvitation } from 'awscdk-resources-mongodbatlas'

CfnOrgInvitation.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `isCfnElement` <a name="isCfnElement" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.isCfnElement"></a>

```typescript
import { CfnOrgInvitation } from 'awscdk-resources-mongodbatlas'

CfnOrgInvitation.isCfnElement(x: any)
```

Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).

Uses duck-typing instead of `instanceof` to allow stack elements from different
versions of this library to be included in the same stack.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.isCfnElement.parameter.x"></a>

- *Type:* any

---

##### `isCfnResource` <a name="isCfnResource" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.isCfnResource"></a>

```typescript
import { CfnOrgInvitation } from 'awscdk-resources-mongodbatlas'

CfnOrgInvitation.isCfnResource(construct: IConstruct)
```

Check whether the given construct is a CfnResource.

###### `construct`<sup>Required</sup> <a name="construct" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.isCfnResource.parameter.construct"></a>

- *Type:* constructs.IConstruct

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitation.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitation.property.creationStack">creationStack</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitation.property.logicalId">logicalId</a></code> | <code>string</code> | The logical ID for this CloudFormation stack element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitation.property.stack">stack</a></code> | <code>aws-cdk-lib.Stack</code> | The stack in which this element is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitation.property.ref">ref</a></code> | <code>string</code> | Return a string that will be resolved to a CloudFormation `{ Ref }` for this element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitation.property.cfnOptions">cfnOptions</a></code> | <code>aws-cdk-lib.ICfnResourceOptions</code> | Options for this resource, such as condition, update policy etc. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitation.property.cfnResourceType">cfnResourceType</a></code> | <code>string</code> | AWS resource type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitation.property.attrCreatedAt">attrCreatedAt</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::OrgInvitation.CreatedAt`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitation.property.attrExpiresAt">attrExpiresAt</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::OrgInvitation.ExpiresAt`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitation.property.attrId">attrId</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::OrgInvitation.Id`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitation.property.attrInviterUsername">attrInviterUsername</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::OrgInvitation.InviterUsername`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitation.property.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitationProps">CfnOrgInvitationProps</a></code> | Resource props. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `creationStack`<sup>Required</sup> <a name="creationStack" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.property.creationStack"></a>

```typescript
public readonly creationStack: string[];
```

- *Type:* string[]

---

##### `logicalId`<sup>Required</sup> <a name="logicalId" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.property.logicalId"></a>

```typescript
public readonly logicalId: string;
```

- *Type:* string

The logical ID for this CloudFormation stack element.

The logical ID of the element
is calculated from the path of the resource node in the construct tree.

To override this value, use `overrideLogicalId(newLogicalId)`.

---

##### `stack`<sup>Required</sup> <a name="stack" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.property.stack"></a>

```typescript
public readonly stack: Stack;
```

- *Type:* aws-cdk-lib.Stack

The stack in which this element is defined.

CfnElements must be defined within a stack scope (directly or indirectly).

---

##### `ref`<sup>Required</sup> <a name="ref" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.

If, by any chance, the intrinsic reference of a resource is not a string, you could
coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.

---

##### `cfnOptions`<sup>Required</sup> <a name="cfnOptions" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.property.cfnOptions"></a>

```typescript
public readonly cfnOptions: ICfnResourceOptions;
```

- *Type:* aws-cdk-lib.ICfnResourceOptions

Options for this resource, such as condition, update policy etc.

---

##### `cfnResourceType`<sup>Required</sup> <a name="cfnResourceType" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.property.cfnResourceType"></a>

```typescript
public readonly cfnResourceType: string;
```

- *Type:* string

AWS resource type.

---

##### `attrCreatedAt`<sup>Required</sup> <a name="attrCreatedAt" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.property.attrCreatedAt"></a>

```typescript
public readonly attrCreatedAt: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::OrgInvitation.CreatedAt`.

---

##### `attrExpiresAt`<sup>Required</sup> <a name="attrExpiresAt" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.property.attrExpiresAt"></a>

```typescript
public readonly attrExpiresAt: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::OrgInvitation.ExpiresAt`.

---

##### `attrId`<sup>Required</sup> <a name="attrId" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.property.attrId"></a>

```typescript
public readonly attrId: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::OrgInvitation.Id`.

---

##### `attrInviterUsername`<sup>Required</sup> <a name="attrInviterUsername" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.property.attrInviterUsername"></a>

```typescript
public readonly attrInviterUsername: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::OrgInvitation.InviterUsername`.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.property.props"></a>

```typescript
public readonly props: CfnOrgInvitationProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnOrgInvitationProps">CfnOrgInvitationProps</a>

Resource props.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitation.property.CFN_RESOURCE_TYPE_NAME">CFN_RESOURCE_TYPE_NAME</a></code> | <code>string</code> | The CloudFormation resource type name for this resource class. |

---

##### `CFN_RESOURCE_TYPE_NAME`<sup>Required</sup> <a name="CFN_RESOURCE_TYPE_NAME" id="awscdk-resources-mongodbatlas.CfnOrgInvitation.property.CFN_RESOURCE_TYPE_NAME"></a>

```typescript
public readonly CFN_RESOURCE_TYPE_NAME: string;
```

- *Type:* string

The CloudFormation resource type name for this resource class.

---

### CfnPrivateEndpoint <a name="CfnPrivateEndpoint" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint"></a>

A CloudFormation `MongoDB::Atlas::PrivateEndpoint`.

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.Initializer"></a>

```typescript
import { CfnPrivateEndpoint } from 'awscdk-resources-mongodbatlas'

new CfnPrivateEndpoint(scope: Construct, id: string, props: CfnPrivateEndpointProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpoint.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - scope in which this resource is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpoint.Initializer.parameter.id">id</a></code> | <code>string</code> | - scoped id of the resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpoint.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointProps">CfnPrivateEndpointProps</a></code> | - resource properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

scope in which this resource is defined.

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.Initializer.parameter.id"></a>

- *Type:* string

scoped id of the resource.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointProps">CfnPrivateEndpointProps</a>

resource properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpoint.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpoint.overrideLogicalId">overrideLogicalId</a></code> | Overrides the auto-generated logical ID with a specific ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpoint.addDeletionOverride">addDeletionOverride</a></code> | Syntactic sugar for `addOverride(path, undefined)`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpoint.addDependency">addDependency</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpoint.addDependsOn">addDependsOn</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpoint.addMetadata">addMetadata</a></code> | Add a value to the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpoint.addOverride">addOverride</a></code> | Adds an override to the synthesized CloudFormation resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpoint.addPropertyDeletionOverride">addPropertyDeletionOverride</a></code> | Adds an override that deletes the value of a property from the resource definition. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpoint.addPropertyOverride">addPropertyOverride</a></code> | Adds an override to a resource property. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpoint.applyRemovalPolicy">applyRemovalPolicy</a></code> | Sets the deletion policy of the resource based on the removal policy specified. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpoint.getAtt">getAtt</a></code> | Returns a token for an runtime attribute of this resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpoint.getMetadata">getMetadata</a></code> | Retrieve a value value from the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpoint.obtainDependencies">obtainDependencies</a></code> | Retrieves an array of resources this resource depends on. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpoint.obtainResourceDependencies">obtainResourceDependencies</a></code> | Get a shallow copy of dependencies between this resource and other resources in the same stack. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpoint.removeDependency">removeDependency</a></code> | Indicates that this resource no longer depends on another resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpoint.replaceDependency">replaceDependency</a></code> | Replaces one dependency with another. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `overrideLogicalId` <a name="overrideLogicalId" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.overrideLogicalId"></a>

```typescript
public overrideLogicalId(newLogicalId: string): void
```

Overrides the auto-generated logical ID with a specific ID.

###### `newLogicalId`<sup>Required</sup> <a name="newLogicalId" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.overrideLogicalId.parameter.newLogicalId"></a>

- *Type:* string

The new logical ID to use for this stack element.

---

##### `addDeletionOverride` <a name="addDeletionOverride" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.addDeletionOverride"></a>

```typescript
public addDeletionOverride(path: string): void
```

Syntactic sugar for `addOverride(path, undefined)`.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.addDeletionOverride.parameter.path"></a>

- *Type:* string

The path of the value to delete.

---

##### `addDependency` <a name="addDependency" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.addDependency"></a>

```typescript
public addDependency(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

This can be used for resources across stacks (or nested stack) boundaries
and the dependency will automatically be transferred to the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.addDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### ~~`addDependsOn`~~ <a name="addDependsOn" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.addDependsOn"></a>

```typescript
public addDependsOn(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.addDependsOn.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `addMetadata` <a name="addMetadata" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.addMetadata"></a>

```typescript
public addMetadata(key: string, value: any): void
```

Add a value to the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.addMetadata.parameter.key"></a>

- *Type:* string

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.addMetadata.parameter.value"></a>

- *Type:* any

---

##### `addOverride` <a name="addOverride" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.addOverride"></a>

```typescript
public addOverride(path: string, value: any): void
```

Adds an override to the synthesized CloudFormation resource.

To add a
property override, either use `addPropertyOverride` or prefix `path` with
"Properties." (i.e. `Properties.TopicName`).

If the override is nested, separate each nested level using a dot (.) in the path parameter.
If there is an array as part of the nesting, specify the index in the path.

To include a literal `.` in the property name, prefix with a `\`. In most
programming languages you will need to write this as `"\\."` because the
`\` itself will need to be escaped.

For example,
```typescript
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
```
would add the overrides
```json
"Properties": {
  "GlobalSecondaryIndexes": [
    {
      "Projection": {
        "NonKeyAttributes": [ "myattribute" ]
        ...
      }
      ...
    },
    {
      "ProjectionType": "INCLUDE"
      ...
    },
  ]
  ...
}
```

The `value` argument to `addOverride` will not be processed or translated
in any way. Pass raw JSON values in here with the correct capitalization
for CloudFormation. If you pass CDK classes or structs, they will be
rendered with lowercased key names, and CloudFormation will reject the
template.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.addOverride.parameter.path"></a>

- *Type:* string

The path of the property, you can use dot notation to override values in complex types.

Any intermediate keys
will be created as needed.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.addOverride.parameter.value"></a>

- *Type:* any

The value.

Could be primitive or complex.

---

##### `addPropertyDeletionOverride` <a name="addPropertyDeletionOverride" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.addPropertyDeletionOverride"></a>

```typescript
public addPropertyDeletionOverride(propertyPath: string): void
```

Adds an override that deletes the value of a property from the resource definition.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.addPropertyDeletionOverride.parameter.propertyPath"></a>

- *Type:* string

The path to the property.

---

##### `addPropertyOverride` <a name="addPropertyOverride" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.addPropertyOverride"></a>

```typescript
public addPropertyOverride(propertyPath: string, value: any): void
```

Adds an override to a resource property.

Syntactic sugar for `addOverride("Properties.<...>", value)`.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.addPropertyOverride.parameter.propertyPath"></a>

- *Type:* string

The path of the property.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.addPropertyOverride.parameter.value"></a>

- *Type:* any

The value.

---

##### `applyRemovalPolicy` <a name="applyRemovalPolicy" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.applyRemovalPolicy"></a>

```typescript
public applyRemovalPolicy(policy?: RemovalPolicy, options?: RemovalPolicyOptions): void
```

Sets the deletion policy of the resource based on the removal policy specified.

The Removal Policy controls what happens to this resource when it stops
being managed by CloudFormation, either because you've removed it from the
CDK application or because you've made a change that requires the resource
to be replaced.

The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
cases, a snapshot can be taken of the resource prior to deletion
(`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
can be found in the following link:

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options)

###### `policy`<sup>Optional</sup> <a name="policy" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.applyRemovalPolicy.parameter.policy"></a>

- *Type:* aws-cdk-lib.RemovalPolicy

---

###### `options`<sup>Optional</sup> <a name="options" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.applyRemovalPolicy.parameter.options"></a>

- *Type:* aws-cdk-lib.RemovalPolicyOptions

---

##### `getAtt` <a name="getAtt" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.getAtt"></a>

```typescript
public getAtt(attributeName: string, typeHint?: ResolutionTypeHint): Reference
```

Returns a token for an runtime attribute of this resource.

Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
in case there is no generated attribute.

###### `attributeName`<sup>Required</sup> <a name="attributeName" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.getAtt.parameter.attributeName"></a>

- *Type:* string

The name of the attribute.

---

###### `typeHint`<sup>Optional</sup> <a name="typeHint" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.getAtt.parameter.typeHint"></a>

- *Type:* aws-cdk-lib.ResolutionTypeHint

---

##### `getMetadata` <a name="getMetadata" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.getMetadata"></a>

```typescript
public getMetadata(key: string): any
```

Retrieve a value value from the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.getMetadata.parameter.key"></a>

- *Type:* string

---

##### `obtainDependencies` <a name="obtainDependencies" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.obtainDependencies"></a>

```typescript
public obtainDependencies(): Stack | CfnResource[]
```

Retrieves an array of resources this resource depends on.

This assembles dependencies on resources across stacks (including nested stacks)
automatically.

##### `obtainResourceDependencies` <a name="obtainResourceDependencies" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.obtainResourceDependencies"></a>

```typescript
public obtainResourceDependencies(): CfnResource[]
```

Get a shallow copy of dependencies between this resource and other resources in the same stack.

##### `removeDependency` <a name="removeDependency" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.removeDependency"></a>

```typescript
public removeDependency(target: CfnResource): void
```

Indicates that this resource no longer depends on another resource.

This can be used for resources across stacks (including nested stacks)
and the dependency will automatically be removed from the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.removeDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `replaceDependency` <a name="replaceDependency" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.replaceDependency"></a>

```typescript
public replaceDependency(target: CfnResource, newTarget: CfnResource): void
```

Replaces one dependency with another.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.replaceDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

The dependency to replace.

---

###### `newTarget`<sup>Required</sup> <a name="newTarget" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.replaceDependency.parameter.newTarget"></a>

- *Type:* aws-cdk-lib.CfnResource

The new dependency to add.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpoint.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpoint.isCfnElement">isCfnElement</a></code> | Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpoint.isCfnResource">isCfnResource</a></code> | Check whether the given construct is a CfnResource. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.isConstruct"></a>

```typescript
import { CfnPrivateEndpoint } from 'awscdk-resources-mongodbatlas'

CfnPrivateEndpoint.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `isCfnElement` <a name="isCfnElement" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.isCfnElement"></a>

```typescript
import { CfnPrivateEndpoint } from 'awscdk-resources-mongodbatlas'

CfnPrivateEndpoint.isCfnElement(x: any)
```

Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).

Uses duck-typing instead of `instanceof` to allow stack elements from different
versions of this library to be included in the same stack.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.isCfnElement.parameter.x"></a>

- *Type:* any

---

##### `isCfnResource` <a name="isCfnResource" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.isCfnResource"></a>

```typescript
import { CfnPrivateEndpoint } from 'awscdk-resources-mongodbatlas'

CfnPrivateEndpoint.isCfnResource(construct: IConstruct)
```

Check whether the given construct is a CfnResource.

###### `construct`<sup>Required</sup> <a name="construct" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.isCfnResource.parameter.construct"></a>

- *Type:* constructs.IConstruct

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpoint.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpoint.property.creationStack">creationStack</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpoint.property.logicalId">logicalId</a></code> | <code>string</code> | The logical ID for this CloudFormation stack element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpoint.property.stack">stack</a></code> | <code>aws-cdk-lib.Stack</code> | The stack in which this element is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpoint.property.ref">ref</a></code> | <code>string</code> | Return a string that will be resolved to a CloudFormation `{ Ref }` for this element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpoint.property.cfnOptions">cfnOptions</a></code> | <code>aws-cdk-lib.ICfnResourceOptions</code> | Options for this resource, such as condition, update policy etc. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpoint.property.cfnResourceType">cfnResourceType</a></code> | <code>string</code> | AWS resource type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpoint.property.attrId">attrId</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::PrivateEndpoint.Id`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpoint.property.attrInterfaceEndpoints">attrInterfaceEndpoints</a></code> | <code>string[]</code> | Attribute `MongoDB::Atlas::PrivateEndpoint.InterfaceEndpoints`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpoint.property.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointProps">CfnPrivateEndpointProps</a></code> | Resource props. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `creationStack`<sup>Required</sup> <a name="creationStack" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.property.creationStack"></a>

```typescript
public readonly creationStack: string[];
```

- *Type:* string[]

---

##### `logicalId`<sup>Required</sup> <a name="logicalId" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.property.logicalId"></a>

```typescript
public readonly logicalId: string;
```

- *Type:* string

The logical ID for this CloudFormation stack element.

The logical ID of the element
is calculated from the path of the resource node in the construct tree.

To override this value, use `overrideLogicalId(newLogicalId)`.

---

##### `stack`<sup>Required</sup> <a name="stack" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.property.stack"></a>

```typescript
public readonly stack: Stack;
```

- *Type:* aws-cdk-lib.Stack

The stack in which this element is defined.

CfnElements must be defined within a stack scope (directly or indirectly).

---

##### `ref`<sup>Required</sup> <a name="ref" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.

If, by any chance, the intrinsic reference of a resource is not a string, you could
coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.

---

##### `cfnOptions`<sup>Required</sup> <a name="cfnOptions" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.property.cfnOptions"></a>

```typescript
public readonly cfnOptions: ICfnResourceOptions;
```

- *Type:* aws-cdk-lib.ICfnResourceOptions

Options for this resource, such as condition, update policy etc.

---

##### `cfnResourceType`<sup>Required</sup> <a name="cfnResourceType" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.property.cfnResourceType"></a>

```typescript
public readonly cfnResourceType: string;
```

- *Type:* string

AWS resource type.

---

##### `attrId`<sup>Required</sup> <a name="attrId" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.property.attrId"></a>

```typescript
public readonly attrId: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::PrivateEndpoint.Id`.

---

##### `attrInterfaceEndpoints`<sup>Required</sup> <a name="attrInterfaceEndpoints" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.property.attrInterfaceEndpoints"></a>

```typescript
public readonly attrInterfaceEndpoints: string[];
```

- *Type:* string[]

Attribute `MongoDB::Atlas::PrivateEndpoint.InterfaceEndpoints`.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.property.props"></a>

```typescript
public readonly props: CfnPrivateEndpointProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointProps">CfnPrivateEndpointProps</a>

Resource props.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpoint.property.CFN_RESOURCE_TYPE_NAME">CFN_RESOURCE_TYPE_NAME</a></code> | <code>string</code> | The CloudFormation resource type name for this resource class. |

---

##### `CFN_RESOURCE_TYPE_NAME`<sup>Required</sup> <a name="CFN_RESOURCE_TYPE_NAME" id="awscdk-resources-mongodbatlas.CfnPrivateEndpoint.property.CFN_RESOURCE_TYPE_NAME"></a>

```typescript
public readonly CFN_RESOURCE_TYPE_NAME: string;
```

- *Type:* string

The CloudFormation resource type name for this resource class.

---

### CfnPrivateEndpointAdl <a name="CfnPrivateEndpointAdl" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl"></a>

A CloudFormation `MongoDB::Atlas::PrivateEndpointADL`.

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.Initializer"></a>

```typescript
import { CfnPrivateEndpointAdl } from 'awscdk-resources-mongodbatlas'

new CfnPrivateEndpointAdl(scope: Construct, id: string, props: CfnPrivateEndpointAdlProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - scope in which this resource is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.Initializer.parameter.id">id</a></code> | <code>string</code> | - scoped id of the resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAdlProps">CfnPrivateEndpointAdlProps</a></code> | - resource properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

scope in which this resource is defined.

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.Initializer.parameter.id"></a>

- *Type:* string

scoped id of the resource.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAdlProps">CfnPrivateEndpointAdlProps</a>

resource properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.overrideLogicalId">overrideLogicalId</a></code> | Overrides the auto-generated logical ID with a specific ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.addDeletionOverride">addDeletionOverride</a></code> | Syntactic sugar for `addOverride(path, undefined)`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.addDependency">addDependency</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.addDependsOn">addDependsOn</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.addMetadata">addMetadata</a></code> | Add a value to the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.addOverride">addOverride</a></code> | Adds an override to the synthesized CloudFormation resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.addPropertyDeletionOverride">addPropertyDeletionOverride</a></code> | Adds an override that deletes the value of a property from the resource definition. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.addPropertyOverride">addPropertyOverride</a></code> | Adds an override to a resource property. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.applyRemovalPolicy">applyRemovalPolicy</a></code> | Sets the deletion policy of the resource based on the removal policy specified. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.getAtt">getAtt</a></code> | Returns a token for an runtime attribute of this resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.getMetadata">getMetadata</a></code> | Retrieve a value value from the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.obtainDependencies">obtainDependencies</a></code> | Retrieves an array of resources this resource depends on. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.obtainResourceDependencies">obtainResourceDependencies</a></code> | Get a shallow copy of dependencies between this resource and other resources in the same stack. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.removeDependency">removeDependency</a></code> | Indicates that this resource no longer depends on another resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.replaceDependency">replaceDependency</a></code> | Replaces one dependency with another. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `overrideLogicalId` <a name="overrideLogicalId" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.overrideLogicalId"></a>

```typescript
public overrideLogicalId(newLogicalId: string): void
```

Overrides the auto-generated logical ID with a specific ID.

###### `newLogicalId`<sup>Required</sup> <a name="newLogicalId" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.overrideLogicalId.parameter.newLogicalId"></a>

- *Type:* string

The new logical ID to use for this stack element.

---

##### `addDeletionOverride` <a name="addDeletionOverride" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.addDeletionOverride"></a>

```typescript
public addDeletionOverride(path: string): void
```

Syntactic sugar for `addOverride(path, undefined)`.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.addDeletionOverride.parameter.path"></a>

- *Type:* string

The path of the value to delete.

---

##### `addDependency` <a name="addDependency" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.addDependency"></a>

```typescript
public addDependency(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

This can be used for resources across stacks (or nested stack) boundaries
and the dependency will automatically be transferred to the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.addDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### ~~`addDependsOn`~~ <a name="addDependsOn" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.addDependsOn"></a>

```typescript
public addDependsOn(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.addDependsOn.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `addMetadata` <a name="addMetadata" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.addMetadata"></a>

```typescript
public addMetadata(key: string, value: any): void
```

Add a value to the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.addMetadata.parameter.key"></a>

- *Type:* string

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.addMetadata.parameter.value"></a>

- *Type:* any

---

##### `addOverride` <a name="addOverride" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.addOverride"></a>

```typescript
public addOverride(path: string, value: any): void
```

Adds an override to the synthesized CloudFormation resource.

To add a
property override, either use `addPropertyOverride` or prefix `path` with
"Properties." (i.e. `Properties.TopicName`).

If the override is nested, separate each nested level using a dot (.) in the path parameter.
If there is an array as part of the nesting, specify the index in the path.

To include a literal `.` in the property name, prefix with a `\`. In most
programming languages you will need to write this as `"\\."` because the
`\` itself will need to be escaped.

For example,
```typescript
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
```
would add the overrides
```json
"Properties": {
  "GlobalSecondaryIndexes": [
    {
      "Projection": {
        "NonKeyAttributes": [ "myattribute" ]
        ...
      }
      ...
    },
    {
      "ProjectionType": "INCLUDE"
      ...
    },
  ]
  ...
}
```

The `value` argument to `addOverride` will not be processed or translated
in any way. Pass raw JSON values in here with the correct capitalization
for CloudFormation. If you pass CDK classes or structs, they will be
rendered with lowercased key names, and CloudFormation will reject the
template.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.addOverride.parameter.path"></a>

- *Type:* string

The path of the property, you can use dot notation to override values in complex types.

Any intermediate keys
will be created as needed.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.addOverride.parameter.value"></a>

- *Type:* any

The value.

Could be primitive or complex.

---

##### `addPropertyDeletionOverride` <a name="addPropertyDeletionOverride" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.addPropertyDeletionOverride"></a>

```typescript
public addPropertyDeletionOverride(propertyPath: string): void
```

Adds an override that deletes the value of a property from the resource definition.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.addPropertyDeletionOverride.parameter.propertyPath"></a>

- *Type:* string

The path to the property.

---

##### `addPropertyOverride` <a name="addPropertyOverride" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.addPropertyOverride"></a>

```typescript
public addPropertyOverride(propertyPath: string, value: any): void
```

Adds an override to a resource property.

Syntactic sugar for `addOverride("Properties.<...>", value)`.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.addPropertyOverride.parameter.propertyPath"></a>

- *Type:* string

The path of the property.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.addPropertyOverride.parameter.value"></a>

- *Type:* any

The value.

---

##### `applyRemovalPolicy` <a name="applyRemovalPolicy" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.applyRemovalPolicy"></a>

```typescript
public applyRemovalPolicy(policy?: RemovalPolicy, options?: RemovalPolicyOptions): void
```

Sets the deletion policy of the resource based on the removal policy specified.

The Removal Policy controls what happens to this resource when it stops
being managed by CloudFormation, either because you've removed it from the
CDK application or because you've made a change that requires the resource
to be replaced.

The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
cases, a snapshot can be taken of the resource prior to deletion
(`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
can be found in the following link:

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options)

###### `policy`<sup>Optional</sup> <a name="policy" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.applyRemovalPolicy.parameter.policy"></a>

- *Type:* aws-cdk-lib.RemovalPolicy

---

###### `options`<sup>Optional</sup> <a name="options" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.applyRemovalPolicy.parameter.options"></a>

- *Type:* aws-cdk-lib.RemovalPolicyOptions

---

##### `getAtt` <a name="getAtt" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.getAtt"></a>

```typescript
public getAtt(attributeName: string, typeHint?: ResolutionTypeHint): Reference
```

Returns a token for an runtime attribute of this resource.

Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
in case there is no generated attribute.

###### `attributeName`<sup>Required</sup> <a name="attributeName" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.getAtt.parameter.attributeName"></a>

- *Type:* string

The name of the attribute.

---

###### `typeHint`<sup>Optional</sup> <a name="typeHint" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.getAtt.parameter.typeHint"></a>

- *Type:* aws-cdk-lib.ResolutionTypeHint

---

##### `getMetadata` <a name="getMetadata" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.getMetadata"></a>

```typescript
public getMetadata(key: string): any
```

Retrieve a value value from the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.getMetadata.parameter.key"></a>

- *Type:* string

---

##### `obtainDependencies` <a name="obtainDependencies" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.obtainDependencies"></a>

```typescript
public obtainDependencies(): Stack | CfnResource[]
```

Retrieves an array of resources this resource depends on.

This assembles dependencies on resources across stacks (including nested stacks)
automatically.

##### `obtainResourceDependencies` <a name="obtainResourceDependencies" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.obtainResourceDependencies"></a>

```typescript
public obtainResourceDependencies(): CfnResource[]
```

Get a shallow copy of dependencies between this resource and other resources in the same stack.

##### `removeDependency` <a name="removeDependency" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.removeDependency"></a>

```typescript
public removeDependency(target: CfnResource): void
```

Indicates that this resource no longer depends on another resource.

This can be used for resources across stacks (including nested stacks)
and the dependency will automatically be removed from the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.removeDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `replaceDependency` <a name="replaceDependency" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.replaceDependency"></a>

```typescript
public replaceDependency(target: CfnResource, newTarget: CfnResource): void
```

Replaces one dependency with another.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.replaceDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

The dependency to replace.

---

###### `newTarget`<sup>Required</sup> <a name="newTarget" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.replaceDependency.parameter.newTarget"></a>

- *Type:* aws-cdk-lib.CfnResource

The new dependency to add.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.isCfnElement">isCfnElement</a></code> | Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.isCfnResource">isCfnResource</a></code> | Check whether the given construct is a CfnResource. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.isConstruct"></a>

```typescript
import { CfnPrivateEndpointAdl } from 'awscdk-resources-mongodbatlas'

CfnPrivateEndpointAdl.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `isCfnElement` <a name="isCfnElement" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.isCfnElement"></a>

```typescript
import { CfnPrivateEndpointAdl } from 'awscdk-resources-mongodbatlas'

CfnPrivateEndpointAdl.isCfnElement(x: any)
```

Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).

Uses duck-typing instead of `instanceof` to allow stack elements from different
versions of this library to be included in the same stack.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.isCfnElement.parameter.x"></a>

- *Type:* any

---

##### `isCfnResource` <a name="isCfnResource" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.isCfnResource"></a>

```typescript
import { CfnPrivateEndpointAdl } from 'awscdk-resources-mongodbatlas'

CfnPrivateEndpointAdl.isCfnResource(construct: IConstruct)
```

Check whether the given construct is a CfnResource.

###### `construct`<sup>Required</sup> <a name="construct" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.isCfnResource.parameter.construct"></a>

- *Type:* constructs.IConstruct

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.property.creationStack">creationStack</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.property.logicalId">logicalId</a></code> | <code>string</code> | The logical ID for this CloudFormation stack element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.property.stack">stack</a></code> | <code>aws-cdk-lib.Stack</code> | The stack in which this element is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.property.ref">ref</a></code> | <code>string</code> | Return a string that will be resolved to a CloudFormation `{ Ref }` for this element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.property.cfnOptions">cfnOptions</a></code> | <code>aws-cdk-lib.ICfnResourceOptions</code> | Options for this resource, such as condition, update policy etc. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.property.cfnResourceType">cfnResourceType</a></code> | <code>string</code> | AWS resource type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.property.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAdlProps">CfnPrivateEndpointAdlProps</a></code> | Resource props. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `creationStack`<sup>Required</sup> <a name="creationStack" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.property.creationStack"></a>

```typescript
public readonly creationStack: string[];
```

- *Type:* string[]

---

##### `logicalId`<sup>Required</sup> <a name="logicalId" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.property.logicalId"></a>

```typescript
public readonly logicalId: string;
```

- *Type:* string

The logical ID for this CloudFormation stack element.

The logical ID of the element
is calculated from the path of the resource node in the construct tree.

To override this value, use `overrideLogicalId(newLogicalId)`.

---

##### `stack`<sup>Required</sup> <a name="stack" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.property.stack"></a>

```typescript
public readonly stack: Stack;
```

- *Type:* aws-cdk-lib.Stack

The stack in which this element is defined.

CfnElements must be defined within a stack scope (directly or indirectly).

---

##### `ref`<sup>Required</sup> <a name="ref" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.

If, by any chance, the intrinsic reference of a resource is not a string, you could
coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.

---

##### `cfnOptions`<sup>Required</sup> <a name="cfnOptions" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.property.cfnOptions"></a>

```typescript
public readonly cfnOptions: ICfnResourceOptions;
```

- *Type:* aws-cdk-lib.ICfnResourceOptions

Options for this resource, such as condition, update policy etc.

---

##### `cfnResourceType`<sup>Required</sup> <a name="cfnResourceType" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.property.cfnResourceType"></a>

```typescript
public readonly cfnResourceType: string;
```

- *Type:* string

AWS resource type.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.property.props"></a>

```typescript
public readonly props: CfnPrivateEndpointAdlProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAdlProps">CfnPrivateEndpointAdlProps</a>

Resource props.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.property.CFN_RESOURCE_TYPE_NAME">CFN_RESOURCE_TYPE_NAME</a></code> | <code>string</code> | The CloudFormation resource type name for this resource class. |

---

##### `CFN_RESOURCE_TYPE_NAME`<sup>Required</sup> <a name="CFN_RESOURCE_TYPE_NAME" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdl.property.CFN_RESOURCE_TYPE_NAME"></a>

```typescript
public readonly CFN_RESOURCE_TYPE_NAME: string;
```

- *Type:* string

The CloudFormation resource type name for this resource class.

---

### CfnPrivateEndpointAws <a name="CfnPrivateEndpointAws" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws"></a>

A CloudFormation `MongoDB::Atlas::PrivateEndpointAWS`.

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.Initializer"></a>

```typescript
import { CfnPrivateEndpointAws } from 'awscdk-resources-mongodbatlas'

new CfnPrivateEndpointAws(scope: Construct, id: string, props: CfnPrivateEndpointAwsProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - scope in which this resource is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.Initializer.parameter.id">id</a></code> | <code>string</code> | - scoped id of the resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAwsProps">CfnPrivateEndpointAwsProps</a></code> | - resource properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

scope in which this resource is defined.

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.Initializer.parameter.id"></a>

- *Type:* string

scoped id of the resource.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAwsProps">CfnPrivateEndpointAwsProps</a>

resource properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.overrideLogicalId">overrideLogicalId</a></code> | Overrides the auto-generated logical ID with a specific ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.addDeletionOverride">addDeletionOverride</a></code> | Syntactic sugar for `addOverride(path, undefined)`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.addDependency">addDependency</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.addDependsOn">addDependsOn</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.addMetadata">addMetadata</a></code> | Add a value to the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.addOverride">addOverride</a></code> | Adds an override to the synthesized CloudFormation resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.addPropertyDeletionOverride">addPropertyDeletionOverride</a></code> | Adds an override that deletes the value of a property from the resource definition. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.addPropertyOverride">addPropertyOverride</a></code> | Adds an override to a resource property. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.applyRemovalPolicy">applyRemovalPolicy</a></code> | Sets the deletion policy of the resource based on the removal policy specified. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.getAtt">getAtt</a></code> | Returns a token for an runtime attribute of this resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.getMetadata">getMetadata</a></code> | Retrieve a value value from the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.obtainDependencies">obtainDependencies</a></code> | Retrieves an array of resources this resource depends on. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.obtainResourceDependencies">obtainResourceDependencies</a></code> | Get a shallow copy of dependencies between this resource and other resources in the same stack. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.removeDependency">removeDependency</a></code> | Indicates that this resource no longer depends on another resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.replaceDependency">replaceDependency</a></code> | Replaces one dependency with another. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `overrideLogicalId` <a name="overrideLogicalId" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.overrideLogicalId"></a>

```typescript
public overrideLogicalId(newLogicalId: string): void
```

Overrides the auto-generated logical ID with a specific ID.

###### `newLogicalId`<sup>Required</sup> <a name="newLogicalId" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.overrideLogicalId.parameter.newLogicalId"></a>

- *Type:* string

The new logical ID to use for this stack element.

---

##### `addDeletionOverride` <a name="addDeletionOverride" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.addDeletionOverride"></a>

```typescript
public addDeletionOverride(path: string): void
```

Syntactic sugar for `addOverride(path, undefined)`.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.addDeletionOverride.parameter.path"></a>

- *Type:* string

The path of the value to delete.

---

##### `addDependency` <a name="addDependency" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.addDependency"></a>

```typescript
public addDependency(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

This can be used for resources across stacks (or nested stack) boundaries
and the dependency will automatically be transferred to the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.addDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### ~~`addDependsOn`~~ <a name="addDependsOn" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.addDependsOn"></a>

```typescript
public addDependsOn(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.addDependsOn.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `addMetadata` <a name="addMetadata" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.addMetadata"></a>

```typescript
public addMetadata(key: string, value: any): void
```

Add a value to the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.addMetadata.parameter.key"></a>

- *Type:* string

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.addMetadata.parameter.value"></a>

- *Type:* any

---

##### `addOverride` <a name="addOverride" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.addOverride"></a>

```typescript
public addOverride(path: string, value: any): void
```

Adds an override to the synthesized CloudFormation resource.

To add a
property override, either use `addPropertyOverride` or prefix `path` with
"Properties." (i.e. `Properties.TopicName`).

If the override is nested, separate each nested level using a dot (.) in the path parameter.
If there is an array as part of the nesting, specify the index in the path.

To include a literal `.` in the property name, prefix with a `\`. In most
programming languages you will need to write this as `"\\."` because the
`\` itself will need to be escaped.

For example,
```typescript
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
```
would add the overrides
```json
"Properties": {
  "GlobalSecondaryIndexes": [
    {
      "Projection": {
        "NonKeyAttributes": [ "myattribute" ]
        ...
      }
      ...
    },
    {
      "ProjectionType": "INCLUDE"
      ...
    },
  ]
  ...
}
```

The `value` argument to `addOverride` will not be processed or translated
in any way. Pass raw JSON values in here with the correct capitalization
for CloudFormation. If you pass CDK classes or structs, they will be
rendered with lowercased key names, and CloudFormation will reject the
template.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.addOverride.parameter.path"></a>

- *Type:* string

The path of the property, you can use dot notation to override values in complex types.

Any intermediate keys
will be created as needed.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.addOverride.parameter.value"></a>

- *Type:* any

The value.

Could be primitive or complex.

---

##### `addPropertyDeletionOverride` <a name="addPropertyDeletionOverride" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.addPropertyDeletionOverride"></a>

```typescript
public addPropertyDeletionOverride(propertyPath: string): void
```

Adds an override that deletes the value of a property from the resource definition.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.addPropertyDeletionOverride.parameter.propertyPath"></a>

- *Type:* string

The path to the property.

---

##### `addPropertyOverride` <a name="addPropertyOverride" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.addPropertyOverride"></a>

```typescript
public addPropertyOverride(propertyPath: string, value: any): void
```

Adds an override to a resource property.

Syntactic sugar for `addOverride("Properties.<...>", value)`.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.addPropertyOverride.parameter.propertyPath"></a>

- *Type:* string

The path of the property.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.addPropertyOverride.parameter.value"></a>

- *Type:* any

The value.

---

##### `applyRemovalPolicy` <a name="applyRemovalPolicy" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.applyRemovalPolicy"></a>

```typescript
public applyRemovalPolicy(policy?: RemovalPolicy, options?: RemovalPolicyOptions): void
```

Sets the deletion policy of the resource based on the removal policy specified.

The Removal Policy controls what happens to this resource when it stops
being managed by CloudFormation, either because you've removed it from the
CDK application or because you've made a change that requires the resource
to be replaced.

The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
cases, a snapshot can be taken of the resource prior to deletion
(`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
can be found in the following link:

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options)

###### `policy`<sup>Optional</sup> <a name="policy" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.applyRemovalPolicy.parameter.policy"></a>

- *Type:* aws-cdk-lib.RemovalPolicy

---

###### `options`<sup>Optional</sup> <a name="options" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.applyRemovalPolicy.parameter.options"></a>

- *Type:* aws-cdk-lib.RemovalPolicyOptions

---

##### `getAtt` <a name="getAtt" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.getAtt"></a>

```typescript
public getAtt(attributeName: string, typeHint?: ResolutionTypeHint): Reference
```

Returns a token for an runtime attribute of this resource.

Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
in case there is no generated attribute.

###### `attributeName`<sup>Required</sup> <a name="attributeName" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.getAtt.parameter.attributeName"></a>

- *Type:* string

The name of the attribute.

---

###### `typeHint`<sup>Optional</sup> <a name="typeHint" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.getAtt.parameter.typeHint"></a>

- *Type:* aws-cdk-lib.ResolutionTypeHint

---

##### `getMetadata` <a name="getMetadata" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.getMetadata"></a>

```typescript
public getMetadata(key: string): any
```

Retrieve a value value from the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.getMetadata.parameter.key"></a>

- *Type:* string

---

##### `obtainDependencies` <a name="obtainDependencies" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.obtainDependencies"></a>

```typescript
public obtainDependencies(): Stack | CfnResource[]
```

Retrieves an array of resources this resource depends on.

This assembles dependencies on resources across stacks (including nested stacks)
automatically.

##### `obtainResourceDependencies` <a name="obtainResourceDependencies" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.obtainResourceDependencies"></a>

```typescript
public obtainResourceDependencies(): CfnResource[]
```

Get a shallow copy of dependencies between this resource and other resources in the same stack.

##### `removeDependency` <a name="removeDependency" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.removeDependency"></a>

```typescript
public removeDependency(target: CfnResource): void
```

Indicates that this resource no longer depends on another resource.

This can be used for resources across stacks (including nested stacks)
and the dependency will automatically be removed from the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.removeDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `replaceDependency` <a name="replaceDependency" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.replaceDependency"></a>

```typescript
public replaceDependency(target: CfnResource, newTarget: CfnResource): void
```

Replaces one dependency with another.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.replaceDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

The dependency to replace.

---

###### `newTarget`<sup>Required</sup> <a name="newTarget" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.replaceDependency.parameter.newTarget"></a>

- *Type:* aws-cdk-lib.CfnResource

The new dependency to add.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.isCfnElement">isCfnElement</a></code> | Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.isCfnResource">isCfnResource</a></code> | Check whether the given construct is a CfnResource. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.isConstruct"></a>

```typescript
import { CfnPrivateEndpointAws } from 'awscdk-resources-mongodbatlas'

CfnPrivateEndpointAws.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `isCfnElement` <a name="isCfnElement" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.isCfnElement"></a>

```typescript
import { CfnPrivateEndpointAws } from 'awscdk-resources-mongodbatlas'

CfnPrivateEndpointAws.isCfnElement(x: any)
```

Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).

Uses duck-typing instead of `instanceof` to allow stack elements from different
versions of this library to be included in the same stack.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.isCfnElement.parameter.x"></a>

- *Type:* any

---

##### `isCfnResource` <a name="isCfnResource" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.isCfnResource"></a>

```typescript
import { CfnPrivateEndpointAws } from 'awscdk-resources-mongodbatlas'

CfnPrivateEndpointAws.isCfnResource(construct: IConstruct)
```

Check whether the given construct is a CfnResource.

###### `construct`<sup>Required</sup> <a name="construct" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.isCfnResource.parameter.construct"></a>

- *Type:* constructs.IConstruct

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.property.creationStack">creationStack</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.property.logicalId">logicalId</a></code> | <code>string</code> | The logical ID for this CloudFormation stack element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.property.stack">stack</a></code> | <code>aws-cdk-lib.Stack</code> | The stack in which this element is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.property.ref">ref</a></code> | <code>string</code> | Return a string that will be resolved to a CloudFormation `{ Ref }` for this element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.property.cfnOptions">cfnOptions</a></code> | <code>aws-cdk-lib.ICfnResourceOptions</code> | Options for this resource, such as condition, update policy etc. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.property.cfnResourceType">cfnResourceType</a></code> | <code>string</code> | AWS resource type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.property.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAwsProps">CfnPrivateEndpointAwsProps</a></code> | Resource props. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `creationStack`<sup>Required</sup> <a name="creationStack" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.property.creationStack"></a>

```typescript
public readonly creationStack: string[];
```

- *Type:* string[]

---

##### `logicalId`<sup>Required</sup> <a name="logicalId" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.property.logicalId"></a>

```typescript
public readonly logicalId: string;
```

- *Type:* string

The logical ID for this CloudFormation stack element.

The logical ID of the element
is calculated from the path of the resource node in the construct tree.

To override this value, use `overrideLogicalId(newLogicalId)`.

---

##### `stack`<sup>Required</sup> <a name="stack" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.property.stack"></a>

```typescript
public readonly stack: Stack;
```

- *Type:* aws-cdk-lib.Stack

The stack in which this element is defined.

CfnElements must be defined within a stack scope (directly or indirectly).

---

##### `ref`<sup>Required</sup> <a name="ref" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.

If, by any chance, the intrinsic reference of a resource is not a string, you could
coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.

---

##### `cfnOptions`<sup>Required</sup> <a name="cfnOptions" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.property.cfnOptions"></a>

```typescript
public readonly cfnOptions: ICfnResourceOptions;
```

- *Type:* aws-cdk-lib.ICfnResourceOptions

Options for this resource, such as condition, update policy etc.

---

##### `cfnResourceType`<sup>Required</sup> <a name="cfnResourceType" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.property.cfnResourceType"></a>

```typescript
public readonly cfnResourceType: string;
```

- *Type:* string

AWS resource type.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.property.props"></a>

```typescript
public readonly props: CfnPrivateEndpointAwsProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAwsProps">CfnPrivateEndpointAwsProps</a>

Resource props.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.property.CFN_RESOURCE_TYPE_NAME">CFN_RESOURCE_TYPE_NAME</a></code> | <code>string</code> | The CloudFormation resource type name for this resource class. |

---

##### `CFN_RESOURCE_TYPE_NAME`<sup>Required</sup> <a name="CFN_RESOURCE_TYPE_NAME" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAws.property.CFN_RESOURCE_TYPE_NAME"></a>

```typescript
public readonly CFN_RESOURCE_TYPE_NAME: string;
```

- *Type:* string

The CloudFormation resource type name for this resource class.

---

### CfnPrivateEndPointRegionalMode <a name="CfnPrivateEndPointRegionalMode" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode"></a>

A CloudFormation `MongoDB::Atlas::PrivateEndPointRegionalMode`.

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.Initializer"></a>

```typescript
import { CfnPrivateEndPointRegionalMode } from 'awscdk-resources-mongodbatlas'

new CfnPrivateEndPointRegionalMode(scope: Construct, id: string, props: CfnPrivateEndPointRegionalModeProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - scope in which this resource is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.Initializer.parameter.id">id</a></code> | <code>string</code> | - scoped id of the resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalModeProps">CfnPrivateEndPointRegionalModeProps</a></code> | - resource properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

scope in which this resource is defined.

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.Initializer.parameter.id"></a>

- *Type:* string

scoped id of the resource.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalModeProps">CfnPrivateEndPointRegionalModeProps</a>

resource properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.overrideLogicalId">overrideLogicalId</a></code> | Overrides the auto-generated logical ID with a specific ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.addDeletionOverride">addDeletionOverride</a></code> | Syntactic sugar for `addOverride(path, undefined)`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.addDependency">addDependency</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.addDependsOn">addDependsOn</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.addMetadata">addMetadata</a></code> | Add a value to the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.addOverride">addOverride</a></code> | Adds an override to the synthesized CloudFormation resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.addPropertyDeletionOverride">addPropertyDeletionOverride</a></code> | Adds an override that deletes the value of a property from the resource definition. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.addPropertyOverride">addPropertyOverride</a></code> | Adds an override to a resource property. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.applyRemovalPolicy">applyRemovalPolicy</a></code> | Sets the deletion policy of the resource based on the removal policy specified. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.getAtt">getAtt</a></code> | Returns a token for an runtime attribute of this resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.getMetadata">getMetadata</a></code> | Retrieve a value value from the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.obtainDependencies">obtainDependencies</a></code> | Retrieves an array of resources this resource depends on. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.obtainResourceDependencies">obtainResourceDependencies</a></code> | Get a shallow copy of dependencies between this resource and other resources in the same stack. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.removeDependency">removeDependency</a></code> | Indicates that this resource no longer depends on another resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.replaceDependency">replaceDependency</a></code> | Replaces one dependency with another. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `overrideLogicalId` <a name="overrideLogicalId" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.overrideLogicalId"></a>

```typescript
public overrideLogicalId(newLogicalId: string): void
```

Overrides the auto-generated logical ID with a specific ID.

###### `newLogicalId`<sup>Required</sup> <a name="newLogicalId" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.overrideLogicalId.parameter.newLogicalId"></a>

- *Type:* string

The new logical ID to use for this stack element.

---

##### `addDeletionOverride` <a name="addDeletionOverride" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.addDeletionOverride"></a>

```typescript
public addDeletionOverride(path: string): void
```

Syntactic sugar for `addOverride(path, undefined)`.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.addDeletionOverride.parameter.path"></a>

- *Type:* string

The path of the value to delete.

---

##### `addDependency` <a name="addDependency" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.addDependency"></a>

```typescript
public addDependency(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

This can be used for resources across stacks (or nested stack) boundaries
and the dependency will automatically be transferred to the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.addDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### ~~`addDependsOn`~~ <a name="addDependsOn" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.addDependsOn"></a>

```typescript
public addDependsOn(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.addDependsOn.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `addMetadata` <a name="addMetadata" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.addMetadata"></a>

```typescript
public addMetadata(key: string, value: any): void
```

Add a value to the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.addMetadata.parameter.key"></a>

- *Type:* string

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.addMetadata.parameter.value"></a>

- *Type:* any

---

##### `addOverride` <a name="addOverride" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.addOverride"></a>

```typescript
public addOverride(path: string, value: any): void
```

Adds an override to the synthesized CloudFormation resource.

To add a
property override, either use `addPropertyOverride` or prefix `path` with
"Properties." (i.e. `Properties.TopicName`).

If the override is nested, separate each nested level using a dot (.) in the path parameter.
If there is an array as part of the nesting, specify the index in the path.

To include a literal `.` in the property name, prefix with a `\`. In most
programming languages you will need to write this as `"\\."` because the
`\` itself will need to be escaped.

For example,
```typescript
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
```
would add the overrides
```json
"Properties": {
  "GlobalSecondaryIndexes": [
    {
      "Projection": {
        "NonKeyAttributes": [ "myattribute" ]
        ...
      }
      ...
    },
    {
      "ProjectionType": "INCLUDE"
      ...
    },
  ]
  ...
}
```

The `value` argument to `addOverride` will not be processed or translated
in any way. Pass raw JSON values in here with the correct capitalization
for CloudFormation. If you pass CDK classes or structs, they will be
rendered with lowercased key names, and CloudFormation will reject the
template.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.addOverride.parameter.path"></a>

- *Type:* string

The path of the property, you can use dot notation to override values in complex types.

Any intermediate keys
will be created as needed.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.addOverride.parameter.value"></a>

- *Type:* any

The value.

Could be primitive or complex.

---

##### `addPropertyDeletionOverride` <a name="addPropertyDeletionOverride" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.addPropertyDeletionOverride"></a>

```typescript
public addPropertyDeletionOverride(propertyPath: string): void
```

Adds an override that deletes the value of a property from the resource definition.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.addPropertyDeletionOverride.parameter.propertyPath"></a>

- *Type:* string

The path to the property.

---

##### `addPropertyOverride` <a name="addPropertyOverride" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.addPropertyOverride"></a>

```typescript
public addPropertyOverride(propertyPath: string, value: any): void
```

Adds an override to a resource property.

Syntactic sugar for `addOverride("Properties.<...>", value)`.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.addPropertyOverride.parameter.propertyPath"></a>

- *Type:* string

The path of the property.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.addPropertyOverride.parameter.value"></a>

- *Type:* any

The value.

---

##### `applyRemovalPolicy` <a name="applyRemovalPolicy" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.applyRemovalPolicy"></a>

```typescript
public applyRemovalPolicy(policy?: RemovalPolicy, options?: RemovalPolicyOptions): void
```

Sets the deletion policy of the resource based on the removal policy specified.

The Removal Policy controls what happens to this resource when it stops
being managed by CloudFormation, either because you've removed it from the
CDK application or because you've made a change that requires the resource
to be replaced.

The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
cases, a snapshot can be taken of the resource prior to deletion
(`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
can be found in the following link:

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options)

###### `policy`<sup>Optional</sup> <a name="policy" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.applyRemovalPolicy.parameter.policy"></a>

- *Type:* aws-cdk-lib.RemovalPolicy

---

###### `options`<sup>Optional</sup> <a name="options" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.applyRemovalPolicy.parameter.options"></a>

- *Type:* aws-cdk-lib.RemovalPolicyOptions

---

##### `getAtt` <a name="getAtt" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.getAtt"></a>

```typescript
public getAtt(attributeName: string, typeHint?: ResolutionTypeHint): Reference
```

Returns a token for an runtime attribute of this resource.

Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
in case there is no generated attribute.

###### `attributeName`<sup>Required</sup> <a name="attributeName" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.getAtt.parameter.attributeName"></a>

- *Type:* string

The name of the attribute.

---

###### `typeHint`<sup>Optional</sup> <a name="typeHint" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.getAtt.parameter.typeHint"></a>

- *Type:* aws-cdk-lib.ResolutionTypeHint

---

##### `getMetadata` <a name="getMetadata" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.getMetadata"></a>

```typescript
public getMetadata(key: string): any
```

Retrieve a value value from the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.getMetadata.parameter.key"></a>

- *Type:* string

---

##### `obtainDependencies` <a name="obtainDependencies" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.obtainDependencies"></a>

```typescript
public obtainDependencies(): Stack | CfnResource[]
```

Retrieves an array of resources this resource depends on.

This assembles dependencies on resources across stacks (including nested stacks)
automatically.

##### `obtainResourceDependencies` <a name="obtainResourceDependencies" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.obtainResourceDependencies"></a>

```typescript
public obtainResourceDependencies(): CfnResource[]
```

Get a shallow copy of dependencies between this resource and other resources in the same stack.

##### `removeDependency` <a name="removeDependency" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.removeDependency"></a>

```typescript
public removeDependency(target: CfnResource): void
```

Indicates that this resource no longer depends on another resource.

This can be used for resources across stacks (including nested stacks)
and the dependency will automatically be removed from the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.removeDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `replaceDependency` <a name="replaceDependency" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.replaceDependency"></a>

```typescript
public replaceDependency(target: CfnResource, newTarget: CfnResource): void
```

Replaces one dependency with another.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.replaceDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

The dependency to replace.

---

###### `newTarget`<sup>Required</sup> <a name="newTarget" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.replaceDependency.parameter.newTarget"></a>

- *Type:* aws-cdk-lib.CfnResource

The new dependency to add.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.isCfnElement">isCfnElement</a></code> | Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.isCfnResource">isCfnResource</a></code> | Check whether the given construct is a CfnResource. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.isConstruct"></a>

```typescript
import { CfnPrivateEndPointRegionalMode } from 'awscdk-resources-mongodbatlas'

CfnPrivateEndPointRegionalMode.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `isCfnElement` <a name="isCfnElement" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.isCfnElement"></a>

```typescript
import { CfnPrivateEndPointRegionalMode } from 'awscdk-resources-mongodbatlas'

CfnPrivateEndPointRegionalMode.isCfnElement(x: any)
```

Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).

Uses duck-typing instead of `instanceof` to allow stack elements from different
versions of this library to be included in the same stack.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.isCfnElement.parameter.x"></a>

- *Type:* any

---

##### `isCfnResource` <a name="isCfnResource" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.isCfnResource"></a>

```typescript
import { CfnPrivateEndPointRegionalMode } from 'awscdk-resources-mongodbatlas'

CfnPrivateEndPointRegionalMode.isCfnResource(construct: IConstruct)
```

Check whether the given construct is a CfnResource.

###### `construct`<sup>Required</sup> <a name="construct" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.isCfnResource.parameter.construct"></a>

- *Type:* constructs.IConstruct

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.property.creationStack">creationStack</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.property.logicalId">logicalId</a></code> | <code>string</code> | The logical ID for this CloudFormation stack element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.property.stack">stack</a></code> | <code>aws-cdk-lib.Stack</code> | The stack in which this element is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.property.ref">ref</a></code> | <code>string</code> | Return a string that will be resolved to a CloudFormation `{ Ref }` for this element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.property.cfnOptions">cfnOptions</a></code> | <code>aws-cdk-lib.ICfnResourceOptions</code> | Options for this resource, such as condition, update policy etc. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.property.cfnResourceType">cfnResourceType</a></code> | <code>string</code> | AWS resource type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.property.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalModeProps">CfnPrivateEndPointRegionalModeProps</a></code> | Resource props. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `creationStack`<sup>Required</sup> <a name="creationStack" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.property.creationStack"></a>

```typescript
public readonly creationStack: string[];
```

- *Type:* string[]

---

##### `logicalId`<sup>Required</sup> <a name="logicalId" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.property.logicalId"></a>

```typescript
public readonly logicalId: string;
```

- *Type:* string

The logical ID for this CloudFormation stack element.

The logical ID of the element
is calculated from the path of the resource node in the construct tree.

To override this value, use `overrideLogicalId(newLogicalId)`.

---

##### `stack`<sup>Required</sup> <a name="stack" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.property.stack"></a>

```typescript
public readonly stack: Stack;
```

- *Type:* aws-cdk-lib.Stack

The stack in which this element is defined.

CfnElements must be defined within a stack scope (directly or indirectly).

---

##### `ref`<sup>Required</sup> <a name="ref" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.

If, by any chance, the intrinsic reference of a resource is not a string, you could
coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.

---

##### `cfnOptions`<sup>Required</sup> <a name="cfnOptions" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.property.cfnOptions"></a>

```typescript
public readonly cfnOptions: ICfnResourceOptions;
```

- *Type:* aws-cdk-lib.ICfnResourceOptions

Options for this resource, such as condition, update policy etc.

---

##### `cfnResourceType`<sup>Required</sup> <a name="cfnResourceType" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.property.cfnResourceType"></a>

```typescript
public readonly cfnResourceType: string;
```

- *Type:* string

AWS resource type.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.property.props"></a>

```typescript
public readonly props: CfnPrivateEndPointRegionalModeProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalModeProps">CfnPrivateEndPointRegionalModeProps</a>

Resource props.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.property.CFN_RESOURCE_TYPE_NAME">CFN_RESOURCE_TYPE_NAME</a></code> | <code>string</code> | The CloudFormation resource type name for this resource class. |

---

##### `CFN_RESOURCE_TYPE_NAME`<sup>Required</sup> <a name="CFN_RESOURCE_TYPE_NAME" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalMode.property.CFN_RESOURCE_TYPE_NAME"></a>

```typescript
public readonly CFN_RESOURCE_TYPE_NAME: string;
```

- *Type:* string

The CloudFormation resource type name for this resource class.

---

### CfnPrivateEndpointService <a name="CfnPrivateEndpointService" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService"></a>

A CloudFormation `MongoDB::Atlas::PrivateEndpointService`.

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.Initializer"></a>

```typescript
import { CfnPrivateEndpointService } from 'awscdk-resources-mongodbatlas'

new CfnPrivateEndpointService(scope: Construct, id: string, props: CfnPrivateEndpointServiceProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointService.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - scope in which this resource is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointService.Initializer.parameter.id">id</a></code> | <code>string</code> | - scoped id of the resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointService.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointServiceProps">CfnPrivateEndpointServiceProps</a></code> | - resource properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

scope in which this resource is defined.

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.Initializer.parameter.id"></a>

- *Type:* string

scoped id of the resource.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointServiceProps">CfnPrivateEndpointServiceProps</a>

resource properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointService.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointService.overrideLogicalId">overrideLogicalId</a></code> | Overrides the auto-generated logical ID with a specific ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointService.addDeletionOverride">addDeletionOverride</a></code> | Syntactic sugar for `addOverride(path, undefined)`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointService.addDependency">addDependency</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointService.addDependsOn">addDependsOn</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointService.addMetadata">addMetadata</a></code> | Add a value to the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointService.addOverride">addOverride</a></code> | Adds an override to the synthesized CloudFormation resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointService.addPropertyDeletionOverride">addPropertyDeletionOverride</a></code> | Adds an override that deletes the value of a property from the resource definition. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointService.addPropertyOverride">addPropertyOverride</a></code> | Adds an override to a resource property. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointService.applyRemovalPolicy">applyRemovalPolicy</a></code> | Sets the deletion policy of the resource based on the removal policy specified. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointService.getAtt">getAtt</a></code> | Returns a token for an runtime attribute of this resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointService.getMetadata">getMetadata</a></code> | Retrieve a value value from the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointService.obtainDependencies">obtainDependencies</a></code> | Retrieves an array of resources this resource depends on. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointService.obtainResourceDependencies">obtainResourceDependencies</a></code> | Get a shallow copy of dependencies between this resource and other resources in the same stack. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointService.removeDependency">removeDependency</a></code> | Indicates that this resource no longer depends on another resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointService.replaceDependency">replaceDependency</a></code> | Replaces one dependency with another. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `overrideLogicalId` <a name="overrideLogicalId" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.overrideLogicalId"></a>

```typescript
public overrideLogicalId(newLogicalId: string): void
```

Overrides the auto-generated logical ID with a specific ID.

###### `newLogicalId`<sup>Required</sup> <a name="newLogicalId" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.overrideLogicalId.parameter.newLogicalId"></a>

- *Type:* string

The new logical ID to use for this stack element.

---

##### `addDeletionOverride` <a name="addDeletionOverride" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.addDeletionOverride"></a>

```typescript
public addDeletionOverride(path: string): void
```

Syntactic sugar for `addOverride(path, undefined)`.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.addDeletionOverride.parameter.path"></a>

- *Type:* string

The path of the value to delete.

---

##### `addDependency` <a name="addDependency" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.addDependency"></a>

```typescript
public addDependency(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

This can be used for resources across stacks (or nested stack) boundaries
and the dependency will automatically be transferred to the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.addDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### ~~`addDependsOn`~~ <a name="addDependsOn" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.addDependsOn"></a>

```typescript
public addDependsOn(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.addDependsOn.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `addMetadata` <a name="addMetadata" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.addMetadata"></a>

```typescript
public addMetadata(key: string, value: any): void
```

Add a value to the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.addMetadata.parameter.key"></a>

- *Type:* string

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.addMetadata.parameter.value"></a>

- *Type:* any

---

##### `addOverride` <a name="addOverride" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.addOverride"></a>

```typescript
public addOverride(path: string, value: any): void
```

Adds an override to the synthesized CloudFormation resource.

To add a
property override, either use `addPropertyOverride` or prefix `path` with
"Properties." (i.e. `Properties.TopicName`).

If the override is nested, separate each nested level using a dot (.) in the path parameter.
If there is an array as part of the nesting, specify the index in the path.

To include a literal `.` in the property name, prefix with a `\`. In most
programming languages you will need to write this as `"\\."` because the
`\` itself will need to be escaped.

For example,
```typescript
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
```
would add the overrides
```json
"Properties": {
  "GlobalSecondaryIndexes": [
    {
      "Projection": {
        "NonKeyAttributes": [ "myattribute" ]
        ...
      }
      ...
    },
    {
      "ProjectionType": "INCLUDE"
      ...
    },
  ]
  ...
}
```

The `value` argument to `addOverride` will not be processed or translated
in any way. Pass raw JSON values in here with the correct capitalization
for CloudFormation. If you pass CDK classes or structs, they will be
rendered with lowercased key names, and CloudFormation will reject the
template.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.addOverride.parameter.path"></a>

- *Type:* string

The path of the property, you can use dot notation to override values in complex types.

Any intermediate keys
will be created as needed.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.addOverride.parameter.value"></a>

- *Type:* any

The value.

Could be primitive or complex.

---

##### `addPropertyDeletionOverride` <a name="addPropertyDeletionOverride" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.addPropertyDeletionOverride"></a>

```typescript
public addPropertyDeletionOverride(propertyPath: string): void
```

Adds an override that deletes the value of a property from the resource definition.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.addPropertyDeletionOverride.parameter.propertyPath"></a>

- *Type:* string

The path to the property.

---

##### `addPropertyOverride` <a name="addPropertyOverride" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.addPropertyOverride"></a>

```typescript
public addPropertyOverride(propertyPath: string, value: any): void
```

Adds an override to a resource property.

Syntactic sugar for `addOverride("Properties.<...>", value)`.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.addPropertyOverride.parameter.propertyPath"></a>

- *Type:* string

The path of the property.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.addPropertyOverride.parameter.value"></a>

- *Type:* any

The value.

---

##### `applyRemovalPolicy` <a name="applyRemovalPolicy" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.applyRemovalPolicy"></a>

```typescript
public applyRemovalPolicy(policy?: RemovalPolicy, options?: RemovalPolicyOptions): void
```

Sets the deletion policy of the resource based on the removal policy specified.

The Removal Policy controls what happens to this resource when it stops
being managed by CloudFormation, either because you've removed it from the
CDK application or because you've made a change that requires the resource
to be replaced.

The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
cases, a snapshot can be taken of the resource prior to deletion
(`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
can be found in the following link:

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options)

###### `policy`<sup>Optional</sup> <a name="policy" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.applyRemovalPolicy.parameter.policy"></a>

- *Type:* aws-cdk-lib.RemovalPolicy

---

###### `options`<sup>Optional</sup> <a name="options" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.applyRemovalPolicy.parameter.options"></a>

- *Type:* aws-cdk-lib.RemovalPolicyOptions

---

##### `getAtt` <a name="getAtt" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.getAtt"></a>

```typescript
public getAtt(attributeName: string, typeHint?: ResolutionTypeHint): Reference
```

Returns a token for an runtime attribute of this resource.

Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
in case there is no generated attribute.

###### `attributeName`<sup>Required</sup> <a name="attributeName" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.getAtt.parameter.attributeName"></a>

- *Type:* string

The name of the attribute.

---

###### `typeHint`<sup>Optional</sup> <a name="typeHint" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.getAtt.parameter.typeHint"></a>

- *Type:* aws-cdk-lib.ResolutionTypeHint

---

##### `getMetadata` <a name="getMetadata" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.getMetadata"></a>

```typescript
public getMetadata(key: string): any
```

Retrieve a value value from the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.getMetadata.parameter.key"></a>

- *Type:* string

---

##### `obtainDependencies` <a name="obtainDependencies" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.obtainDependencies"></a>

```typescript
public obtainDependencies(): Stack | CfnResource[]
```

Retrieves an array of resources this resource depends on.

This assembles dependencies on resources across stacks (including nested stacks)
automatically.

##### `obtainResourceDependencies` <a name="obtainResourceDependencies" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.obtainResourceDependencies"></a>

```typescript
public obtainResourceDependencies(): CfnResource[]
```

Get a shallow copy of dependencies between this resource and other resources in the same stack.

##### `removeDependency` <a name="removeDependency" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.removeDependency"></a>

```typescript
public removeDependency(target: CfnResource): void
```

Indicates that this resource no longer depends on another resource.

This can be used for resources across stacks (including nested stacks)
and the dependency will automatically be removed from the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.removeDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `replaceDependency` <a name="replaceDependency" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.replaceDependency"></a>

```typescript
public replaceDependency(target: CfnResource, newTarget: CfnResource): void
```

Replaces one dependency with another.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.replaceDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

The dependency to replace.

---

###### `newTarget`<sup>Required</sup> <a name="newTarget" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.replaceDependency.parameter.newTarget"></a>

- *Type:* aws-cdk-lib.CfnResource

The new dependency to add.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointService.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointService.isCfnElement">isCfnElement</a></code> | Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointService.isCfnResource">isCfnResource</a></code> | Check whether the given construct is a CfnResource. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.isConstruct"></a>

```typescript
import { CfnPrivateEndpointService } from 'awscdk-resources-mongodbatlas'

CfnPrivateEndpointService.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `isCfnElement` <a name="isCfnElement" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.isCfnElement"></a>

```typescript
import { CfnPrivateEndpointService } from 'awscdk-resources-mongodbatlas'

CfnPrivateEndpointService.isCfnElement(x: any)
```

Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).

Uses duck-typing instead of `instanceof` to allow stack elements from different
versions of this library to be included in the same stack.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.isCfnElement.parameter.x"></a>

- *Type:* any

---

##### `isCfnResource` <a name="isCfnResource" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.isCfnResource"></a>

```typescript
import { CfnPrivateEndpointService } from 'awscdk-resources-mongodbatlas'

CfnPrivateEndpointService.isCfnResource(construct: IConstruct)
```

Check whether the given construct is a CfnResource.

###### `construct`<sup>Required</sup> <a name="construct" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.isCfnResource.parameter.construct"></a>

- *Type:* constructs.IConstruct

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointService.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointService.property.creationStack">creationStack</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointService.property.logicalId">logicalId</a></code> | <code>string</code> | The logical ID for this CloudFormation stack element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointService.property.stack">stack</a></code> | <code>aws-cdk-lib.Stack</code> | The stack in which this element is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointService.property.ref">ref</a></code> | <code>string</code> | Return a string that will be resolved to a CloudFormation `{ Ref }` for this element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointService.property.cfnOptions">cfnOptions</a></code> | <code>aws-cdk-lib.ICfnResourceOptions</code> | Options for this resource, such as condition, update policy etc. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointService.property.cfnResourceType">cfnResourceType</a></code> | <code>string</code> | AWS resource type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointService.property.attrEndpointServiceName">attrEndpointServiceName</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::PrivateEndpointService.EndpointServiceName`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointService.property.attrErrorMessage">attrErrorMessage</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::PrivateEndpointService.ErrorMessage`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointService.property.attrId">attrId</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::PrivateEndpointService.Id`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointService.property.attrInterfaceEndpoints">attrInterfaceEndpoints</a></code> | <code>string[]</code> | Attribute `MongoDB::Atlas::PrivateEndpointService.InterfaceEndpoints`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointService.property.attrStatus">attrStatus</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::PrivateEndpointService.Status`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointService.property.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointServiceProps">CfnPrivateEndpointServiceProps</a></code> | Resource props. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `creationStack`<sup>Required</sup> <a name="creationStack" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.property.creationStack"></a>

```typescript
public readonly creationStack: string[];
```

- *Type:* string[]

---

##### `logicalId`<sup>Required</sup> <a name="logicalId" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.property.logicalId"></a>

```typescript
public readonly logicalId: string;
```

- *Type:* string

The logical ID for this CloudFormation stack element.

The logical ID of the element
is calculated from the path of the resource node in the construct tree.

To override this value, use `overrideLogicalId(newLogicalId)`.

---

##### `stack`<sup>Required</sup> <a name="stack" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.property.stack"></a>

```typescript
public readonly stack: Stack;
```

- *Type:* aws-cdk-lib.Stack

The stack in which this element is defined.

CfnElements must be defined within a stack scope (directly or indirectly).

---

##### `ref`<sup>Required</sup> <a name="ref" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.

If, by any chance, the intrinsic reference of a resource is not a string, you could
coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.

---

##### `cfnOptions`<sup>Required</sup> <a name="cfnOptions" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.property.cfnOptions"></a>

```typescript
public readonly cfnOptions: ICfnResourceOptions;
```

- *Type:* aws-cdk-lib.ICfnResourceOptions

Options for this resource, such as condition, update policy etc.

---

##### `cfnResourceType`<sup>Required</sup> <a name="cfnResourceType" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.property.cfnResourceType"></a>

```typescript
public readonly cfnResourceType: string;
```

- *Type:* string

AWS resource type.

---

##### `attrEndpointServiceName`<sup>Required</sup> <a name="attrEndpointServiceName" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.property.attrEndpointServiceName"></a>

```typescript
public readonly attrEndpointServiceName: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::PrivateEndpointService.EndpointServiceName`.

---

##### `attrErrorMessage`<sup>Required</sup> <a name="attrErrorMessage" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.property.attrErrorMessage"></a>

```typescript
public readonly attrErrorMessage: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::PrivateEndpointService.ErrorMessage`.

---

##### `attrId`<sup>Required</sup> <a name="attrId" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.property.attrId"></a>

```typescript
public readonly attrId: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::PrivateEndpointService.Id`.

---

##### `attrInterfaceEndpoints`<sup>Required</sup> <a name="attrInterfaceEndpoints" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.property.attrInterfaceEndpoints"></a>

```typescript
public readonly attrInterfaceEndpoints: string[];
```

- *Type:* string[]

Attribute `MongoDB::Atlas::PrivateEndpointService.InterfaceEndpoints`.

---

##### `attrStatus`<sup>Required</sup> <a name="attrStatus" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.property.attrStatus"></a>

```typescript
public readonly attrStatus: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::PrivateEndpointService.Status`.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.property.props"></a>

```typescript
public readonly props: CfnPrivateEndpointServiceProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointServiceProps">CfnPrivateEndpointServiceProps</a>

Resource props.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointService.property.CFN_RESOURCE_TYPE_NAME">CFN_RESOURCE_TYPE_NAME</a></code> | <code>string</code> | The CloudFormation resource type name for this resource class. |

---

##### `CFN_RESOURCE_TYPE_NAME`<sup>Required</sup> <a name="CFN_RESOURCE_TYPE_NAME" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointService.property.CFN_RESOURCE_TYPE_NAME"></a>

```typescript
public readonly CFN_RESOURCE_TYPE_NAME: string;
```

- *Type:* string

The CloudFormation resource type name for this resource class.

---

### CfnPrivatelinkEndpointServiceDataFederationOnlineArchive <a name="CfnPrivatelinkEndpointServiceDataFederationOnlineArchive" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive"></a>

A CloudFormation `MongoDB::Atlas::PrivatelinkEndpointServiceDataFederationOnlineArchive`.

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.Initializer"></a>

```typescript
import { CfnPrivatelinkEndpointServiceDataFederationOnlineArchive } from 'awscdk-resources-mongodbatlas'

new CfnPrivatelinkEndpointServiceDataFederationOnlineArchive(scope: Construct, id: string, props: CfnPrivatelinkEndpointServiceDataFederationOnlineArchiveProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - scope in which this resource is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.Initializer.parameter.id">id</a></code> | <code>string</code> | - scoped id of the resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchiveProps">CfnPrivatelinkEndpointServiceDataFederationOnlineArchiveProps</a></code> | - resource properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

scope in which this resource is defined.

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.Initializer.parameter.id"></a>

- *Type:* string

scoped id of the resource.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchiveProps">CfnPrivatelinkEndpointServiceDataFederationOnlineArchiveProps</a>

resource properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.overrideLogicalId">overrideLogicalId</a></code> | Overrides the auto-generated logical ID with a specific ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.addDeletionOverride">addDeletionOverride</a></code> | Syntactic sugar for `addOverride(path, undefined)`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.addDependency">addDependency</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.addDependsOn">addDependsOn</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.addMetadata">addMetadata</a></code> | Add a value to the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.addOverride">addOverride</a></code> | Adds an override to the synthesized CloudFormation resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.addPropertyDeletionOverride">addPropertyDeletionOverride</a></code> | Adds an override that deletes the value of a property from the resource definition. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.addPropertyOverride">addPropertyOverride</a></code> | Adds an override to a resource property. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.applyRemovalPolicy">applyRemovalPolicy</a></code> | Sets the deletion policy of the resource based on the removal policy specified. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.getAtt">getAtt</a></code> | Returns a token for an runtime attribute of this resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.getMetadata">getMetadata</a></code> | Retrieve a value value from the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.obtainDependencies">obtainDependencies</a></code> | Retrieves an array of resources this resource depends on. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.obtainResourceDependencies">obtainResourceDependencies</a></code> | Get a shallow copy of dependencies between this resource and other resources in the same stack. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.removeDependency">removeDependency</a></code> | Indicates that this resource no longer depends on another resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.replaceDependency">replaceDependency</a></code> | Replaces one dependency with another. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `overrideLogicalId` <a name="overrideLogicalId" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.overrideLogicalId"></a>

```typescript
public overrideLogicalId(newLogicalId: string): void
```

Overrides the auto-generated logical ID with a specific ID.

###### `newLogicalId`<sup>Required</sup> <a name="newLogicalId" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.overrideLogicalId.parameter.newLogicalId"></a>

- *Type:* string

The new logical ID to use for this stack element.

---

##### `addDeletionOverride` <a name="addDeletionOverride" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.addDeletionOverride"></a>

```typescript
public addDeletionOverride(path: string): void
```

Syntactic sugar for `addOverride(path, undefined)`.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.addDeletionOverride.parameter.path"></a>

- *Type:* string

The path of the value to delete.

---

##### `addDependency` <a name="addDependency" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.addDependency"></a>

```typescript
public addDependency(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

This can be used for resources across stacks (or nested stack) boundaries
and the dependency will automatically be transferred to the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.addDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### ~~`addDependsOn`~~ <a name="addDependsOn" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.addDependsOn"></a>

```typescript
public addDependsOn(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.addDependsOn.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `addMetadata` <a name="addMetadata" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.addMetadata"></a>

```typescript
public addMetadata(key: string, value: any): void
```

Add a value to the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.addMetadata.parameter.key"></a>

- *Type:* string

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.addMetadata.parameter.value"></a>

- *Type:* any

---

##### `addOverride` <a name="addOverride" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.addOverride"></a>

```typescript
public addOverride(path: string, value: any): void
```

Adds an override to the synthesized CloudFormation resource.

To add a
property override, either use `addPropertyOverride` or prefix `path` with
"Properties." (i.e. `Properties.TopicName`).

If the override is nested, separate each nested level using a dot (.) in the path parameter.
If there is an array as part of the nesting, specify the index in the path.

To include a literal `.` in the property name, prefix with a `\`. In most
programming languages you will need to write this as `"\\."` because the
`\` itself will need to be escaped.

For example,
```typescript
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
```
would add the overrides
```json
"Properties": {
  "GlobalSecondaryIndexes": [
    {
      "Projection": {
        "NonKeyAttributes": [ "myattribute" ]
        ...
      }
      ...
    },
    {
      "ProjectionType": "INCLUDE"
      ...
    },
  ]
  ...
}
```

The `value` argument to `addOverride` will not be processed or translated
in any way. Pass raw JSON values in here with the correct capitalization
for CloudFormation. If you pass CDK classes or structs, they will be
rendered with lowercased key names, and CloudFormation will reject the
template.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.addOverride.parameter.path"></a>

- *Type:* string

The path of the property, you can use dot notation to override values in complex types.

Any intermediate keys
will be created as needed.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.addOverride.parameter.value"></a>

- *Type:* any

The value.

Could be primitive or complex.

---

##### `addPropertyDeletionOverride` <a name="addPropertyDeletionOverride" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.addPropertyDeletionOverride"></a>

```typescript
public addPropertyDeletionOverride(propertyPath: string): void
```

Adds an override that deletes the value of a property from the resource definition.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.addPropertyDeletionOverride.parameter.propertyPath"></a>

- *Type:* string

The path to the property.

---

##### `addPropertyOverride` <a name="addPropertyOverride" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.addPropertyOverride"></a>

```typescript
public addPropertyOverride(propertyPath: string, value: any): void
```

Adds an override to a resource property.

Syntactic sugar for `addOverride("Properties.<...>", value)`.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.addPropertyOverride.parameter.propertyPath"></a>

- *Type:* string

The path of the property.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.addPropertyOverride.parameter.value"></a>

- *Type:* any

The value.

---

##### `applyRemovalPolicy` <a name="applyRemovalPolicy" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.applyRemovalPolicy"></a>

```typescript
public applyRemovalPolicy(policy?: RemovalPolicy, options?: RemovalPolicyOptions): void
```

Sets the deletion policy of the resource based on the removal policy specified.

The Removal Policy controls what happens to this resource when it stops
being managed by CloudFormation, either because you've removed it from the
CDK application or because you've made a change that requires the resource
to be replaced.

The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
cases, a snapshot can be taken of the resource prior to deletion
(`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
can be found in the following link:

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options)

###### `policy`<sup>Optional</sup> <a name="policy" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.applyRemovalPolicy.parameter.policy"></a>

- *Type:* aws-cdk-lib.RemovalPolicy

---

###### `options`<sup>Optional</sup> <a name="options" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.applyRemovalPolicy.parameter.options"></a>

- *Type:* aws-cdk-lib.RemovalPolicyOptions

---

##### `getAtt` <a name="getAtt" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.getAtt"></a>

```typescript
public getAtt(attributeName: string, typeHint?: ResolutionTypeHint): Reference
```

Returns a token for an runtime attribute of this resource.

Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
in case there is no generated attribute.

###### `attributeName`<sup>Required</sup> <a name="attributeName" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.getAtt.parameter.attributeName"></a>

- *Type:* string

The name of the attribute.

---

###### `typeHint`<sup>Optional</sup> <a name="typeHint" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.getAtt.parameter.typeHint"></a>

- *Type:* aws-cdk-lib.ResolutionTypeHint

---

##### `getMetadata` <a name="getMetadata" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.getMetadata"></a>

```typescript
public getMetadata(key: string): any
```

Retrieve a value value from the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.getMetadata.parameter.key"></a>

- *Type:* string

---

##### `obtainDependencies` <a name="obtainDependencies" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.obtainDependencies"></a>

```typescript
public obtainDependencies(): Stack | CfnResource[]
```

Retrieves an array of resources this resource depends on.

This assembles dependencies on resources across stacks (including nested stacks)
automatically.

##### `obtainResourceDependencies` <a name="obtainResourceDependencies" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.obtainResourceDependencies"></a>

```typescript
public obtainResourceDependencies(): CfnResource[]
```

Get a shallow copy of dependencies between this resource and other resources in the same stack.

##### `removeDependency` <a name="removeDependency" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.removeDependency"></a>

```typescript
public removeDependency(target: CfnResource): void
```

Indicates that this resource no longer depends on another resource.

This can be used for resources across stacks (including nested stacks)
and the dependency will automatically be removed from the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.removeDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `replaceDependency` <a name="replaceDependency" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.replaceDependency"></a>

```typescript
public replaceDependency(target: CfnResource, newTarget: CfnResource): void
```

Replaces one dependency with another.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.replaceDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

The dependency to replace.

---

###### `newTarget`<sup>Required</sup> <a name="newTarget" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.replaceDependency.parameter.newTarget"></a>

- *Type:* aws-cdk-lib.CfnResource

The new dependency to add.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.isCfnElement">isCfnElement</a></code> | Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.isCfnResource">isCfnResource</a></code> | Check whether the given construct is a CfnResource. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.isConstruct"></a>

```typescript
import { CfnPrivatelinkEndpointServiceDataFederationOnlineArchive } from 'awscdk-resources-mongodbatlas'

CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `isCfnElement` <a name="isCfnElement" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.isCfnElement"></a>

```typescript
import { CfnPrivatelinkEndpointServiceDataFederationOnlineArchive } from 'awscdk-resources-mongodbatlas'

CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.isCfnElement(x: any)
```

Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).

Uses duck-typing instead of `instanceof` to allow stack elements from different
versions of this library to be included in the same stack.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.isCfnElement.parameter.x"></a>

- *Type:* any

---

##### `isCfnResource` <a name="isCfnResource" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.isCfnResource"></a>

```typescript
import { CfnPrivatelinkEndpointServiceDataFederationOnlineArchive } from 'awscdk-resources-mongodbatlas'

CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.isCfnResource(construct: IConstruct)
```

Check whether the given construct is a CfnResource.

###### `construct`<sup>Required</sup> <a name="construct" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.isCfnResource.parameter.construct"></a>

- *Type:* constructs.IConstruct

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.property.creationStack">creationStack</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.property.logicalId">logicalId</a></code> | <code>string</code> | The logical ID for this CloudFormation stack element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.property.stack">stack</a></code> | <code>aws-cdk-lib.Stack</code> | The stack in which this element is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.property.ref">ref</a></code> | <code>string</code> | Return a string that will be resolved to a CloudFormation `{ Ref }` for this element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.property.cfnOptions">cfnOptions</a></code> | <code>aws-cdk-lib.ICfnResourceOptions</code> | Options for this resource, such as condition, update policy etc. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.property.cfnResourceType">cfnResourceType</a></code> | <code>string</code> | AWS resource type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.property.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchiveProps">CfnPrivatelinkEndpointServiceDataFederationOnlineArchiveProps</a></code> | Resource props. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `creationStack`<sup>Required</sup> <a name="creationStack" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.property.creationStack"></a>

```typescript
public readonly creationStack: string[];
```

- *Type:* string[]

---

##### `logicalId`<sup>Required</sup> <a name="logicalId" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.property.logicalId"></a>

```typescript
public readonly logicalId: string;
```

- *Type:* string

The logical ID for this CloudFormation stack element.

The logical ID of the element
is calculated from the path of the resource node in the construct tree.

To override this value, use `overrideLogicalId(newLogicalId)`.

---

##### `stack`<sup>Required</sup> <a name="stack" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.property.stack"></a>

```typescript
public readonly stack: Stack;
```

- *Type:* aws-cdk-lib.Stack

The stack in which this element is defined.

CfnElements must be defined within a stack scope (directly or indirectly).

---

##### `ref`<sup>Required</sup> <a name="ref" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.

If, by any chance, the intrinsic reference of a resource is not a string, you could
coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.

---

##### `cfnOptions`<sup>Required</sup> <a name="cfnOptions" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.property.cfnOptions"></a>

```typescript
public readonly cfnOptions: ICfnResourceOptions;
```

- *Type:* aws-cdk-lib.ICfnResourceOptions

Options for this resource, such as condition, update policy etc.

---

##### `cfnResourceType`<sup>Required</sup> <a name="cfnResourceType" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.property.cfnResourceType"></a>

```typescript
public readonly cfnResourceType: string;
```

- *Type:* string

AWS resource type.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.property.props"></a>

```typescript
public readonly props: CfnPrivatelinkEndpointServiceDataFederationOnlineArchiveProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchiveProps">CfnPrivatelinkEndpointServiceDataFederationOnlineArchiveProps</a>

Resource props.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.property.CFN_RESOURCE_TYPE_NAME">CFN_RESOURCE_TYPE_NAME</a></code> | <code>string</code> | The CloudFormation resource type name for this resource class. |

---

##### `CFN_RESOURCE_TYPE_NAME`<sup>Required</sup> <a name="CFN_RESOURCE_TYPE_NAME" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchive.property.CFN_RESOURCE_TYPE_NAME"></a>

```typescript
public readonly CFN_RESOURCE_TYPE_NAME: string;
```

- *Type:* string

The CloudFormation resource type name for this resource class.

---

### CfnProject <a name="CfnProject" id="awscdk-resources-mongodbatlas.CfnProject"></a>

A CloudFormation `MongoDB::Atlas::Project`.

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.CfnProject.Initializer"></a>

```typescript
import { CfnProject } from 'awscdk-resources-mongodbatlas'

new CfnProject(scope: Construct, id: string, props: CfnProjectProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProject.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - scope in which this resource is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProject.Initializer.parameter.id">id</a></code> | <code>string</code> | - scoped id of the resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProject.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnProjectProps">CfnProjectProps</a></code> | - resource properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.CfnProject.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

scope in which this resource is defined.

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnProject.Initializer.parameter.id"></a>

- *Type:* string

scoped id of the resource.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnProject.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnProjectProps">CfnProjectProps</a>

resource properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProject.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProject.overrideLogicalId">overrideLogicalId</a></code> | Overrides the auto-generated logical ID with a specific ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProject.addDeletionOverride">addDeletionOverride</a></code> | Syntactic sugar for `addOverride(path, undefined)`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProject.addDependency">addDependency</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProject.addDependsOn">addDependsOn</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProject.addMetadata">addMetadata</a></code> | Add a value to the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProject.addOverride">addOverride</a></code> | Adds an override to the synthesized CloudFormation resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProject.addPropertyDeletionOverride">addPropertyDeletionOverride</a></code> | Adds an override that deletes the value of a property from the resource definition. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProject.addPropertyOverride">addPropertyOverride</a></code> | Adds an override to a resource property. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProject.applyRemovalPolicy">applyRemovalPolicy</a></code> | Sets the deletion policy of the resource based on the removal policy specified. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProject.getAtt">getAtt</a></code> | Returns a token for an runtime attribute of this resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProject.getMetadata">getMetadata</a></code> | Retrieve a value value from the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProject.obtainDependencies">obtainDependencies</a></code> | Retrieves an array of resources this resource depends on. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProject.obtainResourceDependencies">obtainResourceDependencies</a></code> | Get a shallow copy of dependencies between this resource and other resources in the same stack. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProject.removeDependency">removeDependency</a></code> | Indicates that this resource no longer depends on another resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProject.replaceDependency">replaceDependency</a></code> | Replaces one dependency with another. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.CfnProject.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `overrideLogicalId` <a name="overrideLogicalId" id="awscdk-resources-mongodbatlas.CfnProject.overrideLogicalId"></a>

```typescript
public overrideLogicalId(newLogicalId: string): void
```

Overrides the auto-generated logical ID with a specific ID.

###### `newLogicalId`<sup>Required</sup> <a name="newLogicalId" id="awscdk-resources-mongodbatlas.CfnProject.overrideLogicalId.parameter.newLogicalId"></a>

- *Type:* string

The new logical ID to use for this stack element.

---

##### `addDeletionOverride` <a name="addDeletionOverride" id="awscdk-resources-mongodbatlas.CfnProject.addDeletionOverride"></a>

```typescript
public addDeletionOverride(path: string): void
```

Syntactic sugar for `addOverride(path, undefined)`.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnProject.addDeletionOverride.parameter.path"></a>

- *Type:* string

The path of the value to delete.

---

##### `addDependency` <a name="addDependency" id="awscdk-resources-mongodbatlas.CfnProject.addDependency"></a>

```typescript
public addDependency(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

This can be used for resources across stacks (or nested stack) boundaries
and the dependency will automatically be transferred to the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnProject.addDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### ~~`addDependsOn`~~ <a name="addDependsOn" id="awscdk-resources-mongodbatlas.CfnProject.addDependsOn"></a>

```typescript
public addDependsOn(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnProject.addDependsOn.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `addMetadata` <a name="addMetadata" id="awscdk-resources-mongodbatlas.CfnProject.addMetadata"></a>

```typescript
public addMetadata(key: string, value: any): void
```

Add a value to the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnProject.addMetadata.parameter.key"></a>

- *Type:* string

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnProject.addMetadata.parameter.value"></a>

- *Type:* any

---

##### `addOverride` <a name="addOverride" id="awscdk-resources-mongodbatlas.CfnProject.addOverride"></a>

```typescript
public addOverride(path: string, value: any): void
```

Adds an override to the synthesized CloudFormation resource.

To add a
property override, either use `addPropertyOverride` or prefix `path` with
"Properties." (i.e. `Properties.TopicName`).

If the override is nested, separate each nested level using a dot (.) in the path parameter.
If there is an array as part of the nesting, specify the index in the path.

To include a literal `.` in the property name, prefix with a `\`. In most
programming languages you will need to write this as `"\\."` because the
`\` itself will need to be escaped.

For example,
```typescript
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
```
would add the overrides
```json
"Properties": {
  "GlobalSecondaryIndexes": [
    {
      "Projection": {
        "NonKeyAttributes": [ "myattribute" ]
        ...
      }
      ...
    },
    {
      "ProjectionType": "INCLUDE"
      ...
    },
  ]
  ...
}
```

The `value` argument to `addOverride` will not be processed or translated
in any way. Pass raw JSON values in here with the correct capitalization
for CloudFormation. If you pass CDK classes or structs, they will be
rendered with lowercased key names, and CloudFormation will reject the
template.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnProject.addOverride.parameter.path"></a>

- *Type:* string

The path of the property, you can use dot notation to override values in complex types.

Any intermediate keys
will be created as needed.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnProject.addOverride.parameter.value"></a>

- *Type:* any

The value.

Could be primitive or complex.

---

##### `addPropertyDeletionOverride` <a name="addPropertyDeletionOverride" id="awscdk-resources-mongodbatlas.CfnProject.addPropertyDeletionOverride"></a>

```typescript
public addPropertyDeletionOverride(propertyPath: string): void
```

Adds an override that deletes the value of a property from the resource definition.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnProject.addPropertyDeletionOverride.parameter.propertyPath"></a>

- *Type:* string

The path to the property.

---

##### `addPropertyOverride` <a name="addPropertyOverride" id="awscdk-resources-mongodbatlas.CfnProject.addPropertyOverride"></a>

```typescript
public addPropertyOverride(propertyPath: string, value: any): void
```

Adds an override to a resource property.

Syntactic sugar for `addOverride("Properties.<...>", value)`.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnProject.addPropertyOverride.parameter.propertyPath"></a>

- *Type:* string

The path of the property.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnProject.addPropertyOverride.parameter.value"></a>

- *Type:* any

The value.

---

##### `applyRemovalPolicy` <a name="applyRemovalPolicy" id="awscdk-resources-mongodbatlas.CfnProject.applyRemovalPolicy"></a>

```typescript
public applyRemovalPolicy(policy?: RemovalPolicy, options?: RemovalPolicyOptions): void
```

Sets the deletion policy of the resource based on the removal policy specified.

The Removal Policy controls what happens to this resource when it stops
being managed by CloudFormation, either because you've removed it from the
CDK application or because you've made a change that requires the resource
to be replaced.

The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
cases, a snapshot can be taken of the resource prior to deletion
(`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
can be found in the following link:

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options)

###### `policy`<sup>Optional</sup> <a name="policy" id="awscdk-resources-mongodbatlas.CfnProject.applyRemovalPolicy.parameter.policy"></a>

- *Type:* aws-cdk-lib.RemovalPolicy

---

###### `options`<sup>Optional</sup> <a name="options" id="awscdk-resources-mongodbatlas.CfnProject.applyRemovalPolicy.parameter.options"></a>

- *Type:* aws-cdk-lib.RemovalPolicyOptions

---

##### `getAtt` <a name="getAtt" id="awscdk-resources-mongodbatlas.CfnProject.getAtt"></a>

```typescript
public getAtt(attributeName: string, typeHint?: ResolutionTypeHint): Reference
```

Returns a token for an runtime attribute of this resource.

Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
in case there is no generated attribute.

###### `attributeName`<sup>Required</sup> <a name="attributeName" id="awscdk-resources-mongodbatlas.CfnProject.getAtt.parameter.attributeName"></a>

- *Type:* string

The name of the attribute.

---

###### `typeHint`<sup>Optional</sup> <a name="typeHint" id="awscdk-resources-mongodbatlas.CfnProject.getAtt.parameter.typeHint"></a>

- *Type:* aws-cdk-lib.ResolutionTypeHint

---

##### `getMetadata` <a name="getMetadata" id="awscdk-resources-mongodbatlas.CfnProject.getMetadata"></a>

```typescript
public getMetadata(key: string): any
```

Retrieve a value value from the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnProject.getMetadata.parameter.key"></a>

- *Type:* string

---

##### `obtainDependencies` <a name="obtainDependencies" id="awscdk-resources-mongodbatlas.CfnProject.obtainDependencies"></a>

```typescript
public obtainDependencies(): Stack | CfnResource[]
```

Retrieves an array of resources this resource depends on.

This assembles dependencies on resources across stacks (including nested stacks)
automatically.

##### `obtainResourceDependencies` <a name="obtainResourceDependencies" id="awscdk-resources-mongodbatlas.CfnProject.obtainResourceDependencies"></a>

```typescript
public obtainResourceDependencies(): CfnResource[]
```

Get a shallow copy of dependencies between this resource and other resources in the same stack.

##### `removeDependency` <a name="removeDependency" id="awscdk-resources-mongodbatlas.CfnProject.removeDependency"></a>

```typescript
public removeDependency(target: CfnResource): void
```

Indicates that this resource no longer depends on another resource.

This can be used for resources across stacks (including nested stacks)
and the dependency will automatically be removed from the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnProject.removeDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `replaceDependency` <a name="replaceDependency" id="awscdk-resources-mongodbatlas.CfnProject.replaceDependency"></a>

```typescript
public replaceDependency(target: CfnResource, newTarget: CfnResource): void
```

Replaces one dependency with another.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnProject.replaceDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

The dependency to replace.

---

###### `newTarget`<sup>Required</sup> <a name="newTarget" id="awscdk-resources-mongodbatlas.CfnProject.replaceDependency.parameter.newTarget"></a>

- *Type:* aws-cdk-lib.CfnResource

The new dependency to add.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProject.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProject.isCfnElement">isCfnElement</a></code> | Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProject.isCfnResource">isCfnResource</a></code> | Check whether the given construct is a CfnResource. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.CfnProject.isConstruct"></a>

```typescript
import { CfnProject } from 'awscdk-resources-mongodbatlas'

CfnProject.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnProject.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `isCfnElement` <a name="isCfnElement" id="awscdk-resources-mongodbatlas.CfnProject.isCfnElement"></a>

```typescript
import { CfnProject } from 'awscdk-resources-mongodbatlas'

CfnProject.isCfnElement(x: any)
```

Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).

Uses duck-typing instead of `instanceof` to allow stack elements from different
versions of this library to be included in the same stack.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnProject.isCfnElement.parameter.x"></a>

- *Type:* any

---

##### `isCfnResource` <a name="isCfnResource" id="awscdk-resources-mongodbatlas.CfnProject.isCfnResource"></a>

```typescript
import { CfnProject } from 'awscdk-resources-mongodbatlas'

CfnProject.isCfnResource(construct: IConstruct)
```

Check whether the given construct is a CfnResource.

###### `construct`<sup>Required</sup> <a name="construct" id="awscdk-resources-mongodbatlas.CfnProject.isCfnResource.parameter.construct"></a>

- *Type:* constructs.IConstruct

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProject.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProject.property.creationStack">creationStack</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProject.property.logicalId">logicalId</a></code> | <code>string</code> | The logical ID for this CloudFormation stack element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProject.property.stack">stack</a></code> | <code>aws-cdk-lib.Stack</code> | The stack in which this element is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProject.property.ref">ref</a></code> | <code>string</code> | Return a string that will be resolved to a CloudFormation `{ Ref }` for this element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProject.property.cfnOptions">cfnOptions</a></code> | <code>aws-cdk-lib.ICfnResourceOptions</code> | Options for this resource, such as condition, update policy etc. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProject.property.cfnResourceType">cfnResourceType</a></code> | <code>string</code> | AWS resource type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProject.property.attrClusterCount">attrClusterCount</a></code> | <code>number</code> | Attribute `MongoDB::Atlas::Project.ClusterCount`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProject.property.attrCreated">attrCreated</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::Project.Created`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProject.property.attrId">attrId</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::Project.Id`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProject.property.attrProjectOwnerId">attrProjectOwnerId</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::Project.ProjectOwnerId`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProject.property.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnProjectProps">CfnProjectProps</a></code> | Resource props. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.CfnProject.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `creationStack`<sup>Required</sup> <a name="creationStack" id="awscdk-resources-mongodbatlas.CfnProject.property.creationStack"></a>

```typescript
public readonly creationStack: string[];
```

- *Type:* string[]

---

##### `logicalId`<sup>Required</sup> <a name="logicalId" id="awscdk-resources-mongodbatlas.CfnProject.property.logicalId"></a>

```typescript
public readonly logicalId: string;
```

- *Type:* string

The logical ID for this CloudFormation stack element.

The logical ID of the element
is calculated from the path of the resource node in the construct tree.

To override this value, use `overrideLogicalId(newLogicalId)`.

---

##### `stack`<sup>Required</sup> <a name="stack" id="awscdk-resources-mongodbatlas.CfnProject.property.stack"></a>

```typescript
public readonly stack: Stack;
```

- *Type:* aws-cdk-lib.Stack

The stack in which this element is defined.

CfnElements must be defined within a stack scope (directly or indirectly).

---

##### `ref`<sup>Required</sup> <a name="ref" id="awscdk-resources-mongodbatlas.CfnProject.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.

If, by any chance, the intrinsic reference of a resource is not a string, you could
coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.

---

##### `cfnOptions`<sup>Required</sup> <a name="cfnOptions" id="awscdk-resources-mongodbatlas.CfnProject.property.cfnOptions"></a>

```typescript
public readonly cfnOptions: ICfnResourceOptions;
```

- *Type:* aws-cdk-lib.ICfnResourceOptions

Options for this resource, such as condition, update policy etc.

---

##### `cfnResourceType`<sup>Required</sup> <a name="cfnResourceType" id="awscdk-resources-mongodbatlas.CfnProject.property.cfnResourceType"></a>

```typescript
public readonly cfnResourceType: string;
```

- *Type:* string

AWS resource type.

---

##### `attrClusterCount`<sup>Required</sup> <a name="attrClusterCount" id="awscdk-resources-mongodbatlas.CfnProject.property.attrClusterCount"></a>

```typescript
public readonly attrClusterCount: number;
```

- *Type:* number

Attribute `MongoDB::Atlas::Project.ClusterCount`.

---

##### `attrCreated`<sup>Required</sup> <a name="attrCreated" id="awscdk-resources-mongodbatlas.CfnProject.property.attrCreated"></a>

```typescript
public readonly attrCreated: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::Project.Created`.

---

##### `attrId`<sup>Required</sup> <a name="attrId" id="awscdk-resources-mongodbatlas.CfnProject.property.attrId"></a>

```typescript
public readonly attrId: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::Project.Id`.

---

##### `attrProjectOwnerId`<sup>Required</sup> <a name="attrProjectOwnerId" id="awscdk-resources-mongodbatlas.CfnProject.property.attrProjectOwnerId"></a>

```typescript
public readonly attrProjectOwnerId: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::Project.ProjectOwnerId`.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnProject.property.props"></a>

```typescript
public readonly props: CfnProjectProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnProjectProps">CfnProjectProps</a>

Resource props.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProject.property.CFN_RESOURCE_TYPE_NAME">CFN_RESOURCE_TYPE_NAME</a></code> | <code>string</code> | The CloudFormation resource type name for this resource class. |

---

##### `CFN_RESOURCE_TYPE_NAME`<sup>Required</sup> <a name="CFN_RESOURCE_TYPE_NAME" id="awscdk-resources-mongodbatlas.CfnProject.property.CFN_RESOURCE_TYPE_NAME"></a>

```typescript
public readonly CFN_RESOURCE_TYPE_NAME: string;
```

- *Type:* string

The CloudFormation resource type name for this resource class.

---

### CfnProjectInvitation <a name="CfnProjectInvitation" id="awscdk-resources-mongodbatlas.CfnProjectInvitation"></a>

A CloudFormation `MongoDB::Atlas::ProjectInvitation`.

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.Initializer"></a>

```typescript
import { CfnProjectInvitation } from 'awscdk-resources-mongodbatlas'

new CfnProjectInvitation(scope: Construct, id: string, props: CfnProjectInvitationProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitation.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - scope in which this resource is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitation.Initializer.parameter.id">id</a></code> | <code>string</code> | - scoped id of the resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitation.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitationProps">CfnProjectInvitationProps</a></code> | - resource properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

scope in which this resource is defined.

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.Initializer.parameter.id"></a>

- *Type:* string

scoped id of the resource.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnProjectInvitationProps">CfnProjectInvitationProps</a>

resource properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitation.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitation.overrideLogicalId">overrideLogicalId</a></code> | Overrides the auto-generated logical ID with a specific ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitation.addDeletionOverride">addDeletionOverride</a></code> | Syntactic sugar for `addOverride(path, undefined)`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitation.addDependency">addDependency</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitation.addDependsOn">addDependsOn</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitation.addMetadata">addMetadata</a></code> | Add a value to the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitation.addOverride">addOverride</a></code> | Adds an override to the synthesized CloudFormation resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitation.addPropertyDeletionOverride">addPropertyDeletionOverride</a></code> | Adds an override that deletes the value of a property from the resource definition. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitation.addPropertyOverride">addPropertyOverride</a></code> | Adds an override to a resource property. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitation.applyRemovalPolicy">applyRemovalPolicy</a></code> | Sets the deletion policy of the resource based on the removal policy specified. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitation.getAtt">getAtt</a></code> | Returns a token for an runtime attribute of this resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitation.getMetadata">getMetadata</a></code> | Retrieve a value value from the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitation.obtainDependencies">obtainDependencies</a></code> | Retrieves an array of resources this resource depends on. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitation.obtainResourceDependencies">obtainResourceDependencies</a></code> | Get a shallow copy of dependencies between this resource and other resources in the same stack. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitation.removeDependency">removeDependency</a></code> | Indicates that this resource no longer depends on another resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitation.replaceDependency">replaceDependency</a></code> | Replaces one dependency with another. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `overrideLogicalId` <a name="overrideLogicalId" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.overrideLogicalId"></a>

```typescript
public overrideLogicalId(newLogicalId: string): void
```

Overrides the auto-generated logical ID with a specific ID.

###### `newLogicalId`<sup>Required</sup> <a name="newLogicalId" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.overrideLogicalId.parameter.newLogicalId"></a>

- *Type:* string

The new logical ID to use for this stack element.

---

##### `addDeletionOverride` <a name="addDeletionOverride" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.addDeletionOverride"></a>

```typescript
public addDeletionOverride(path: string): void
```

Syntactic sugar for `addOverride(path, undefined)`.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.addDeletionOverride.parameter.path"></a>

- *Type:* string

The path of the value to delete.

---

##### `addDependency` <a name="addDependency" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.addDependency"></a>

```typescript
public addDependency(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

This can be used for resources across stacks (or nested stack) boundaries
and the dependency will automatically be transferred to the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.addDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### ~~`addDependsOn`~~ <a name="addDependsOn" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.addDependsOn"></a>

```typescript
public addDependsOn(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.addDependsOn.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `addMetadata` <a name="addMetadata" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.addMetadata"></a>

```typescript
public addMetadata(key: string, value: any): void
```

Add a value to the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.addMetadata.parameter.key"></a>

- *Type:* string

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.addMetadata.parameter.value"></a>

- *Type:* any

---

##### `addOverride` <a name="addOverride" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.addOverride"></a>

```typescript
public addOverride(path: string, value: any): void
```

Adds an override to the synthesized CloudFormation resource.

To add a
property override, either use `addPropertyOverride` or prefix `path` with
"Properties." (i.e. `Properties.TopicName`).

If the override is nested, separate each nested level using a dot (.) in the path parameter.
If there is an array as part of the nesting, specify the index in the path.

To include a literal `.` in the property name, prefix with a `\`. In most
programming languages you will need to write this as `"\\."` because the
`\` itself will need to be escaped.

For example,
```typescript
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
```
would add the overrides
```json
"Properties": {
  "GlobalSecondaryIndexes": [
    {
      "Projection": {
        "NonKeyAttributes": [ "myattribute" ]
        ...
      }
      ...
    },
    {
      "ProjectionType": "INCLUDE"
      ...
    },
  ]
  ...
}
```

The `value` argument to `addOverride` will not be processed or translated
in any way. Pass raw JSON values in here with the correct capitalization
for CloudFormation. If you pass CDK classes or structs, they will be
rendered with lowercased key names, and CloudFormation will reject the
template.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.addOverride.parameter.path"></a>

- *Type:* string

The path of the property, you can use dot notation to override values in complex types.

Any intermediate keys
will be created as needed.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.addOverride.parameter.value"></a>

- *Type:* any

The value.

Could be primitive or complex.

---

##### `addPropertyDeletionOverride` <a name="addPropertyDeletionOverride" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.addPropertyDeletionOverride"></a>

```typescript
public addPropertyDeletionOverride(propertyPath: string): void
```

Adds an override that deletes the value of a property from the resource definition.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.addPropertyDeletionOverride.parameter.propertyPath"></a>

- *Type:* string

The path to the property.

---

##### `addPropertyOverride` <a name="addPropertyOverride" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.addPropertyOverride"></a>

```typescript
public addPropertyOverride(propertyPath: string, value: any): void
```

Adds an override to a resource property.

Syntactic sugar for `addOverride("Properties.<...>", value)`.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.addPropertyOverride.parameter.propertyPath"></a>

- *Type:* string

The path of the property.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.addPropertyOverride.parameter.value"></a>

- *Type:* any

The value.

---

##### `applyRemovalPolicy` <a name="applyRemovalPolicy" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.applyRemovalPolicy"></a>

```typescript
public applyRemovalPolicy(policy?: RemovalPolicy, options?: RemovalPolicyOptions): void
```

Sets the deletion policy of the resource based on the removal policy specified.

The Removal Policy controls what happens to this resource when it stops
being managed by CloudFormation, either because you've removed it from the
CDK application or because you've made a change that requires the resource
to be replaced.

The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
cases, a snapshot can be taken of the resource prior to deletion
(`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
can be found in the following link:

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options)

###### `policy`<sup>Optional</sup> <a name="policy" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.applyRemovalPolicy.parameter.policy"></a>

- *Type:* aws-cdk-lib.RemovalPolicy

---

###### `options`<sup>Optional</sup> <a name="options" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.applyRemovalPolicy.parameter.options"></a>

- *Type:* aws-cdk-lib.RemovalPolicyOptions

---

##### `getAtt` <a name="getAtt" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.getAtt"></a>

```typescript
public getAtt(attributeName: string, typeHint?: ResolutionTypeHint): Reference
```

Returns a token for an runtime attribute of this resource.

Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
in case there is no generated attribute.

###### `attributeName`<sup>Required</sup> <a name="attributeName" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.getAtt.parameter.attributeName"></a>

- *Type:* string

The name of the attribute.

---

###### `typeHint`<sup>Optional</sup> <a name="typeHint" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.getAtt.parameter.typeHint"></a>

- *Type:* aws-cdk-lib.ResolutionTypeHint

---

##### `getMetadata` <a name="getMetadata" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.getMetadata"></a>

```typescript
public getMetadata(key: string): any
```

Retrieve a value value from the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.getMetadata.parameter.key"></a>

- *Type:* string

---

##### `obtainDependencies` <a name="obtainDependencies" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.obtainDependencies"></a>

```typescript
public obtainDependencies(): Stack | CfnResource[]
```

Retrieves an array of resources this resource depends on.

This assembles dependencies on resources across stacks (including nested stacks)
automatically.

##### `obtainResourceDependencies` <a name="obtainResourceDependencies" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.obtainResourceDependencies"></a>

```typescript
public obtainResourceDependencies(): CfnResource[]
```

Get a shallow copy of dependencies between this resource and other resources in the same stack.

##### `removeDependency` <a name="removeDependency" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.removeDependency"></a>

```typescript
public removeDependency(target: CfnResource): void
```

Indicates that this resource no longer depends on another resource.

This can be used for resources across stacks (including nested stacks)
and the dependency will automatically be removed from the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.removeDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `replaceDependency` <a name="replaceDependency" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.replaceDependency"></a>

```typescript
public replaceDependency(target: CfnResource, newTarget: CfnResource): void
```

Replaces one dependency with another.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.replaceDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

The dependency to replace.

---

###### `newTarget`<sup>Required</sup> <a name="newTarget" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.replaceDependency.parameter.newTarget"></a>

- *Type:* aws-cdk-lib.CfnResource

The new dependency to add.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitation.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitation.isCfnElement">isCfnElement</a></code> | Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitation.isCfnResource">isCfnResource</a></code> | Check whether the given construct is a CfnResource. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.isConstruct"></a>

```typescript
import { CfnProjectInvitation } from 'awscdk-resources-mongodbatlas'

CfnProjectInvitation.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `isCfnElement` <a name="isCfnElement" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.isCfnElement"></a>

```typescript
import { CfnProjectInvitation } from 'awscdk-resources-mongodbatlas'

CfnProjectInvitation.isCfnElement(x: any)
```

Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).

Uses duck-typing instead of `instanceof` to allow stack elements from different
versions of this library to be included in the same stack.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.isCfnElement.parameter.x"></a>

- *Type:* any

---

##### `isCfnResource` <a name="isCfnResource" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.isCfnResource"></a>

```typescript
import { CfnProjectInvitation } from 'awscdk-resources-mongodbatlas'

CfnProjectInvitation.isCfnResource(construct: IConstruct)
```

Check whether the given construct is a CfnResource.

###### `construct`<sup>Required</sup> <a name="construct" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.isCfnResource.parameter.construct"></a>

- *Type:* constructs.IConstruct

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitation.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitation.property.creationStack">creationStack</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitation.property.logicalId">logicalId</a></code> | <code>string</code> | The logical ID for this CloudFormation stack element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitation.property.stack">stack</a></code> | <code>aws-cdk-lib.Stack</code> | The stack in which this element is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitation.property.ref">ref</a></code> | <code>string</code> | Return a string that will be resolved to a CloudFormation `{ Ref }` for this element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitation.property.cfnOptions">cfnOptions</a></code> | <code>aws-cdk-lib.ICfnResourceOptions</code> | Options for this resource, such as condition, update policy etc. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitation.property.cfnResourceType">cfnResourceType</a></code> | <code>string</code> | AWS resource type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitation.property.attrCreatedAt">attrCreatedAt</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::ProjectInvitation.CreatedAt`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitation.property.attrExpiresAt">attrExpiresAt</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::ProjectInvitation.ExpiresAt`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitation.property.attrId">attrId</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::ProjectInvitation.Id`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitation.property.attrInviterUsername">attrInviterUsername</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::ProjectInvitation.InviterUsername`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitation.property.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitationProps">CfnProjectInvitationProps</a></code> | Resource props. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `creationStack`<sup>Required</sup> <a name="creationStack" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.property.creationStack"></a>

```typescript
public readonly creationStack: string[];
```

- *Type:* string[]

---

##### `logicalId`<sup>Required</sup> <a name="logicalId" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.property.logicalId"></a>

```typescript
public readonly logicalId: string;
```

- *Type:* string

The logical ID for this CloudFormation stack element.

The logical ID of the element
is calculated from the path of the resource node in the construct tree.

To override this value, use `overrideLogicalId(newLogicalId)`.

---

##### `stack`<sup>Required</sup> <a name="stack" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.property.stack"></a>

```typescript
public readonly stack: Stack;
```

- *Type:* aws-cdk-lib.Stack

The stack in which this element is defined.

CfnElements must be defined within a stack scope (directly or indirectly).

---

##### `ref`<sup>Required</sup> <a name="ref" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.

If, by any chance, the intrinsic reference of a resource is not a string, you could
coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.

---

##### `cfnOptions`<sup>Required</sup> <a name="cfnOptions" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.property.cfnOptions"></a>

```typescript
public readonly cfnOptions: ICfnResourceOptions;
```

- *Type:* aws-cdk-lib.ICfnResourceOptions

Options for this resource, such as condition, update policy etc.

---

##### `cfnResourceType`<sup>Required</sup> <a name="cfnResourceType" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.property.cfnResourceType"></a>

```typescript
public readonly cfnResourceType: string;
```

- *Type:* string

AWS resource type.

---

##### `attrCreatedAt`<sup>Required</sup> <a name="attrCreatedAt" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.property.attrCreatedAt"></a>

```typescript
public readonly attrCreatedAt: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::ProjectInvitation.CreatedAt`.

---

##### `attrExpiresAt`<sup>Required</sup> <a name="attrExpiresAt" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.property.attrExpiresAt"></a>

```typescript
public readonly attrExpiresAt: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::ProjectInvitation.ExpiresAt`.

---

##### `attrId`<sup>Required</sup> <a name="attrId" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.property.attrId"></a>

```typescript
public readonly attrId: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::ProjectInvitation.Id`.

---

##### `attrInviterUsername`<sup>Required</sup> <a name="attrInviterUsername" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.property.attrInviterUsername"></a>

```typescript
public readonly attrInviterUsername: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::ProjectInvitation.InviterUsername`.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.property.props"></a>

```typescript
public readonly props: CfnProjectInvitationProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnProjectInvitationProps">CfnProjectInvitationProps</a>

Resource props.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitation.property.CFN_RESOURCE_TYPE_NAME">CFN_RESOURCE_TYPE_NAME</a></code> | <code>string</code> | The CloudFormation resource type name for this resource class. |

---

##### `CFN_RESOURCE_TYPE_NAME`<sup>Required</sup> <a name="CFN_RESOURCE_TYPE_NAME" id="awscdk-resources-mongodbatlas.CfnProjectInvitation.property.CFN_RESOURCE_TYPE_NAME"></a>

```typescript
public readonly CFN_RESOURCE_TYPE_NAME: string;
```

- *Type:* string

The CloudFormation resource type name for this resource class.

---

### CfnProjectIpAccessList <a name="CfnProjectIpAccessList" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList"></a>

A CloudFormation `MongoDB::Atlas::ProjectIpAccessList`.

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.Initializer"></a>

```typescript
import { CfnProjectIpAccessList } from 'awscdk-resources-mongodbatlas'

new CfnProjectIpAccessList(scope: Construct, id: string, props: CfnProjectIpAccessListProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectIpAccessList.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - scope in which this resource is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectIpAccessList.Initializer.parameter.id">id</a></code> | <code>string</code> | - scoped id of the resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectIpAccessList.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnProjectIpAccessListProps">CfnProjectIpAccessListProps</a></code> | - resource properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

scope in which this resource is defined.

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.Initializer.parameter.id"></a>

- *Type:* string

scoped id of the resource.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnProjectIpAccessListProps">CfnProjectIpAccessListProps</a>

resource properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectIpAccessList.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectIpAccessList.overrideLogicalId">overrideLogicalId</a></code> | Overrides the auto-generated logical ID with a specific ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectIpAccessList.addDeletionOverride">addDeletionOverride</a></code> | Syntactic sugar for `addOverride(path, undefined)`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectIpAccessList.addDependency">addDependency</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectIpAccessList.addDependsOn">addDependsOn</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectIpAccessList.addMetadata">addMetadata</a></code> | Add a value to the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectIpAccessList.addOverride">addOverride</a></code> | Adds an override to the synthesized CloudFormation resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectIpAccessList.addPropertyDeletionOverride">addPropertyDeletionOverride</a></code> | Adds an override that deletes the value of a property from the resource definition. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectIpAccessList.addPropertyOverride">addPropertyOverride</a></code> | Adds an override to a resource property. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectIpAccessList.applyRemovalPolicy">applyRemovalPolicy</a></code> | Sets the deletion policy of the resource based on the removal policy specified. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectIpAccessList.getAtt">getAtt</a></code> | Returns a token for an runtime attribute of this resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectIpAccessList.getMetadata">getMetadata</a></code> | Retrieve a value value from the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectIpAccessList.obtainDependencies">obtainDependencies</a></code> | Retrieves an array of resources this resource depends on. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectIpAccessList.obtainResourceDependencies">obtainResourceDependencies</a></code> | Get a shallow copy of dependencies between this resource and other resources in the same stack. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectIpAccessList.removeDependency">removeDependency</a></code> | Indicates that this resource no longer depends on another resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectIpAccessList.replaceDependency">replaceDependency</a></code> | Replaces one dependency with another. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `overrideLogicalId` <a name="overrideLogicalId" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.overrideLogicalId"></a>

```typescript
public overrideLogicalId(newLogicalId: string): void
```

Overrides the auto-generated logical ID with a specific ID.

###### `newLogicalId`<sup>Required</sup> <a name="newLogicalId" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.overrideLogicalId.parameter.newLogicalId"></a>

- *Type:* string

The new logical ID to use for this stack element.

---

##### `addDeletionOverride` <a name="addDeletionOverride" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.addDeletionOverride"></a>

```typescript
public addDeletionOverride(path: string): void
```

Syntactic sugar for `addOverride(path, undefined)`.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.addDeletionOverride.parameter.path"></a>

- *Type:* string

The path of the value to delete.

---

##### `addDependency` <a name="addDependency" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.addDependency"></a>

```typescript
public addDependency(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

This can be used for resources across stacks (or nested stack) boundaries
and the dependency will automatically be transferred to the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.addDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### ~~`addDependsOn`~~ <a name="addDependsOn" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.addDependsOn"></a>

```typescript
public addDependsOn(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.addDependsOn.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `addMetadata` <a name="addMetadata" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.addMetadata"></a>

```typescript
public addMetadata(key: string, value: any): void
```

Add a value to the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.addMetadata.parameter.key"></a>

- *Type:* string

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.addMetadata.parameter.value"></a>

- *Type:* any

---

##### `addOverride` <a name="addOverride" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.addOverride"></a>

```typescript
public addOverride(path: string, value: any): void
```

Adds an override to the synthesized CloudFormation resource.

To add a
property override, either use `addPropertyOverride` or prefix `path` with
"Properties." (i.e. `Properties.TopicName`).

If the override is nested, separate each nested level using a dot (.) in the path parameter.
If there is an array as part of the nesting, specify the index in the path.

To include a literal `.` in the property name, prefix with a `\`. In most
programming languages you will need to write this as `"\\."` because the
`\` itself will need to be escaped.

For example,
```typescript
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
```
would add the overrides
```json
"Properties": {
  "GlobalSecondaryIndexes": [
    {
      "Projection": {
        "NonKeyAttributes": [ "myattribute" ]
        ...
      }
      ...
    },
    {
      "ProjectionType": "INCLUDE"
      ...
    },
  ]
  ...
}
```

The `value` argument to `addOverride` will not be processed or translated
in any way. Pass raw JSON values in here with the correct capitalization
for CloudFormation. If you pass CDK classes or structs, they will be
rendered with lowercased key names, and CloudFormation will reject the
template.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.addOverride.parameter.path"></a>

- *Type:* string

The path of the property, you can use dot notation to override values in complex types.

Any intermediate keys
will be created as needed.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.addOverride.parameter.value"></a>

- *Type:* any

The value.

Could be primitive or complex.

---

##### `addPropertyDeletionOverride` <a name="addPropertyDeletionOverride" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.addPropertyDeletionOverride"></a>

```typescript
public addPropertyDeletionOverride(propertyPath: string): void
```

Adds an override that deletes the value of a property from the resource definition.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.addPropertyDeletionOverride.parameter.propertyPath"></a>

- *Type:* string

The path to the property.

---

##### `addPropertyOverride` <a name="addPropertyOverride" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.addPropertyOverride"></a>

```typescript
public addPropertyOverride(propertyPath: string, value: any): void
```

Adds an override to a resource property.

Syntactic sugar for `addOverride("Properties.<...>", value)`.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.addPropertyOverride.parameter.propertyPath"></a>

- *Type:* string

The path of the property.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.addPropertyOverride.parameter.value"></a>

- *Type:* any

The value.

---

##### `applyRemovalPolicy` <a name="applyRemovalPolicy" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.applyRemovalPolicy"></a>

```typescript
public applyRemovalPolicy(policy?: RemovalPolicy, options?: RemovalPolicyOptions): void
```

Sets the deletion policy of the resource based on the removal policy specified.

The Removal Policy controls what happens to this resource when it stops
being managed by CloudFormation, either because you've removed it from the
CDK application or because you've made a change that requires the resource
to be replaced.

The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
cases, a snapshot can be taken of the resource prior to deletion
(`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
can be found in the following link:

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options)

###### `policy`<sup>Optional</sup> <a name="policy" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.applyRemovalPolicy.parameter.policy"></a>

- *Type:* aws-cdk-lib.RemovalPolicy

---

###### `options`<sup>Optional</sup> <a name="options" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.applyRemovalPolicy.parameter.options"></a>

- *Type:* aws-cdk-lib.RemovalPolicyOptions

---

##### `getAtt` <a name="getAtt" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.getAtt"></a>

```typescript
public getAtt(attributeName: string, typeHint?: ResolutionTypeHint): Reference
```

Returns a token for an runtime attribute of this resource.

Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
in case there is no generated attribute.

###### `attributeName`<sup>Required</sup> <a name="attributeName" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.getAtt.parameter.attributeName"></a>

- *Type:* string

The name of the attribute.

---

###### `typeHint`<sup>Optional</sup> <a name="typeHint" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.getAtt.parameter.typeHint"></a>

- *Type:* aws-cdk-lib.ResolutionTypeHint

---

##### `getMetadata` <a name="getMetadata" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.getMetadata"></a>

```typescript
public getMetadata(key: string): any
```

Retrieve a value value from the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.getMetadata.parameter.key"></a>

- *Type:* string

---

##### `obtainDependencies` <a name="obtainDependencies" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.obtainDependencies"></a>

```typescript
public obtainDependencies(): Stack | CfnResource[]
```

Retrieves an array of resources this resource depends on.

This assembles dependencies on resources across stacks (including nested stacks)
automatically.

##### `obtainResourceDependencies` <a name="obtainResourceDependencies" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.obtainResourceDependencies"></a>

```typescript
public obtainResourceDependencies(): CfnResource[]
```

Get a shallow copy of dependencies between this resource and other resources in the same stack.

##### `removeDependency` <a name="removeDependency" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.removeDependency"></a>

```typescript
public removeDependency(target: CfnResource): void
```

Indicates that this resource no longer depends on another resource.

This can be used for resources across stacks (including nested stacks)
and the dependency will automatically be removed from the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.removeDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `replaceDependency` <a name="replaceDependency" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.replaceDependency"></a>

```typescript
public replaceDependency(target: CfnResource, newTarget: CfnResource): void
```

Replaces one dependency with another.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.replaceDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

The dependency to replace.

---

###### `newTarget`<sup>Required</sup> <a name="newTarget" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.replaceDependency.parameter.newTarget"></a>

- *Type:* aws-cdk-lib.CfnResource

The new dependency to add.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectIpAccessList.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectIpAccessList.isCfnElement">isCfnElement</a></code> | Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectIpAccessList.isCfnResource">isCfnResource</a></code> | Check whether the given construct is a CfnResource. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.isConstruct"></a>

```typescript
import { CfnProjectIpAccessList } from 'awscdk-resources-mongodbatlas'

CfnProjectIpAccessList.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `isCfnElement` <a name="isCfnElement" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.isCfnElement"></a>

```typescript
import { CfnProjectIpAccessList } from 'awscdk-resources-mongodbatlas'

CfnProjectIpAccessList.isCfnElement(x: any)
```

Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).

Uses duck-typing instead of `instanceof` to allow stack elements from different
versions of this library to be included in the same stack.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.isCfnElement.parameter.x"></a>

- *Type:* any

---

##### `isCfnResource` <a name="isCfnResource" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.isCfnResource"></a>

```typescript
import { CfnProjectIpAccessList } from 'awscdk-resources-mongodbatlas'

CfnProjectIpAccessList.isCfnResource(construct: IConstruct)
```

Check whether the given construct is a CfnResource.

###### `construct`<sup>Required</sup> <a name="construct" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.isCfnResource.parameter.construct"></a>

- *Type:* constructs.IConstruct

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectIpAccessList.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectIpAccessList.property.creationStack">creationStack</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectIpAccessList.property.logicalId">logicalId</a></code> | <code>string</code> | The logical ID for this CloudFormation stack element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectIpAccessList.property.stack">stack</a></code> | <code>aws-cdk-lib.Stack</code> | The stack in which this element is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectIpAccessList.property.ref">ref</a></code> | <code>string</code> | Return a string that will be resolved to a CloudFormation `{ Ref }` for this element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectIpAccessList.property.cfnOptions">cfnOptions</a></code> | <code>aws-cdk-lib.ICfnResourceOptions</code> | Options for this resource, such as condition, update policy etc. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectIpAccessList.property.cfnResourceType">cfnResourceType</a></code> | <code>string</code> | AWS resource type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectIpAccessList.property.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnProjectIpAccessListProps">CfnProjectIpAccessListProps</a></code> | Resource props. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `creationStack`<sup>Required</sup> <a name="creationStack" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.property.creationStack"></a>

```typescript
public readonly creationStack: string[];
```

- *Type:* string[]

---

##### `logicalId`<sup>Required</sup> <a name="logicalId" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.property.logicalId"></a>

```typescript
public readonly logicalId: string;
```

- *Type:* string

The logical ID for this CloudFormation stack element.

The logical ID of the element
is calculated from the path of the resource node in the construct tree.

To override this value, use `overrideLogicalId(newLogicalId)`.

---

##### `stack`<sup>Required</sup> <a name="stack" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.property.stack"></a>

```typescript
public readonly stack: Stack;
```

- *Type:* aws-cdk-lib.Stack

The stack in which this element is defined.

CfnElements must be defined within a stack scope (directly or indirectly).

---

##### `ref`<sup>Required</sup> <a name="ref" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.

If, by any chance, the intrinsic reference of a resource is not a string, you could
coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.

---

##### `cfnOptions`<sup>Required</sup> <a name="cfnOptions" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.property.cfnOptions"></a>

```typescript
public readonly cfnOptions: ICfnResourceOptions;
```

- *Type:* aws-cdk-lib.ICfnResourceOptions

Options for this resource, such as condition, update policy etc.

---

##### `cfnResourceType`<sup>Required</sup> <a name="cfnResourceType" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.property.cfnResourceType"></a>

```typescript
public readonly cfnResourceType: string;
```

- *Type:* string

AWS resource type.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.property.props"></a>

```typescript
public readonly props: CfnProjectIpAccessListProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnProjectIpAccessListProps">CfnProjectIpAccessListProps</a>

Resource props.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectIpAccessList.property.CFN_RESOURCE_TYPE_NAME">CFN_RESOURCE_TYPE_NAME</a></code> | <code>string</code> | The CloudFormation resource type name for this resource class. |

---

##### `CFN_RESOURCE_TYPE_NAME`<sup>Required</sup> <a name="CFN_RESOURCE_TYPE_NAME" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessList.property.CFN_RESOURCE_TYPE_NAME"></a>

```typescript
public readonly CFN_RESOURCE_TYPE_NAME: string;
```

- *Type:* string

The CloudFormation resource type name for this resource class.

---

### CfnSearchDeployment <a name="CfnSearchDeployment" id="awscdk-resources-mongodbatlas.CfnSearchDeployment"></a>

A CloudFormation `MongoDB::Atlas::SearchDeployment`.

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.Initializer"></a>

```typescript
import { CfnSearchDeployment } from 'awscdk-resources-mongodbatlas'

new CfnSearchDeployment(scope: Construct, id: string, props: CfnSearchDeploymentProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchDeployment.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - scope in which this resource is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchDeployment.Initializer.parameter.id">id</a></code> | <code>string</code> | - scoped id of the resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchDeployment.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnSearchDeploymentProps">CfnSearchDeploymentProps</a></code> | - resource properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

scope in which this resource is defined.

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.Initializer.parameter.id"></a>

- *Type:* string

scoped id of the resource.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnSearchDeploymentProps">CfnSearchDeploymentProps</a>

resource properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchDeployment.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchDeployment.overrideLogicalId">overrideLogicalId</a></code> | Overrides the auto-generated logical ID with a specific ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchDeployment.addDeletionOverride">addDeletionOverride</a></code> | Syntactic sugar for `addOverride(path, undefined)`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchDeployment.addDependency">addDependency</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchDeployment.addDependsOn">addDependsOn</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchDeployment.addMetadata">addMetadata</a></code> | Add a value to the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchDeployment.addOverride">addOverride</a></code> | Adds an override to the synthesized CloudFormation resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchDeployment.addPropertyDeletionOverride">addPropertyDeletionOverride</a></code> | Adds an override that deletes the value of a property from the resource definition. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchDeployment.addPropertyOverride">addPropertyOverride</a></code> | Adds an override to a resource property. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchDeployment.applyRemovalPolicy">applyRemovalPolicy</a></code> | Sets the deletion policy of the resource based on the removal policy specified. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchDeployment.getAtt">getAtt</a></code> | Returns a token for an runtime attribute of this resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchDeployment.getMetadata">getMetadata</a></code> | Retrieve a value value from the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchDeployment.obtainDependencies">obtainDependencies</a></code> | Retrieves an array of resources this resource depends on. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchDeployment.obtainResourceDependencies">obtainResourceDependencies</a></code> | Get a shallow copy of dependencies between this resource and other resources in the same stack. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchDeployment.removeDependency">removeDependency</a></code> | Indicates that this resource no longer depends on another resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchDeployment.replaceDependency">replaceDependency</a></code> | Replaces one dependency with another. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `overrideLogicalId` <a name="overrideLogicalId" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.overrideLogicalId"></a>

```typescript
public overrideLogicalId(newLogicalId: string): void
```

Overrides the auto-generated logical ID with a specific ID.

###### `newLogicalId`<sup>Required</sup> <a name="newLogicalId" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.overrideLogicalId.parameter.newLogicalId"></a>

- *Type:* string

The new logical ID to use for this stack element.

---

##### `addDeletionOverride` <a name="addDeletionOverride" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.addDeletionOverride"></a>

```typescript
public addDeletionOverride(path: string): void
```

Syntactic sugar for `addOverride(path, undefined)`.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.addDeletionOverride.parameter.path"></a>

- *Type:* string

The path of the value to delete.

---

##### `addDependency` <a name="addDependency" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.addDependency"></a>

```typescript
public addDependency(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

This can be used for resources across stacks (or nested stack) boundaries
and the dependency will automatically be transferred to the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.addDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### ~~`addDependsOn`~~ <a name="addDependsOn" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.addDependsOn"></a>

```typescript
public addDependsOn(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.addDependsOn.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `addMetadata` <a name="addMetadata" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.addMetadata"></a>

```typescript
public addMetadata(key: string, value: any): void
```

Add a value to the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.addMetadata.parameter.key"></a>

- *Type:* string

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.addMetadata.parameter.value"></a>

- *Type:* any

---

##### `addOverride` <a name="addOverride" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.addOverride"></a>

```typescript
public addOverride(path: string, value: any): void
```

Adds an override to the synthesized CloudFormation resource.

To add a
property override, either use `addPropertyOverride` or prefix `path` with
"Properties." (i.e. `Properties.TopicName`).

If the override is nested, separate each nested level using a dot (.) in the path parameter.
If there is an array as part of the nesting, specify the index in the path.

To include a literal `.` in the property name, prefix with a `\`. In most
programming languages you will need to write this as `"\\."` because the
`\` itself will need to be escaped.

For example,
```typescript
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
```
would add the overrides
```json
"Properties": {
  "GlobalSecondaryIndexes": [
    {
      "Projection": {
        "NonKeyAttributes": [ "myattribute" ]
        ...
      }
      ...
    },
    {
      "ProjectionType": "INCLUDE"
      ...
    },
  ]
  ...
}
```

The `value` argument to `addOverride` will not be processed or translated
in any way. Pass raw JSON values in here with the correct capitalization
for CloudFormation. If you pass CDK classes or structs, they will be
rendered with lowercased key names, and CloudFormation will reject the
template.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.addOverride.parameter.path"></a>

- *Type:* string

The path of the property, you can use dot notation to override values in complex types.

Any intermediate keys
will be created as needed.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.addOverride.parameter.value"></a>

- *Type:* any

The value.

Could be primitive or complex.

---

##### `addPropertyDeletionOverride` <a name="addPropertyDeletionOverride" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.addPropertyDeletionOverride"></a>

```typescript
public addPropertyDeletionOverride(propertyPath: string): void
```

Adds an override that deletes the value of a property from the resource definition.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.addPropertyDeletionOverride.parameter.propertyPath"></a>

- *Type:* string

The path to the property.

---

##### `addPropertyOverride` <a name="addPropertyOverride" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.addPropertyOverride"></a>

```typescript
public addPropertyOverride(propertyPath: string, value: any): void
```

Adds an override to a resource property.

Syntactic sugar for `addOverride("Properties.<...>", value)`.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.addPropertyOverride.parameter.propertyPath"></a>

- *Type:* string

The path of the property.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.addPropertyOverride.parameter.value"></a>

- *Type:* any

The value.

---

##### `applyRemovalPolicy` <a name="applyRemovalPolicy" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.applyRemovalPolicy"></a>

```typescript
public applyRemovalPolicy(policy?: RemovalPolicy, options?: RemovalPolicyOptions): void
```

Sets the deletion policy of the resource based on the removal policy specified.

The Removal Policy controls what happens to this resource when it stops
being managed by CloudFormation, either because you've removed it from the
CDK application or because you've made a change that requires the resource
to be replaced.

The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
cases, a snapshot can be taken of the resource prior to deletion
(`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
can be found in the following link:

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options)

###### `policy`<sup>Optional</sup> <a name="policy" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.applyRemovalPolicy.parameter.policy"></a>

- *Type:* aws-cdk-lib.RemovalPolicy

---

###### `options`<sup>Optional</sup> <a name="options" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.applyRemovalPolicy.parameter.options"></a>

- *Type:* aws-cdk-lib.RemovalPolicyOptions

---

##### `getAtt` <a name="getAtt" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.getAtt"></a>

```typescript
public getAtt(attributeName: string, typeHint?: ResolutionTypeHint): Reference
```

Returns a token for an runtime attribute of this resource.

Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
in case there is no generated attribute.

###### `attributeName`<sup>Required</sup> <a name="attributeName" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.getAtt.parameter.attributeName"></a>

- *Type:* string

The name of the attribute.

---

###### `typeHint`<sup>Optional</sup> <a name="typeHint" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.getAtt.parameter.typeHint"></a>

- *Type:* aws-cdk-lib.ResolutionTypeHint

---

##### `getMetadata` <a name="getMetadata" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.getMetadata"></a>

```typescript
public getMetadata(key: string): any
```

Retrieve a value value from the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.getMetadata.parameter.key"></a>

- *Type:* string

---

##### `obtainDependencies` <a name="obtainDependencies" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.obtainDependencies"></a>

```typescript
public obtainDependencies(): Stack | CfnResource[]
```

Retrieves an array of resources this resource depends on.

This assembles dependencies on resources across stacks (including nested stacks)
automatically.

##### `obtainResourceDependencies` <a name="obtainResourceDependencies" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.obtainResourceDependencies"></a>

```typescript
public obtainResourceDependencies(): CfnResource[]
```

Get a shallow copy of dependencies between this resource and other resources in the same stack.

##### `removeDependency` <a name="removeDependency" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.removeDependency"></a>

```typescript
public removeDependency(target: CfnResource): void
```

Indicates that this resource no longer depends on another resource.

This can be used for resources across stacks (including nested stacks)
and the dependency will automatically be removed from the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.removeDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `replaceDependency` <a name="replaceDependency" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.replaceDependency"></a>

```typescript
public replaceDependency(target: CfnResource, newTarget: CfnResource): void
```

Replaces one dependency with another.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.replaceDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

The dependency to replace.

---

###### `newTarget`<sup>Required</sup> <a name="newTarget" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.replaceDependency.parameter.newTarget"></a>

- *Type:* aws-cdk-lib.CfnResource

The new dependency to add.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchDeployment.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchDeployment.isCfnElement">isCfnElement</a></code> | Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchDeployment.isCfnResource">isCfnResource</a></code> | Check whether the given construct is a CfnResource. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.isConstruct"></a>

```typescript
import { CfnSearchDeployment } from 'awscdk-resources-mongodbatlas'

CfnSearchDeployment.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `isCfnElement` <a name="isCfnElement" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.isCfnElement"></a>

```typescript
import { CfnSearchDeployment } from 'awscdk-resources-mongodbatlas'

CfnSearchDeployment.isCfnElement(x: any)
```

Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).

Uses duck-typing instead of `instanceof` to allow stack elements from different
versions of this library to be included in the same stack.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.isCfnElement.parameter.x"></a>

- *Type:* any

---

##### `isCfnResource` <a name="isCfnResource" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.isCfnResource"></a>

```typescript
import { CfnSearchDeployment } from 'awscdk-resources-mongodbatlas'

CfnSearchDeployment.isCfnResource(construct: IConstruct)
```

Check whether the given construct is a CfnResource.

###### `construct`<sup>Required</sup> <a name="construct" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.isCfnResource.parameter.construct"></a>

- *Type:* constructs.IConstruct

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchDeployment.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchDeployment.property.creationStack">creationStack</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchDeployment.property.logicalId">logicalId</a></code> | <code>string</code> | The logical ID for this CloudFormation stack element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchDeployment.property.stack">stack</a></code> | <code>aws-cdk-lib.Stack</code> | The stack in which this element is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchDeployment.property.ref">ref</a></code> | <code>string</code> | Return a string that will be resolved to a CloudFormation `{ Ref }` for this element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchDeployment.property.cfnOptions">cfnOptions</a></code> | <code>aws-cdk-lib.ICfnResourceOptions</code> | Options for this resource, such as condition, update policy etc. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchDeployment.property.cfnResourceType">cfnResourceType</a></code> | <code>string</code> | AWS resource type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchDeployment.property.attrId">attrId</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::SearchDeployment.Id`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchDeployment.property.attrStateName">attrStateName</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::SearchDeployment.StateName`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchDeployment.property.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnSearchDeploymentProps">CfnSearchDeploymentProps</a></code> | Resource props. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `creationStack`<sup>Required</sup> <a name="creationStack" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.property.creationStack"></a>

```typescript
public readonly creationStack: string[];
```

- *Type:* string[]

---

##### `logicalId`<sup>Required</sup> <a name="logicalId" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.property.logicalId"></a>

```typescript
public readonly logicalId: string;
```

- *Type:* string

The logical ID for this CloudFormation stack element.

The logical ID of the element
is calculated from the path of the resource node in the construct tree.

To override this value, use `overrideLogicalId(newLogicalId)`.

---

##### `stack`<sup>Required</sup> <a name="stack" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.property.stack"></a>

```typescript
public readonly stack: Stack;
```

- *Type:* aws-cdk-lib.Stack

The stack in which this element is defined.

CfnElements must be defined within a stack scope (directly or indirectly).

---

##### `ref`<sup>Required</sup> <a name="ref" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.

If, by any chance, the intrinsic reference of a resource is not a string, you could
coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.

---

##### `cfnOptions`<sup>Required</sup> <a name="cfnOptions" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.property.cfnOptions"></a>

```typescript
public readonly cfnOptions: ICfnResourceOptions;
```

- *Type:* aws-cdk-lib.ICfnResourceOptions

Options for this resource, such as condition, update policy etc.

---

##### `cfnResourceType`<sup>Required</sup> <a name="cfnResourceType" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.property.cfnResourceType"></a>

```typescript
public readonly cfnResourceType: string;
```

- *Type:* string

AWS resource type.

---

##### `attrId`<sup>Required</sup> <a name="attrId" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.property.attrId"></a>

```typescript
public readonly attrId: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::SearchDeployment.Id`.

---

##### `attrStateName`<sup>Required</sup> <a name="attrStateName" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.property.attrStateName"></a>

```typescript
public readonly attrStateName: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::SearchDeployment.StateName`.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.property.props"></a>

```typescript
public readonly props: CfnSearchDeploymentProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnSearchDeploymentProps">CfnSearchDeploymentProps</a>

Resource props.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchDeployment.property.CFN_RESOURCE_TYPE_NAME">CFN_RESOURCE_TYPE_NAME</a></code> | <code>string</code> | The CloudFormation resource type name for this resource class. |

---

##### `CFN_RESOURCE_TYPE_NAME`<sup>Required</sup> <a name="CFN_RESOURCE_TYPE_NAME" id="awscdk-resources-mongodbatlas.CfnSearchDeployment.property.CFN_RESOURCE_TYPE_NAME"></a>

```typescript
public readonly CFN_RESOURCE_TYPE_NAME: string;
```

- *Type:* string

The CloudFormation resource type name for this resource class.

---

### CfnSearchIndex <a name="CfnSearchIndex" id="awscdk-resources-mongodbatlas.CfnSearchIndex"></a>

A CloudFormation `MongoDB::Atlas::SearchIndex`.

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.CfnSearchIndex.Initializer"></a>

```typescript
import { CfnSearchIndex } from 'awscdk-resources-mongodbatlas'

new CfnSearchIndex(scope: Construct, id: string, props: CfnSearchIndexProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndex.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - scope in which this resource is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndex.Initializer.parameter.id">id</a></code> | <code>string</code> | - scoped id of the resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndex.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndexProps">CfnSearchIndexProps</a></code> | - resource properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.CfnSearchIndex.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

scope in which this resource is defined.

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnSearchIndex.Initializer.parameter.id"></a>

- *Type:* string

scoped id of the resource.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnSearchIndex.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnSearchIndexProps">CfnSearchIndexProps</a>

resource properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndex.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndex.overrideLogicalId">overrideLogicalId</a></code> | Overrides the auto-generated logical ID with a specific ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndex.addDeletionOverride">addDeletionOverride</a></code> | Syntactic sugar for `addOverride(path, undefined)`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndex.addDependency">addDependency</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndex.addDependsOn">addDependsOn</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndex.addMetadata">addMetadata</a></code> | Add a value to the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndex.addOverride">addOverride</a></code> | Adds an override to the synthesized CloudFormation resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndex.addPropertyDeletionOverride">addPropertyDeletionOverride</a></code> | Adds an override that deletes the value of a property from the resource definition. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndex.addPropertyOverride">addPropertyOverride</a></code> | Adds an override to a resource property. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndex.applyRemovalPolicy">applyRemovalPolicy</a></code> | Sets the deletion policy of the resource based on the removal policy specified. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndex.getAtt">getAtt</a></code> | Returns a token for an runtime attribute of this resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndex.getMetadata">getMetadata</a></code> | Retrieve a value value from the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndex.obtainDependencies">obtainDependencies</a></code> | Retrieves an array of resources this resource depends on. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndex.obtainResourceDependencies">obtainResourceDependencies</a></code> | Get a shallow copy of dependencies between this resource and other resources in the same stack. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndex.removeDependency">removeDependency</a></code> | Indicates that this resource no longer depends on another resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndex.replaceDependency">replaceDependency</a></code> | Replaces one dependency with another. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.CfnSearchIndex.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `overrideLogicalId` <a name="overrideLogicalId" id="awscdk-resources-mongodbatlas.CfnSearchIndex.overrideLogicalId"></a>

```typescript
public overrideLogicalId(newLogicalId: string): void
```

Overrides the auto-generated logical ID with a specific ID.

###### `newLogicalId`<sup>Required</sup> <a name="newLogicalId" id="awscdk-resources-mongodbatlas.CfnSearchIndex.overrideLogicalId.parameter.newLogicalId"></a>

- *Type:* string

The new logical ID to use for this stack element.

---

##### `addDeletionOverride` <a name="addDeletionOverride" id="awscdk-resources-mongodbatlas.CfnSearchIndex.addDeletionOverride"></a>

```typescript
public addDeletionOverride(path: string): void
```

Syntactic sugar for `addOverride(path, undefined)`.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnSearchIndex.addDeletionOverride.parameter.path"></a>

- *Type:* string

The path of the value to delete.

---

##### `addDependency` <a name="addDependency" id="awscdk-resources-mongodbatlas.CfnSearchIndex.addDependency"></a>

```typescript
public addDependency(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

This can be used for resources across stacks (or nested stack) boundaries
and the dependency will automatically be transferred to the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnSearchIndex.addDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### ~~`addDependsOn`~~ <a name="addDependsOn" id="awscdk-resources-mongodbatlas.CfnSearchIndex.addDependsOn"></a>

```typescript
public addDependsOn(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnSearchIndex.addDependsOn.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `addMetadata` <a name="addMetadata" id="awscdk-resources-mongodbatlas.CfnSearchIndex.addMetadata"></a>

```typescript
public addMetadata(key: string, value: any): void
```

Add a value to the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnSearchIndex.addMetadata.parameter.key"></a>

- *Type:* string

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnSearchIndex.addMetadata.parameter.value"></a>

- *Type:* any

---

##### `addOverride` <a name="addOverride" id="awscdk-resources-mongodbatlas.CfnSearchIndex.addOverride"></a>

```typescript
public addOverride(path: string, value: any): void
```

Adds an override to the synthesized CloudFormation resource.

To add a
property override, either use `addPropertyOverride` or prefix `path` with
"Properties." (i.e. `Properties.TopicName`).

If the override is nested, separate each nested level using a dot (.) in the path parameter.
If there is an array as part of the nesting, specify the index in the path.

To include a literal `.` in the property name, prefix with a `\`. In most
programming languages you will need to write this as `"\\."` because the
`\` itself will need to be escaped.

For example,
```typescript
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
```
would add the overrides
```json
"Properties": {
  "GlobalSecondaryIndexes": [
    {
      "Projection": {
        "NonKeyAttributes": [ "myattribute" ]
        ...
      }
      ...
    },
    {
      "ProjectionType": "INCLUDE"
      ...
    },
  ]
  ...
}
```

The `value` argument to `addOverride` will not be processed or translated
in any way. Pass raw JSON values in here with the correct capitalization
for CloudFormation. If you pass CDK classes or structs, they will be
rendered with lowercased key names, and CloudFormation will reject the
template.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnSearchIndex.addOverride.parameter.path"></a>

- *Type:* string

The path of the property, you can use dot notation to override values in complex types.

Any intermediate keys
will be created as needed.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnSearchIndex.addOverride.parameter.value"></a>

- *Type:* any

The value.

Could be primitive or complex.

---

##### `addPropertyDeletionOverride` <a name="addPropertyDeletionOverride" id="awscdk-resources-mongodbatlas.CfnSearchIndex.addPropertyDeletionOverride"></a>

```typescript
public addPropertyDeletionOverride(propertyPath: string): void
```

Adds an override that deletes the value of a property from the resource definition.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnSearchIndex.addPropertyDeletionOverride.parameter.propertyPath"></a>

- *Type:* string

The path to the property.

---

##### `addPropertyOverride` <a name="addPropertyOverride" id="awscdk-resources-mongodbatlas.CfnSearchIndex.addPropertyOverride"></a>

```typescript
public addPropertyOverride(propertyPath: string, value: any): void
```

Adds an override to a resource property.

Syntactic sugar for `addOverride("Properties.<...>", value)`.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnSearchIndex.addPropertyOverride.parameter.propertyPath"></a>

- *Type:* string

The path of the property.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnSearchIndex.addPropertyOverride.parameter.value"></a>

- *Type:* any

The value.

---

##### `applyRemovalPolicy` <a name="applyRemovalPolicy" id="awscdk-resources-mongodbatlas.CfnSearchIndex.applyRemovalPolicy"></a>

```typescript
public applyRemovalPolicy(policy?: RemovalPolicy, options?: RemovalPolicyOptions): void
```

Sets the deletion policy of the resource based on the removal policy specified.

The Removal Policy controls what happens to this resource when it stops
being managed by CloudFormation, either because you've removed it from the
CDK application or because you've made a change that requires the resource
to be replaced.

The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
cases, a snapshot can be taken of the resource prior to deletion
(`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
can be found in the following link:

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options)

###### `policy`<sup>Optional</sup> <a name="policy" id="awscdk-resources-mongodbatlas.CfnSearchIndex.applyRemovalPolicy.parameter.policy"></a>

- *Type:* aws-cdk-lib.RemovalPolicy

---

###### `options`<sup>Optional</sup> <a name="options" id="awscdk-resources-mongodbatlas.CfnSearchIndex.applyRemovalPolicy.parameter.options"></a>

- *Type:* aws-cdk-lib.RemovalPolicyOptions

---

##### `getAtt` <a name="getAtt" id="awscdk-resources-mongodbatlas.CfnSearchIndex.getAtt"></a>

```typescript
public getAtt(attributeName: string, typeHint?: ResolutionTypeHint): Reference
```

Returns a token for an runtime attribute of this resource.

Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
in case there is no generated attribute.

###### `attributeName`<sup>Required</sup> <a name="attributeName" id="awscdk-resources-mongodbatlas.CfnSearchIndex.getAtt.parameter.attributeName"></a>

- *Type:* string

The name of the attribute.

---

###### `typeHint`<sup>Optional</sup> <a name="typeHint" id="awscdk-resources-mongodbatlas.CfnSearchIndex.getAtt.parameter.typeHint"></a>

- *Type:* aws-cdk-lib.ResolutionTypeHint

---

##### `getMetadata` <a name="getMetadata" id="awscdk-resources-mongodbatlas.CfnSearchIndex.getMetadata"></a>

```typescript
public getMetadata(key: string): any
```

Retrieve a value value from the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnSearchIndex.getMetadata.parameter.key"></a>

- *Type:* string

---

##### `obtainDependencies` <a name="obtainDependencies" id="awscdk-resources-mongodbatlas.CfnSearchIndex.obtainDependencies"></a>

```typescript
public obtainDependencies(): Stack | CfnResource[]
```

Retrieves an array of resources this resource depends on.

This assembles dependencies on resources across stacks (including nested stacks)
automatically.

##### `obtainResourceDependencies` <a name="obtainResourceDependencies" id="awscdk-resources-mongodbatlas.CfnSearchIndex.obtainResourceDependencies"></a>

```typescript
public obtainResourceDependencies(): CfnResource[]
```

Get a shallow copy of dependencies between this resource and other resources in the same stack.

##### `removeDependency` <a name="removeDependency" id="awscdk-resources-mongodbatlas.CfnSearchIndex.removeDependency"></a>

```typescript
public removeDependency(target: CfnResource): void
```

Indicates that this resource no longer depends on another resource.

This can be used for resources across stacks (including nested stacks)
and the dependency will automatically be removed from the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnSearchIndex.removeDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `replaceDependency` <a name="replaceDependency" id="awscdk-resources-mongodbatlas.CfnSearchIndex.replaceDependency"></a>

```typescript
public replaceDependency(target: CfnResource, newTarget: CfnResource): void
```

Replaces one dependency with another.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnSearchIndex.replaceDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

The dependency to replace.

---

###### `newTarget`<sup>Required</sup> <a name="newTarget" id="awscdk-resources-mongodbatlas.CfnSearchIndex.replaceDependency.parameter.newTarget"></a>

- *Type:* aws-cdk-lib.CfnResource

The new dependency to add.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndex.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndex.isCfnElement">isCfnElement</a></code> | Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndex.isCfnResource">isCfnResource</a></code> | Check whether the given construct is a CfnResource. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.CfnSearchIndex.isConstruct"></a>

```typescript
import { CfnSearchIndex } from 'awscdk-resources-mongodbatlas'

CfnSearchIndex.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnSearchIndex.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `isCfnElement` <a name="isCfnElement" id="awscdk-resources-mongodbatlas.CfnSearchIndex.isCfnElement"></a>

```typescript
import { CfnSearchIndex } from 'awscdk-resources-mongodbatlas'

CfnSearchIndex.isCfnElement(x: any)
```

Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).

Uses duck-typing instead of `instanceof` to allow stack elements from different
versions of this library to be included in the same stack.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnSearchIndex.isCfnElement.parameter.x"></a>

- *Type:* any

---

##### `isCfnResource` <a name="isCfnResource" id="awscdk-resources-mongodbatlas.CfnSearchIndex.isCfnResource"></a>

```typescript
import { CfnSearchIndex } from 'awscdk-resources-mongodbatlas'

CfnSearchIndex.isCfnResource(construct: IConstruct)
```

Check whether the given construct is a CfnResource.

###### `construct`<sup>Required</sup> <a name="construct" id="awscdk-resources-mongodbatlas.CfnSearchIndex.isCfnResource.parameter.construct"></a>

- *Type:* constructs.IConstruct

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndex.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndex.property.creationStack">creationStack</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndex.property.logicalId">logicalId</a></code> | <code>string</code> | The logical ID for this CloudFormation stack element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndex.property.stack">stack</a></code> | <code>aws-cdk-lib.Stack</code> | The stack in which this element is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndex.property.ref">ref</a></code> | <code>string</code> | Return a string that will be resolved to a CloudFormation `{ Ref }` for this element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndex.property.cfnOptions">cfnOptions</a></code> | <code>aws-cdk-lib.ICfnResourceOptions</code> | Options for this resource, such as condition, update policy etc. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndex.property.cfnResourceType">cfnResourceType</a></code> | <code>string</code> | AWS resource type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndex.property.attrIndexId">attrIndexId</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::SearchIndex.IndexId`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndex.property.attrStatus">attrStatus</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::SearchIndex.Status`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndex.property.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndexProps">CfnSearchIndexProps</a></code> | Resource props. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.CfnSearchIndex.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `creationStack`<sup>Required</sup> <a name="creationStack" id="awscdk-resources-mongodbatlas.CfnSearchIndex.property.creationStack"></a>

```typescript
public readonly creationStack: string[];
```

- *Type:* string[]

---

##### `logicalId`<sup>Required</sup> <a name="logicalId" id="awscdk-resources-mongodbatlas.CfnSearchIndex.property.logicalId"></a>

```typescript
public readonly logicalId: string;
```

- *Type:* string

The logical ID for this CloudFormation stack element.

The logical ID of the element
is calculated from the path of the resource node in the construct tree.

To override this value, use `overrideLogicalId(newLogicalId)`.

---

##### `stack`<sup>Required</sup> <a name="stack" id="awscdk-resources-mongodbatlas.CfnSearchIndex.property.stack"></a>

```typescript
public readonly stack: Stack;
```

- *Type:* aws-cdk-lib.Stack

The stack in which this element is defined.

CfnElements must be defined within a stack scope (directly or indirectly).

---

##### `ref`<sup>Required</sup> <a name="ref" id="awscdk-resources-mongodbatlas.CfnSearchIndex.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.

If, by any chance, the intrinsic reference of a resource is not a string, you could
coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.

---

##### `cfnOptions`<sup>Required</sup> <a name="cfnOptions" id="awscdk-resources-mongodbatlas.CfnSearchIndex.property.cfnOptions"></a>

```typescript
public readonly cfnOptions: ICfnResourceOptions;
```

- *Type:* aws-cdk-lib.ICfnResourceOptions

Options for this resource, such as condition, update policy etc.

---

##### `cfnResourceType`<sup>Required</sup> <a name="cfnResourceType" id="awscdk-resources-mongodbatlas.CfnSearchIndex.property.cfnResourceType"></a>

```typescript
public readonly cfnResourceType: string;
```

- *Type:* string

AWS resource type.

---

##### `attrIndexId`<sup>Required</sup> <a name="attrIndexId" id="awscdk-resources-mongodbatlas.CfnSearchIndex.property.attrIndexId"></a>

```typescript
public readonly attrIndexId: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::SearchIndex.IndexId`.

---

##### `attrStatus`<sup>Required</sup> <a name="attrStatus" id="awscdk-resources-mongodbatlas.CfnSearchIndex.property.attrStatus"></a>

```typescript
public readonly attrStatus: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::SearchIndex.Status`.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnSearchIndex.property.props"></a>

```typescript
public readonly props: CfnSearchIndexProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnSearchIndexProps">CfnSearchIndexProps</a>

Resource props.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndex.property.CFN_RESOURCE_TYPE_NAME">CFN_RESOURCE_TYPE_NAME</a></code> | <code>string</code> | The CloudFormation resource type name for this resource class. |

---

##### `CFN_RESOURCE_TYPE_NAME`<sup>Required</sup> <a name="CFN_RESOURCE_TYPE_NAME" id="awscdk-resources-mongodbatlas.CfnSearchIndex.property.CFN_RESOURCE_TYPE_NAME"></a>

```typescript
public readonly CFN_RESOURCE_TYPE_NAME: string;
```

- *Type:* string

The CloudFormation resource type name for this resource class.

---

### CfnServerlessInstance <a name="CfnServerlessInstance" id="awscdk-resources-mongodbatlas.CfnServerlessInstance"></a>

A CloudFormation `MongoDB::Atlas::ServerlessInstance`.

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.Initializer"></a>

```typescript
import { CfnServerlessInstance } from 'awscdk-resources-mongodbatlas'

new CfnServerlessInstance(scope: Construct, id: string, props: CfnServerlessInstanceProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstance.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - scope in which this resource is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstance.Initializer.parameter.id">id</a></code> | <code>string</code> | - scoped id of the resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstance.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstanceProps">CfnServerlessInstanceProps</a></code> | - resource properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

scope in which this resource is defined.

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.Initializer.parameter.id"></a>

- *Type:* string

scoped id of the resource.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnServerlessInstanceProps">CfnServerlessInstanceProps</a>

resource properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstance.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstance.overrideLogicalId">overrideLogicalId</a></code> | Overrides the auto-generated logical ID with a specific ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstance.addDeletionOverride">addDeletionOverride</a></code> | Syntactic sugar for `addOverride(path, undefined)`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstance.addDependency">addDependency</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstance.addDependsOn">addDependsOn</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstance.addMetadata">addMetadata</a></code> | Add a value to the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstance.addOverride">addOverride</a></code> | Adds an override to the synthesized CloudFormation resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstance.addPropertyDeletionOverride">addPropertyDeletionOverride</a></code> | Adds an override that deletes the value of a property from the resource definition. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstance.addPropertyOverride">addPropertyOverride</a></code> | Adds an override to a resource property. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstance.applyRemovalPolicy">applyRemovalPolicy</a></code> | Sets the deletion policy of the resource based on the removal policy specified. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstance.getAtt">getAtt</a></code> | Returns a token for an runtime attribute of this resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstance.getMetadata">getMetadata</a></code> | Retrieve a value value from the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstance.obtainDependencies">obtainDependencies</a></code> | Retrieves an array of resources this resource depends on. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstance.obtainResourceDependencies">obtainResourceDependencies</a></code> | Get a shallow copy of dependencies between this resource and other resources in the same stack. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstance.removeDependency">removeDependency</a></code> | Indicates that this resource no longer depends on another resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstance.replaceDependency">replaceDependency</a></code> | Replaces one dependency with another. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `overrideLogicalId` <a name="overrideLogicalId" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.overrideLogicalId"></a>

```typescript
public overrideLogicalId(newLogicalId: string): void
```

Overrides the auto-generated logical ID with a specific ID.

###### `newLogicalId`<sup>Required</sup> <a name="newLogicalId" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.overrideLogicalId.parameter.newLogicalId"></a>

- *Type:* string

The new logical ID to use for this stack element.

---

##### `addDeletionOverride` <a name="addDeletionOverride" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.addDeletionOverride"></a>

```typescript
public addDeletionOverride(path: string): void
```

Syntactic sugar for `addOverride(path, undefined)`.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.addDeletionOverride.parameter.path"></a>

- *Type:* string

The path of the value to delete.

---

##### `addDependency` <a name="addDependency" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.addDependency"></a>

```typescript
public addDependency(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

This can be used for resources across stacks (or nested stack) boundaries
and the dependency will automatically be transferred to the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.addDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### ~~`addDependsOn`~~ <a name="addDependsOn" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.addDependsOn"></a>

```typescript
public addDependsOn(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.addDependsOn.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `addMetadata` <a name="addMetadata" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.addMetadata"></a>

```typescript
public addMetadata(key: string, value: any): void
```

Add a value to the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.addMetadata.parameter.key"></a>

- *Type:* string

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.addMetadata.parameter.value"></a>

- *Type:* any

---

##### `addOverride` <a name="addOverride" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.addOverride"></a>

```typescript
public addOverride(path: string, value: any): void
```

Adds an override to the synthesized CloudFormation resource.

To add a
property override, either use `addPropertyOverride` or prefix `path` with
"Properties." (i.e. `Properties.TopicName`).

If the override is nested, separate each nested level using a dot (.) in the path parameter.
If there is an array as part of the nesting, specify the index in the path.

To include a literal `.` in the property name, prefix with a `\`. In most
programming languages you will need to write this as `"\\."` because the
`\` itself will need to be escaped.

For example,
```typescript
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
```
would add the overrides
```json
"Properties": {
  "GlobalSecondaryIndexes": [
    {
      "Projection": {
        "NonKeyAttributes": [ "myattribute" ]
        ...
      }
      ...
    },
    {
      "ProjectionType": "INCLUDE"
      ...
    },
  ]
  ...
}
```

The `value` argument to `addOverride` will not be processed or translated
in any way. Pass raw JSON values in here with the correct capitalization
for CloudFormation. If you pass CDK classes or structs, they will be
rendered with lowercased key names, and CloudFormation will reject the
template.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.addOverride.parameter.path"></a>

- *Type:* string

The path of the property, you can use dot notation to override values in complex types.

Any intermediate keys
will be created as needed.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.addOverride.parameter.value"></a>

- *Type:* any

The value.

Could be primitive or complex.

---

##### `addPropertyDeletionOverride` <a name="addPropertyDeletionOverride" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.addPropertyDeletionOverride"></a>

```typescript
public addPropertyDeletionOverride(propertyPath: string): void
```

Adds an override that deletes the value of a property from the resource definition.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.addPropertyDeletionOverride.parameter.propertyPath"></a>

- *Type:* string

The path to the property.

---

##### `addPropertyOverride` <a name="addPropertyOverride" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.addPropertyOverride"></a>

```typescript
public addPropertyOverride(propertyPath: string, value: any): void
```

Adds an override to a resource property.

Syntactic sugar for `addOverride("Properties.<...>", value)`.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.addPropertyOverride.parameter.propertyPath"></a>

- *Type:* string

The path of the property.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.addPropertyOverride.parameter.value"></a>

- *Type:* any

The value.

---

##### `applyRemovalPolicy` <a name="applyRemovalPolicy" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.applyRemovalPolicy"></a>

```typescript
public applyRemovalPolicy(policy?: RemovalPolicy, options?: RemovalPolicyOptions): void
```

Sets the deletion policy of the resource based on the removal policy specified.

The Removal Policy controls what happens to this resource when it stops
being managed by CloudFormation, either because you've removed it from the
CDK application or because you've made a change that requires the resource
to be replaced.

The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
cases, a snapshot can be taken of the resource prior to deletion
(`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
can be found in the following link:

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options)

###### `policy`<sup>Optional</sup> <a name="policy" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.applyRemovalPolicy.parameter.policy"></a>

- *Type:* aws-cdk-lib.RemovalPolicy

---

###### `options`<sup>Optional</sup> <a name="options" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.applyRemovalPolicy.parameter.options"></a>

- *Type:* aws-cdk-lib.RemovalPolicyOptions

---

##### `getAtt` <a name="getAtt" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.getAtt"></a>

```typescript
public getAtt(attributeName: string, typeHint?: ResolutionTypeHint): Reference
```

Returns a token for an runtime attribute of this resource.

Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
in case there is no generated attribute.

###### `attributeName`<sup>Required</sup> <a name="attributeName" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.getAtt.parameter.attributeName"></a>

- *Type:* string

The name of the attribute.

---

###### `typeHint`<sup>Optional</sup> <a name="typeHint" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.getAtt.parameter.typeHint"></a>

- *Type:* aws-cdk-lib.ResolutionTypeHint

---

##### `getMetadata` <a name="getMetadata" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.getMetadata"></a>

```typescript
public getMetadata(key: string): any
```

Retrieve a value value from the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.getMetadata.parameter.key"></a>

- *Type:* string

---

##### `obtainDependencies` <a name="obtainDependencies" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.obtainDependencies"></a>

```typescript
public obtainDependencies(): Stack | CfnResource[]
```

Retrieves an array of resources this resource depends on.

This assembles dependencies on resources across stacks (including nested stacks)
automatically.

##### `obtainResourceDependencies` <a name="obtainResourceDependencies" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.obtainResourceDependencies"></a>

```typescript
public obtainResourceDependencies(): CfnResource[]
```

Get a shallow copy of dependencies between this resource and other resources in the same stack.

##### `removeDependency` <a name="removeDependency" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.removeDependency"></a>

```typescript
public removeDependency(target: CfnResource): void
```

Indicates that this resource no longer depends on another resource.

This can be used for resources across stacks (including nested stacks)
and the dependency will automatically be removed from the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.removeDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `replaceDependency` <a name="replaceDependency" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.replaceDependency"></a>

```typescript
public replaceDependency(target: CfnResource, newTarget: CfnResource): void
```

Replaces one dependency with another.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.replaceDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

The dependency to replace.

---

###### `newTarget`<sup>Required</sup> <a name="newTarget" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.replaceDependency.parameter.newTarget"></a>

- *Type:* aws-cdk-lib.CfnResource

The new dependency to add.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstance.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstance.isCfnElement">isCfnElement</a></code> | Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstance.isCfnResource">isCfnResource</a></code> | Check whether the given construct is a CfnResource. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.isConstruct"></a>

```typescript
import { CfnServerlessInstance } from 'awscdk-resources-mongodbatlas'

CfnServerlessInstance.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `isCfnElement` <a name="isCfnElement" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.isCfnElement"></a>

```typescript
import { CfnServerlessInstance } from 'awscdk-resources-mongodbatlas'

CfnServerlessInstance.isCfnElement(x: any)
```

Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).

Uses duck-typing instead of `instanceof` to allow stack elements from different
versions of this library to be included in the same stack.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.isCfnElement.parameter.x"></a>

- *Type:* any

---

##### `isCfnResource` <a name="isCfnResource" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.isCfnResource"></a>

```typescript
import { CfnServerlessInstance } from 'awscdk-resources-mongodbatlas'

CfnServerlessInstance.isCfnResource(construct: IConstruct)
```

Check whether the given construct is a CfnResource.

###### `construct`<sup>Required</sup> <a name="construct" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.isCfnResource.parameter.construct"></a>

- *Type:* constructs.IConstruct

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstance.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstance.property.creationStack">creationStack</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstance.property.logicalId">logicalId</a></code> | <code>string</code> | The logical ID for this CloudFormation stack element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstance.property.stack">stack</a></code> | <code>aws-cdk-lib.Stack</code> | The stack in which this element is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstance.property.ref">ref</a></code> | <code>string</code> | Return a string that will be resolved to a CloudFormation `{ Ref }` for this element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstance.property.cfnOptions">cfnOptions</a></code> | <code>aws-cdk-lib.ICfnResourceOptions</code> | Options for this resource, such as condition, update policy etc. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstance.property.cfnResourceType">cfnResourceType</a></code> | <code>string</code> | AWS resource type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstance.property.attrCreateDate">attrCreateDate</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::ServerlessInstance.CreateDate`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstance.property.attrId">attrId</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::ServerlessInstance.Id`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstance.property.attrMongoDBVersion">attrMongoDBVersion</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::ServerlessInstance.MongoDBVersion`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstance.property.attrStateName">attrStateName</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::ServerlessInstance.StateName`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstance.property.attrTotalCount">attrTotalCount</a></code> | <code>number</code> | Attribute `MongoDB::Atlas::ServerlessInstance.TotalCount`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstance.property.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstanceProps">CfnServerlessInstanceProps</a></code> | Resource props. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `creationStack`<sup>Required</sup> <a name="creationStack" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.property.creationStack"></a>

```typescript
public readonly creationStack: string[];
```

- *Type:* string[]

---

##### `logicalId`<sup>Required</sup> <a name="logicalId" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.property.logicalId"></a>

```typescript
public readonly logicalId: string;
```

- *Type:* string

The logical ID for this CloudFormation stack element.

The logical ID of the element
is calculated from the path of the resource node in the construct tree.

To override this value, use `overrideLogicalId(newLogicalId)`.

---

##### `stack`<sup>Required</sup> <a name="stack" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.property.stack"></a>

```typescript
public readonly stack: Stack;
```

- *Type:* aws-cdk-lib.Stack

The stack in which this element is defined.

CfnElements must be defined within a stack scope (directly or indirectly).

---

##### `ref`<sup>Required</sup> <a name="ref" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.

If, by any chance, the intrinsic reference of a resource is not a string, you could
coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.

---

##### `cfnOptions`<sup>Required</sup> <a name="cfnOptions" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.property.cfnOptions"></a>

```typescript
public readonly cfnOptions: ICfnResourceOptions;
```

- *Type:* aws-cdk-lib.ICfnResourceOptions

Options for this resource, such as condition, update policy etc.

---

##### `cfnResourceType`<sup>Required</sup> <a name="cfnResourceType" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.property.cfnResourceType"></a>

```typescript
public readonly cfnResourceType: string;
```

- *Type:* string

AWS resource type.

---

##### `attrCreateDate`<sup>Required</sup> <a name="attrCreateDate" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.property.attrCreateDate"></a>

```typescript
public readonly attrCreateDate: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::ServerlessInstance.CreateDate`.

---

##### `attrId`<sup>Required</sup> <a name="attrId" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.property.attrId"></a>

```typescript
public readonly attrId: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::ServerlessInstance.Id`.

---

##### `attrMongoDBVersion`<sup>Required</sup> <a name="attrMongoDBVersion" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.property.attrMongoDBVersion"></a>

```typescript
public readonly attrMongoDBVersion: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::ServerlessInstance.MongoDBVersion`.

---

##### `attrStateName`<sup>Required</sup> <a name="attrStateName" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.property.attrStateName"></a>

```typescript
public readonly attrStateName: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::ServerlessInstance.StateName`.

---

##### `attrTotalCount`<sup>Required</sup> <a name="attrTotalCount" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.property.attrTotalCount"></a>

```typescript
public readonly attrTotalCount: number;
```

- *Type:* number

Attribute `MongoDB::Atlas::ServerlessInstance.TotalCount`.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.property.props"></a>

```typescript
public readonly props: CfnServerlessInstanceProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnServerlessInstanceProps">CfnServerlessInstanceProps</a>

Resource props.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstance.property.CFN_RESOURCE_TYPE_NAME">CFN_RESOURCE_TYPE_NAME</a></code> | <code>string</code> | The CloudFormation resource type name for this resource class. |

---

##### `CFN_RESOURCE_TYPE_NAME`<sup>Required</sup> <a name="CFN_RESOURCE_TYPE_NAME" id="awscdk-resources-mongodbatlas.CfnServerlessInstance.property.CFN_RESOURCE_TYPE_NAME"></a>

```typescript
public readonly CFN_RESOURCE_TYPE_NAME: string;
```

- *Type:* string

The CloudFormation resource type name for this resource class.

---

### CfnServerlessPrivateEndpoint <a name="CfnServerlessPrivateEndpoint" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint"></a>

A CloudFormation `MongoDB::Atlas::ServerlessPrivateEndpoint`.

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.Initializer"></a>

```typescript
import { CfnServerlessPrivateEndpoint } from 'awscdk-resources-mongodbatlas'

new CfnServerlessPrivateEndpoint(scope: Construct, id: string, props: CfnServerlessPrivateEndpointProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - scope in which this resource is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.Initializer.parameter.id">id</a></code> | <code>string</code> | - scoped id of the resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpointProps">CfnServerlessPrivateEndpointProps</a></code> | - resource properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

scope in which this resource is defined.

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.Initializer.parameter.id"></a>

- *Type:* string

scoped id of the resource.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpointProps">CfnServerlessPrivateEndpointProps</a>

resource properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.overrideLogicalId">overrideLogicalId</a></code> | Overrides the auto-generated logical ID with a specific ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.addDeletionOverride">addDeletionOverride</a></code> | Syntactic sugar for `addOverride(path, undefined)`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.addDependency">addDependency</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.addDependsOn">addDependsOn</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.addMetadata">addMetadata</a></code> | Add a value to the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.addOverride">addOverride</a></code> | Adds an override to the synthesized CloudFormation resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.addPropertyDeletionOverride">addPropertyDeletionOverride</a></code> | Adds an override that deletes the value of a property from the resource definition. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.addPropertyOverride">addPropertyOverride</a></code> | Adds an override to a resource property. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.applyRemovalPolicy">applyRemovalPolicy</a></code> | Sets the deletion policy of the resource based on the removal policy specified. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.getAtt">getAtt</a></code> | Returns a token for an runtime attribute of this resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.getMetadata">getMetadata</a></code> | Retrieve a value value from the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.obtainDependencies">obtainDependencies</a></code> | Retrieves an array of resources this resource depends on. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.obtainResourceDependencies">obtainResourceDependencies</a></code> | Get a shallow copy of dependencies between this resource and other resources in the same stack. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.removeDependency">removeDependency</a></code> | Indicates that this resource no longer depends on another resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.replaceDependency">replaceDependency</a></code> | Replaces one dependency with another. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `overrideLogicalId` <a name="overrideLogicalId" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.overrideLogicalId"></a>

```typescript
public overrideLogicalId(newLogicalId: string): void
```

Overrides the auto-generated logical ID with a specific ID.

###### `newLogicalId`<sup>Required</sup> <a name="newLogicalId" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.overrideLogicalId.parameter.newLogicalId"></a>

- *Type:* string

The new logical ID to use for this stack element.

---

##### `addDeletionOverride` <a name="addDeletionOverride" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.addDeletionOverride"></a>

```typescript
public addDeletionOverride(path: string): void
```

Syntactic sugar for `addOverride(path, undefined)`.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.addDeletionOverride.parameter.path"></a>

- *Type:* string

The path of the value to delete.

---

##### `addDependency` <a name="addDependency" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.addDependency"></a>

```typescript
public addDependency(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

This can be used for resources across stacks (or nested stack) boundaries
and the dependency will automatically be transferred to the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.addDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### ~~`addDependsOn`~~ <a name="addDependsOn" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.addDependsOn"></a>

```typescript
public addDependsOn(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.addDependsOn.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `addMetadata` <a name="addMetadata" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.addMetadata"></a>

```typescript
public addMetadata(key: string, value: any): void
```

Add a value to the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.addMetadata.parameter.key"></a>

- *Type:* string

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.addMetadata.parameter.value"></a>

- *Type:* any

---

##### `addOverride` <a name="addOverride" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.addOverride"></a>

```typescript
public addOverride(path: string, value: any): void
```

Adds an override to the synthesized CloudFormation resource.

To add a
property override, either use `addPropertyOverride` or prefix `path` with
"Properties." (i.e. `Properties.TopicName`).

If the override is nested, separate each nested level using a dot (.) in the path parameter.
If there is an array as part of the nesting, specify the index in the path.

To include a literal `.` in the property name, prefix with a `\`. In most
programming languages you will need to write this as `"\\."` because the
`\` itself will need to be escaped.

For example,
```typescript
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
```
would add the overrides
```json
"Properties": {
  "GlobalSecondaryIndexes": [
    {
      "Projection": {
        "NonKeyAttributes": [ "myattribute" ]
        ...
      }
      ...
    },
    {
      "ProjectionType": "INCLUDE"
      ...
    },
  ]
  ...
}
```

The `value` argument to `addOverride` will not be processed or translated
in any way. Pass raw JSON values in here with the correct capitalization
for CloudFormation. If you pass CDK classes or structs, they will be
rendered with lowercased key names, and CloudFormation will reject the
template.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.addOverride.parameter.path"></a>

- *Type:* string

The path of the property, you can use dot notation to override values in complex types.

Any intermediate keys
will be created as needed.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.addOverride.parameter.value"></a>

- *Type:* any

The value.

Could be primitive or complex.

---

##### `addPropertyDeletionOverride` <a name="addPropertyDeletionOverride" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.addPropertyDeletionOverride"></a>

```typescript
public addPropertyDeletionOverride(propertyPath: string): void
```

Adds an override that deletes the value of a property from the resource definition.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.addPropertyDeletionOverride.parameter.propertyPath"></a>

- *Type:* string

The path to the property.

---

##### `addPropertyOverride` <a name="addPropertyOverride" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.addPropertyOverride"></a>

```typescript
public addPropertyOverride(propertyPath: string, value: any): void
```

Adds an override to a resource property.

Syntactic sugar for `addOverride("Properties.<...>", value)`.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.addPropertyOverride.parameter.propertyPath"></a>

- *Type:* string

The path of the property.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.addPropertyOverride.parameter.value"></a>

- *Type:* any

The value.

---

##### `applyRemovalPolicy` <a name="applyRemovalPolicy" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.applyRemovalPolicy"></a>

```typescript
public applyRemovalPolicy(policy?: RemovalPolicy, options?: RemovalPolicyOptions): void
```

Sets the deletion policy of the resource based on the removal policy specified.

The Removal Policy controls what happens to this resource when it stops
being managed by CloudFormation, either because you've removed it from the
CDK application or because you've made a change that requires the resource
to be replaced.

The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
cases, a snapshot can be taken of the resource prior to deletion
(`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
can be found in the following link:

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options)

###### `policy`<sup>Optional</sup> <a name="policy" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.applyRemovalPolicy.parameter.policy"></a>

- *Type:* aws-cdk-lib.RemovalPolicy

---

###### `options`<sup>Optional</sup> <a name="options" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.applyRemovalPolicy.parameter.options"></a>

- *Type:* aws-cdk-lib.RemovalPolicyOptions

---

##### `getAtt` <a name="getAtt" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.getAtt"></a>

```typescript
public getAtt(attributeName: string, typeHint?: ResolutionTypeHint): Reference
```

Returns a token for an runtime attribute of this resource.

Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
in case there is no generated attribute.

###### `attributeName`<sup>Required</sup> <a name="attributeName" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.getAtt.parameter.attributeName"></a>

- *Type:* string

The name of the attribute.

---

###### `typeHint`<sup>Optional</sup> <a name="typeHint" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.getAtt.parameter.typeHint"></a>

- *Type:* aws-cdk-lib.ResolutionTypeHint

---

##### `getMetadata` <a name="getMetadata" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.getMetadata"></a>

```typescript
public getMetadata(key: string): any
```

Retrieve a value value from the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.getMetadata.parameter.key"></a>

- *Type:* string

---

##### `obtainDependencies` <a name="obtainDependencies" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.obtainDependencies"></a>

```typescript
public obtainDependencies(): Stack | CfnResource[]
```

Retrieves an array of resources this resource depends on.

This assembles dependencies on resources across stacks (including nested stacks)
automatically.

##### `obtainResourceDependencies` <a name="obtainResourceDependencies" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.obtainResourceDependencies"></a>

```typescript
public obtainResourceDependencies(): CfnResource[]
```

Get a shallow copy of dependencies between this resource and other resources in the same stack.

##### `removeDependency` <a name="removeDependency" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.removeDependency"></a>

```typescript
public removeDependency(target: CfnResource): void
```

Indicates that this resource no longer depends on another resource.

This can be used for resources across stacks (including nested stacks)
and the dependency will automatically be removed from the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.removeDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `replaceDependency` <a name="replaceDependency" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.replaceDependency"></a>

```typescript
public replaceDependency(target: CfnResource, newTarget: CfnResource): void
```

Replaces one dependency with another.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.replaceDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

The dependency to replace.

---

###### `newTarget`<sup>Required</sup> <a name="newTarget" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.replaceDependency.parameter.newTarget"></a>

- *Type:* aws-cdk-lib.CfnResource

The new dependency to add.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.isCfnElement">isCfnElement</a></code> | Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.isCfnResource">isCfnResource</a></code> | Check whether the given construct is a CfnResource. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.isConstruct"></a>

```typescript
import { CfnServerlessPrivateEndpoint } from 'awscdk-resources-mongodbatlas'

CfnServerlessPrivateEndpoint.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `isCfnElement` <a name="isCfnElement" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.isCfnElement"></a>

```typescript
import { CfnServerlessPrivateEndpoint } from 'awscdk-resources-mongodbatlas'

CfnServerlessPrivateEndpoint.isCfnElement(x: any)
```

Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).

Uses duck-typing instead of `instanceof` to allow stack elements from different
versions of this library to be included in the same stack.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.isCfnElement.parameter.x"></a>

- *Type:* any

---

##### `isCfnResource` <a name="isCfnResource" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.isCfnResource"></a>

```typescript
import { CfnServerlessPrivateEndpoint } from 'awscdk-resources-mongodbatlas'

CfnServerlessPrivateEndpoint.isCfnResource(construct: IConstruct)
```

Check whether the given construct is a CfnResource.

###### `construct`<sup>Required</sup> <a name="construct" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.isCfnResource.parameter.construct"></a>

- *Type:* constructs.IConstruct

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.property.creationStack">creationStack</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.property.logicalId">logicalId</a></code> | <code>string</code> | The logical ID for this CloudFormation stack element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.property.stack">stack</a></code> | <code>aws-cdk-lib.Stack</code> | The stack in which this element is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.property.ref">ref</a></code> | <code>string</code> | Return a string that will be resolved to a CloudFormation `{ Ref }` for this element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.property.cfnOptions">cfnOptions</a></code> | <code>aws-cdk-lib.ICfnResourceOptions</code> | Options for this resource, such as condition, update policy etc. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.property.cfnResourceType">cfnResourceType</a></code> | <code>string</code> | AWS resource type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.property.attrAwsPrivateEndpointMetaData">attrAwsPrivateEndpointMetaData</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::ServerlessPrivateEndpoint.AwsPrivateEndpointMetaData`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.property.attrEndpointServiceName">attrEndpointServiceName</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::ServerlessPrivateEndpoint.EndpointServiceName`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.property.attrErrorMessage">attrErrorMessage</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::ServerlessPrivateEndpoint.ErrorMessage`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.property.attrId">attrId</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::ServerlessPrivateEndpoint.Id`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.property.attrProviderName">attrProviderName</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::ServerlessPrivateEndpoint.ProviderName`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.property.attrStatus">attrStatus</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::ServerlessPrivateEndpoint.Status`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.property.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpointProps">CfnServerlessPrivateEndpointProps</a></code> | Resource props. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `creationStack`<sup>Required</sup> <a name="creationStack" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.property.creationStack"></a>

```typescript
public readonly creationStack: string[];
```

- *Type:* string[]

---

##### `logicalId`<sup>Required</sup> <a name="logicalId" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.property.logicalId"></a>

```typescript
public readonly logicalId: string;
```

- *Type:* string

The logical ID for this CloudFormation stack element.

The logical ID of the element
is calculated from the path of the resource node in the construct tree.

To override this value, use `overrideLogicalId(newLogicalId)`.

---

##### `stack`<sup>Required</sup> <a name="stack" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.property.stack"></a>

```typescript
public readonly stack: Stack;
```

- *Type:* aws-cdk-lib.Stack

The stack in which this element is defined.

CfnElements must be defined within a stack scope (directly or indirectly).

---

##### `ref`<sup>Required</sup> <a name="ref" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.

If, by any chance, the intrinsic reference of a resource is not a string, you could
coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.

---

##### `cfnOptions`<sup>Required</sup> <a name="cfnOptions" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.property.cfnOptions"></a>

```typescript
public readonly cfnOptions: ICfnResourceOptions;
```

- *Type:* aws-cdk-lib.ICfnResourceOptions

Options for this resource, such as condition, update policy etc.

---

##### `cfnResourceType`<sup>Required</sup> <a name="cfnResourceType" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.property.cfnResourceType"></a>

```typescript
public readonly cfnResourceType: string;
```

- *Type:* string

AWS resource type.

---

##### `attrAwsPrivateEndpointMetaData`<sup>Required</sup> <a name="attrAwsPrivateEndpointMetaData" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.property.attrAwsPrivateEndpointMetaData"></a>

```typescript
public readonly attrAwsPrivateEndpointMetaData: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::ServerlessPrivateEndpoint.AwsPrivateEndpointMetaData`.

---

##### `attrEndpointServiceName`<sup>Required</sup> <a name="attrEndpointServiceName" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.property.attrEndpointServiceName"></a>

```typescript
public readonly attrEndpointServiceName: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::ServerlessPrivateEndpoint.EndpointServiceName`.

---

##### `attrErrorMessage`<sup>Required</sup> <a name="attrErrorMessage" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.property.attrErrorMessage"></a>

```typescript
public readonly attrErrorMessage: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::ServerlessPrivateEndpoint.ErrorMessage`.

---

##### `attrId`<sup>Required</sup> <a name="attrId" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.property.attrId"></a>

```typescript
public readonly attrId: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::ServerlessPrivateEndpoint.Id`.

---

##### `attrProviderName`<sup>Required</sup> <a name="attrProviderName" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.property.attrProviderName"></a>

```typescript
public readonly attrProviderName: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::ServerlessPrivateEndpoint.ProviderName`.

---

##### `attrStatus`<sup>Required</sup> <a name="attrStatus" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.property.attrStatus"></a>

```typescript
public readonly attrStatus: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::ServerlessPrivateEndpoint.Status`.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.property.props"></a>

```typescript
public readonly props: CfnServerlessPrivateEndpointProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpointProps">CfnServerlessPrivateEndpointProps</a>

Resource props.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.property.CFN_RESOURCE_TYPE_NAME">CFN_RESOURCE_TYPE_NAME</a></code> | <code>string</code> | The CloudFormation resource type name for this resource class. |

---

##### `CFN_RESOURCE_TYPE_NAME`<sup>Required</sup> <a name="CFN_RESOURCE_TYPE_NAME" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpoint.property.CFN_RESOURCE_TYPE_NAME"></a>

```typescript
public readonly CFN_RESOURCE_TYPE_NAME: string;
```

- *Type:* string

The CloudFormation resource type name for this resource class.

---

### CfnStreamConnection <a name="CfnStreamConnection" id="awscdk-resources-mongodbatlas.CfnStreamConnection"></a>

A CloudFormation `MongoDB::Atlas::StreamConnection`.

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.CfnStreamConnection.Initializer"></a>

```typescript
import { CfnStreamConnection } from 'awscdk-resources-mongodbatlas'

new CfnStreamConnection(scope: Construct, id: string, props: CfnStreamConnectionProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnection.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - scope in which this resource is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnection.Initializer.parameter.id">id</a></code> | <code>string</code> | - scoped id of the resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnection.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnectionProps">CfnStreamConnectionProps</a></code> | - resource properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.CfnStreamConnection.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

scope in which this resource is defined.

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnStreamConnection.Initializer.parameter.id"></a>

- *Type:* string

scoped id of the resource.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnStreamConnection.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnStreamConnectionProps">CfnStreamConnectionProps</a>

resource properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnection.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnection.overrideLogicalId">overrideLogicalId</a></code> | Overrides the auto-generated logical ID with a specific ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnection.addDeletionOverride">addDeletionOverride</a></code> | Syntactic sugar for `addOverride(path, undefined)`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnection.addDependency">addDependency</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnection.addDependsOn">addDependsOn</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnection.addMetadata">addMetadata</a></code> | Add a value to the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnection.addOverride">addOverride</a></code> | Adds an override to the synthesized CloudFormation resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnection.addPropertyDeletionOverride">addPropertyDeletionOverride</a></code> | Adds an override that deletes the value of a property from the resource definition. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnection.addPropertyOverride">addPropertyOverride</a></code> | Adds an override to a resource property. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnection.applyRemovalPolicy">applyRemovalPolicy</a></code> | Sets the deletion policy of the resource based on the removal policy specified. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnection.getAtt">getAtt</a></code> | Returns a token for an runtime attribute of this resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnection.getMetadata">getMetadata</a></code> | Retrieve a value value from the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnection.obtainDependencies">obtainDependencies</a></code> | Retrieves an array of resources this resource depends on. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnection.obtainResourceDependencies">obtainResourceDependencies</a></code> | Get a shallow copy of dependencies between this resource and other resources in the same stack. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnection.removeDependency">removeDependency</a></code> | Indicates that this resource no longer depends on another resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnection.replaceDependency">replaceDependency</a></code> | Replaces one dependency with another. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.CfnStreamConnection.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `overrideLogicalId` <a name="overrideLogicalId" id="awscdk-resources-mongodbatlas.CfnStreamConnection.overrideLogicalId"></a>

```typescript
public overrideLogicalId(newLogicalId: string): void
```

Overrides the auto-generated logical ID with a specific ID.

###### `newLogicalId`<sup>Required</sup> <a name="newLogicalId" id="awscdk-resources-mongodbatlas.CfnStreamConnection.overrideLogicalId.parameter.newLogicalId"></a>

- *Type:* string

The new logical ID to use for this stack element.

---

##### `addDeletionOverride` <a name="addDeletionOverride" id="awscdk-resources-mongodbatlas.CfnStreamConnection.addDeletionOverride"></a>

```typescript
public addDeletionOverride(path: string): void
```

Syntactic sugar for `addOverride(path, undefined)`.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnStreamConnection.addDeletionOverride.parameter.path"></a>

- *Type:* string

The path of the value to delete.

---

##### `addDependency` <a name="addDependency" id="awscdk-resources-mongodbatlas.CfnStreamConnection.addDependency"></a>

```typescript
public addDependency(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

This can be used for resources across stacks (or nested stack) boundaries
and the dependency will automatically be transferred to the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnStreamConnection.addDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### ~~`addDependsOn`~~ <a name="addDependsOn" id="awscdk-resources-mongodbatlas.CfnStreamConnection.addDependsOn"></a>

```typescript
public addDependsOn(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnStreamConnection.addDependsOn.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `addMetadata` <a name="addMetadata" id="awscdk-resources-mongodbatlas.CfnStreamConnection.addMetadata"></a>

```typescript
public addMetadata(key: string, value: any): void
```

Add a value to the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnStreamConnection.addMetadata.parameter.key"></a>

- *Type:* string

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnStreamConnection.addMetadata.parameter.value"></a>

- *Type:* any

---

##### `addOverride` <a name="addOverride" id="awscdk-resources-mongodbatlas.CfnStreamConnection.addOverride"></a>

```typescript
public addOverride(path: string, value: any): void
```

Adds an override to the synthesized CloudFormation resource.

To add a
property override, either use `addPropertyOverride` or prefix `path` with
"Properties." (i.e. `Properties.TopicName`).

If the override is nested, separate each nested level using a dot (.) in the path parameter.
If there is an array as part of the nesting, specify the index in the path.

To include a literal `.` in the property name, prefix with a `\`. In most
programming languages you will need to write this as `"\\."` because the
`\` itself will need to be escaped.

For example,
```typescript
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
```
would add the overrides
```json
"Properties": {
  "GlobalSecondaryIndexes": [
    {
      "Projection": {
        "NonKeyAttributes": [ "myattribute" ]
        ...
      }
      ...
    },
    {
      "ProjectionType": "INCLUDE"
      ...
    },
  ]
  ...
}
```

The `value` argument to `addOverride` will not be processed or translated
in any way. Pass raw JSON values in here with the correct capitalization
for CloudFormation. If you pass CDK classes or structs, they will be
rendered with lowercased key names, and CloudFormation will reject the
template.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnStreamConnection.addOverride.parameter.path"></a>

- *Type:* string

The path of the property, you can use dot notation to override values in complex types.

Any intermediate keys
will be created as needed.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnStreamConnection.addOverride.parameter.value"></a>

- *Type:* any

The value.

Could be primitive or complex.

---

##### `addPropertyDeletionOverride` <a name="addPropertyDeletionOverride" id="awscdk-resources-mongodbatlas.CfnStreamConnection.addPropertyDeletionOverride"></a>

```typescript
public addPropertyDeletionOverride(propertyPath: string): void
```

Adds an override that deletes the value of a property from the resource definition.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnStreamConnection.addPropertyDeletionOverride.parameter.propertyPath"></a>

- *Type:* string

The path to the property.

---

##### `addPropertyOverride` <a name="addPropertyOverride" id="awscdk-resources-mongodbatlas.CfnStreamConnection.addPropertyOverride"></a>

```typescript
public addPropertyOverride(propertyPath: string, value: any): void
```

Adds an override to a resource property.

Syntactic sugar for `addOverride("Properties.<...>", value)`.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnStreamConnection.addPropertyOverride.parameter.propertyPath"></a>

- *Type:* string

The path of the property.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnStreamConnection.addPropertyOverride.parameter.value"></a>

- *Type:* any

The value.

---

##### `applyRemovalPolicy` <a name="applyRemovalPolicy" id="awscdk-resources-mongodbatlas.CfnStreamConnection.applyRemovalPolicy"></a>

```typescript
public applyRemovalPolicy(policy?: RemovalPolicy, options?: RemovalPolicyOptions): void
```

Sets the deletion policy of the resource based on the removal policy specified.

The Removal Policy controls what happens to this resource when it stops
being managed by CloudFormation, either because you've removed it from the
CDK application or because you've made a change that requires the resource
to be replaced.

The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
cases, a snapshot can be taken of the resource prior to deletion
(`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
can be found in the following link:

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options)

###### `policy`<sup>Optional</sup> <a name="policy" id="awscdk-resources-mongodbatlas.CfnStreamConnection.applyRemovalPolicy.parameter.policy"></a>

- *Type:* aws-cdk-lib.RemovalPolicy

---

###### `options`<sup>Optional</sup> <a name="options" id="awscdk-resources-mongodbatlas.CfnStreamConnection.applyRemovalPolicy.parameter.options"></a>

- *Type:* aws-cdk-lib.RemovalPolicyOptions

---

##### `getAtt` <a name="getAtt" id="awscdk-resources-mongodbatlas.CfnStreamConnection.getAtt"></a>

```typescript
public getAtt(attributeName: string, typeHint?: ResolutionTypeHint): Reference
```

Returns a token for an runtime attribute of this resource.

Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
in case there is no generated attribute.

###### `attributeName`<sup>Required</sup> <a name="attributeName" id="awscdk-resources-mongodbatlas.CfnStreamConnection.getAtt.parameter.attributeName"></a>

- *Type:* string

The name of the attribute.

---

###### `typeHint`<sup>Optional</sup> <a name="typeHint" id="awscdk-resources-mongodbatlas.CfnStreamConnection.getAtt.parameter.typeHint"></a>

- *Type:* aws-cdk-lib.ResolutionTypeHint

---

##### `getMetadata` <a name="getMetadata" id="awscdk-resources-mongodbatlas.CfnStreamConnection.getMetadata"></a>

```typescript
public getMetadata(key: string): any
```

Retrieve a value value from the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnStreamConnection.getMetadata.parameter.key"></a>

- *Type:* string

---

##### `obtainDependencies` <a name="obtainDependencies" id="awscdk-resources-mongodbatlas.CfnStreamConnection.obtainDependencies"></a>

```typescript
public obtainDependencies(): Stack | CfnResource[]
```

Retrieves an array of resources this resource depends on.

This assembles dependencies on resources across stacks (including nested stacks)
automatically.

##### `obtainResourceDependencies` <a name="obtainResourceDependencies" id="awscdk-resources-mongodbatlas.CfnStreamConnection.obtainResourceDependencies"></a>

```typescript
public obtainResourceDependencies(): CfnResource[]
```

Get a shallow copy of dependencies between this resource and other resources in the same stack.

##### `removeDependency` <a name="removeDependency" id="awscdk-resources-mongodbatlas.CfnStreamConnection.removeDependency"></a>

```typescript
public removeDependency(target: CfnResource): void
```

Indicates that this resource no longer depends on another resource.

This can be used for resources across stacks (including nested stacks)
and the dependency will automatically be removed from the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnStreamConnection.removeDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `replaceDependency` <a name="replaceDependency" id="awscdk-resources-mongodbatlas.CfnStreamConnection.replaceDependency"></a>

```typescript
public replaceDependency(target: CfnResource, newTarget: CfnResource): void
```

Replaces one dependency with another.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnStreamConnection.replaceDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

The dependency to replace.

---

###### `newTarget`<sup>Required</sup> <a name="newTarget" id="awscdk-resources-mongodbatlas.CfnStreamConnection.replaceDependency.parameter.newTarget"></a>

- *Type:* aws-cdk-lib.CfnResource

The new dependency to add.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnection.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnection.isCfnElement">isCfnElement</a></code> | Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnection.isCfnResource">isCfnResource</a></code> | Check whether the given construct is a CfnResource. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.CfnStreamConnection.isConstruct"></a>

```typescript
import { CfnStreamConnection } from 'awscdk-resources-mongodbatlas'

CfnStreamConnection.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnStreamConnection.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `isCfnElement` <a name="isCfnElement" id="awscdk-resources-mongodbatlas.CfnStreamConnection.isCfnElement"></a>

```typescript
import { CfnStreamConnection } from 'awscdk-resources-mongodbatlas'

CfnStreamConnection.isCfnElement(x: any)
```

Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).

Uses duck-typing instead of `instanceof` to allow stack elements from different
versions of this library to be included in the same stack.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnStreamConnection.isCfnElement.parameter.x"></a>

- *Type:* any

---

##### `isCfnResource` <a name="isCfnResource" id="awscdk-resources-mongodbatlas.CfnStreamConnection.isCfnResource"></a>

```typescript
import { CfnStreamConnection } from 'awscdk-resources-mongodbatlas'

CfnStreamConnection.isCfnResource(construct: IConstruct)
```

Check whether the given construct is a CfnResource.

###### `construct`<sup>Required</sup> <a name="construct" id="awscdk-resources-mongodbatlas.CfnStreamConnection.isCfnResource.parameter.construct"></a>

- *Type:* constructs.IConstruct

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnection.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnection.property.creationStack">creationStack</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnection.property.logicalId">logicalId</a></code> | <code>string</code> | The logical ID for this CloudFormation stack element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnection.property.stack">stack</a></code> | <code>aws-cdk-lib.Stack</code> | The stack in which this element is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnection.property.ref">ref</a></code> | <code>string</code> | Return a string that will be resolved to a CloudFormation `{ Ref }` for this element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnection.property.cfnOptions">cfnOptions</a></code> | <code>aws-cdk-lib.ICfnResourceOptions</code> | Options for this resource, such as condition, update policy etc. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnection.property.cfnResourceType">cfnResourceType</a></code> | <code>string</code> | AWS resource type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnection.property.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnectionProps">CfnStreamConnectionProps</a></code> | Resource props. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.CfnStreamConnection.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `creationStack`<sup>Required</sup> <a name="creationStack" id="awscdk-resources-mongodbatlas.CfnStreamConnection.property.creationStack"></a>

```typescript
public readonly creationStack: string[];
```

- *Type:* string[]

---

##### `logicalId`<sup>Required</sup> <a name="logicalId" id="awscdk-resources-mongodbatlas.CfnStreamConnection.property.logicalId"></a>

```typescript
public readonly logicalId: string;
```

- *Type:* string

The logical ID for this CloudFormation stack element.

The logical ID of the element
is calculated from the path of the resource node in the construct tree.

To override this value, use `overrideLogicalId(newLogicalId)`.

---

##### `stack`<sup>Required</sup> <a name="stack" id="awscdk-resources-mongodbatlas.CfnStreamConnection.property.stack"></a>

```typescript
public readonly stack: Stack;
```

- *Type:* aws-cdk-lib.Stack

The stack in which this element is defined.

CfnElements must be defined within a stack scope (directly or indirectly).

---

##### `ref`<sup>Required</sup> <a name="ref" id="awscdk-resources-mongodbatlas.CfnStreamConnection.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.

If, by any chance, the intrinsic reference of a resource is not a string, you could
coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.

---

##### `cfnOptions`<sup>Required</sup> <a name="cfnOptions" id="awscdk-resources-mongodbatlas.CfnStreamConnection.property.cfnOptions"></a>

```typescript
public readonly cfnOptions: ICfnResourceOptions;
```

- *Type:* aws-cdk-lib.ICfnResourceOptions

Options for this resource, such as condition, update policy etc.

---

##### `cfnResourceType`<sup>Required</sup> <a name="cfnResourceType" id="awscdk-resources-mongodbatlas.CfnStreamConnection.property.cfnResourceType"></a>

```typescript
public readonly cfnResourceType: string;
```

- *Type:* string

AWS resource type.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnStreamConnection.property.props"></a>

```typescript
public readonly props: CfnStreamConnectionProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnStreamConnectionProps">CfnStreamConnectionProps</a>

Resource props.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnection.property.CFN_RESOURCE_TYPE_NAME">CFN_RESOURCE_TYPE_NAME</a></code> | <code>string</code> | The CloudFormation resource type name for this resource class. |

---

##### `CFN_RESOURCE_TYPE_NAME`<sup>Required</sup> <a name="CFN_RESOURCE_TYPE_NAME" id="awscdk-resources-mongodbatlas.CfnStreamConnection.property.CFN_RESOURCE_TYPE_NAME"></a>

```typescript
public readonly CFN_RESOURCE_TYPE_NAME: string;
```

- *Type:* string

The CloudFormation resource type name for this resource class.

---

### CfnStreamInstance <a name="CfnStreamInstance" id="awscdk-resources-mongodbatlas.CfnStreamInstance"></a>

A CloudFormation `MongoDB::Atlas::StreamInstance`.

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.CfnStreamInstance.Initializer"></a>

```typescript
import { CfnStreamInstance } from 'awscdk-resources-mongodbatlas'

new CfnStreamInstance(scope: Construct, id: string, props: CfnStreamInstanceProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamInstance.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - scope in which this resource is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamInstance.Initializer.parameter.id">id</a></code> | <code>string</code> | - scoped id of the resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamInstance.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnStreamInstanceProps">CfnStreamInstanceProps</a></code> | - resource properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.CfnStreamInstance.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

scope in which this resource is defined.

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnStreamInstance.Initializer.parameter.id"></a>

- *Type:* string

scoped id of the resource.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnStreamInstance.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnStreamInstanceProps">CfnStreamInstanceProps</a>

resource properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamInstance.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamInstance.overrideLogicalId">overrideLogicalId</a></code> | Overrides the auto-generated logical ID with a specific ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamInstance.addDeletionOverride">addDeletionOverride</a></code> | Syntactic sugar for `addOverride(path, undefined)`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamInstance.addDependency">addDependency</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamInstance.addDependsOn">addDependsOn</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamInstance.addMetadata">addMetadata</a></code> | Add a value to the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamInstance.addOverride">addOverride</a></code> | Adds an override to the synthesized CloudFormation resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamInstance.addPropertyDeletionOverride">addPropertyDeletionOverride</a></code> | Adds an override that deletes the value of a property from the resource definition. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamInstance.addPropertyOverride">addPropertyOverride</a></code> | Adds an override to a resource property. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamInstance.applyRemovalPolicy">applyRemovalPolicy</a></code> | Sets the deletion policy of the resource based on the removal policy specified. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamInstance.getAtt">getAtt</a></code> | Returns a token for an runtime attribute of this resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamInstance.getMetadata">getMetadata</a></code> | Retrieve a value value from the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamInstance.obtainDependencies">obtainDependencies</a></code> | Retrieves an array of resources this resource depends on. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamInstance.obtainResourceDependencies">obtainResourceDependencies</a></code> | Get a shallow copy of dependencies between this resource and other resources in the same stack. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamInstance.removeDependency">removeDependency</a></code> | Indicates that this resource no longer depends on another resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamInstance.replaceDependency">replaceDependency</a></code> | Replaces one dependency with another. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.CfnStreamInstance.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `overrideLogicalId` <a name="overrideLogicalId" id="awscdk-resources-mongodbatlas.CfnStreamInstance.overrideLogicalId"></a>

```typescript
public overrideLogicalId(newLogicalId: string): void
```

Overrides the auto-generated logical ID with a specific ID.

###### `newLogicalId`<sup>Required</sup> <a name="newLogicalId" id="awscdk-resources-mongodbatlas.CfnStreamInstance.overrideLogicalId.parameter.newLogicalId"></a>

- *Type:* string

The new logical ID to use for this stack element.

---

##### `addDeletionOverride` <a name="addDeletionOverride" id="awscdk-resources-mongodbatlas.CfnStreamInstance.addDeletionOverride"></a>

```typescript
public addDeletionOverride(path: string): void
```

Syntactic sugar for `addOverride(path, undefined)`.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnStreamInstance.addDeletionOverride.parameter.path"></a>

- *Type:* string

The path of the value to delete.

---

##### `addDependency` <a name="addDependency" id="awscdk-resources-mongodbatlas.CfnStreamInstance.addDependency"></a>

```typescript
public addDependency(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

This can be used for resources across stacks (or nested stack) boundaries
and the dependency will automatically be transferred to the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnStreamInstance.addDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### ~~`addDependsOn`~~ <a name="addDependsOn" id="awscdk-resources-mongodbatlas.CfnStreamInstance.addDependsOn"></a>

```typescript
public addDependsOn(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnStreamInstance.addDependsOn.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `addMetadata` <a name="addMetadata" id="awscdk-resources-mongodbatlas.CfnStreamInstance.addMetadata"></a>

```typescript
public addMetadata(key: string, value: any): void
```

Add a value to the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnStreamInstance.addMetadata.parameter.key"></a>

- *Type:* string

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnStreamInstance.addMetadata.parameter.value"></a>

- *Type:* any

---

##### `addOverride` <a name="addOverride" id="awscdk-resources-mongodbatlas.CfnStreamInstance.addOverride"></a>

```typescript
public addOverride(path: string, value: any): void
```

Adds an override to the synthesized CloudFormation resource.

To add a
property override, either use `addPropertyOverride` or prefix `path` with
"Properties." (i.e. `Properties.TopicName`).

If the override is nested, separate each nested level using a dot (.) in the path parameter.
If there is an array as part of the nesting, specify the index in the path.

To include a literal `.` in the property name, prefix with a `\`. In most
programming languages you will need to write this as `"\\."` because the
`\` itself will need to be escaped.

For example,
```typescript
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
```
would add the overrides
```json
"Properties": {
  "GlobalSecondaryIndexes": [
    {
      "Projection": {
        "NonKeyAttributes": [ "myattribute" ]
        ...
      }
      ...
    },
    {
      "ProjectionType": "INCLUDE"
      ...
    },
  ]
  ...
}
```

The `value` argument to `addOverride` will not be processed or translated
in any way. Pass raw JSON values in here with the correct capitalization
for CloudFormation. If you pass CDK classes or structs, they will be
rendered with lowercased key names, and CloudFormation will reject the
template.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnStreamInstance.addOverride.parameter.path"></a>

- *Type:* string

The path of the property, you can use dot notation to override values in complex types.

Any intermediate keys
will be created as needed.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnStreamInstance.addOverride.parameter.value"></a>

- *Type:* any

The value.

Could be primitive or complex.

---

##### `addPropertyDeletionOverride` <a name="addPropertyDeletionOverride" id="awscdk-resources-mongodbatlas.CfnStreamInstance.addPropertyDeletionOverride"></a>

```typescript
public addPropertyDeletionOverride(propertyPath: string): void
```

Adds an override that deletes the value of a property from the resource definition.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnStreamInstance.addPropertyDeletionOverride.parameter.propertyPath"></a>

- *Type:* string

The path to the property.

---

##### `addPropertyOverride` <a name="addPropertyOverride" id="awscdk-resources-mongodbatlas.CfnStreamInstance.addPropertyOverride"></a>

```typescript
public addPropertyOverride(propertyPath: string, value: any): void
```

Adds an override to a resource property.

Syntactic sugar for `addOverride("Properties.<...>", value)`.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnStreamInstance.addPropertyOverride.parameter.propertyPath"></a>

- *Type:* string

The path of the property.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnStreamInstance.addPropertyOverride.parameter.value"></a>

- *Type:* any

The value.

---

##### `applyRemovalPolicy` <a name="applyRemovalPolicy" id="awscdk-resources-mongodbatlas.CfnStreamInstance.applyRemovalPolicy"></a>

```typescript
public applyRemovalPolicy(policy?: RemovalPolicy, options?: RemovalPolicyOptions): void
```

Sets the deletion policy of the resource based on the removal policy specified.

The Removal Policy controls what happens to this resource when it stops
being managed by CloudFormation, either because you've removed it from the
CDK application or because you've made a change that requires the resource
to be replaced.

The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
cases, a snapshot can be taken of the resource prior to deletion
(`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
can be found in the following link:

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options)

###### `policy`<sup>Optional</sup> <a name="policy" id="awscdk-resources-mongodbatlas.CfnStreamInstance.applyRemovalPolicy.parameter.policy"></a>

- *Type:* aws-cdk-lib.RemovalPolicy

---

###### `options`<sup>Optional</sup> <a name="options" id="awscdk-resources-mongodbatlas.CfnStreamInstance.applyRemovalPolicy.parameter.options"></a>

- *Type:* aws-cdk-lib.RemovalPolicyOptions

---

##### `getAtt` <a name="getAtt" id="awscdk-resources-mongodbatlas.CfnStreamInstance.getAtt"></a>

```typescript
public getAtt(attributeName: string, typeHint?: ResolutionTypeHint): Reference
```

Returns a token for an runtime attribute of this resource.

Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
in case there is no generated attribute.

###### `attributeName`<sup>Required</sup> <a name="attributeName" id="awscdk-resources-mongodbatlas.CfnStreamInstance.getAtt.parameter.attributeName"></a>

- *Type:* string

The name of the attribute.

---

###### `typeHint`<sup>Optional</sup> <a name="typeHint" id="awscdk-resources-mongodbatlas.CfnStreamInstance.getAtt.parameter.typeHint"></a>

- *Type:* aws-cdk-lib.ResolutionTypeHint

---

##### `getMetadata` <a name="getMetadata" id="awscdk-resources-mongodbatlas.CfnStreamInstance.getMetadata"></a>

```typescript
public getMetadata(key: string): any
```

Retrieve a value value from the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnStreamInstance.getMetadata.parameter.key"></a>

- *Type:* string

---

##### `obtainDependencies` <a name="obtainDependencies" id="awscdk-resources-mongodbatlas.CfnStreamInstance.obtainDependencies"></a>

```typescript
public obtainDependencies(): Stack | CfnResource[]
```

Retrieves an array of resources this resource depends on.

This assembles dependencies on resources across stacks (including nested stacks)
automatically.

##### `obtainResourceDependencies` <a name="obtainResourceDependencies" id="awscdk-resources-mongodbatlas.CfnStreamInstance.obtainResourceDependencies"></a>

```typescript
public obtainResourceDependencies(): CfnResource[]
```

Get a shallow copy of dependencies between this resource and other resources in the same stack.

##### `removeDependency` <a name="removeDependency" id="awscdk-resources-mongodbatlas.CfnStreamInstance.removeDependency"></a>

```typescript
public removeDependency(target: CfnResource): void
```

Indicates that this resource no longer depends on another resource.

This can be used for resources across stacks (including nested stacks)
and the dependency will automatically be removed from the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnStreamInstance.removeDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `replaceDependency` <a name="replaceDependency" id="awscdk-resources-mongodbatlas.CfnStreamInstance.replaceDependency"></a>

```typescript
public replaceDependency(target: CfnResource, newTarget: CfnResource): void
```

Replaces one dependency with another.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnStreamInstance.replaceDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

The dependency to replace.

---

###### `newTarget`<sup>Required</sup> <a name="newTarget" id="awscdk-resources-mongodbatlas.CfnStreamInstance.replaceDependency.parameter.newTarget"></a>

- *Type:* aws-cdk-lib.CfnResource

The new dependency to add.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamInstance.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamInstance.isCfnElement">isCfnElement</a></code> | Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamInstance.isCfnResource">isCfnResource</a></code> | Check whether the given construct is a CfnResource. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.CfnStreamInstance.isConstruct"></a>

```typescript
import { CfnStreamInstance } from 'awscdk-resources-mongodbatlas'

CfnStreamInstance.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnStreamInstance.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `isCfnElement` <a name="isCfnElement" id="awscdk-resources-mongodbatlas.CfnStreamInstance.isCfnElement"></a>

```typescript
import { CfnStreamInstance } from 'awscdk-resources-mongodbatlas'

CfnStreamInstance.isCfnElement(x: any)
```

Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).

Uses duck-typing instead of `instanceof` to allow stack elements from different
versions of this library to be included in the same stack.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnStreamInstance.isCfnElement.parameter.x"></a>

- *Type:* any

---

##### `isCfnResource` <a name="isCfnResource" id="awscdk-resources-mongodbatlas.CfnStreamInstance.isCfnResource"></a>

```typescript
import { CfnStreamInstance } from 'awscdk-resources-mongodbatlas'

CfnStreamInstance.isCfnResource(construct: IConstruct)
```

Check whether the given construct is a CfnResource.

###### `construct`<sup>Required</sup> <a name="construct" id="awscdk-resources-mongodbatlas.CfnStreamInstance.isCfnResource.parameter.construct"></a>

- *Type:* constructs.IConstruct

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamInstance.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamInstance.property.creationStack">creationStack</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamInstance.property.logicalId">logicalId</a></code> | <code>string</code> | The logical ID for this CloudFormation stack element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamInstance.property.stack">stack</a></code> | <code>aws-cdk-lib.Stack</code> | The stack in which this element is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamInstance.property.ref">ref</a></code> | <code>string</code> | Return a string that will be resolved to a CloudFormation `{ Ref }` for this element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamInstance.property.cfnOptions">cfnOptions</a></code> | <code>aws-cdk-lib.ICfnResourceOptions</code> | Options for this resource, such as condition, update policy etc. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamInstance.property.cfnResourceType">cfnResourceType</a></code> | <code>string</code> | AWS resource type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamInstance.property.attrHostnames">attrHostnames</a></code> | <code>string[]</code> | Attribute `MongoDB::Atlas::StreamInstance.Hostnames`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamInstance.property.attrId">attrId</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::StreamInstance.Id`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamInstance.property.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnStreamInstanceProps">CfnStreamInstanceProps</a></code> | Resource props. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.CfnStreamInstance.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `creationStack`<sup>Required</sup> <a name="creationStack" id="awscdk-resources-mongodbatlas.CfnStreamInstance.property.creationStack"></a>

```typescript
public readonly creationStack: string[];
```

- *Type:* string[]

---

##### `logicalId`<sup>Required</sup> <a name="logicalId" id="awscdk-resources-mongodbatlas.CfnStreamInstance.property.logicalId"></a>

```typescript
public readonly logicalId: string;
```

- *Type:* string

The logical ID for this CloudFormation stack element.

The logical ID of the element
is calculated from the path of the resource node in the construct tree.

To override this value, use `overrideLogicalId(newLogicalId)`.

---

##### `stack`<sup>Required</sup> <a name="stack" id="awscdk-resources-mongodbatlas.CfnStreamInstance.property.stack"></a>

```typescript
public readonly stack: Stack;
```

- *Type:* aws-cdk-lib.Stack

The stack in which this element is defined.

CfnElements must be defined within a stack scope (directly or indirectly).

---

##### `ref`<sup>Required</sup> <a name="ref" id="awscdk-resources-mongodbatlas.CfnStreamInstance.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.

If, by any chance, the intrinsic reference of a resource is not a string, you could
coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.

---

##### `cfnOptions`<sup>Required</sup> <a name="cfnOptions" id="awscdk-resources-mongodbatlas.CfnStreamInstance.property.cfnOptions"></a>

```typescript
public readonly cfnOptions: ICfnResourceOptions;
```

- *Type:* aws-cdk-lib.ICfnResourceOptions

Options for this resource, such as condition, update policy etc.

---

##### `cfnResourceType`<sup>Required</sup> <a name="cfnResourceType" id="awscdk-resources-mongodbatlas.CfnStreamInstance.property.cfnResourceType"></a>

```typescript
public readonly cfnResourceType: string;
```

- *Type:* string

AWS resource type.

---

##### `attrHostnames`<sup>Required</sup> <a name="attrHostnames" id="awscdk-resources-mongodbatlas.CfnStreamInstance.property.attrHostnames"></a>

```typescript
public readonly attrHostnames: string[];
```

- *Type:* string[]

Attribute `MongoDB::Atlas::StreamInstance.Hostnames`.

---

##### `attrId`<sup>Required</sup> <a name="attrId" id="awscdk-resources-mongodbatlas.CfnStreamInstance.property.attrId"></a>

```typescript
public readonly attrId: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::StreamInstance.Id`.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnStreamInstance.property.props"></a>

```typescript
public readonly props: CfnStreamInstanceProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnStreamInstanceProps">CfnStreamInstanceProps</a>

Resource props.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamInstance.property.CFN_RESOURCE_TYPE_NAME">CFN_RESOURCE_TYPE_NAME</a></code> | <code>string</code> | The CloudFormation resource type name for this resource class. |

---

##### `CFN_RESOURCE_TYPE_NAME`<sup>Required</sup> <a name="CFN_RESOURCE_TYPE_NAME" id="awscdk-resources-mongodbatlas.CfnStreamInstance.property.CFN_RESOURCE_TYPE_NAME"></a>

```typescript
public readonly CFN_RESOURCE_TYPE_NAME: string;
```

- *Type:* string

The CloudFormation resource type name for this resource class.

---

### CfnTeams <a name="CfnTeams" id="awscdk-resources-mongodbatlas.CfnTeams"></a>

A CloudFormation `MongoDB::Atlas::Teams`.

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.CfnTeams.Initializer"></a>

```typescript
import { CfnTeams } from 'awscdk-resources-mongodbatlas'

new CfnTeams(scope: Construct, id: string, props: CfnTeamsProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTeams.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - scope in which this resource is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTeams.Initializer.parameter.id">id</a></code> | <code>string</code> | - scoped id of the resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTeams.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnTeamsProps">CfnTeamsProps</a></code> | - resource properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.CfnTeams.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

scope in which this resource is defined.

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnTeams.Initializer.parameter.id"></a>

- *Type:* string

scoped id of the resource.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnTeams.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnTeamsProps">CfnTeamsProps</a>

resource properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTeams.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTeams.overrideLogicalId">overrideLogicalId</a></code> | Overrides the auto-generated logical ID with a specific ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTeams.addDeletionOverride">addDeletionOverride</a></code> | Syntactic sugar for `addOverride(path, undefined)`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTeams.addDependency">addDependency</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTeams.addDependsOn">addDependsOn</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTeams.addMetadata">addMetadata</a></code> | Add a value to the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTeams.addOverride">addOverride</a></code> | Adds an override to the synthesized CloudFormation resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTeams.addPropertyDeletionOverride">addPropertyDeletionOverride</a></code> | Adds an override that deletes the value of a property from the resource definition. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTeams.addPropertyOverride">addPropertyOverride</a></code> | Adds an override to a resource property. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTeams.applyRemovalPolicy">applyRemovalPolicy</a></code> | Sets the deletion policy of the resource based on the removal policy specified. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTeams.getAtt">getAtt</a></code> | Returns a token for an runtime attribute of this resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTeams.getMetadata">getMetadata</a></code> | Retrieve a value value from the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTeams.obtainDependencies">obtainDependencies</a></code> | Retrieves an array of resources this resource depends on. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTeams.obtainResourceDependencies">obtainResourceDependencies</a></code> | Get a shallow copy of dependencies between this resource and other resources in the same stack. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTeams.removeDependency">removeDependency</a></code> | Indicates that this resource no longer depends on another resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTeams.replaceDependency">replaceDependency</a></code> | Replaces one dependency with another. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.CfnTeams.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `overrideLogicalId` <a name="overrideLogicalId" id="awscdk-resources-mongodbatlas.CfnTeams.overrideLogicalId"></a>

```typescript
public overrideLogicalId(newLogicalId: string): void
```

Overrides the auto-generated logical ID with a specific ID.

###### `newLogicalId`<sup>Required</sup> <a name="newLogicalId" id="awscdk-resources-mongodbatlas.CfnTeams.overrideLogicalId.parameter.newLogicalId"></a>

- *Type:* string

The new logical ID to use for this stack element.

---

##### `addDeletionOverride` <a name="addDeletionOverride" id="awscdk-resources-mongodbatlas.CfnTeams.addDeletionOverride"></a>

```typescript
public addDeletionOverride(path: string): void
```

Syntactic sugar for `addOverride(path, undefined)`.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnTeams.addDeletionOverride.parameter.path"></a>

- *Type:* string

The path of the value to delete.

---

##### `addDependency` <a name="addDependency" id="awscdk-resources-mongodbatlas.CfnTeams.addDependency"></a>

```typescript
public addDependency(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

This can be used for resources across stacks (or nested stack) boundaries
and the dependency will automatically be transferred to the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnTeams.addDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### ~~`addDependsOn`~~ <a name="addDependsOn" id="awscdk-resources-mongodbatlas.CfnTeams.addDependsOn"></a>

```typescript
public addDependsOn(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnTeams.addDependsOn.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `addMetadata` <a name="addMetadata" id="awscdk-resources-mongodbatlas.CfnTeams.addMetadata"></a>

```typescript
public addMetadata(key: string, value: any): void
```

Add a value to the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnTeams.addMetadata.parameter.key"></a>

- *Type:* string

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnTeams.addMetadata.parameter.value"></a>

- *Type:* any

---

##### `addOverride` <a name="addOverride" id="awscdk-resources-mongodbatlas.CfnTeams.addOverride"></a>

```typescript
public addOverride(path: string, value: any): void
```

Adds an override to the synthesized CloudFormation resource.

To add a
property override, either use `addPropertyOverride` or prefix `path` with
"Properties." (i.e. `Properties.TopicName`).

If the override is nested, separate each nested level using a dot (.) in the path parameter.
If there is an array as part of the nesting, specify the index in the path.

To include a literal `.` in the property name, prefix with a `\`. In most
programming languages you will need to write this as `"\\."` because the
`\` itself will need to be escaped.

For example,
```typescript
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
```
would add the overrides
```json
"Properties": {
  "GlobalSecondaryIndexes": [
    {
      "Projection": {
        "NonKeyAttributes": [ "myattribute" ]
        ...
      }
      ...
    },
    {
      "ProjectionType": "INCLUDE"
      ...
    },
  ]
  ...
}
```

The `value` argument to `addOverride` will not be processed or translated
in any way. Pass raw JSON values in here with the correct capitalization
for CloudFormation. If you pass CDK classes or structs, they will be
rendered with lowercased key names, and CloudFormation will reject the
template.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnTeams.addOverride.parameter.path"></a>

- *Type:* string

The path of the property, you can use dot notation to override values in complex types.

Any intermediate keys
will be created as needed.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnTeams.addOverride.parameter.value"></a>

- *Type:* any

The value.

Could be primitive or complex.

---

##### `addPropertyDeletionOverride` <a name="addPropertyDeletionOverride" id="awscdk-resources-mongodbatlas.CfnTeams.addPropertyDeletionOverride"></a>

```typescript
public addPropertyDeletionOverride(propertyPath: string): void
```

Adds an override that deletes the value of a property from the resource definition.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnTeams.addPropertyDeletionOverride.parameter.propertyPath"></a>

- *Type:* string

The path to the property.

---

##### `addPropertyOverride` <a name="addPropertyOverride" id="awscdk-resources-mongodbatlas.CfnTeams.addPropertyOverride"></a>

```typescript
public addPropertyOverride(propertyPath: string, value: any): void
```

Adds an override to a resource property.

Syntactic sugar for `addOverride("Properties.<...>", value)`.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnTeams.addPropertyOverride.parameter.propertyPath"></a>

- *Type:* string

The path of the property.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnTeams.addPropertyOverride.parameter.value"></a>

- *Type:* any

The value.

---

##### `applyRemovalPolicy` <a name="applyRemovalPolicy" id="awscdk-resources-mongodbatlas.CfnTeams.applyRemovalPolicy"></a>

```typescript
public applyRemovalPolicy(policy?: RemovalPolicy, options?: RemovalPolicyOptions): void
```

Sets the deletion policy of the resource based on the removal policy specified.

The Removal Policy controls what happens to this resource when it stops
being managed by CloudFormation, either because you've removed it from the
CDK application or because you've made a change that requires the resource
to be replaced.

The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
cases, a snapshot can be taken of the resource prior to deletion
(`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
can be found in the following link:

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options)

###### `policy`<sup>Optional</sup> <a name="policy" id="awscdk-resources-mongodbatlas.CfnTeams.applyRemovalPolicy.parameter.policy"></a>

- *Type:* aws-cdk-lib.RemovalPolicy

---

###### `options`<sup>Optional</sup> <a name="options" id="awscdk-resources-mongodbatlas.CfnTeams.applyRemovalPolicy.parameter.options"></a>

- *Type:* aws-cdk-lib.RemovalPolicyOptions

---

##### `getAtt` <a name="getAtt" id="awscdk-resources-mongodbatlas.CfnTeams.getAtt"></a>

```typescript
public getAtt(attributeName: string, typeHint?: ResolutionTypeHint): Reference
```

Returns a token for an runtime attribute of this resource.

Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
in case there is no generated attribute.

###### `attributeName`<sup>Required</sup> <a name="attributeName" id="awscdk-resources-mongodbatlas.CfnTeams.getAtt.parameter.attributeName"></a>

- *Type:* string

The name of the attribute.

---

###### `typeHint`<sup>Optional</sup> <a name="typeHint" id="awscdk-resources-mongodbatlas.CfnTeams.getAtt.parameter.typeHint"></a>

- *Type:* aws-cdk-lib.ResolutionTypeHint

---

##### `getMetadata` <a name="getMetadata" id="awscdk-resources-mongodbatlas.CfnTeams.getMetadata"></a>

```typescript
public getMetadata(key: string): any
```

Retrieve a value value from the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnTeams.getMetadata.parameter.key"></a>

- *Type:* string

---

##### `obtainDependencies` <a name="obtainDependencies" id="awscdk-resources-mongodbatlas.CfnTeams.obtainDependencies"></a>

```typescript
public obtainDependencies(): Stack | CfnResource[]
```

Retrieves an array of resources this resource depends on.

This assembles dependencies on resources across stacks (including nested stacks)
automatically.

##### `obtainResourceDependencies` <a name="obtainResourceDependencies" id="awscdk-resources-mongodbatlas.CfnTeams.obtainResourceDependencies"></a>

```typescript
public obtainResourceDependencies(): CfnResource[]
```

Get a shallow copy of dependencies between this resource and other resources in the same stack.

##### `removeDependency` <a name="removeDependency" id="awscdk-resources-mongodbatlas.CfnTeams.removeDependency"></a>

```typescript
public removeDependency(target: CfnResource): void
```

Indicates that this resource no longer depends on another resource.

This can be used for resources across stacks (including nested stacks)
and the dependency will automatically be removed from the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnTeams.removeDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `replaceDependency` <a name="replaceDependency" id="awscdk-resources-mongodbatlas.CfnTeams.replaceDependency"></a>

```typescript
public replaceDependency(target: CfnResource, newTarget: CfnResource): void
```

Replaces one dependency with another.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnTeams.replaceDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

The dependency to replace.

---

###### `newTarget`<sup>Required</sup> <a name="newTarget" id="awscdk-resources-mongodbatlas.CfnTeams.replaceDependency.parameter.newTarget"></a>

- *Type:* aws-cdk-lib.CfnResource

The new dependency to add.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTeams.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTeams.isCfnElement">isCfnElement</a></code> | Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTeams.isCfnResource">isCfnResource</a></code> | Check whether the given construct is a CfnResource. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.CfnTeams.isConstruct"></a>

```typescript
import { CfnTeams } from 'awscdk-resources-mongodbatlas'

CfnTeams.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnTeams.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `isCfnElement` <a name="isCfnElement" id="awscdk-resources-mongodbatlas.CfnTeams.isCfnElement"></a>

```typescript
import { CfnTeams } from 'awscdk-resources-mongodbatlas'

CfnTeams.isCfnElement(x: any)
```

Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).

Uses duck-typing instead of `instanceof` to allow stack elements from different
versions of this library to be included in the same stack.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnTeams.isCfnElement.parameter.x"></a>

- *Type:* any

---

##### `isCfnResource` <a name="isCfnResource" id="awscdk-resources-mongodbatlas.CfnTeams.isCfnResource"></a>

```typescript
import { CfnTeams } from 'awscdk-resources-mongodbatlas'

CfnTeams.isCfnResource(construct: IConstruct)
```

Check whether the given construct is a CfnResource.

###### `construct`<sup>Required</sup> <a name="construct" id="awscdk-resources-mongodbatlas.CfnTeams.isCfnResource.parameter.construct"></a>

- *Type:* constructs.IConstruct

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTeams.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTeams.property.creationStack">creationStack</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTeams.property.logicalId">logicalId</a></code> | <code>string</code> | The logical ID for this CloudFormation stack element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTeams.property.stack">stack</a></code> | <code>aws-cdk-lib.Stack</code> | The stack in which this element is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTeams.property.ref">ref</a></code> | <code>string</code> | Return a string that will be resolved to a CloudFormation `{ Ref }` for this element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTeams.property.cfnOptions">cfnOptions</a></code> | <code>aws-cdk-lib.ICfnResourceOptions</code> | Options for this resource, such as condition, update policy etc. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTeams.property.cfnResourceType">cfnResourceType</a></code> | <code>string</code> | AWS resource type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTeams.property.attrTeamId">attrTeamId</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::Teams.TeamId`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTeams.property.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnTeamsProps">CfnTeamsProps</a></code> | Resource props. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.CfnTeams.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `creationStack`<sup>Required</sup> <a name="creationStack" id="awscdk-resources-mongodbatlas.CfnTeams.property.creationStack"></a>

```typescript
public readonly creationStack: string[];
```

- *Type:* string[]

---

##### `logicalId`<sup>Required</sup> <a name="logicalId" id="awscdk-resources-mongodbatlas.CfnTeams.property.logicalId"></a>

```typescript
public readonly logicalId: string;
```

- *Type:* string

The logical ID for this CloudFormation stack element.

The logical ID of the element
is calculated from the path of the resource node in the construct tree.

To override this value, use `overrideLogicalId(newLogicalId)`.

---

##### `stack`<sup>Required</sup> <a name="stack" id="awscdk-resources-mongodbatlas.CfnTeams.property.stack"></a>

```typescript
public readonly stack: Stack;
```

- *Type:* aws-cdk-lib.Stack

The stack in which this element is defined.

CfnElements must be defined within a stack scope (directly or indirectly).

---

##### `ref`<sup>Required</sup> <a name="ref" id="awscdk-resources-mongodbatlas.CfnTeams.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.

If, by any chance, the intrinsic reference of a resource is not a string, you could
coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.

---

##### `cfnOptions`<sup>Required</sup> <a name="cfnOptions" id="awscdk-resources-mongodbatlas.CfnTeams.property.cfnOptions"></a>

```typescript
public readonly cfnOptions: ICfnResourceOptions;
```

- *Type:* aws-cdk-lib.ICfnResourceOptions

Options for this resource, such as condition, update policy etc.

---

##### `cfnResourceType`<sup>Required</sup> <a name="cfnResourceType" id="awscdk-resources-mongodbatlas.CfnTeams.property.cfnResourceType"></a>

```typescript
public readonly cfnResourceType: string;
```

- *Type:* string

AWS resource type.

---

##### `attrTeamId`<sup>Required</sup> <a name="attrTeamId" id="awscdk-resources-mongodbatlas.CfnTeams.property.attrTeamId"></a>

```typescript
public readonly attrTeamId: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::Teams.TeamId`.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnTeams.property.props"></a>

```typescript
public readonly props: CfnTeamsProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnTeamsProps">CfnTeamsProps</a>

Resource props.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTeams.property.CFN_RESOURCE_TYPE_NAME">CFN_RESOURCE_TYPE_NAME</a></code> | <code>string</code> | The CloudFormation resource type name for this resource class. |

---

##### `CFN_RESOURCE_TYPE_NAME`<sup>Required</sup> <a name="CFN_RESOURCE_TYPE_NAME" id="awscdk-resources-mongodbatlas.CfnTeams.property.CFN_RESOURCE_TYPE_NAME"></a>

```typescript
public readonly CFN_RESOURCE_TYPE_NAME: string;
```

- *Type:* string

The CloudFormation resource type name for this resource class.

---

### CfnThirdPartyIntegration <a name="CfnThirdPartyIntegration" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration"></a>

A CloudFormation `MongoDB::Atlas::ThirdPartyIntegration`.

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.Initializer"></a>

```typescript
import { CfnThirdPartyIntegration } from 'awscdk-resources-mongodbatlas'

new CfnThirdPartyIntegration(scope: Construct, id: string, props: CfnThirdPartyIntegrationProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - scope in which this resource is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.Initializer.parameter.id">id</a></code> | <code>string</code> | - scoped id of the resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationProps">CfnThirdPartyIntegrationProps</a></code> | - resource properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

scope in which this resource is defined.

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.Initializer.parameter.id"></a>

- *Type:* string

scoped id of the resource.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationProps">CfnThirdPartyIntegrationProps</a>

resource properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.overrideLogicalId">overrideLogicalId</a></code> | Overrides the auto-generated logical ID with a specific ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.addDeletionOverride">addDeletionOverride</a></code> | Syntactic sugar for `addOverride(path, undefined)`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.addDependency">addDependency</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.addDependsOn">addDependsOn</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.addMetadata">addMetadata</a></code> | Add a value to the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.addOverride">addOverride</a></code> | Adds an override to the synthesized CloudFormation resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.addPropertyDeletionOverride">addPropertyDeletionOverride</a></code> | Adds an override that deletes the value of a property from the resource definition. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.addPropertyOverride">addPropertyOverride</a></code> | Adds an override to a resource property. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.applyRemovalPolicy">applyRemovalPolicy</a></code> | Sets the deletion policy of the resource based on the removal policy specified. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.getAtt">getAtt</a></code> | Returns a token for an runtime attribute of this resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.getMetadata">getMetadata</a></code> | Retrieve a value value from the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.obtainDependencies">obtainDependencies</a></code> | Retrieves an array of resources this resource depends on. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.obtainResourceDependencies">obtainResourceDependencies</a></code> | Get a shallow copy of dependencies between this resource and other resources in the same stack. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.removeDependency">removeDependency</a></code> | Indicates that this resource no longer depends on another resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.replaceDependency">replaceDependency</a></code> | Replaces one dependency with another. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `overrideLogicalId` <a name="overrideLogicalId" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.overrideLogicalId"></a>

```typescript
public overrideLogicalId(newLogicalId: string): void
```

Overrides the auto-generated logical ID with a specific ID.

###### `newLogicalId`<sup>Required</sup> <a name="newLogicalId" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.overrideLogicalId.parameter.newLogicalId"></a>

- *Type:* string

The new logical ID to use for this stack element.

---

##### `addDeletionOverride` <a name="addDeletionOverride" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.addDeletionOverride"></a>

```typescript
public addDeletionOverride(path: string): void
```

Syntactic sugar for `addOverride(path, undefined)`.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.addDeletionOverride.parameter.path"></a>

- *Type:* string

The path of the value to delete.

---

##### `addDependency` <a name="addDependency" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.addDependency"></a>

```typescript
public addDependency(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

This can be used for resources across stacks (or nested stack) boundaries
and the dependency will automatically be transferred to the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.addDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### ~~`addDependsOn`~~ <a name="addDependsOn" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.addDependsOn"></a>

```typescript
public addDependsOn(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.addDependsOn.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `addMetadata` <a name="addMetadata" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.addMetadata"></a>

```typescript
public addMetadata(key: string, value: any): void
```

Add a value to the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.addMetadata.parameter.key"></a>

- *Type:* string

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.addMetadata.parameter.value"></a>

- *Type:* any

---

##### `addOverride` <a name="addOverride" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.addOverride"></a>

```typescript
public addOverride(path: string, value: any): void
```

Adds an override to the synthesized CloudFormation resource.

To add a
property override, either use `addPropertyOverride` or prefix `path` with
"Properties." (i.e. `Properties.TopicName`).

If the override is nested, separate each nested level using a dot (.) in the path parameter.
If there is an array as part of the nesting, specify the index in the path.

To include a literal `.` in the property name, prefix with a `\`. In most
programming languages you will need to write this as `"\\."` because the
`\` itself will need to be escaped.

For example,
```typescript
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
```
would add the overrides
```json
"Properties": {
  "GlobalSecondaryIndexes": [
    {
      "Projection": {
        "NonKeyAttributes": [ "myattribute" ]
        ...
      }
      ...
    },
    {
      "ProjectionType": "INCLUDE"
      ...
    },
  ]
  ...
}
```

The `value` argument to `addOverride` will not be processed or translated
in any way. Pass raw JSON values in here with the correct capitalization
for CloudFormation. If you pass CDK classes or structs, they will be
rendered with lowercased key names, and CloudFormation will reject the
template.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.addOverride.parameter.path"></a>

- *Type:* string

The path of the property, you can use dot notation to override values in complex types.

Any intermediate keys
will be created as needed.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.addOverride.parameter.value"></a>

- *Type:* any

The value.

Could be primitive or complex.

---

##### `addPropertyDeletionOverride` <a name="addPropertyDeletionOverride" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.addPropertyDeletionOverride"></a>

```typescript
public addPropertyDeletionOverride(propertyPath: string): void
```

Adds an override that deletes the value of a property from the resource definition.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.addPropertyDeletionOverride.parameter.propertyPath"></a>

- *Type:* string

The path to the property.

---

##### `addPropertyOverride` <a name="addPropertyOverride" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.addPropertyOverride"></a>

```typescript
public addPropertyOverride(propertyPath: string, value: any): void
```

Adds an override to a resource property.

Syntactic sugar for `addOverride("Properties.<...>", value)`.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.addPropertyOverride.parameter.propertyPath"></a>

- *Type:* string

The path of the property.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.addPropertyOverride.parameter.value"></a>

- *Type:* any

The value.

---

##### `applyRemovalPolicy` <a name="applyRemovalPolicy" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.applyRemovalPolicy"></a>

```typescript
public applyRemovalPolicy(policy?: RemovalPolicy, options?: RemovalPolicyOptions): void
```

Sets the deletion policy of the resource based on the removal policy specified.

The Removal Policy controls what happens to this resource when it stops
being managed by CloudFormation, either because you've removed it from the
CDK application or because you've made a change that requires the resource
to be replaced.

The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
cases, a snapshot can be taken of the resource prior to deletion
(`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
can be found in the following link:

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options)

###### `policy`<sup>Optional</sup> <a name="policy" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.applyRemovalPolicy.parameter.policy"></a>

- *Type:* aws-cdk-lib.RemovalPolicy

---

###### `options`<sup>Optional</sup> <a name="options" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.applyRemovalPolicy.parameter.options"></a>

- *Type:* aws-cdk-lib.RemovalPolicyOptions

---

##### `getAtt` <a name="getAtt" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.getAtt"></a>

```typescript
public getAtt(attributeName: string, typeHint?: ResolutionTypeHint): Reference
```

Returns a token for an runtime attribute of this resource.

Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
in case there is no generated attribute.

###### `attributeName`<sup>Required</sup> <a name="attributeName" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.getAtt.parameter.attributeName"></a>

- *Type:* string

The name of the attribute.

---

###### `typeHint`<sup>Optional</sup> <a name="typeHint" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.getAtt.parameter.typeHint"></a>

- *Type:* aws-cdk-lib.ResolutionTypeHint

---

##### `getMetadata` <a name="getMetadata" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.getMetadata"></a>

```typescript
public getMetadata(key: string): any
```

Retrieve a value value from the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.getMetadata.parameter.key"></a>

- *Type:* string

---

##### `obtainDependencies` <a name="obtainDependencies" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.obtainDependencies"></a>

```typescript
public obtainDependencies(): Stack | CfnResource[]
```

Retrieves an array of resources this resource depends on.

This assembles dependencies on resources across stacks (including nested stacks)
automatically.

##### `obtainResourceDependencies` <a name="obtainResourceDependencies" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.obtainResourceDependencies"></a>

```typescript
public obtainResourceDependencies(): CfnResource[]
```

Get a shallow copy of dependencies between this resource and other resources in the same stack.

##### `removeDependency` <a name="removeDependency" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.removeDependency"></a>

```typescript
public removeDependency(target: CfnResource): void
```

Indicates that this resource no longer depends on another resource.

This can be used for resources across stacks (including nested stacks)
and the dependency will automatically be removed from the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.removeDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `replaceDependency` <a name="replaceDependency" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.replaceDependency"></a>

```typescript
public replaceDependency(target: CfnResource, newTarget: CfnResource): void
```

Replaces one dependency with another.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.replaceDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

The dependency to replace.

---

###### `newTarget`<sup>Required</sup> <a name="newTarget" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.replaceDependency.parameter.newTarget"></a>

- *Type:* aws-cdk-lib.CfnResource

The new dependency to add.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.isCfnElement">isCfnElement</a></code> | Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.isCfnResource">isCfnResource</a></code> | Check whether the given construct is a CfnResource. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.isConstruct"></a>

```typescript
import { CfnThirdPartyIntegration } from 'awscdk-resources-mongodbatlas'

CfnThirdPartyIntegration.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `isCfnElement` <a name="isCfnElement" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.isCfnElement"></a>

```typescript
import { CfnThirdPartyIntegration } from 'awscdk-resources-mongodbatlas'

CfnThirdPartyIntegration.isCfnElement(x: any)
```

Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).

Uses duck-typing instead of `instanceof` to allow stack elements from different
versions of this library to be included in the same stack.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.isCfnElement.parameter.x"></a>

- *Type:* any

---

##### `isCfnResource` <a name="isCfnResource" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.isCfnResource"></a>

```typescript
import { CfnThirdPartyIntegration } from 'awscdk-resources-mongodbatlas'

CfnThirdPartyIntegration.isCfnResource(construct: IConstruct)
```

Check whether the given construct is a CfnResource.

###### `construct`<sup>Required</sup> <a name="construct" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.isCfnResource.parameter.construct"></a>

- *Type:* constructs.IConstruct

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.property.creationStack">creationStack</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.property.logicalId">logicalId</a></code> | <code>string</code> | The logical ID for this CloudFormation stack element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.property.stack">stack</a></code> | <code>aws-cdk-lib.Stack</code> | The stack in which this element is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.property.ref">ref</a></code> | <code>string</code> | Return a string that will be resolved to a CloudFormation `{ Ref }` for this element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.property.cfnOptions">cfnOptions</a></code> | <code>aws-cdk-lib.ICfnResourceOptions</code> | Options for this resource, such as condition, update policy etc. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.property.cfnResourceType">cfnResourceType</a></code> | <code>string</code> | AWS resource type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.property.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationProps">CfnThirdPartyIntegrationProps</a></code> | Resource props. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `creationStack`<sup>Required</sup> <a name="creationStack" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.property.creationStack"></a>

```typescript
public readonly creationStack: string[];
```

- *Type:* string[]

---

##### `logicalId`<sup>Required</sup> <a name="logicalId" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.property.logicalId"></a>

```typescript
public readonly logicalId: string;
```

- *Type:* string

The logical ID for this CloudFormation stack element.

The logical ID of the element
is calculated from the path of the resource node in the construct tree.

To override this value, use `overrideLogicalId(newLogicalId)`.

---

##### `stack`<sup>Required</sup> <a name="stack" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.property.stack"></a>

```typescript
public readonly stack: Stack;
```

- *Type:* aws-cdk-lib.Stack

The stack in which this element is defined.

CfnElements must be defined within a stack scope (directly or indirectly).

---

##### `ref`<sup>Required</sup> <a name="ref" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.

If, by any chance, the intrinsic reference of a resource is not a string, you could
coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.

---

##### `cfnOptions`<sup>Required</sup> <a name="cfnOptions" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.property.cfnOptions"></a>

```typescript
public readonly cfnOptions: ICfnResourceOptions;
```

- *Type:* aws-cdk-lib.ICfnResourceOptions

Options for this resource, such as condition, update policy etc.

---

##### `cfnResourceType`<sup>Required</sup> <a name="cfnResourceType" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.property.cfnResourceType"></a>

```typescript
public readonly cfnResourceType: string;
```

- *Type:* string

AWS resource type.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.property.props"></a>

```typescript
public readonly props: CfnThirdPartyIntegrationProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationProps">CfnThirdPartyIntegrationProps</a>

Resource props.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.property.CFN_RESOURCE_TYPE_NAME">CFN_RESOURCE_TYPE_NAME</a></code> | <code>string</code> | The CloudFormation resource type name for this resource class. |

---

##### `CFN_RESOURCE_TYPE_NAME`<sup>Required</sup> <a name="CFN_RESOURCE_TYPE_NAME" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegration.property.CFN_RESOURCE_TYPE_NAME"></a>

```typescript
public readonly CFN_RESOURCE_TYPE_NAME: string;
```

- *Type:* string

The CloudFormation resource type name for this resource class.

---

### CfnTrigger <a name="CfnTrigger" id="awscdk-resources-mongodbatlas.CfnTrigger"></a>

A CloudFormation `MongoDB::Atlas::Trigger`.

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.CfnTrigger.Initializer"></a>

```typescript
import { CfnTrigger } from 'awscdk-resources-mongodbatlas'

new CfnTrigger(scope: Construct, id: string, props: CfnTriggerProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTrigger.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - scope in which this resource is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTrigger.Initializer.parameter.id">id</a></code> | <code>string</code> | - scoped id of the resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTrigger.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnTriggerProps">CfnTriggerProps</a></code> | - resource properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.CfnTrigger.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

scope in which this resource is defined.

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnTrigger.Initializer.parameter.id"></a>

- *Type:* string

scoped id of the resource.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnTrigger.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnTriggerProps">CfnTriggerProps</a>

resource properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTrigger.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTrigger.overrideLogicalId">overrideLogicalId</a></code> | Overrides the auto-generated logical ID with a specific ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTrigger.addDeletionOverride">addDeletionOverride</a></code> | Syntactic sugar for `addOverride(path, undefined)`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTrigger.addDependency">addDependency</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTrigger.addDependsOn">addDependsOn</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTrigger.addMetadata">addMetadata</a></code> | Add a value to the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTrigger.addOverride">addOverride</a></code> | Adds an override to the synthesized CloudFormation resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTrigger.addPropertyDeletionOverride">addPropertyDeletionOverride</a></code> | Adds an override that deletes the value of a property from the resource definition. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTrigger.addPropertyOverride">addPropertyOverride</a></code> | Adds an override to a resource property. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTrigger.applyRemovalPolicy">applyRemovalPolicy</a></code> | Sets the deletion policy of the resource based on the removal policy specified. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTrigger.getAtt">getAtt</a></code> | Returns a token for an runtime attribute of this resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTrigger.getMetadata">getMetadata</a></code> | Retrieve a value value from the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTrigger.obtainDependencies">obtainDependencies</a></code> | Retrieves an array of resources this resource depends on. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTrigger.obtainResourceDependencies">obtainResourceDependencies</a></code> | Get a shallow copy of dependencies between this resource and other resources in the same stack. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTrigger.removeDependency">removeDependency</a></code> | Indicates that this resource no longer depends on another resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTrigger.replaceDependency">replaceDependency</a></code> | Replaces one dependency with another. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.CfnTrigger.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `overrideLogicalId` <a name="overrideLogicalId" id="awscdk-resources-mongodbatlas.CfnTrigger.overrideLogicalId"></a>

```typescript
public overrideLogicalId(newLogicalId: string): void
```

Overrides the auto-generated logical ID with a specific ID.

###### `newLogicalId`<sup>Required</sup> <a name="newLogicalId" id="awscdk-resources-mongodbatlas.CfnTrigger.overrideLogicalId.parameter.newLogicalId"></a>

- *Type:* string

The new logical ID to use for this stack element.

---

##### `addDeletionOverride` <a name="addDeletionOverride" id="awscdk-resources-mongodbatlas.CfnTrigger.addDeletionOverride"></a>

```typescript
public addDeletionOverride(path: string): void
```

Syntactic sugar for `addOverride(path, undefined)`.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnTrigger.addDeletionOverride.parameter.path"></a>

- *Type:* string

The path of the value to delete.

---

##### `addDependency` <a name="addDependency" id="awscdk-resources-mongodbatlas.CfnTrigger.addDependency"></a>

```typescript
public addDependency(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

This can be used for resources across stacks (or nested stack) boundaries
and the dependency will automatically be transferred to the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnTrigger.addDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### ~~`addDependsOn`~~ <a name="addDependsOn" id="awscdk-resources-mongodbatlas.CfnTrigger.addDependsOn"></a>

```typescript
public addDependsOn(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnTrigger.addDependsOn.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `addMetadata` <a name="addMetadata" id="awscdk-resources-mongodbatlas.CfnTrigger.addMetadata"></a>

```typescript
public addMetadata(key: string, value: any): void
```

Add a value to the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnTrigger.addMetadata.parameter.key"></a>

- *Type:* string

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnTrigger.addMetadata.parameter.value"></a>

- *Type:* any

---

##### `addOverride` <a name="addOverride" id="awscdk-resources-mongodbatlas.CfnTrigger.addOverride"></a>

```typescript
public addOverride(path: string, value: any): void
```

Adds an override to the synthesized CloudFormation resource.

To add a
property override, either use `addPropertyOverride` or prefix `path` with
"Properties." (i.e. `Properties.TopicName`).

If the override is nested, separate each nested level using a dot (.) in the path parameter.
If there is an array as part of the nesting, specify the index in the path.

To include a literal `.` in the property name, prefix with a `\`. In most
programming languages you will need to write this as `"\\."` because the
`\` itself will need to be escaped.

For example,
```typescript
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
```
would add the overrides
```json
"Properties": {
  "GlobalSecondaryIndexes": [
    {
      "Projection": {
        "NonKeyAttributes": [ "myattribute" ]
        ...
      }
      ...
    },
    {
      "ProjectionType": "INCLUDE"
      ...
    },
  ]
  ...
}
```

The `value` argument to `addOverride` will not be processed or translated
in any way. Pass raw JSON values in here with the correct capitalization
for CloudFormation. If you pass CDK classes or structs, they will be
rendered with lowercased key names, and CloudFormation will reject the
template.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnTrigger.addOverride.parameter.path"></a>

- *Type:* string

The path of the property, you can use dot notation to override values in complex types.

Any intermediate keys
will be created as needed.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnTrigger.addOverride.parameter.value"></a>

- *Type:* any

The value.

Could be primitive or complex.

---

##### `addPropertyDeletionOverride` <a name="addPropertyDeletionOverride" id="awscdk-resources-mongodbatlas.CfnTrigger.addPropertyDeletionOverride"></a>

```typescript
public addPropertyDeletionOverride(propertyPath: string): void
```

Adds an override that deletes the value of a property from the resource definition.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnTrigger.addPropertyDeletionOverride.parameter.propertyPath"></a>

- *Type:* string

The path to the property.

---

##### `addPropertyOverride` <a name="addPropertyOverride" id="awscdk-resources-mongodbatlas.CfnTrigger.addPropertyOverride"></a>

```typescript
public addPropertyOverride(propertyPath: string, value: any): void
```

Adds an override to a resource property.

Syntactic sugar for `addOverride("Properties.<...>", value)`.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnTrigger.addPropertyOverride.parameter.propertyPath"></a>

- *Type:* string

The path of the property.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnTrigger.addPropertyOverride.parameter.value"></a>

- *Type:* any

The value.

---

##### `applyRemovalPolicy` <a name="applyRemovalPolicy" id="awscdk-resources-mongodbatlas.CfnTrigger.applyRemovalPolicy"></a>

```typescript
public applyRemovalPolicy(policy?: RemovalPolicy, options?: RemovalPolicyOptions): void
```

Sets the deletion policy of the resource based on the removal policy specified.

The Removal Policy controls what happens to this resource when it stops
being managed by CloudFormation, either because you've removed it from the
CDK application or because you've made a change that requires the resource
to be replaced.

The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
cases, a snapshot can be taken of the resource prior to deletion
(`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
can be found in the following link:

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options)

###### `policy`<sup>Optional</sup> <a name="policy" id="awscdk-resources-mongodbatlas.CfnTrigger.applyRemovalPolicy.parameter.policy"></a>

- *Type:* aws-cdk-lib.RemovalPolicy

---

###### `options`<sup>Optional</sup> <a name="options" id="awscdk-resources-mongodbatlas.CfnTrigger.applyRemovalPolicy.parameter.options"></a>

- *Type:* aws-cdk-lib.RemovalPolicyOptions

---

##### `getAtt` <a name="getAtt" id="awscdk-resources-mongodbatlas.CfnTrigger.getAtt"></a>

```typescript
public getAtt(attributeName: string, typeHint?: ResolutionTypeHint): Reference
```

Returns a token for an runtime attribute of this resource.

Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
in case there is no generated attribute.

###### `attributeName`<sup>Required</sup> <a name="attributeName" id="awscdk-resources-mongodbatlas.CfnTrigger.getAtt.parameter.attributeName"></a>

- *Type:* string

The name of the attribute.

---

###### `typeHint`<sup>Optional</sup> <a name="typeHint" id="awscdk-resources-mongodbatlas.CfnTrigger.getAtt.parameter.typeHint"></a>

- *Type:* aws-cdk-lib.ResolutionTypeHint

---

##### `getMetadata` <a name="getMetadata" id="awscdk-resources-mongodbatlas.CfnTrigger.getMetadata"></a>

```typescript
public getMetadata(key: string): any
```

Retrieve a value value from the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnTrigger.getMetadata.parameter.key"></a>

- *Type:* string

---

##### `obtainDependencies` <a name="obtainDependencies" id="awscdk-resources-mongodbatlas.CfnTrigger.obtainDependencies"></a>

```typescript
public obtainDependencies(): Stack | CfnResource[]
```

Retrieves an array of resources this resource depends on.

This assembles dependencies on resources across stacks (including nested stacks)
automatically.

##### `obtainResourceDependencies` <a name="obtainResourceDependencies" id="awscdk-resources-mongodbatlas.CfnTrigger.obtainResourceDependencies"></a>

```typescript
public obtainResourceDependencies(): CfnResource[]
```

Get a shallow copy of dependencies between this resource and other resources in the same stack.

##### `removeDependency` <a name="removeDependency" id="awscdk-resources-mongodbatlas.CfnTrigger.removeDependency"></a>

```typescript
public removeDependency(target: CfnResource): void
```

Indicates that this resource no longer depends on another resource.

This can be used for resources across stacks (including nested stacks)
and the dependency will automatically be removed from the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnTrigger.removeDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `replaceDependency` <a name="replaceDependency" id="awscdk-resources-mongodbatlas.CfnTrigger.replaceDependency"></a>

```typescript
public replaceDependency(target: CfnResource, newTarget: CfnResource): void
```

Replaces one dependency with another.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnTrigger.replaceDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

The dependency to replace.

---

###### `newTarget`<sup>Required</sup> <a name="newTarget" id="awscdk-resources-mongodbatlas.CfnTrigger.replaceDependency.parameter.newTarget"></a>

- *Type:* aws-cdk-lib.CfnResource

The new dependency to add.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTrigger.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTrigger.isCfnElement">isCfnElement</a></code> | Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTrigger.isCfnResource">isCfnResource</a></code> | Check whether the given construct is a CfnResource. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.CfnTrigger.isConstruct"></a>

```typescript
import { CfnTrigger } from 'awscdk-resources-mongodbatlas'

CfnTrigger.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnTrigger.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `isCfnElement` <a name="isCfnElement" id="awscdk-resources-mongodbatlas.CfnTrigger.isCfnElement"></a>

```typescript
import { CfnTrigger } from 'awscdk-resources-mongodbatlas'

CfnTrigger.isCfnElement(x: any)
```

Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).

Uses duck-typing instead of `instanceof` to allow stack elements from different
versions of this library to be included in the same stack.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnTrigger.isCfnElement.parameter.x"></a>

- *Type:* any

---

##### `isCfnResource` <a name="isCfnResource" id="awscdk-resources-mongodbatlas.CfnTrigger.isCfnResource"></a>

```typescript
import { CfnTrigger } from 'awscdk-resources-mongodbatlas'

CfnTrigger.isCfnResource(construct: IConstruct)
```

Check whether the given construct is a CfnResource.

###### `construct`<sup>Required</sup> <a name="construct" id="awscdk-resources-mongodbatlas.CfnTrigger.isCfnResource.parameter.construct"></a>

- *Type:* constructs.IConstruct

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTrigger.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTrigger.property.creationStack">creationStack</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTrigger.property.logicalId">logicalId</a></code> | <code>string</code> | The logical ID for this CloudFormation stack element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTrigger.property.stack">stack</a></code> | <code>aws-cdk-lib.Stack</code> | The stack in which this element is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTrigger.property.ref">ref</a></code> | <code>string</code> | Return a string that will be resolved to a CloudFormation `{ Ref }` for this element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTrigger.property.cfnOptions">cfnOptions</a></code> | <code>aws-cdk-lib.ICfnResourceOptions</code> | Options for this resource, such as condition, update policy etc. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTrigger.property.cfnResourceType">cfnResourceType</a></code> | <code>string</code> | AWS resource type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTrigger.property.attrId">attrId</a></code> | <code>string</code> | Attribute `MongoDB::Atlas::Trigger.Id`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTrigger.property.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnTriggerProps">CfnTriggerProps</a></code> | Resource props. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.CfnTrigger.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `creationStack`<sup>Required</sup> <a name="creationStack" id="awscdk-resources-mongodbatlas.CfnTrigger.property.creationStack"></a>

```typescript
public readonly creationStack: string[];
```

- *Type:* string[]

---

##### `logicalId`<sup>Required</sup> <a name="logicalId" id="awscdk-resources-mongodbatlas.CfnTrigger.property.logicalId"></a>

```typescript
public readonly logicalId: string;
```

- *Type:* string

The logical ID for this CloudFormation stack element.

The logical ID of the element
is calculated from the path of the resource node in the construct tree.

To override this value, use `overrideLogicalId(newLogicalId)`.

---

##### `stack`<sup>Required</sup> <a name="stack" id="awscdk-resources-mongodbatlas.CfnTrigger.property.stack"></a>

```typescript
public readonly stack: Stack;
```

- *Type:* aws-cdk-lib.Stack

The stack in which this element is defined.

CfnElements must be defined within a stack scope (directly or indirectly).

---

##### `ref`<sup>Required</sup> <a name="ref" id="awscdk-resources-mongodbatlas.CfnTrigger.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.

If, by any chance, the intrinsic reference of a resource is not a string, you could
coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.

---

##### `cfnOptions`<sup>Required</sup> <a name="cfnOptions" id="awscdk-resources-mongodbatlas.CfnTrigger.property.cfnOptions"></a>

```typescript
public readonly cfnOptions: ICfnResourceOptions;
```

- *Type:* aws-cdk-lib.ICfnResourceOptions

Options for this resource, such as condition, update policy etc.

---

##### `cfnResourceType`<sup>Required</sup> <a name="cfnResourceType" id="awscdk-resources-mongodbatlas.CfnTrigger.property.cfnResourceType"></a>

```typescript
public readonly cfnResourceType: string;
```

- *Type:* string

AWS resource type.

---

##### `attrId`<sup>Required</sup> <a name="attrId" id="awscdk-resources-mongodbatlas.CfnTrigger.property.attrId"></a>

```typescript
public readonly attrId: string;
```

- *Type:* string

Attribute `MongoDB::Atlas::Trigger.Id`.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnTrigger.property.props"></a>

```typescript
public readonly props: CfnTriggerProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnTriggerProps">CfnTriggerProps</a>

Resource props.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTrigger.property.CFN_RESOURCE_TYPE_NAME">CFN_RESOURCE_TYPE_NAME</a></code> | <code>string</code> | The CloudFormation resource type name for this resource class. |

---

##### `CFN_RESOURCE_TYPE_NAME`<sup>Required</sup> <a name="CFN_RESOURCE_TYPE_NAME" id="awscdk-resources-mongodbatlas.CfnTrigger.property.CFN_RESOURCE_TYPE_NAME"></a>

```typescript
public readonly CFN_RESOURCE_TYPE_NAME: string;
```

- *Type:* string

The CloudFormation resource type name for this resource class.

---

### CfnX509AuthenticationDatabaseUser <a name="CfnX509AuthenticationDatabaseUser" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser"></a>

A CloudFormation `MongoDB::Atlas::X509AuthenticationDatabaseUser`.

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.Initializer"></a>

```typescript
import { CfnX509AuthenticationDatabaseUser } from 'awscdk-resources-mongodbatlas'

new CfnX509AuthenticationDatabaseUser(scope: Construct, id: string, props: CfnX509AuthenticationDatabaseUserProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - scope in which this resource is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.Initializer.parameter.id">id</a></code> | <code>string</code> | - scoped id of the resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUserProps">CfnX509AuthenticationDatabaseUserProps</a></code> | - resource properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

scope in which this resource is defined.

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.Initializer.parameter.id"></a>

- *Type:* string

scoped id of the resource.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUserProps">CfnX509AuthenticationDatabaseUserProps</a>

resource properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.overrideLogicalId">overrideLogicalId</a></code> | Overrides the auto-generated logical ID with a specific ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.addDeletionOverride">addDeletionOverride</a></code> | Syntactic sugar for `addOverride(path, undefined)`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.addDependency">addDependency</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.addDependsOn">addDependsOn</a></code> | Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.addMetadata">addMetadata</a></code> | Add a value to the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.addOverride">addOverride</a></code> | Adds an override to the synthesized CloudFormation resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.addPropertyDeletionOverride">addPropertyDeletionOverride</a></code> | Adds an override that deletes the value of a property from the resource definition. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.addPropertyOverride">addPropertyOverride</a></code> | Adds an override to a resource property. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.applyRemovalPolicy">applyRemovalPolicy</a></code> | Sets the deletion policy of the resource based on the removal policy specified. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.getAtt">getAtt</a></code> | Returns a token for an runtime attribute of this resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.getMetadata">getMetadata</a></code> | Retrieve a value value from the CloudFormation Resource Metadata. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.obtainDependencies">obtainDependencies</a></code> | Retrieves an array of resources this resource depends on. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.obtainResourceDependencies">obtainResourceDependencies</a></code> | Get a shallow copy of dependencies between this resource and other resources in the same stack. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.removeDependency">removeDependency</a></code> | Indicates that this resource no longer depends on another resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.replaceDependency">replaceDependency</a></code> | Replaces one dependency with another. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `overrideLogicalId` <a name="overrideLogicalId" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.overrideLogicalId"></a>

```typescript
public overrideLogicalId(newLogicalId: string): void
```

Overrides the auto-generated logical ID with a specific ID.

###### `newLogicalId`<sup>Required</sup> <a name="newLogicalId" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.overrideLogicalId.parameter.newLogicalId"></a>

- *Type:* string

The new logical ID to use for this stack element.

---

##### `addDeletionOverride` <a name="addDeletionOverride" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.addDeletionOverride"></a>

```typescript
public addDeletionOverride(path: string): void
```

Syntactic sugar for `addOverride(path, undefined)`.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.addDeletionOverride.parameter.path"></a>

- *Type:* string

The path of the value to delete.

---

##### `addDependency` <a name="addDependency" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.addDependency"></a>

```typescript
public addDependency(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

This can be used for resources across stacks (or nested stack) boundaries
and the dependency will automatically be transferred to the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.addDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### ~~`addDependsOn`~~ <a name="addDependsOn" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.addDependsOn"></a>

```typescript
public addDependsOn(target: CfnResource): void
```

Indicates that this resource depends on another resource and cannot be provisioned unless the other resource has been successfully provisioned.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.addDependsOn.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `addMetadata` <a name="addMetadata" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.addMetadata"></a>

```typescript
public addMetadata(key: string, value: any): void
```

Add a value to the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.addMetadata.parameter.key"></a>

- *Type:* string

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.addMetadata.parameter.value"></a>

- *Type:* any

---

##### `addOverride` <a name="addOverride" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.addOverride"></a>

```typescript
public addOverride(path: string, value: any): void
```

Adds an override to the synthesized CloudFormation resource.

To add a
property override, either use `addPropertyOverride` or prefix `path` with
"Properties." (i.e. `Properties.TopicName`).

If the override is nested, separate each nested level using a dot (.) in the path parameter.
If there is an array as part of the nesting, specify the index in the path.

To include a literal `.` in the property name, prefix with a `\`. In most
programming languages you will need to write this as `"\\."` because the
`\` itself will need to be escaped.

For example,
```typescript
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.0.Projection.NonKeyAttributes', ['myattribute']);
cfnResource.addOverride('Properties.GlobalSecondaryIndexes.1.ProjectionType', 'INCLUDE');
```
would add the overrides
```json
"Properties": {
  "GlobalSecondaryIndexes": [
    {
      "Projection": {
        "NonKeyAttributes": [ "myattribute" ]
        ...
      }
      ...
    },
    {
      "ProjectionType": "INCLUDE"
      ...
    },
  ]
  ...
}
```

The `value` argument to `addOverride` will not be processed or translated
in any way. Pass raw JSON values in here with the correct capitalization
for CloudFormation. If you pass CDK classes or structs, they will be
rendered with lowercased key names, and CloudFormation will reject the
template.

###### `path`<sup>Required</sup> <a name="path" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.addOverride.parameter.path"></a>

- *Type:* string

The path of the property, you can use dot notation to override values in complex types.

Any intermediate keys
will be created as needed.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.addOverride.parameter.value"></a>

- *Type:* any

The value.

Could be primitive or complex.

---

##### `addPropertyDeletionOverride` <a name="addPropertyDeletionOverride" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.addPropertyDeletionOverride"></a>

```typescript
public addPropertyDeletionOverride(propertyPath: string): void
```

Adds an override that deletes the value of a property from the resource definition.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.addPropertyDeletionOverride.parameter.propertyPath"></a>

- *Type:* string

The path to the property.

---

##### `addPropertyOverride` <a name="addPropertyOverride" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.addPropertyOverride"></a>

```typescript
public addPropertyOverride(propertyPath: string, value: any): void
```

Adds an override to a resource property.

Syntactic sugar for `addOverride("Properties.<...>", value)`.

###### `propertyPath`<sup>Required</sup> <a name="propertyPath" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.addPropertyOverride.parameter.propertyPath"></a>

- *Type:* string

The path of the property.

---

###### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.addPropertyOverride.parameter.value"></a>

- *Type:* any

The value.

---

##### `applyRemovalPolicy` <a name="applyRemovalPolicy" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.applyRemovalPolicy"></a>

```typescript
public applyRemovalPolicy(policy?: RemovalPolicy, options?: RemovalPolicyOptions): void
```

Sets the deletion policy of the resource based on the removal policy specified.

The Removal Policy controls what happens to this resource when it stops
being managed by CloudFormation, either because you've removed it from the
CDK application or because you've made a change that requires the resource
to be replaced.

The resource can be deleted (`RemovalPolicy.DESTROY`), or left in your AWS
account for data recovery and cleanup later (`RemovalPolicy.RETAIN`). In some
cases, a snapshot can be taken of the resource prior to deletion
(`RemovalPolicy.SNAPSHOT`). A list of resources that support this policy
can be found in the following link:

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html#aws-attribute-deletionpolicy-options)

###### `policy`<sup>Optional</sup> <a name="policy" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.applyRemovalPolicy.parameter.policy"></a>

- *Type:* aws-cdk-lib.RemovalPolicy

---

###### `options`<sup>Optional</sup> <a name="options" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.applyRemovalPolicy.parameter.options"></a>

- *Type:* aws-cdk-lib.RemovalPolicyOptions

---

##### `getAtt` <a name="getAtt" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.getAtt"></a>

```typescript
public getAtt(attributeName: string, typeHint?: ResolutionTypeHint): Reference
```

Returns a token for an runtime attribute of this resource.

Ideally, use generated attribute accessors (e.g. `resource.arn`), but this can be used for future compatibility
in case there is no generated attribute.

###### `attributeName`<sup>Required</sup> <a name="attributeName" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.getAtt.parameter.attributeName"></a>

- *Type:* string

The name of the attribute.

---

###### `typeHint`<sup>Optional</sup> <a name="typeHint" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.getAtt.parameter.typeHint"></a>

- *Type:* aws-cdk-lib.ResolutionTypeHint

---

##### `getMetadata` <a name="getMetadata" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.getMetadata"></a>

```typescript
public getMetadata(key: string): any
```

Retrieve a value value from the CloudFormation Resource Metadata.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/metadata-section-structure.html

Note that this is a different set of metadata from CDK node metadata; this
metadata ends up in the stack template under the resource, whereas CDK
node metadata ends up in the Cloud Assembly.)

###### `key`<sup>Required</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.getMetadata.parameter.key"></a>

- *Type:* string

---

##### `obtainDependencies` <a name="obtainDependencies" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.obtainDependencies"></a>

```typescript
public obtainDependencies(): Stack | CfnResource[]
```

Retrieves an array of resources this resource depends on.

This assembles dependencies on resources across stacks (including nested stacks)
automatically.

##### `obtainResourceDependencies` <a name="obtainResourceDependencies" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.obtainResourceDependencies"></a>

```typescript
public obtainResourceDependencies(): CfnResource[]
```

Get a shallow copy of dependencies between this resource and other resources in the same stack.

##### `removeDependency` <a name="removeDependency" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.removeDependency"></a>

```typescript
public removeDependency(target: CfnResource): void
```

Indicates that this resource no longer depends on another resource.

This can be used for resources across stacks (including nested stacks)
and the dependency will automatically be removed from the relevant scope.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.removeDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

---

##### `replaceDependency` <a name="replaceDependency" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.replaceDependency"></a>

```typescript
public replaceDependency(target: CfnResource, newTarget: CfnResource): void
```

Replaces one dependency with another.

###### `target`<sup>Required</sup> <a name="target" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.replaceDependency.parameter.target"></a>

- *Type:* aws-cdk-lib.CfnResource

The dependency to replace.

---

###### `newTarget`<sup>Required</sup> <a name="newTarget" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.replaceDependency.parameter.newTarget"></a>

- *Type:* aws-cdk-lib.CfnResource

The new dependency to add.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.isCfnElement">isCfnElement</a></code> | Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.isCfnResource">isCfnResource</a></code> | Check whether the given construct is a CfnResource. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.isConstruct"></a>

```typescript
import { CfnX509AuthenticationDatabaseUser } from 'awscdk-resources-mongodbatlas'

CfnX509AuthenticationDatabaseUser.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

##### `isCfnElement` <a name="isCfnElement" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.isCfnElement"></a>

```typescript
import { CfnX509AuthenticationDatabaseUser } from 'awscdk-resources-mongodbatlas'

CfnX509AuthenticationDatabaseUser.isCfnElement(x: any)
```

Returns `true` if a construct is a stack element (i.e. part of the synthesized cloudformation template).

Uses duck-typing instead of `instanceof` to allow stack elements from different
versions of this library to be included in the same stack.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.isCfnElement.parameter.x"></a>

- *Type:* any

---

##### `isCfnResource` <a name="isCfnResource" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.isCfnResource"></a>

```typescript
import { CfnX509AuthenticationDatabaseUser } from 'awscdk-resources-mongodbatlas'

CfnX509AuthenticationDatabaseUser.isCfnResource(construct: IConstruct)
```

Check whether the given construct is a CfnResource.

###### `construct`<sup>Required</sup> <a name="construct" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.isCfnResource.parameter.construct"></a>

- *Type:* constructs.IConstruct

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.property.creationStack">creationStack</a></code> | <code>string[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.property.logicalId">logicalId</a></code> | <code>string</code> | The logical ID for this CloudFormation stack element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.property.stack">stack</a></code> | <code>aws-cdk-lib.Stack</code> | The stack in which this element is defined. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.property.ref">ref</a></code> | <code>string</code> | Return a string that will be resolved to a CloudFormation `{ Ref }` for this element. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.property.cfnOptions">cfnOptions</a></code> | <code>aws-cdk-lib.ICfnResourceOptions</code> | Options for this resource, such as condition, update policy etc. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.property.cfnResourceType">cfnResourceType</a></code> | <code>string</code> | AWS resource type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.property.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUserProps">CfnX509AuthenticationDatabaseUserProps</a></code> | Resource props. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `creationStack`<sup>Required</sup> <a name="creationStack" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.property.creationStack"></a>

```typescript
public readonly creationStack: string[];
```

- *Type:* string[]

---

##### `logicalId`<sup>Required</sup> <a name="logicalId" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.property.logicalId"></a>

```typescript
public readonly logicalId: string;
```

- *Type:* string

The logical ID for this CloudFormation stack element.

The logical ID of the element
is calculated from the path of the resource node in the construct tree.

To override this value, use `overrideLogicalId(newLogicalId)`.

---

##### `stack`<sup>Required</sup> <a name="stack" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.property.stack"></a>

```typescript
public readonly stack: Stack;
```

- *Type:* aws-cdk-lib.Stack

The stack in which this element is defined.

CfnElements must be defined within a stack scope (directly or indirectly).

---

##### `ref`<sup>Required</sup> <a name="ref" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.property.ref"></a>

```typescript
public readonly ref: string;
```

- *Type:* string

Return a string that will be resolved to a CloudFormation `{ Ref }` for this element.

If, by any chance, the intrinsic reference of a resource is not a string, you could
coerce it to an IResolvable through `Lazy.any({ produce: resource.ref })`.

---

##### `cfnOptions`<sup>Required</sup> <a name="cfnOptions" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.property.cfnOptions"></a>

```typescript
public readonly cfnOptions: ICfnResourceOptions;
```

- *Type:* aws-cdk-lib.ICfnResourceOptions

Options for this resource, such as condition, update policy etc.

---

##### `cfnResourceType`<sup>Required</sup> <a name="cfnResourceType" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.property.cfnResourceType"></a>

```typescript
public readonly cfnResourceType: string;
```

- *Type:* string

AWS resource type.

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.property.props"></a>

```typescript
public readonly props: CfnX509AuthenticationDatabaseUserProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUserProps">CfnX509AuthenticationDatabaseUserProps</a>

Resource props.

---

#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.property.CFN_RESOURCE_TYPE_NAME">CFN_RESOURCE_TYPE_NAME</a></code> | <code>string</code> | The CloudFormation resource type name for this resource class. |

---

##### `CFN_RESOURCE_TYPE_NAME`<sup>Required</sup> <a name="CFN_RESOURCE_TYPE_NAME" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUser.property.CFN_RESOURCE_TYPE_NAME"></a>

```typescript
public readonly CFN_RESOURCE_TYPE_NAME: string;
```

- *Type:* string

The CloudFormation resource type name for this resource class.

---

### DatadogIntegration <a name="DatadogIntegration" id="awscdk-resources-mongodbatlas.DatadogIntegration"></a>

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.DatadogIntegration.Initializer"></a>

```typescript
import { DatadogIntegration } from 'awscdk-resources-mongodbatlas'

new DatadogIntegration(scope: Construct, id: string, props: DatadogIntegrationProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.DatadogIntegration.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.DatadogIntegration.Initializer.parameter.id">id</a></code> | <code>string</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.DatadogIntegration.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.DatadogIntegrationProps">DatadogIntegrationProps</a></code> | *No description.* |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.DatadogIntegration.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.DatadogIntegration.Initializer.parameter.id"></a>

- *Type:* string

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.DatadogIntegration.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.DatadogIntegrationProps">DatadogIntegrationProps</a>

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.DatadogIntegration.toString">toString</a></code> | Returns a string representation of this construct. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.DatadogIntegration.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.DatadogIntegration.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.DatadogIntegration.isConstruct"></a>

```typescript
import { DatadogIntegration } from 'awscdk-resources-mongodbatlas'

DatadogIntegration.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.DatadogIntegration.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.DatadogIntegration.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.DatadogIntegration.property.cfnThirdPartyIntegration">cfnThirdPartyIntegration</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegration">CfnThirdPartyIntegration</a></code> | *No description.* |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.DatadogIntegration.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `cfnThirdPartyIntegration`<sup>Required</sup> <a name="cfnThirdPartyIntegration" id="awscdk-resources-mongodbatlas.DatadogIntegration.property.cfnThirdPartyIntegration"></a>

```typescript
public readonly cfnThirdPartyIntegration: CfnThirdPartyIntegration;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegration">CfnThirdPartyIntegration</a>

---


### MicrosoftTeamsIntegration <a name="MicrosoftTeamsIntegration" id="awscdk-resources-mongodbatlas.MicrosoftTeamsIntegration"></a>

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.MicrosoftTeamsIntegration.Initializer"></a>

```typescript
import { MicrosoftTeamsIntegration } from 'awscdk-resources-mongodbatlas'

new MicrosoftTeamsIntegration(scope: Construct, id: string, props: MicrosoftTeamsIntegrationProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.MicrosoftTeamsIntegration.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.MicrosoftTeamsIntegration.Initializer.parameter.id">id</a></code> | <code>string</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.MicrosoftTeamsIntegration.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.MicrosoftTeamsIntegrationProps">MicrosoftTeamsIntegrationProps</a></code> | *No description.* |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.MicrosoftTeamsIntegration.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.MicrosoftTeamsIntegration.Initializer.parameter.id"></a>

- *Type:* string

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.MicrosoftTeamsIntegration.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.MicrosoftTeamsIntegrationProps">MicrosoftTeamsIntegrationProps</a>

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.MicrosoftTeamsIntegration.toString">toString</a></code> | Returns a string representation of this construct. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.MicrosoftTeamsIntegration.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.MicrosoftTeamsIntegration.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.MicrosoftTeamsIntegration.isConstruct"></a>

```typescript
import { MicrosoftTeamsIntegration } from 'awscdk-resources-mongodbatlas'

MicrosoftTeamsIntegration.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.MicrosoftTeamsIntegration.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.MicrosoftTeamsIntegration.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.MicrosoftTeamsIntegration.property.cfnThirdPartyIntegration">cfnThirdPartyIntegration</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegration">CfnThirdPartyIntegration</a></code> | *No description.* |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.MicrosoftTeamsIntegration.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `cfnThirdPartyIntegration`<sup>Required</sup> <a name="cfnThirdPartyIntegration" id="awscdk-resources-mongodbatlas.MicrosoftTeamsIntegration.property.cfnThirdPartyIntegration"></a>

```typescript
public readonly cfnThirdPartyIntegration: CfnThirdPartyIntegration;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegration">CfnThirdPartyIntegration</a>

---


### MongoAtlasBootstrap <a name="MongoAtlasBootstrap" id="awscdk-resources-mongodbatlas.MongoAtlasBootstrap"></a>

Generate the CFN extension execution role.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/registry-public.html](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/registry-public.html)

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.MongoAtlasBootstrap.Initializer"></a>

```typescript
import { MongoAtlasBootstrap } from 'awscdk-resources-mongodbatlas'

new MongoAtlasBootstrap(scope: Construct, id: string, props?: MongoAtlasBootstrapProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.MongoAtlasBootstrap.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.MongoAtlasBootstrap.Initializer.parameter.id">id</a></code> | <code>string</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.MongoAtlasBootstrap.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.MongoAtlasBootstrapProps">MongoAtlasBootstrapProps</a></code> | *No description.* |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.MongoAtlasBootstrap.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.MongoAtlasBootstrap.Initializer.parameter.id"></a>

- *Type:* string

---

##### `props`<sup>Optional</sup> <a name="props" id="awscdk-resources-mongodbatlas.MongoAtlasBootstrap.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.MongoAtlasBootstrapProps">MongoAtlasBootstrapProps</a>

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.MongoAtlasBootstrap.toString">toString</a></code> | Returns a string representation of this construct. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.MongoAtlasBootstrap.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.MongoAtlasBootstrap.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.MongoAtlasBootstrap.isConstruct"></a>

```typescript
import { MongoAtlasBootstrap } from 'awscdk-resources-mongodbatlas'

MongoAtlasBootstrap.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.MongoAtlasBootstrap.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.MongoAtlasBootstrap.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.MongoAtlasBootstrap.property.role">role</a></code> | <code>aws-cdk-lib.aws_iam.IRole</code> | *No description.* |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.MongoAtlasBootstrap.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `role`<sup>Required</sup> <a name="role" id="awscdk-resources-mongodbatlas.MongoAtlasBootstrap.property.role"></a>

```typescript
public readonly role: IRole;
```

- *Type:* aws-cdk-lib.aws_iam.IRole

---


### MongoSecretProfile <a name="MongoSecretProfile" id="awscdk-resources-mongodbatlas.MongoSecretProfile"></a>

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.MongoSecretProfile.Initializer"></a>

```typescript
import { MongoSecretProfile } from 'awscdk-resources-mongodbatlas'

new MongoSecretProfile(scope: Construct, id: string, profileName: string)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.MongoSecretProfile.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.MongoSecretProfile.Initializer.parameter.id">id</a></code> | <code>string</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.MongoSecretProfile.Initializer.parameter.profileName">profileName</a></code> | <code>string</code> | *No description.* |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.MongoSecretProfile.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.MongoSecretProfile.Initializer.parameter.id"></a>

- *Type:* string

---

##### `profileName`<sup>Required</sup> <a name="profileName" id="awscdk-resources-mongodbatlas.MongoSecretProfile.Initializer.parameter.profileName"></a>

- *Type:* string

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.MongoSecretProfile.toString">toString</a></code> | Returns a string representation of this construct. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.MongoSecretProfile.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.MongoSecretProfile.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.MongoSecretProfile.isConstruct"></a>

```typescript
import { MongoSecretProfile } from 'awscdk-resources-mongodbatlas'

MongoSecretProfile.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.MongoSecretProfile.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.MongoSecretProfile.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.MongoSecretProfile.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---


### PagerDutyIntegration <a name="PagerDutyIntegration" id="awscdk-resources-mongodbatlas.PagerDutyIntegration"></a>

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.PagerDutyIntegration.Initializer"></a>

```typescript
import { PagerDutyIntegration } from 'awscdk-resources-mongodbatlas'

new PagerDutyIntegration(scope: Construct, id: string, props: PagerDutyIntegrationProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.PagerDutyIntegration.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.PagerDutyIntegration.Initializer.parameter.id">id</a></code> | <code>string</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.PagerDutyIntegration.Initializer.parameter.props">props</a></code> | <code><a href="#awscdk-resources-mongodbatlas.PagerDutyIntegrationProps">PagerDutyIntegrationProps</a></code> | *No description.* |

---

##### `scope`<sup>Required</sup> <a name="scope" id="awscdk-resources-mongodbatlas.PagerDutyIntegration.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

---

##### `id`<sup>Required</sup> <a name="id" id="awscdk-resources-mongodbatlas.PagerDutyIntegration.Initializer.parameter.id"></a>

- *Type:* string

---

##### `props`<sup>Required</sup> <a name="props" id="awscdk-resources-mongodbatlas.PagerDutyIntegration.Initializer.parameter.props"></a>

- *Type:* <a href="#awscdk-resources-mongodbatlas.PagerDutyIntegrationProps">PagerDutyIntegrationProps</a>

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.PagerDutyIntegration.toString">toString</a></code> | Returns a string representation of this construct. |

---

##### `toString` <a name="toString" id="awscdk-resources-mongodbatlas.PagerDutyIntegration.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.PagerDutyIntegration.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="awscdk-resources-mongodbatlas.PagerDutyIntegration.isConstruct"></a>

```typescript
import { PagerDutyIntegration } from 'awscdk-resources-mongodbatlas'

PagerDutyIntegration.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="awscdk-resources-mongodbatlas.PagerDutyIntegration.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.PagerDutyIntegration.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#awscdk-resources-mongodbatlas.PagerDutyIntegration.property.cfnThirdPartyIntegration">cfnThirdPartyIntegration</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegration">CfnThirdPartyIntegration</a></code> | *No description.* |

---

##### `node`<sup>Required</sup> <a name="node" id="awscdk-resources-mongodbatlas.PagerDutyIntegration.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `cfnThirdPartyIntegration`<sup>Required</sup> <a name="cfnThirdPartyIntegration" id="awscdk-resources-mongodbatlas.PagerDutyIntegration.property.cfnThirdPartyIntegration"></a>

```typescript
public readonly cfnThirdPartyIntegration: CfnThirdPartyIntegration;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegration">CfnThirdPartyIntegration</a>

---


## Structs <a name="Structs" id="Structs"></a>

### AccessListDefinition <a name="AccessListDefinition" id="awscdk-resources-mongodbatlas.AccessListDefinition"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.AccessListDefinition.Initializer"></a>

```typescript
import { AccessListDefinition } from 'awscdk-resources-mongodbatlas'

const accessListDefinition: AccessListDefinition = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.AccessListDefinition.property.awsSecurityGroup">awsSecurityGroup</a></code> | <code>string</code> | Unique string of the Amazon Web Services (AWS) security group that you want to add to the project's IP access list. |
| <code><a href="#awscdk-resources-mongodbatlas.AccessListDefinition.property.cidrBlock">cidrBlock</a></code> | <code>string</code> | Range of IP addresses in Classless Inter-Domain Routing (CIDR) notation that you want to add to the project's IP access list. |
| <code><a href="#awscdk-resources-mongodbatlas.AccessListDefinition.property.comment">comment</a></code> | <code>string</code> | Remark that explains the purpose or scope of this IP access list entry. |
| <code><a href="#awscdk-resources-mongodbatlas.AccessListDefinition.property.deleteAfterDate">deleteAfterDate</a></code> | <code>string</code> | Date and time after which MongoDB Cloud deletes the temporary access list entry. |
| <code><a href="#awscdk-resources-mongodbatlas.AccessListDefinition.property.ipAddress">ipAddress</a></code> | <code>string</code> | IP address that you want to add to the project's IP access list. |
| <code><a href="#awscdk-resources-mongodbatlas.AccessListDefinition.property.projectId">projectId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies your project. |

---

##### `awsSecurityGroup`<sup>Optional</sup> <a name="awsSecurityGroup" id="awscdk-resources-mongodbatlas.AccessListDefinition.property.awsSecurityGroup"></a>

```typescript
public readonly awsSecurityGroup: string;
```

- *Type:* string

Unique string of the Amazon Web Services (AWS) security group that you want to add to the project's IP access list.

Your IP access list entry can be one awsSecurityGroup, one cidrBlock, or one ipAddress. You must configure Virtual Private Connection (VPC) peering for your project before you can add an AWS security group to an IP access list. You cannot set AWS security groups as temporary access list entries. Don't set this parameter if you set cidrBlock or ipAddress.

---

##### `cidrBlock`<sup>Optional</sup> <a name="cidrBlock" id="awscdk-resources-mongodbatlas.AccessListDefinition.property.cidrBlock"></a>

```typescript
public readonly cidrBlock: string;
```

- *Type:* string

Range of IP addresses in Classless Inter-Domain Routing (CIDR) notation that you want to add to the project's IP access list.

Your IP access list entry can be one awsSecurityGroup, one cidrBlock, or one ipAddress. Don't set this parameter if you set awsSecurityGroup or ipAddress

---

##### `comment`<sup>Optional</sup> <a name="comment" id="awscdk-resources-mongodbatlas.AccessListDefinition.property.comment"></a>

```typescript
public readonly comment: string;
```

- *Type:* string

Remark that explains the purpose or scope of this IP access list entry.

---

##### `deleteAfterDate`<sup>Optional</sup> <a name="deleteAfterDate" id="awscdk-resources-mongodbatlas.AccessListDefinition.property.deleteAfterDate"></a>

```typescript
public readonly deleteAfterDate: string;
```

- *Type:* string

Date and time after which MongoDB Cloud deletes the temporary access list entry.

This parameter expresses its value in the ISO 8601 timestamp format in UTC and can include the time zone designation. The date must be later than the current date but no later than one week after you submit this request. The resource returns this parameter if you specified an expiration date when creating this IP access list entry.

---

##### `ipAddress`<sup>Optional</sup> <a name="ipAddress" id="awscdk-resources-mongodbatlas.AccessListDefinition.property.ipAddress"></a>

```typescript
public readonly ipAddress: string;
```

- *Type:* string

IP address that you want to add to the project's IP access list.

Your IP access list entry can be one awsSecurityGroup, one cidrBlock, or one ipAddress. Don't set this parameter if you set awsSecurityGroup or cidrBlock.

---

##### `projectId`<sup>Optional</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.AccessListDefinition.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies your project.

---

### Action <a name="Action" id="awscdk-resources-mongodbatlas.Action"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.Action.Initializer"></a>

```typescript
import { Action } from 'awscdk-resources-mongodbatlas'

const action: Action = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.Action.property.action">action</a></code> | <code>string</code> | Human-readable label that identifies the privilege action. |
| <code><a href="#awscdk-resources-mongodbatlas.Action.property.resources">resources</a></code> | <code><a href="#awscdk-resources-mongodbatlas.Resource">Resource</a>[]</code> | List of resources on which you grant the action. |

---

##### `action`<sup>Optional</sup> <a name="action" id="awscdk-resources-mongodbatlas.Action.property.action"></a>

```typescript
public readonly action: string;
```

- *Type:* string

Human-readable label that identifies the privilege action.

---

##### `resources`<sup>Optional</sup> <a name="resources" id="awscdk-resources-mongodbatlas.Action.property.resources"></a>

```typescript
public readonly resources: Resource[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.Resource">Resource</a>[]

List of resources on which you grant the action.

---

### AdvancedAutoScaling <a name="AdvancedAutoScaling" id="awscdk-resources-mongodbatlas.AdvancedAutoScaling"></a>

AWS Automatic Cluster Scaling.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.AdvancedAutoScaling.Initializer"></a>

```typescript
import { AdvancedAutoScaling } from 'awscdk-resources-mongodbatlas'

const advancedAutoScaling: AdvancedAutoScaling = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.AdvancedAutoScaling.property.compute">compute</a></code> | <code><a href="#awscdk-resources-mongodbatlas.Compute">Compute</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.AdvancedAutoScaling.property.diskGb">diskGb</a></code> | <code><a href="#awscdk-resources-mongodbatlas.DiskGb">DiskGb</a></code> | *No description.* |

---

##### `compute`<sup>Optional</sup> <a name="compute" id="awscdk-resources-mongodbatlas.AdvancedAutoScaling.property.compute"></a>

```typescript
public readonly compute: Compute;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.Compute">Compute</a>

---

##### `diskGb`<sup>Optional</sup> <a name="diskGb" id="awscdk-resources-mongodbatlas.AdvancedAutoScaling.property.diskGb"></a>

```typescript
public readonly diskGb: DiskGb;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.DiskGb">DiskGb</a>

---

### AdvancedRegionConfig <a name="AdvancedRegionConfig" id="awscdk-resources-mongodbatlas.AdvancedRegionConfig"></a>

Hardware specifications for nodes set for a given region.

Each regionConfigs object describes the region's priority in elections and the number and type of MongoDB nodes that MongoDB Cloud deploys to the region. Each regionConfigs object must have either an analyticsSpecs object, electableSpecs object, or readOnlySpecs object. Tenant clusters only require electableSpecs. Dedicated clusters can specify any of these specifications, but must have at least one electableSpecs object within a replicationSpec. Every hardware specification must use the same instanceSize.

Example:

If you set "replicationSpecs[n].regionConfigs[m].analyticsSpecs.instanceSize" : "M30", set "replicationSpecs[n].regionConfigs[m].electableSpecs.instanceSize" : "M30"if you have electable nodes and"replicationSpecs[n].regionConfigs[m].readOnlySpecs.instanceSize" : "M30" if you have read-only nodes.",

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.AdvancedRegionConfig.Initializer"></a>

```typescript
import { AdvancedRegionConfig } from 'awscdk-resources-mongodbatlas'

const advancedRegionConfig: AdvancedRegionConfig = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.AdvancedRegionConfig.property.analyticsAutoScaling">analyticsAutoScaling</a></code> | <code><a href="#awscdk-resources-mongodbatlas.AdvancedAutoScaling">AdvancedAutoScaling</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.AdvancedRegionConfig.property.analyticsSpecs">analyticsSpecs</a></code> | <code><a href="#awscdk-resources-mongodbatlas.Specs">Specs</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.AdvancedRegionConfig.property.autoScaling">autoScaling</a></code> | <code><a href="#awscdk-resources-mongodbatlas.AdvancedAutoScaling">AdvancedAutoScaling</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.AdvancedRegionConfig.property.backingProviderName">backingProviderName</a></code> | <code>string</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.AdvancedRegionConfig.property.electableSpecs">electableSpecs</a></code> | <code><a href="#awscdk-resources-mongodbatlas.Specs">Specs</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.AdvancedRegionConfig.property.priority">priority</a></code> | <code>number</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.AdvancedRegionConfig.property.providerName">providerName</a></code> | <code><a href="#awscdk-resources-mongodbatlas.AdvancedRegionConfigProviderName">AdvancedRegionConfigProviderName</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.AdvancedRegionConfig.property.readOnlySpecs">readOnlySpecs</a></code> | <code><a href="#awscdk-resources-mongodbatlas.Specs">Specs</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.AdvancedRegionConfig.property.regionName">regionName</a></code> | <code>string</code> | *No description.* |

---

##### `analyticsAutoScaling`<sup>Optional</sup> <a name="analyticsAutoScaling" id="awscdk-resources-mongodbatlas.AdvancedRegionConfig.property.analyticsAutoScaling"></a>

```typescript
public readonly analyticsAutoScaling: AdvancedAutoScaling;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.AdvancedAutoScaling">AdvancedAutoScaling</a>

---

##### `analyticsSpecs`<sup>Optional</sup> <a name="analyticsSpecs" id="awscdk-resources-mongodbatlas.AdvancedRegionConfig.property.analyticsSpecs"></a>

```typescript
public readonly analyticsSpecs: Specs;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.Specs">Specs</a>

---

##### `autoScaling`<sup>Optional</sup> <a name="autoScaling" id="awscdk-resources-mongodbatlas.AdvancedRegionConfig.property.autoScaling"></a>

```typescript
public readonly autoScaling: AdvancedAutoScaling;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.AdvancedAutoScaling">AdvancedAutoScaling</a>

---

##### `backingProviderName`<sup>Optional</sup> <a name="backingProviderName" id="awscdk-resources-mongodbatlas.AdvancedRegionConfig.property.backingProviderName"></a>

```typescript
public readonly backingProviderName: string;
```

- *Type:* string

---

##### `electableSpecs`<sup>Optional</sup> <a name="electableSpecs" id="awscdk-resources-mongodbatlas.AdvancedRegionConfig.property.electableSpecs"></a>

```typescript
public readonly electableSpecs: Specs;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.Specs">Specs</a>

---

##### `priority`<sup>Optional</sup> <a name="priority" id="awscdk-resources-mongodbatlas.AdvancedRegionConfig.property.priority"></a>

```typescript
public readonly priority: number;
```

- *Type:* number

---

##### `providerName`<sup>Optional</sup> <a name="providerName" id="awscdk-resources-mongodbatlas.AdvancedRegionConfig.property.providerName"></a>

```typescript
public readonly providerName: AdvancedRegionConfigProviderName;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.AdvancedRegionConfigProviderName">AdvancedRegionConfigProviderName</a>

---

##### `readOnlySpecs`<sup>Optional</sup> <a name="readOnlySpecs" id="awscdk-resources-mongodbatlas.AdvancedRegionConfig.property.readOnlySpecs"></a>

```typescript
public readonly readOnlySpecs: Specs;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.Specs">Specs</a>

---

##### `regionName`<sup>Optional</sup> <a name="regionName" id="awscdk-resources-mongodbatlas.AdvancedRegionConfig.property.regionName"></a>

```typescript
public readonly regionName: string;
```

- *Type:* string

---

### AdvancedReplicationSpec <a name="AdvancedReplicationSpec" id="awscdk-resources-mongodbatlas.AdvancedReplicationSpec"></a>

List of settings that configure your cluster regions.

For Global Clusters, each object in the array represents a zone where your clusters nodes deploy. For non-Global replica sets and sharded clusters, this array has one object representing where your clusters nodes deploy.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.AdvancedReplicationSpec.Initializer"></a>

```typescript
import { AdvancedReplicationSpec } from 'awscdk-resources-mongodbatlas'

const advancedReplicationSpec: AdvancedReplicationSpec = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.AdvancedReplicationSpec.property.advancedRegionConfigs">advancedRegionConfigs</a></code> | <code><a href="#awscdk-resources-mongodbatlas.AdvancedRegionConfig">AdvancedRegionConfig</a>[]</code> | Hardware specifications for nodes set for a given region. |
| <code><a href="#awscdk-resources-mongodbatlas.AdvancedReplicationSpec.property.id">id</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies the replication object for a zone in a Multi-Cloud Cluster. |
| <code><a href="#awscdk-resources-mongodbatlas.AdvancedReplicationSpec.property.numShards">numShards</a></code> | <code>number</code> | Positive integer that specifies the number of shards to deploy in each specified zone. |
| <code><a href="#awscdk-resources-mongodbatlas.AdvancedReplicationSpec.property.zoneName">zoneName</a></code> | <code>string</code> | Human-readable label that identifies the zone in a Global Cluster. |

---

##### `advancedRegionConfigs`<sup>Optional</sup> <a name="advancedRegionConfigs" id="awscdk-resources-mongodbatlas.AdvancedReplicationSpec.property.advancedRegionConfigs"></a>

```typescript
public readonly advancedRegionConfigs: AdvancedRegionConfig[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.AdvancedRegionConfig">AdvancedRegionConfig</a>[]

Hardware specifications for nodes set for a given region.

Each regionConfigs object describes the region's priority in elections and the number and type of MongoDB nodes that MongoDB Cloud deploys to the region. Each regionConfigs object must have either an analyticsSpecs object, electableSpecs object, or readOnlySpecs object. Tenant clusters only require electableSpecs. Dedicated clusters can specify any of these specifications, but must have at least one electableSpecs object within a replicationSpec. Every hardware specification must use the same instanceSize.

Example:

If you set "replicationSpecs[n].regionConfigs[m].analyticsSpecs.instanceSize" : "M30", set "replicationSpecs[n].regionConfigs[m].electableSpecs.instanceSize" : "M30"if you have electable nodes and"replicationSpecs[n].regionConfigs[m].readOnlySpecs.instanceSize" : "M30" if you have read-only nodes.",

---

##### `id`<sup>Optional</sup> <a name="id" id="awscdk-resources-mongodbatlas.AdvancedReplicationSpec.property.id"></a>

```typescript
public readonly id: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies the replication object for a zone in a Multi-Cloud Cluster.

If you include existing zones in the request, you must specify this parameter. If you add a new zone to an existing Multi-Cloud Cluster, you may specify this parameter. The request deletes any existing zones in the Multi-Cloud Cluster that you exclude from the request.

---

##### `numShards`<sup>Optional</sup> <a name="numShards" id="awscdk-resources-mongodbatlas.AdvancedReplicationSpec.property.numShards"></a>

```typescript
public readonly numShards: number;
```

- *Type:* number

Positive integer that specifies the number of shards to deploy in each specified zone.

If you set this value to 1 and "clusterType" : "SHARDED", MongoDB Cloud deploys a single-shard sharded cluster. Don't create a sharded cluster with a single shard for production environments. Single-shard sharded clusters don't provide the same benefits as multi-shard configurations.

---

##### `zoneName`<sup>Optional</sup> <a name="zoneName" id="awscdk-resources-mongodbatlas.AdvancedReplicationSpec.property.zoneName"></a>

```typescript
public readonly zoneName: string;
```

- *Type:* string

Human-readable label that identifies the zone in a Global Cluster.

Provide this value only if "clusterType" : "GEOSHARDED".

---

### ApiAtlasDiskBackupCopySettingView <a name="ApiAtlasDiskBackupCopySettingView" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupCopySettingView"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupCopySettingView.Initializer"></a>

```typescript
import { ApiAtlasDiskBackupCopySettingView } from 'awscdk-resources-mongodbatlas'

const apiAtlasDiskBackupCopySettingView: ApiAtlasDiskBackupCopySettingView = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupCopySettingView.property.cloudProvider">cloudProvider</a></code> | <code>string</code> | A label that identifies the cloud provider that stores the snapshot copy. |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupCopySettingView.property.frequencies">frequencies</a></code> | <code>string[]</code> | List that describes which types of snapshots to copy. |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupCopySettingView.property.regionName">regionName</a></code> | <code>string</code> | Target region to copy snapshots belonging to replicationSpecId to. |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupCopySettingView.property.replicationSpecId">replicationSpecId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies the replication object for a zone in a cluster. |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupCopySettingView.property.shouldCopyOplogs">shouldCopyOplogs</a></code> | <code>boolean</code> | Flag that indicates whether to copy the oplogs to the target region. |

---

##### `cloudProvider`<sup>Optional</sup> <a name="cloudProvider" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupCopySettingView.property.cloudProvider"></a>

```typescript
public readonly cloudProvider: string;
```

- *Type:* string

A label that identifies the cloud provider that stores the snapshot copy.

---

##### `frequencies`<sup>Optional</sup> <a name="frequencies" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupCopySettingView.property.frequencies"></a>

```typescript
public readonly frequencies: string[];
```

- *Type:* string[]

List that describes which types of snapshots to copy.

---

##### `regionName`<sup>Optional</sup> <a name="regionName" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupCopySettingView.property.regionName"></a>

```typescript
public readonly regionName: string;
```

- *Type:* string

Target region to copy snapshots belonging to replicationSpecId to.

---

##### `replicationSpecId`<sup>Optional</sup> <a name="replicationSpecId" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupCopySettingView.property.replicationSpecId"></a>

```typescript
public readonly replicationSpecId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies the replication object for a zone in a cluster.

---

##### `shouldCopyOplogs`<sup>Optional</sup> <a name="shouldCopyOplogs" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupCopySettingView.property.shouldCopyOplogs"></a>

```typescript
public readonly shouldCopyOplogs: boolean;
```

- *Type:* boolean

Flag that indicates whether to copy the oplogs to the target region.

---

### ApiAtlasDiskBackupShardedClusterSnapshotMemberView <a name="ApiAtlasDiskBackupShardedClusterSnapshotMemberView" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotMemberView"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotMemberView.Initializer"></a>

```typescript
import { ApiAtlasDiskBackupShardedClusterSnapshotMemberView } from 'awscdk-resources-mongodbatlas'

const apiAtlasDiskBackupShardedClusterSnapshotMemberView: ApiAtlasDiskBackupShardedClusterSnapshotMemberView = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotMemberView.property.cloudProvider">cloudProvider</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotMemberViewCloudProvider">ApiAtlasDiskBackupShardedClusterSnapshotMemberViewCloudProvider</a></code> | Human-readable label that identifies the cloud provider that stores this snapshot. |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotMemberView.property.id">id</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies the snapshot. |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotMemberView.property.replicaSetName">replicaSetName</a></code> | <code>string</code> | Human-readable label that identifies the shard or config host from which MongoDB Cloud took this snapshot. |

---

##### `cloudProvider`<sup>Optional</sup> <a name="cloudProvider" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotMemberView.property.cloudProvider"></a>

```typescript
public readonly cloudProvider: ApiAtlasDiskBackupShardedClusterSnapshotMemberViewCloudProvider;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotMemberViewCloudProvider">ApiAtlasDiskBackupShardedClusterSnapshotMemberViewCloudProvider</a>

Human-readable label that identifies the cloud provider that stores this snapshot.

The resource returns this parameter when `"type": "replicaSet".`

---

##### `id`<sup>Optional</sup> <a name="id" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotMemberView.property.id"></a>

```typescript
public readonly id: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies the snapshot.

---

##### `replicaSetName`<sup>Optional</sup> <a name="replicaSetName" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotMemberView.property.replicaSetName"></a>

```typescript
public readonly replicaSetName: string;
```

- *Type:* string

Human-readable label that identifies the shard or config host from which MongoDB Cloud took this snapshot.

---

### ApiAtlasDiskBackupShardedClusterSnapshotView <a name="ApiAtlasDiskBackupShardedClusterSnapshotView" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotView"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotView.Initializer"></a>

```typescript
import { ApiAtlasDiskBackupShardedClusterSnapshotView } from 'awscdk-resources-mongodbatlas'

const apiAtlasDiskBackupShardedClusterSnapshotView: ApiAtlasDiskBackupShardedClusterSnapshotView = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotView.property.createdAt">createdAt</a></code> | <code>string</code> | Date and time when MongoDB Cloud took the snapshot. |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotView.property.description">description</a></code> | <code>string</code> | Human-readable phrase or sentence that explains the purpose of the snapshot. |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotView.property.expiresAt">expiresAt</a></code> | <code>string</code> | Date and time when MongoDB Cloud deletes the snapshot. |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotView.property.frequencyType">frequencyType</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotViewFrequencyType">ApiAtlasDiskBackupShardedClusterSnapshotViewFrequencyType</a></code> | Human-readable label that identifies how often this snapshot triggers. |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotView.property.id">id</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies the snapshot. |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotView.property.masterKeyUuid">masterKeyUuid</a></code> | <code>string</code> | Unique string that identifies the Amazon Web Services (AWS) Key Management Service (KMS) Customer Master Key (CMK) used to encrypt the snapshot. |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotView.property.members">members</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotMemberView">ApiAtlasDiskBackupShardedClusterSnapshotMemberView</a>[]</code> | List that includes the snapshots and the cloud provider that stores the snapshots. |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotView.property.mongodVersion">mongodVersion</a></code> | <code>string</code> | Version of the MongoDB host that this snapshot backs up. |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotView.property.policyItems">policyItems</a></code> | <code>string[]</code> | List that contains unique identifiers for the policy items. |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotView.property.snapshotIds">snapshotIds</a></code> | <code>string[]</code> | List that contains the unique identifiers of the snapshots created for the shards and config host for a sharded cluster. |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotView.property.snapshotType">snapshotType</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotViewSnapshotType">ApiAtlasDiskBackupShardedClusterSnapshotViewSnapshotType</a></code> | Human-readable label that identifies when this snapshot triggers. |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotView.property.status">status</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotViewStatus">ApiAtlasDiskBackupShardedClusterSnapshotViewStatus</a></code> | Human-readable label that indicates the stage of the backup process for this snapshot. |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotView.property.storageSizeBytes">storageSizeBytes</a></code> | <code>string</code> | Number of bytes taken to store the backup snapshot. |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotView.property.type">type</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotViewType">ApiAtlasDiskBackupShardedClusterSnapshotViewType</a></code> | Human-readable label that categorizes the cluster as a replica set or sharded cluster. |

---

##### `createdAt`<sup>Optional</sup> <a name="createdAt" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotView.property.createdAt"></a>

```typescript
public readonly createdAt: string;
```

- *Type:* string

Date and time when MongoDB Cloud took the snapshot.

This parameter expresses its value in the ISO 8601 timestamp format in UTC.

---

##### `description`<sup>Optional</sup> <a name="description" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotView.property.description"></a>

```typescript
public readonly description: string;
```

- *Type:* string

Human-readable phrase or sentence that explains the purpose of the snapshot.

The resource returns this parameter when `"status": "onDemand"`.

---

##### `expiresAt`<sup>Optional</sup> <a name="expiresAt" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotView.property.expiresAt"></a>

```typescript
public readonly expiresAt: string;
```

- *Type:* string

Date and time when MongoDB Cloud deletes the snapshot.

This parameter expresses its value in the ISO 8601 timestamp format in UTC.

---

##### `frequencyType`<sup>Optional</sup> <a name="frequencyType" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotView.property.frequencyType"></a>

```typescript
public readonly frequencyType: ApiAtlasDiskBackupShardedClusterSnapshotViewFrequencyType;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotViewFrequencyType">ApiAtlasDiskBackupShardedClusterSnapshotViewFrequencyType</a>

Human-readable label that identifies how often this snapshot triggers.

---

##### `id`<sup>Optional</sup> <a name="id" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotView.property.id"></a>

```typescript
public readonly id: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies the snapshot.

---

##### `masterKeyUuid`<sup>Optional</sup> <a name="masterKeyUuid" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotView.property.masterKeyUuid"></a>

```typescript
public readonly masterKeyUuid: string;
```

- *Type:* string

Unique string that identifies the Amazon Web Services (AWS) Key Management Service (KMS) Customer Master Key (CMK) used to encrypt the snapshot.

The resource returns this value when `"encryptionEnabled" : true`.

---

##### `members`<sup>Optional</sup> <a name="members" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotView.property.members"></a>

```typescript
public readonly members: ApiAtlasDiskBackupShardedClusterSnapshotMemberView[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotMemberView">ApiAtlasDiskBackupShardedClusterSnapshotMemberView</a>[]

List that includes the snapshots and the cloud provider that stores the snapshots.

The resource returns this parameter when `"type" : "SHARDED_CLUSTER"`.

---

##### `mongodVersion`<sup>Optional</sup> <a name="mongodVersion" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotView.property.mongodVersion"></a>

```typescript
public readonly mongodVersion: string;
```

- *Type:* string

Version of the MongoDB host that this snapshot backs up.

---

##### `policyItems`<sup>Optional</sup> <a name="policyItems" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotView.property.policyItems"></a>

```typescript
public readonly policyItems: string[];
```

- *Type:* string[]

List that contains unique identifiers for the policy items.

---

##### `snapshotIds`<sup>Optional</sup> <a name="snapshotIds" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotView.property.snapshotIds"></a>

```typescript
public readonly snapshotIds: string[];
```

- *Type:* string[]

List that contains the unique identifiers of the snapshots created for the shards and config host for a sharded cluster.

The resource returns this parameter when `"type": "SHARDED_CLUSTER"`. These identifiers should match the ones specified in the **members[n].id** parameters. This allows you to map a snapshot to its shard or config host name.

---

##### `snapshotType`<sup>Optional</sup> <a name="snapshotType" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotView.property.snapshotType"></a>

```typescript
public readonly snapshotType: ApiAtlasDiskBackupShardedClusterSnapshotViewSnapshotType;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotViewSnapshotType">ApiAtlasDiskBackupShardedClusterSnapshotViewSnapshotType</a>

Human-readable label that identifies when this snapshot triggers.

---

##### `status`<sup>Optional</sup> <a name="status" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotView.property.status"></a>

```typescript
public readonly status: ApiAtlasDiskBackupShardedClusterSnapshotViewStatus;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotViewStatus">ApiAtlasDiskBackupShardedClusterSnapshotViewStatus</a>

Human-readable label that indicates the stage of the backup process for this snapshot.

---

##### `storageSizeBytes`<sup>Optional</sup> <a name="storageSizeBytes" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotView.property.storageSizeBytes"></a>

```typescript
public readonly storageSizeBytes: string;
```

- *Type:* string

Number of bytes taken to store the backup snapshot.

---

##### `type`<sup>Optional</sup> <a name="type" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotView.property.type"></a>

```typescript
public readonly type: ApiAtlasDiskBackupShardedClusterSnapshotViewType;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotViewType">ApiAtlasDiskBackupShardedClusterSnapshotViewType</a>

Human-readable label that categorizes the cluster as a replica set or sharded cluster.

---

### ApiAtlasFtsAnalyzersViewManual <a name="ApiAtlasFtsAnalyzersViewManual" id="awscdk-resources-mongodbatlas.ApiAtlasFtsAnalyzersViewManual"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.ApiAtlasFtsAnalyzersViewManual.Initializer"></a>

```typescript
import { ApiAtlasFtsAnalyzersViewManual } from 'awscdk-resources-mongodbatlas'

const apiAtlasFtsAnalyzersViewManual: ApiAtlasFtsAnalyzersViewManual = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasFtsAnalyzersViewManual.property.charFilters">charFilters</a></code> | <code>string[]</code> | Filters that examine text one character at a time and perform filtering operations. |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasFtsAnalyzersViewManual.property.name">name</a></code> | <code>string</code> | Human-readable name that identifies the custom analyzer. |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasFtsAnalyzersViewManual.property.tokenFilters">tokenFilters</a></code> | <code>string[]</code> | Filter that performs operations such as:. |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasFtsAnalyzersViewManual.property.tokenizer">tokenizer</a></code> | <code>any</code> | Tokenizer that you want to use to create tokens. |

---

##### `charFilters`<sup>Optional</sup> <a name="charFilters" id="awscdk-resources-mongodbatlas.ApiAtlasFtsAnalyzersViewManual.property.charFilters"></a>

```typescript
public readonly charFilters: string[];
```

- *Type:* string[]

Filters that examine text one character at a time and perform filtering operations.

---

##### `name`<sup>Optional</sup> <a name="name" id="awscdk-resources-mongodbatlas.ApiAtlasFtsAnalyzersViewManual.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Human-readable name that identifies the custom analyzer.

Names must be unique within an index, and must not start with any of the following strings:
- `lucene.`
- `builtin.`
- `mongodb.`

---

##### `tokenFilters`<sup>Optional</sup> <a name="tokenFilters" id="awscdk-resources-mongodbatlas.ApiAtlasFtsAnalyzersViewManual.property.tokenFilters"></a>

```typescript
public readonly tokenFilters: string[];
```

- *Type:* string[]

Filter that performs operations such as:.

Stemming, which reduces related words, such as "talking", "talked", and "talks" to their root word "talk".

- Redaction, the removal of sensitive information from public documents.

---

##### `tokenizer`<sup>Optional</sup> <a name="tokenizer" id="awscdk-resources-mongodbatlas.ApiAtlasFtsAnalyzersViewManual.property.tokenizer"></a>

```typescript
public readonly tokenizer: any;
```

- *Type:* any

Tokenizer that you want to use to create tokens.

Tokens determine how Atlas Search splits up text into discrete chunks for indexing.

---

### ApiAtlasFtsMappingsViewManual <a name="ApiAtlasFtsMappingsViewManual" id="awscdk-resources-mongodbatlas.ApiAtlasFtsMappingsViewManual"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.ApiAtlasFtsMappingsViewManual.Initializer"></a>

```typescript
import { ApiAtlasFtsMappingsViewManual } from 'awscdk-resources-mongodbatlas'

const apiAtlasFtsMappingsViewManual: ApiAtlasFtsMappingsViewManual = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasFtsMappingsViewManual.property.dynamic">dynamic</a></code> | <code>boolean</code> | Flag that indicates whether the index uses dynamic or static mappings. |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasFtsMappingsViewManual.property.fields">fields</a></code> | <code>string</code> | One or more field specifications for the Atlas Search index. |

---

##### `dynamic`<sup>Optional</sup> <a name="dynamic" id="awscdk-resources-mongodbatlas.ApiAtlasFtsMappingsViewManual.property.dynamic"></a>

```typescript
public readonly dynamic: boolean;
```

- *Type:* boolean

Flag that indicates whether the index uses dynamic or static mappings.

Required for search indexes if **mappings.fields** is omitted.

---

##### `fields`<sup>Optional</sup> <a name="fields" id="awscdk-resources-mongodbatlas.ApiAtlasFtsMappingsViewManual.property.fields"></a>

```typescript
public readonly fields: string;
```

- *Type:* string

One or more field specifications for the Atlas Search index.

Stringify json representation of field with types and properties. Required for search indexes if **mappings.dynamic** is omitted or set to **false**.

---

### ApiAtlasFtsSynonymMappingDefinitionView <a name="ApiAtlasFtsSynonymMappingDefinitionView" id="awscdk-resources-mongodbatlas.ApiAtlasFtsSynonymMappingDefinitionView"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.ApiAtlasFtsSynonymMappingDefinitionView.Initializer"></a>

```typescript
import { ApiAtlasFtsSynonymMappingDefinitionView } from 'awscdk-resources-mongodbatlas'

const apiAtlasFtsSynonymMappingDefinitionView: ApiAtlasFtsSynonymMappingDefinitionView = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasFtsSynonymMappingDefinitionView.property.analyzer">analyzer</a></code> | <code>string</code> | Specific pre-defined method chosen to apply to the synonyms to be searched. |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasFtsSynonymMappingDefinitionView.property.name">name</a></code> | <code>string</code> | Human-readable label that identifies the synonym definition. |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasFtsSynonymMappingDefinitionView.property.source">source</a></code> | <code><a href="#awscdk-resources-mongodbatlas.SynonymSource">SynonymSource</a></code> | Data set that stores the mapping one or more words map to one or more synonyms of those words. |

---

##### `analyzer`<sup>Required</sup> <a name="analyzer" id="awscdk-resources-mongodbatlas.ApiAtlasFtsSynonymMappingDefinitionView.property.analyzer"></a>

```typescript
public readonly analyzer: string;
```

- *Type:* string

Specific pre-defined method chosen to apply to the synonyms to be searched.

---

##### `name`<sup>Required</sup> <a name="name" id="awscdk-resources-mongodbatlas.ApiAtlasFtsSynonymMappingDefinitionView.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Human-readable label that identifies the synonym definition.

Each **synonym.name** must be unique within the same index definition.

---

##### `source`<sup>Required</sup> <a name="source" id="awscdk-resources-mongodbatlas.ApiAtlasFtsSynonymMappingDefinitionView.property.source"></a>

```typescript
public readonly source: SynonymSource;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.SynonymSource">SynonymSource</a>

Data set that stores the mapping one or more words map to one or more synonyms of those words.

---

### ApiAtlasNdsUserToDnMappingView <a name="ApiAtlasNdsUserToDnMappingView" id="awscdk-resources-mongodbatlas.ApiAtlasNdsUserToDnMappingView"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.ApiAtlasNdsUserToDnMappingView.Initializer"></a>

```typescript
import { ApiAtlasNdsUserToDnMappingView } from 'awscdk-resources-mongodbatlas'

const apiAtlasNdsUserToDnMappingView: ApiAtlasNdsUserToDnMappingView = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasNdsUserToDnMappingView.property.ldapQuery">ldapQuery</a></code> | <code>string</code> | Lightweight Directory Access Protocol (LDAP) query template that inserts the LDAP name that the regular expression matches into an LDAP query Uniform Resource Identifier (URI). |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasNdsUserToDnMappingView.property.match">match</a></code> | <code>string</code> | Regular expression that MongoDB Cloud uses to match against the provided Lightweight Directory Access Protocol (LDAP) username. |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasNdsUserToDnMappingView.property.substitution">substitution</a></code> | <code>string</code> | Lightweight Directory Access Protocol (LDAP) Distinguished Name (DN) template that converts the LDAP username that matches regular expression in the *match* parameter into an LDAP Distinguished Name (DN). |

---

##### `ldapQuery`<sup>Optional</sup> <a name="ldapQuery" id="awscdk-resources-mongodbatlas.ApiAtlasNdsUserToDnMappingView.property.ldapQuery"></a>

```typescript
public readonly ldapQuery: string;
```

- *Type:* string

Lightweight Directory Access Protocol (LDAP) query template that inserts the LDAP name that the regular expression matches into an LDAP query Uniform Resource Identifier (URI).

The formatting for the query must conform to [RFC 4515](https://datatracker.ietf.org/doc/html/rfc4515) and [RFC 4516](https://datatracker.ietf.org/doc/html/rfc4516).

---

##### `match`<sup>Optional</sup> <a name="match" id="awscdk-resources-mongodbatlas.ApiAtlasNdsUserToDnMappingView.property.match"></a>

```typescript
public readonly match: string;
```

- *Type:* string

Regular expression that MongoDB Cloud uses to match against the provided Lightweight Directory Access Protocol (LDAP) username.

Each parenthesis-enclosed section represents a regular expression capture group that the substitution or `ldapQuery` template uses.

---

##### `substitution`<sup>Optional</sup> <a name="substitution" id="awscdk-resources-mongodbatlas.ApiAtlasNdsUserToDnMappingView.property.substitution"></a>

```typescript
public readonly substitution: string;
```

- *Type:* string

Lightweight Directory Access Protocol (LDAP) Distinguished Name (DN) template that converts the LDAP username that matches regular expression in the *match* parameter into an LDAP Distinguished Name (DN).

---

### ApiDeleteCopiedBackupsView <a name="ApiDeleteCopiedBackupsView" id="awscdk-resources-mongodbatlas.ApiDeleteCopiedBackupsView"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.ApiDeleteCopiedBackupsView.Initializer"></a>

```typescript
import { ApiDeleteCopiedBackupsView } from 'awscdk-resources-mongodbatlas'

const apiDeleteCopiedBackupsView: ApiDeleteCopiedBackupsView = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.ApiDeleteCopiedBackupsView.property.cloudProvider">cloudProvider</a></code> | <code>string</code> | A label that identifies the cloud provider for the deleted copy setting whose backup copies you want to delete. |
| <code><a href="#awscdk-resources-mongodbatlas.ApiDeleteCopiedBackupsView.property.regionName">regionName</a></code> | <code>string</code> | Target region for the deleted copy setting whose backup copies you want to delete. |
| <code><a href="#awscdk-resources-mongodbatlas.ApiDeleteCopiedBackupsView.property.replicationSpecId">replicationSpecId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies the replication object for a zone in a cluster. |

---

##### `cloudProvider`<sup>Optional</sup> <a name="cloudProvider" id="awscdk-resources-mongodbatlas.ApiDeleteCopiedBackupsView.property.cloudProvider"></a>

```typescript
public readonly cloudProvider: string;
```

- *Type:* string

A label that identifies the cloud provider for the deleted copy setting whose backup copies you want to delete.

---

##### `regionName`<sup>Optional</sup> <a name="regionName" id="awscdk-resources-mongodbatlas.ApiDeleteCopiedBackupsView.property.regionName"></a>

```typescript
public readonly regionName: string;
```

- *Type:* string

Target region for the deleted copy setting whose backup copies you want to delete.

---

##### `replicationSpecId`<sup>Optional</sup> <a name="replicationSpecId" id="awscdk-resources-mongodbatlas.ApiDeleteCopiedBackupsView.property.replicationSpecId"></a>

```typescript
public readonly replicationSpecId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies the replication object for a zone in a cluster.

---

### ApiKey <a name="ApiKey" id="awscdk-resources-mongodbatlas.ApiKey"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.ApiKey.Initializer"></a>

```typescript
import { ApiKey } from 'awscdk-resources-mongodbatlas'

const apiKey: ApiKey = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.ApiKey.property.description">description</a></code> | <code>string</code> | Purpose or explanation provided when someone created this organization API key. |
| <code><a href="#awscdk-resources-mongodbatlas.ApiKey.property.roles">roles</a></code> | <code>string[]</code> | List of roles to grant this API key. |

---

##### `description`<sup>Optional</sup> <a name="description" id="awscdk-resources-mongodbatlas.ApiKey.property.description"></a>

```typescript
public readonly description: string;
```

- *Type:* string

Purpose or explanation provided when someone created this organization API key.

1 to 250 characters

---

##### `roles`<sup>Optional</sup> <a name="roles" id="awscdk-resources-mongodbatlas.ApiKey.property.roles"></a>

```typescript
public readonly roles: string[];
```

- *Type:* string[]

List of roles to grant this API key.

If you provide this list, provide a minimum of one role and ensure each role applies to this organization.

---

### ApiPolicyItemView <a name="ApiPolicyItemView" id="awscdk-resources-mongodbatlas.ApiPolicyItemView"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.ApiPolicyItemView.Initializer"></a>

```typescript
import { ApiPolicyItemView } from 'awscdk-resources-mongodbatlas'

const apiPolicyItemView: ApiPolicyItemView = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.ApiPolicyItemView.property.frequencyInterval">frequencyInterval</a></code> | <code>number</code> | Desired frequency of the new backup policy item specified by frequencyType. |
| <code><a href="#awscdk-resources-mongodbatlas.ApiPolicyItemView.property.frequencyType">frequencyType</a></code> | <code>string</code> | Frequency associated with the backup policy item. |
| <code><a href="#awscdk-resources-mongodbatlas.ApiPolicyItemView.property.id">id</a></code> | <code>string</code> | Unique identifier of the backup policy item. |
| <code><a href="#awscdk-resources-mongodbatlas.ApiPolicyItemView.property.retentionUnit">retentionUnit</a></code> | <code>string</code> | Metric of duration of the backup policy item: days, weeks, or months. |
| <code><a href="#awscdk-resources-mongodbatlas.ApiPolicyItemView.property.retentionValue">retentionValue</a></code> | <code>number</code> | Duration for which the backup is kept. |

---

##### `frequencyInterval`<sup>Optional</sup> <a name="frequencyInterval" id="awscdk-resources-mongodbatlas.ApiPolicyItemView.property.frequencyInterval"></a>

```typescript
public readonly frequencyInterval: number;
```

- *Type:* number

Desired frequency of the new backup policy item specified by frequencyType.

---

##### `frequencyType`<sup>Optional</sup> <a name="frequencyType" id="awscdk-resources-mongodbatlas.ApiPolicyItemView.property.frequencyType"></a>

```typescript
public readonly frequencyType: string;
```

- *Type:* string

Frequency associated with the backup policy item.

One of the following values: hourly, daily, weekly or monthly.

---

##### `id`<sup>Optional</sup> <a name="id" id="awscdk-resources-mongodbatlas.ApiPolicyItemView.property.id"></a>

```typescript
public readonly id: string;
```

- *Type:* string

Unique identifier of the backup policy item.

---

##### `retentionUnit`<sup>Optional</sup> <a name="retentionUnit" id="awscdk-resources-mongodbatlas.ApiPolicyItemView.property.retentionUnit"></a>

```typescript
public readonly retentionUnit: string;
```

- *Type:* string

Metric of duration of the backup policy item: days, weeks, or months.

---

##### `retentionValue`<sup>Optional</sup> <a name="retentionValue" id="awscdk-resources-mongodbatlas.ApiPolicyItemView.property.retentionValue"></a>

```typescript
public readonly retentionValue: number;
```

- *Type:* number

Duration for which the backup is kept.

Associated with retentionUnit.

---

### ApiPolicyView <a name="ApiPolicyView" id="awscdk-resources-mongodbatlas.ApiPolicyView"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.ApiPolicyView.Initializer"></a>

```typescript
import { ApiPolicyView } from 'awscdk-resources-mongodbatlas'

const apiPolicyView: ApiPolicyView = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.ApiPolicyView.property.id">id</a></code> | <code>string</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.ApiPolicyView.property.policyItems">policyItems</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ApiPolicyItemView">ApiPolicyItemView</a>[]</code> | *No description.* |

---

##### `id`<sup>Optional</sup> <a name="id" id="awscdk-resources-mongodbatlas.ApiPolicyView.property.id"></a>

```typescript
public readonly id: string;
```

- *Type:* string

---

##### `policyItems`<sup>Optional</sup> <a name="policyItems" id="awscdk-resources-mongodbatlas.ApiPolicyView.property.policyItems"></a>

```typescript
public readonly policyItems: ApiPolicyItemView[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ApiPolicyItemView">ApiPolicyItemView</a>[]

---

### ApiSearchDeploymentSpec <a name="ApiSearchDeploymentSpec" id="awscdk-resources-mongodbatlas.ApiSearchDeploymentSpec"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.ApiSearchDeploymentSpec.Initializer"></a>

```typescript
import { ApiSearchDeploymentSpec } from 'awscdk-resources-mongodbatlas'

const apiSearchDeploymentSpec: ApiSearchDeploymentSpec = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.ApiSearchDeploymentSpec.property.instanceSize">instanceSize</a></code> | <code>string</code> | Hardware specification for the search node instance sizes. |
| <code><a href="#awscdk-resources-mongodbatlas.ApiSearchDeploymentSpec.property.nodeCount">nodeCount</a></code> | <code>number</code> | Number of search nodes in the cluster. |

---

##### `instanceSize`<sup>Required</sup> <a name="instanceSize" id="awscdk-resources-mongodbatlas.ApiSearchDeploymentSpec.property.instanceSize"></a>

```typescript
public readonly instanceSize: string;
```

- *Type:* string

Hardware specification for the search node instance sizes.

The [MongoDB Atlas API](https://www.mongodb.com/docs/atlas/reference/api-resources-spec/#tag/Atlas-Search/operation/createAtlasSearchDeployment) describes the valid values. More details can also be found in the [Search Node Documentation](https://www.mongodb.com/docs/atlas/cluster-config/multi-cloud-distribution/#search-tier).

---

##### `nodeCount`<sup>Required</sup> <a name="nodeCount" id="awscdk-resources-mongodbatlas.ApiSearchDeploymentSpec.property.nodeCount"></a>

```typescript
public readonly nodeCount: number;
```

- *Type:* number

Number of search nodes in the cluster.

---

### AtlasBasicPrivateEndpointProps <a name="AtlasBasicPrivateEndpointProps" id="awscdk-resources-mongodbatlas.AtlasBasicPrivateEndpointProps"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.AtlasBasicPrivateEndpointProps.Initializer"></a>

```typescript
import { AtlasBasicPrivateEndpointProps } from 'awscdk-resources-mongodbatlas'

const atlasBasicPrivateEndpointProps: AtlasBasicPrivateEndpointProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasBasicPrivateEndpointProps.property.atlasBasicProps">atlasBasicProps</a></code> | <code><a href="#awscdk-resources-mongodbatlas.AtlasBasicProps">AtlasBasicProps</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasBasicPrivateEndpointProps.property.privateEndpointProps">privateEndpointProps</a></code> | <code><a href="#awscdk-resources-mongodbatlas.PrivateEndpointProps">PrivateEndpointProps</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasBasicPrivateEndpointProps.property.region">region</a></code> | <code>string</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasBasicPrivateEndpointProps.property.profile">profile</a></code> | <code>string</code> | *No description.* |

---

##### `atlasBasicProps`<sup>Required</sup> <a name="atlasBasicProps" id="awscdk-resources-mongodbatlas.AtlasBasicPrivateEndpointProps.property.atlasBasicProps"></a>

```typescript
public readonly atlasBasicProps: AtlasBasicProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.AtlasBasicProps">AtlasBasicProps</a>

---

##### `privateEndpointProps`<sup>Required</sup> <a name="privateEndpointProps" id="awscdk-resources-mongodbatlas.AtlasBasicPrivateEndpointProps.property.privateEndpointProps"></a>

```typescript
public readonly privateEndpointProps: PrivateEndpointProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.PrivateEndpointProps">PrivateEndpointProps</a>

---

##### `region`<sup>Required</sup> <a name="region" id="awscdk-resources-mongodbatlas.AtlasBasicPrivateEndpointProps.property.region"></a>

```typescript
public readonly region: string;
```

- *Type:* string
- *Default:* us-east-1

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.AtlasBasicPrivateEndpointProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

---

### AtlasBasicProps <a name="AtlasBasicProps" id="awscdk-resources-mongodbatlas.AtlasBasicProps"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.AtlasBasicProps.Initializer"></a>

```typescript
import { AtlasBasicProps } from 'awscdk-resources-mongodbatlas'

const atlasBasicProps: AtlasBasicProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasBasicProps.property.clusterProps">clusterProps</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ClusterProps">ClusterProps</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasBasicProps.property.ipAccessListProps">ipAccessListProps</a></code> | <code><a href="#awscdk-resources-mongodbatlas.IpAccessListProps">IpAccessListProps</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasBasicProps.property.projectProps">projectProps</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ProjectProps">ProjectProps</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasBasicProps.property.dbUserProps">dbUserProps</a></code> | <code><a href="#awscdk-resources-mongodbatlas.DatabaseUserProps">DatabaseUserProps</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasBasicProps.property.profile">profile</a></code> | <code>string</code> | *No description.* |

---

##### `clusterProps`<sup>Required</sup> <a name="clusterProps" id="awscdk-resources-mongodbatlas.AtlasBasicProps.property.clusterProps"></a>

```typescript
public readonly clusterProps: ClusterProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ClusterProps">ClusterProps</a>

---

##### `ipAccessListProps`<sup>Required</sup> <a name="ipAccessListProps" id="awscdk-resources-mongodbatlas.AtlasBasicProps.property.ipAccessListProps"></a>

```typescript
public readonly ipAccessListProps: IpAccessListProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.IpAccessListProps">IpAccessListProps</a>

---

##### `projectProps`<sup>Required</sup> <a name="projectProps" id="awscdk-resources-mongodbatlas.AtlasBasicProps.property.projectProps"></a>

```typescript
public readonly projectProps: ProjectProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ProjectProps">ProjectProps</a>

---

##### `dbUserProps`<sup>Optional</sup> <a name="dbUserProps" id="awscdk-resources-mongodbatlas.AtlasBasicProps.property.dbUserProps"></a>

```typescript
public readonly dbUserProps: DatabaseUserProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.DatabaseUserProps">DatabaseUserProps</a>

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.AtlasBasicProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

---

### AtlasEncryptionAtRestExpressProps <a name="AtlasEncryptionAtRestExpressProps" id="awscdk-resources-mongodbatlas.AtlasEncryptionAtRestExpressProps"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.AtlasEncryptionAtRestExpressProps.Initializer"></a>

```typescript
import { AtlasEncryptionAtRestExpressProps } from 'awscdk-resources-mongodbatlas'

const atlasEncryptionAtRestExpressProps: AtlasEncryptionAtRestExpressProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasEncryptionAtRestExpressProps.property.encryptionAtRest">encryptionAtRest</a></code> | <code><a href="#awscdk-resources-mongodbatlas.EncryptionAtRestProps">EncryptionAtRestProps</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasEncryptionAtRestExpressProps.property.projectId">projectId</a></code> | <code>string</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasEncryptionAtRestExpressProps.property.accessList">accessList</a></code> | <code><a href="#awscdk-resources-mongodbatlas.IpAccessListProps">IpAccessListProps</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasEncryptionAtRestExpressProps.property.cluster">cluster</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ClusterProps">ClusterProps</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasEncryptionAtRestExpressProps.property.databaseUser">databaseUser</a></code> | <code><a href="#awscdk-resources-mongodbatlas.DatabaseUserProps">DatabaseUserProps</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasEncryptionAtRestExpressProps.property.profile">profile</a></code> | <code>string</code> | *No description.* |

---

##### `encryptionAtRest`<sup>Required</sup> <a name="encryptionAtRest" id="awscdk-resources-mongodbatlas.AtlasEncryptionAtRestExpressProps.property.encryptionAtRest"></a>

```typescript
public readonly encryptionAtRest: EncryptionAtRestProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.EncryptionAtRestProps">EncryptionAtRestProps</a>

---

##### `projectId`<sup>Required</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.AtlasEncryptionAtRestExpressProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

---

##### `accessList`<sup>Optional</sup> <a name="accessList" id="awscdk-resources-mongodbatlas.AtlasEncryptionAtRestExpressProps.property.accessList"></a>

```typescript
public readonly accessList: IpAccessListProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.IpAccessListProps">IpAccessListProps</a>

---

##### `cluster`<sup>Optional</sup> <a name="cluster" id="awscdk-resources-mongodbatlas.AtlasEncryptionAtRestExpressProps.property.cluster"></a>

```typescript
public readonly cluster: ClusterProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ClusterProps">ClusterProps</a>

---

##### `databaseUser`<sup>Optional</sup> <a name="databaseUser" id="awscdk-resources-mongodbatlas.AtlasEncryptionAtRestExpressProps.property.databaseUser"></a>

```typescript
public readonly databaseUser: DatabaseUserProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.DatabaseUserProps">DatabaseUserProps</a>

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.AtlasEncryptionAtRestExpressProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

---

### AtlasEncryptionAtRestProps <a name="AtlasEncryptionAtRestProps" id="awscdk-resources-mongodbatlas.AtlasEncryptionAtRestProps"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.AtlasEncryptionAtRestProps.Initializer"></a>

```typescript
import { AtlasEncryptionAtRestProps } from 'awscdk-resources-mongodbatlas'

const atlasEncryptionAtRestProps: AtlasEncryptionAtRestProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasEncryptionAtRestProps.property.customerMasterKeyId">customerMasterKeyId</a></code> | <code>string</code> | The AWS customer master key used to encrypt and decrypt the MongoDB master keys. |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasEncryptionAtRestProps.property.projectId">projectId</a></code> | <code>string</code> | Unique identifier of the Atlas project to which the user belongs. |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasEncryptionAtRestProps.property.roleId">roleId</a></code> | <code>string</code> | ID of an AWS IAM role authorized to manage an AWS customer master key. |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasEncryptionAtRestProps.property.enabled">enabled</a></code> | <code>boolean</code> | Specifies whether Encryption at Rest is enabled for an Atlas project. |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasEncryptionAtRestProps.property.profile">profile</a></code> | <code>string</code> | The profile is defined in AWS Secret manager. |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasEncryptionAtRestProps.property.region">region</a></code> | <code>string</code> | The AWS region in which the AWS customer master key exists. |

---

##### `customerMasterKeyId`<sup>Required</sup> <a name="customerMasterKeyId" id="awscdk-resources-mongodbatlas.AtlasEncryptionAtRestProps.property.customerMasterKeyId"></a>

```typescript
public readonly customerMasterKeyId: string;
```

- *Type:* string

The AWS customer master key used to encrypt and decrypt the MongoDB master keys.

---

##### `projectId`<sup>Required</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.AtlasEncryptionAtRestProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

Unique identifier of the Atlas project to which the user belongs.

---

##### `roleId`<sup>Required</sup> <a name="roleId" id="awscdk-resources-mongodbatlas.AtlasEncryptionAtRestProps.property.roleId"></a>

```typescript
public readonly roleId: string;
```

- *Type:* string

ID of an AWS IAM role authorized to manage an AWS customer master key.

---

##### `enabled`<sup>Optional</sup> <a name="enabled" id="awscdk-resources-mongodbatlas.AtlasEncryptionAtRestProps.property.enabled"></a>

```typescript
public readonly enabled: boolean;
```

- *Type:* boolean

Specifies whether Encryption at Rest is enabled for an Atlas project.

To disable Encryption at Rest, pass only this parameter with a value of false. When you disable Encryption at Rest, Atlas also removes the configuration details.
Default Value: true

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.AtlasEncryptionAtRestProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

The profile is defined in AWS Secret manager.

See [Secret Manager Profile setup](../../../examples/profile-secret.yaml).

---

##### `region`<sup>Optional</sup> <a name="region" id="awscdk-resources-mongodbatlas.AtlasEncryptionAtRestProps.property.region"></a>

```typescript
public readonly region: string;
```

- *Type:* string

The AWS region in which the AWS customer master key exists.

Default Value: US_EAST_1

---

### AtlasRole <a name="AtlasRole" id="awscdk-resources-mongodbatlas.AtlasRole"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.AtlasRole.Initializer"></a>

```typescript
import { AtlasRole } from 'awscdk-resources-mongodbatlas'

const atlasRole: AtlasRole = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasRole.property.orgId">orgId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies the organization to which this role belongs. |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasRole.property.projectId">projectId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies the project to which this role belongs. |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasRole.property.roleName">roleName</a></code> | <code><a href="#awscdk-resources-mongodbatlas.AtlasRoleRoleName">AtlasRoleRoleName</a></code> | Human-readable label that identifies the collection of privileges that MongoDB Cloud grants a specific API key, MongoDB Cloud user, or MongoDB Cloud team. |

---

##### `orgId`<sup>Optional</sup> <a name="orgId" id="awscdk-resources-mongodbatlas.AtlasRole.property.orgId"></a>

```typescript
public readonly orgId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies the organization to which this role belongs.

You can set a value for this parameter or **groupId** but not both in the same request

---

##### `projectId`<sup>Optional</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.AtlasRole.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies the project to which this role belongs.

You can set a value for this parameter or **orgId** but not both in the same request.

---

##### `roleName`<sup>Optional</sup> <a name="roleName" id="awscdk-resources-mongodbatlas.AtlasRole.property.roleName"></a>

```typescript
public readonly roleName: AtlasRoleRoleName;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.AtlasRoleRoleName">AtlasRoleRoleName</a>

Human-readable label that identifies the collection of privileges that MongoDB Cloud grants a specific API key, MongoDB Cloud user, or MongoDB Cloud team.

These roles include organization- and project-level roles.

Organization Roles

* ORG_OWNER
* ORG_MEMBER
* ORG_GROUP_CREATOR
* ORG_BILLING_ADMIN
* ORG_READ_ONLY

Project Roles

* GROUP_CLUSTER_MANAGER
* GROUP_DATA_ACCESS_ADMIN
* GROUP_DATA_ACCESS_READ_ONLY
* GROUP_DATA_ACCESS_READ_WRITE
* GROUP_OWNER
* GROUP_READ_ONLY

---

### AtlasServerlessBasicProps <a name="AtlasServerlessBasicProps" id="awscdk-resources-mongodbatlas.AtlasServerlessBasicProps"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.AtlasServerlessBasicProps.Initializer"></a>

```typescript
import { AtlasServerlessBasicProps } from 'awscdk-resources-mongodbatlas'

const atlasServerlessBasicProps: AtlasServerlessBasicProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasServerlessBasicProps.property.projectProps">projectProps</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ProjectProps">ProjectProps</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasServerlessBasicProps.property.serverlessProps">serverlessProps</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstanceProps">CfnServerlessInstanceProps</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasServerlessBasicProps.property.dbUserProps">dbUserProps</a></code> | <code><a href="#awscdk-resources-mongodbatlas.DatabaseUserProps">DatabaseUserProps</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasServerlessBasicProps.property.ipAccessListProps">ipAccessListProps</a></code> | <code><a href="#awscdk-resources-mongodbatlas.IpAccessListProps">IpAccessListProps</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasServerlessBasicProps.property.profile">profile</a></code> | <code>string</code> | *No description.* |

---

##### `projectProps`<sup>Required</sup> <a name="projectProps" id="awscdk-resources-mongodbatlas.AtlasServerlessBasicProps.property.projectProps"></a>

```typescript
public readonly projectProps: ProjectProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ProjectProps">ProjectProps</a>

---

##### `serverlessProps`<sup>Required</sup> <a name="serverlessProps" id="awscdk-resources-mongodbatlas.AtlasServerlessBasicProps.property.serverlessProps"></a>

```typescript
public readonly serverlessProps: CfnServerlessInstanceProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnServerlessInstanceProps">CfnServerlessInstanceProps</a>

---

##### `dbUserProps`<sup>Optional</sup> <a name="dbUserProps" id="awscdk-resources-mongodbatlas.AtlasServerlessBasicProps.property.dbUserProps"></a>

```typescript
public readonly dbUserProps: DatabaseUserProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.DatabaseUserProps">DatabaseUserProps</a>

---

##### `ipAccessListProps`<sup>Optional</sup> <a name="ipAccessListProps" id="awscdk-resources-mongodbatlas.AtlasServerlessBasicProps.property.ipAccessListProps"></a>

```typescript
public readonly ipAccessListProps: IpAccessListProps;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.IpAccessListProps">IpAccessListProps</a>

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.AtlasServerlessBasicProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

---

### AtlasUser <a name="AtlasUser" id="awscdk-resources-mongodbatlas.AtlasUser"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.AtlasUser.Initializer"></a>

```typescript
import { AtlasUser } from 'awscdk-resources-mongodbatlas'

const atlasUser: AtlasUser = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasUser.property.country">country</a></code> | <code>string</code> | Two alphabet characters that identifies MongoDB Cloud user's geographic location. |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasUser.property.emailAddress">emailAddress</a></code> | <code>string</code> | Email address that belongs to the MongoDB Cloud user. |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasUser.property.firstName">firstName</a></code> | <code>string</code> | First or given name that belongs to the MongoDB Cloud user. |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasUser.property.id">id</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies the MongoDB Cloud user. |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasUser.property.lastName">lastName</a></code> | <code>string</code> | Last name, family name, or surname that belongs to the MongoDB Cloud user. |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasUser.property.links">links</a></code> | <code><a href="#awscdk-resources-mongodbatlas.Link">Link</a>[]</code> | List of one or more Uniform Resource Locators (URLs) that point to API sub-resources, related API resources, or both. |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasUser.property.mobileNumber">mobileNumber</a></code> | <code>string</code> | Mobile phone number that belongs to the MongoDB Cloud user. |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasUser.property.password">password</a></code> | <code>string</code> | Password applied with the username to log in to MongoDB Cloud. |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasUser.property.roles">roles</a></code> | <code><a href="#awscdk-resources-mongodbatlas.AtlasRole">AtlasRole</a>[]</code> | List of objects that display the MongoDB Cloud user's roles and the corresponding organization or project to which that role applies. |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasUser.property.teamIds">teamIds</a></code> | <code>string[]</code> | List of unique 24-hexadecimal digit strings that identifies the teams to which this MongoDB Cloud user belongs. |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasUser.property.username">username</a></code> | <code>string</code> | Email address that represents the username of the MongoDB Cloud user. |

---

##### `country`<sup>Optional</sup> <a name="country" id="awscdk-resources-mongodbatlas.AtlasUser.property.country"></a>

```typescript
public readonly country: string;
```

- *Type:* string

Two alphabet characters that identifies MongoDB Cloud user's geographic location.

This parameter uses the ISO 3166-1a2 code format.

---

##### `emailAddress`<sup>Optional</sup> <a name="emailAddress" id="awscdk-resources-mongodbatlas.AtlasUser.property.emailAddress"></a>

```typescript
public readonly emailAddress: string;
```

- *Type:* string

Email address that belongs to the MongoDB Cloud user.

---

##### `firstName`<sup>Optional</sup> <a name="firstName" id="awscdk-resources-mongodbatlas.AtlasUser.property.firstName"></a>

```typescript
public readonly firstName: string;
```

- *Type:* string

First or given name that belongs to the MongoDB Cloud user.

---

##### `id`<sup>Optional</sup> <a name="id" id="awscdk-resources-mongodbatlas.AtlasUser.property.id"></a>

```typescript
public readonly id: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies the MongoDB Cloud user.

---

##### `lastName`<sup>Optional</sup> <a name="lastName" id="awscdk-resources-mongodbatlas.AtlasUser.property.lastName"></a>

```typescript
public readonly lastName: string;
```

- *Type:* string

Last name, family name, or surname that belongs to the MongoDB Cloud user.

---

##### `links`<sup>Optional</sup> <a name="links" id="awscdk-resources-mongodbatlas.AtlasUser.property.links"></a>

```typescript
public readonly links: Link[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.Link">Link</a>[]

List of one or more Uniform Resource Locators (URLs) that point to API sub-resources, related API resources, or both.

RFC 5988 outlines these relationships.

---

##### `mobileNumber`<sup>Optional</sup> <a name="mobileNumber" id="awscdk-resources-mongodbatlas.AtlasUser.property.mobileNumber"></a>

```typescript
public readonly mobileNumber: string;
```

- *Type:* string

Mobile phone number that belongs to the MongoDB Cloud user.

---

##### `password`<sup>Optional</sup> <a name="password" id="awscdk-resources-mongodbatlas.AtlasUser.property.password"></a>

```typescript
public readonly password: string;
```

- *Type:* string

Password applied with the username to log in to MongoDB Cloud.

MongoDB Cloud does not return this parameter except in response to creating a new MongoDB Cloud user. Only the MongoDB Cloud user can update their password after it has been set from the MongoDB Cloud console.

---

##### `roles`<sup>Optional</sup> <a name="roles" id="awscdk-resources-mongodbatlas.AtlasUser.property.roles"></a>

```typescript
public readonly roles: AtlasRole[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.AtlasRole">AtlasRole</a>[]

List of objects that display the MongoDB Cloud user's roles and the corresponding organization or project to which that role applies.

A role can apply to one organization or one project but not both.

---

##### `teamIds`<sup>Optional</sup> <a name="teamIds" id="awscdk-resources-mongodbatlas.AtlasUser.property.teamIds"></a>

```typescript
public readonly teamIds: string[];
```

- *Type:* string[]

List of unique 24-hexadecimal digit strings that identifies the teams to which this MongoDB Cloud user belongs.

---

##### `username`<sup>Optional</sup> <a name="username" id="awscdk-resources-mongodbatlas.AtlasUser.property.username"></a>

```typescript
public readonly username: string;
```

- *Type:* string

Email address that represents the username of the MongoDB Cloud user.

---

### AuthConfig <a name="AuthConfig" id="awscdk-resources-mongodbatlas.AuthConfig"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.AuthConfig.Initializer"></a>

```typescript
import { AuthConfig } from 'awscdk-resources-mongodbatlas'

const authConfig: AuthConfig = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.AuthConfig.property.operationType">operationType</a></code> | <code><a href="#awscdk-resources-mongodbatlas.AuthConfigOperationType">AuthConfigOperationType</a></code> | The type of authentication event that the trigger listens for. |
| <code><a href="#awscdk-resources-mongodbatlas.AuthConfig.property.providers">providers</a></code> | <code><a href="#awscdk-resources-mongodbatlas.AuthConfigProviders">AuthConfigProviders</a>[]</code> | The type(s) of authentication provider that the trigger listens to. |

---

##### `operationType`<sup>Required</sup> <a name="operationType" id="awscdk-resources-mongodbatlas.AuthConfig.property.operationType"></a>

```typescript
public readonly operationType: AuthConfigOperationType;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.AuthConfigOperationType">AuthConfigOperationType</a>

The type of authentication event that the trigger listens for.

---

##### `providers`<sup>Required</sup> <a name="providers" id="awscdk-resources-mongodbatlas.AuthConfig.property.providers"></a>

```typescript
public readonly providers: AuthConfigProviders[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.AuthConfigProviders">AuthConfigProviders</a>[]

The type(s) of authentication provider that the trigger listens to.

---

### AwsKmsConfiguration <a name="AwsKmsConfiguration" id="awscdk-resources-mongodbatlas.AwsKmsConfiguration"></a>

Specifies AWS KMS configuration details and whether Encryption at Rest is enabled for an Atlas project.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.AwsKmsConfiguration.Initializer"></a>

```typescript
import { AwsKmsConfiguration } from 'awscdk-resources-mongodbatlas'

const awsKmsConfiguration: AwsKmsConfiguration = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.AwsKmsConfiguration.property.customerMasterKeyId">customerMasterKeyId</a></code> | <code>string</code> | The AWS customer master key used to encrypt and decrypt the MongoDB master keys. |
| <code><a href="#awscdk-resources-mongodbatlas.AwsKmsConfiguration.property.enabled">enabled</a></code> | <code>boolean</code> | Specifies whether Encryption at Rest is enabled for an Atlas project. |
| <code><a href="#awscdk-resources-mongodbatlas.AwsKmsConfiguration.property.region">region</a></code> | <code>string</code> | The AWS region in which the AWS customer master key exists. |
| <code><a href="#awscdk-resources-mongodbatlas.AwsKmsConfiguration.property.roleId">roleId</a></code> | <code>string</code> | ID of an AWS IAM role authorized to manage an AWS customer master key. |

---

##### `customerMasterKeyId`<sup>Optional</sup> <a name="customerMasterKeyId" id="awscdk-resources-mongodbatlas.AwsKmsConfiguration.property.customerMasterKeyId"></a>

```typescript
public readonly customerMasterKeyId: string;
```

- *Type:* string

The AWS customer master key used to encrypt and decrypt the MongoDB master keys.

---

##### `enabled`<sup>Optional</sup> <a name="enabled" id="awscdk-resources-mongodbatlas.AwsKmsConfiguration.property.enabled"></a>

```typescript
public readonly enabled: boolean;
```

- *Type:* boolean

Specifies whether Encryption at Rest is enabled for an Atlas project.

To disable Encryption at Rest, pass only this parameter with a value of false. When you disable Encryption at Rest, Atlas also removes the configuration details.

---

##### `region`<sup>Optional</sup> <a name="region" id="awscdk-resources-mongodbatlas.AwsKmsConfiguration.property.region"></a>

```typescript
public readonly region: string;
```

- *Type:* string

The AWS region in which the AWS customer master key exists.

---

##### `roleId`<sup>Optional</sup> <a name="roleId" id="awscdk-resources-mongodbatlas.AwsKmsConfiguration.property.roleId"></a>

```typescript
public readonly roleId: string;
```

- *Type:* string

ID of an AWS IAM role authorized to manage an AWS customer master key.

---

### AwsPrivateEndpointConfig <a name="AwsPrivateEndpointConfig" id="awscdk-resources-mongodbatlas.AwsPrivateEndpointConfig"></a>

AWS Private endpoint configuration properties.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.AwsPrivateEndpointConfig.Initializer"></a>

```typescript
import { AwsPrivateEndpointConfig } from 'awscdk-resources-mongodbatlas'

const awsPrivateEndpointConfig: AwsPrivateEndpointConfig = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.AwsPrivateEndpointConfig.property.awsPrivateEndpointStatus">awsPrivateEndpointStatus</a></code> | <code>string</code> | Status of the AWS PrivateEndpoint connection. |
| <code><a href="#awscdk-resources-mongodbatlas.AwsPrivateEndpointConfig.property.interfaceEndpointId">interfaceEndpointId</a></code> | <code>string</code> | Unique identifiers of the interface endpoints in your VPC that you added to the AWS PrivateLink connection. |
| <code><a href="#awscdk-resources-mongodbatlas.AwsPrivateEndpointConfig.property.region">region</a></code> | <code>string</code> | Aws Region. |
| <code><a href="#awscdk-resources-mongodbatlas.AwsPrivateEndpointConfig.property.subnetIds">subnetIds</a></code> | <code>string[]</code> | List of string representing the AWS VPC Subnet ID (like: subnet-xxxxxxxxxxxxxxxxx) (Used For Creating the AWS VPC Endpoint). |
| <code><a href="#awscdk-resources-mongodbatlas.AwsPrivateEndpointConfig.property.vpcId">vpcId</a></code> | <code>string</code> | String Representing the AWS VPC ID (like: vpc-xxxxxxxxxxxxxxxx) (Used For Creating the AWS VPC Endpoint). |

---

##### `awsPrivateEndpointStatus`<sup>Optional</sup> <a name="awsPrivateEndpointStatus" id="awscdk-resources-mongodbatlas.AwsPrivateEndpointConfig.property.awsPrivateEndpointStatus"></a>

```typescript
public readonly awsPrivateEndpointStatus: string;
```

- *Type:* string

Status of the AWS PrivateEndpoint connection.

---

##### `interfaceEndpointId`<sup>Optional</sup> <a name="interfaceEndpointId" id="awscdk-resources-mongodbatlas.AwsPrivateEndpointConfig.property.interfaceEndpointId"></a>

```typescript
public readonly interfaceEndpointId: string;
```

- *Type:* string

Unique identifiers of the interface endpoints in your VPC that you added to the AWS PrivateLink connection.

---

##### `region`<sup>Optional</sup> <a name="region" id="awscdk-resources-mongodbatlas.AwsPrivateEndpointConfig.property.region"></a>

```typescript
public readonly region: string;
```

- *Type:* string

Aws Region.

---

##### `subnetIds`<sup>Optional</sup> <a name="subnetIds" id="awscdk-resources-mongodbatlas.AwsPrivateEndpointConfig.property.subnetIds"></a>

```typescript
public readonly subnetIds: string[];
```

- *Type:* string[]

List of string representing the AWS VPC Subnet ID (like: subnet-xxxxxxxxxxxxxxxxx) (Used For Creating the AWS VPC Endpoint).

---

##### `vpcId`<sup>Optional</sup> <a name="vpcId" id="awscdk-resources-mongodbatlas.AwsPrivateEndpointConfig.property.vpcId"></a>

```typescript
public readonly vpcId: string;
```

- *Type:* string

String Representing the AWS VPC ID (like: vpc-xxxxxxxxxxxxxxxx) (Used For Creating the AWS VPC Endpoint).

---

### CfnAccessListApiKeyProps <a name="CfnAccessListApiKeyProps" id="awscdk-resources-mongodbatlas.CfnAccessListApiKeyProps"></a>

Creates the access list entries for the specified organization API key.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnAccessListApiKeyProps.Initializer"></a>

```typescript
import { CfnAccessListApiKeyProps } from 'awscdk-resources-mongodbatlas'

const cfnAccessListApiKeyProps: CfnAccessListApiKeyProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAccessListApiKeyProps.property.apiUserId">apiUserId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies this organization API key for which you want to return access list entries. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAccessListApiKeyProps.property.orgId">orgId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies the organization that contains your projects. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAccessListApiKeyProps.property.cidrBlock">cidrBlock</a></code> | <code>string</code> | Range of network addresses that you want to add to the access list for the API key. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAccessListApiKeyProps.property.ipAddress">ipAddress</a></code> | <code>string</code> | Network address that you want to add to the access list for the API key. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAccessListApiKeyProps.property.profile">profile</a></code> | <code>string</code> | Network address that issued the most recent request to the API. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAccessListApiKeyProps.property.totalCount">totalCount</a></code> | <code>number</code> | Number of documents returned in this response. |

---

##### `apiUserId`<sup>Required</sup> <a name="apiUserId" id="awscdk-resources-mongodbatlas.CfnAccessListApiKeyProps.property.apiUserId"></a>

```typescript
public readonly apiUserId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies this organization API key for which you want to return access list entries.

---

##### `orgId`<sup>Required</sup> <a name="orgId" id="awscdk-resources-mongodbatlas.CfnAccessListApiKeyProps.property.orgId"></a>

```typescript
public readonly orgId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies the organization that contains your projects.

---

##### `cidrBlock`<sup>Optional</sup> <a name="cidrBlock" id="awscdk-resources-mongodbatlas.CfnAccessListApiKeyProps.property.cidrBlock"></a>

```typescript
public readonly cidrBlock: string;
```

- *Type:* string

Range of network addresses that you want to add to the access list for the API key.

---

##### `ipAddress`<sup>Optional</sup> <a name="ipAddress" id="awscdk-resources-mongodbatlas.CfnAccessListApiKeyProps.property.ipAddress"></a>

```typescript
public readonly ipAddress: string;
```

- *Type:* string

Network address that you want to add to the access list for the API key.

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.CfnAccessListApiKeyProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

Network address that issued the most recent request to the API.

---

##### `totalCount`<sup>Optional</sup> <a name="totalCount" id="awscdk-resources-mongodbatlas.CfnAccessListApiKeyProps.property.totalCount"></a>

```typescript
public readonly totalCount: number;
```

- *Type:* number

Number of documents returned in this response.

---

### CfnAlertConfigurationProps <a name="CfnAlertConfigurationProps" id="awscdk-resources-mongodbatlas.CfnAlertConfigurationProps"></a>

Returns and edits the conditions that trigger alerts and how MongoDB Cloud notifies users.

This collection remains under revision and may change. Refer to the legacy documentation for this collection in the following link.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnAlertConfigurationProps.Initializer"></a>

```typescript
import { CfnAlertConfigurationProps } from 'awscdk-resources-mongodbatlas'

const cfnAlertConfigurationProps: CfnAlertConfigurationProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAlertConfigurationProps.property.created">created</a></code> | <code>string</code> | Date and time when MongoDB Cloud created the alert configuration. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAlertConfigurationProps.property.eventTypeName">eventTypeName</a></code> | <code>string</code> | Event type that triggers an alert. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAlertConfigurationProps.property.matchers">matchers</a></code> | <code><a href="#awscdk-resources-mongodbatlas.Matcher">Matcher</a>[]</code> | List of rules that determine whether MongoDB Cloud checks an object for the alert configuration. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAlertConfigurationProps.property.metricThreshold">metricThreshold</a></code> | <code><a href="#awscdk-resources-mongodbatlas.MetricThresholdView">MetricThresholdView</a></code> | Threshold for the metric that, when exceeded, triggers an alert. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAlertConfigurationProps.property.notifications">notifications</a></code> | <code><a href="#awscdk-resources-mongodbatlas.NotificationView">NotificationView</a>[]</code> | List that contains the targets that MongoDB Cloud sends notifications. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAlertConfigurationProps.property.profile">profile</a></code> | <code>string</code> | Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided default is used. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAlertConfigurationProps.property.projectId">projectId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies your project. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAlertConfigurationProps.property.threshold">threshold</a></code> | <code><a href="#awscdk-resources-mongodbatlas.IntegerThresholdView">IntegerThresholdView</a></code> | Limit that triggers an alert when exceeded. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAlertConfigurationProps.property.typeName">typeName</a></code> | <code>string</code> | Human-readable label that displays the alert type. |

---

##### `created`<sup>Optional</sup> <a name="created" id="awscdk-resources-mongodbatlas.CfnAlertConfigurationProps.property.created"></a>

```typescript
public readonly created: string;
```

- *Type:* string

Date and time when MongoDB Cloud created the alert configuration.

This parameter expresses its value in the ISO 8601 timestamp format in UTC.

---

##### `eventTypeName`<sup>Optional</sup> <a name="eventTypeName" id="awscdk-resources-mongodbatlas.CfnAlertConfigurationProps.property.eventTypeName"></a>

```typescript
public readonly eventTypeName: string;
```

- *Type:* string

Event type that triggers an alert.

---

##### `matchers`<sup>Optional</sup> <a name="matchers" id="awscdk-resources-mongodbatlas.CfnAlertConfigurationProps.property.matchers"></a>

```typescript
public readonly matchers: Matcher[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.Matcher">Matcher</a>[]

List of rules that determine whether MongoDB Cloud checks an object for the alert configuration.

You can filter using the matchers array if the **eventTypeName** specifies an event for a host, replica set, or sharded cluster.

---

##### `metricThreshold`<sup>Optional</sup> <a name="metricThreshold" id="awscdk-resources-mongodbatlas.CfnAlertConfigurationProps.property.metricThreshold"></a>

```typescript
public readonly metricThreshold: MetricThresholdView;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.MetricThresholdView">MetricThresholdView</a>

Threshold for the metric that, when exceeded, triggers an alert.

The resource returns this parameter when '"eventTypeName" : "OUTSIDE_METRIC_THRESHOLD"'.

---

##### `notifications`<sup>Optional</sup> <a name="notifications" id="awscdk-resources-mongodbatlas.CfnAlertConfigurationProps.property.notifications"></a>

```typescript
public readonly notifications: NotificationView[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.NotificationView">NotificationView</a>[]

List that contains the targets that MongoDB Cloud sends notifications.

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.CfnAlertConfigurationProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided default is used.

---

##### `projectId`<sup>Optional</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.CfnAlertConfigurationProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies your project.

---

##### `threshold`<sup>Optional</sup> <a name="threshold" id="awscdk-resources-mongodbatlas.CfnAlertConfigurationProps.property.threshold"></a>

```typescript
public readonly threshold: IntegerThresholdView;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.IntegerThresholdView">IntegerThresholdView</a>

Limit that triggers an alert when exceeded.

The resource returns this parameter when **eventTypeName** has not been set to 'OUTSIDE_METRIC_THRESHOLD'.

---

##### `typeName`<sup>Optional</sup> <a name="typeName" id="awscdk-resources-mongodbatlas.CfnAlertConfigurationProps.property.typeName"></a>

```typescript
public readonly typeName: string;
```

- *Type:* string

Human-readable label that displays the alert type.

---

### CfnApiKeyProps <a name="CfnApiKeyProps" id="awscdk-resources-mongodbatlas.CfnApiKeyProps"></a>

Creates one API key for the specified organization.

An organization API key grants programmatic access to an organization.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnApiKeyProps.Initializer"></a>

```typescript
import { CfnApiKeyProps } from 'awscdk-resources-mongodbatlas'

const cfnApiKeyProps: CfnApiKeyProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnApiKeyProps.property.description">description</a></code> | <code>string</code> | Purpose or explanation provided when someone created this organization API key. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnApiKeyProps.property.orgId">orgId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies the organization that contains your projects. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnApiKeyProps.property.awsSecretName">awsSecretName</a></code> | <code>string</code> | Name of the AWS Secrets Manager secret that stores the API key Details. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnApiKeyProps.property.listOptions">listOptions</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ListOptions">ListOptions</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnApiKeyProps.property.profile">profile</a></code> | <code>string</code> | Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided default is used. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnApiKeyProps.property.projectAssignments">projectAssignments</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ProjectAssignment">ProjectAssignment</a>[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnApiKeyProps.property.roles">roles</a></code> | <code>string[]</code> | List of roles to grant this API key. |

---

##### `description`<sup>Required</sup> <a name="description" id="awscdk-resources-mongodbatlas.CfnApiKeyProps.property.description"></a>

```typescript
public readonly description: string;
```

- *Type:* string

Purpose or explanation provided when someone created this organization API key.

---

##### `orgId`<sup>Required</sup> <a name="orgId" id="awscdk-resources-mongodbatlas.CfnApiKeyProps.property.orgId"></a>

```typescript
public readonly orgId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies the organization that contains your projects.

Use the /orgs endpoint to retrieve all organizations to which the authenticated user has access.

---

##### `awsSecretName`<sup>Optional</sup> <a name="awsSecretName" id="awscdk-resources-mongodbatlas.CfnApiKeyProps.property.awsSecretName"></a>

```typescript
public readonly awsSecretName: string;
```

- *Type:* string

Name of the AWS Secrets Manager secret that stores the API key Details.

The secret name must be unique to the AWS account and region. If you don't specify a name, AWS CloudFormation use APIUserId for the secret name.

---

##### `listOptions`<sup>Optional</sup> <a name="listOptions" id="awscdk-resources-mongodbatlas.CfnApiKeyProps.property.listOptions"></a>

```typescript
public readonly listOptions: ListOptions;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ListOptions">ListOptions</a>

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.CfnApiKeyProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided default is used.

---

##### `projectAssignments`<sup>Optional</sup> <a name="projectAssignments" id="awscdk-resources-mongodbatlas.CfnApiKeyProps.property.projectAssignments"></a>

```typescript
public readonly projectAssignments: ProjectAssignment[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ProjectAssignment">ProjectAssignment</a>[]

---

##### `roles`<sup>Optional</sup> <a name="roles" id="awscdk-resources-mongodbatlas.CfnApiKeyProps.property.roles"></a>

```typescript
public readonly roles: string[];
```

- *Type:* string[]

List of roles to grant this API key.

If you provide this list, provide a minimum of one role and ensure each role applies to this organization.

---

### CfnAuditingProps <a name="CfnAuditingProps" id="awscdk-resources-mongodbatlas.CfnAuditingProps"></a>

Returns and edits database auditing settings for MongoDB Cloud projects.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnAuditingProps.Initializer"></a>

```typescript
import { CfnAuditingProps } from 'awscdk-resources-mongodbatlas'

const cfnAuditingProps: CfnAuditingProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAuditingProps.property.projectId">projectId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies your project. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnAuditingProps.property.profile">profile</a></code> | <code>string</code> | Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided default is used. |

---

##### `projectId`<sup>Required</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.CfnAuditingProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies your project.

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.CfnAuditingProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided default is used.

---

### CfnCloudBackUpRestoreJobsProps <a name="CfnCloudBackUpRestoreJobsProps" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsProps"></a>

Returns, starts, and cancels Cloud Backup restore jobs.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsProps.Initializer"></a>

```typescript
import { CfnCloudBackUpRestoreJobsProps } from 'awscdk-resources-mongodbatlas'

const cfnCloudBackUpRestoreJobsProps: CfnCloudBackUpRestoreJobsProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsProps.property.deliveryType">deliveryType</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsPropsDeliveryType">CfnCloudBackUpRestoreJobsPropsDeliveryType</a></code> | Type of restore job to create.The value can be any one of download,automated or point_in_time. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsProps.property.instanceName">instanceName</a></code> | <code>string</code> | The instance name of the Serverless/Cluster whose snapshot you want to restore or you want to retrieve restore jobs. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsProps.property.instanceType">instanceType</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsPropsInstanceType">CfnCloudBackUpRestoreJobsPropsInstanceType</a></code> | Type of instance specified on the Instance Name serverless or cluster. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsProps.property.projectId">projectId</a></code> | <code>string</code> | The unique identifier of the project for the Atlas cluster. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsProps.property.snapshotId">snapshotId</a></code> | <code>string</code> | Unique identifier of the source snapshot ID of the restore job. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsProps.property.cancelled">cancelled</a></code> | <code>boolean</code> | Indicates whether the restore job was canceled. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsProps.property.enableSynchronousCreation">enableSynchronousCreation</a></code> | <code>boolean</code> | If set to true, the CloudFormation resource will wait until the job is completed, WARNING: if the snapshot has a big load of data, the cloud formation resource might take a long time to finish leading to high costs. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsProps.property.expired">expired</a></code> | <code>boolean</code> | Indicates whether the restore job expired. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsProps.property.failed">failed</a></code> | <code>boolean</code> | Indicates whether the restore job failed. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsProps.property.opLogInc">opLogInc</a></code> | <code>string</code> | Oplog operation number from which to you want to restore this snapshot. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsProps.property.opLogTs">opLogTs</a></code> | <code>string</code> | Timestamp in the number of seconds that have elapsed since the UNIX epoch from which to you want to restore this snapshot. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsProps.property.pointInTimeUtcSeconds">pointInTimeUtcSeconds</a></code> | <code>number</code> | If you performed a Point-in-Time restores at a time specified by a Unix time in seconds since epoch, pointInTimeUTCSeconds indicates the Unix time used. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsProps.property.profile">profile</a></code> | <code>string</code> | Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided default is used. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsProps.property.synchronousCreationOptions">synchronousCreationOptions</a></code> | <code><a href="#awscdk-resources-mongodbatlas.SynchronousCreationOptions">SynchronousCreationOptions</a></code> | Options that needs to be set to control the synchronous creation flow, this options need to be set if EnableSynchronousCreation is se to TRUE. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsProps.property.targetClusterName">targetClusterName</a></code> | <code>string</code> | Name of the target Atlas cluster to which the restore job restores the snapshot. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsProps.property.targetProjectId">targetProjectId</a></code> | <code>string</code> | Name of the target Atlas project of the restore job. |

---

##### `deliveryType`<sup>Required</sup> <a name="deliveryType" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsProps.property.deliveryType"></a>

```typescript
public readonly deliveryType: CfnCloudBackUpRestoreJobsPropsDeliveryType;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsPropsDeliveryType">CfnCloudBackUpRestoreJobsPropsDeliveryType</a>

Type of restore job to create.The value can be any one of download,automated or point_in_time.

---

##### `instanceName`<sup>Required</sup> <a name="instanceName" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsProps.property.instanceName"></a>

```typescript
public readonly instanceName: string;
```

- *Type:* string

The instance name of the Serverless/Cluster whose snapshot you want to restore or you want to retrieve restore jobs.

---

##### `instanceType`<sup>Required</sup> <a name="instanceType" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsProps.property.instanceType"></a>

```typescript
public readonly instanceType: CfnCloudBackUpRestoreJobsPropsInstanceType;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsPropsInstanceType">CfnCloudBackUpRestoreJobsPropsInstanceType</a>

Type of instance specified on the Instance Name serverless or cluster.

---

##### `projectId`<sup>Required</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

The unique identifier of the project for the Atlas cluster.

---

##### `snapshotId`<sup>Required</sup> <a name="snapshotId" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsProps.property.snapshotId"></a>

```typescript
public readonly snapshotId: string;
```

- *Type:* string

Unique identifier of the source snapshot ID of the restore job.

---

##### `cancelled`<sup>Optional</sup> <a name="cancelled" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsProps.property.cancelled"></a>

```typescript
public readonly cancelled: boolean;
```

- *Type:* boolean

Indicates whether the restore job was canceled.

---

##### `enableSynchronousCreation`<sup>Optional</sup> <a name="enableSynchronousCreation" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsProps.property.enableSynchronousCreation"></a>

```typescript
public readonly enableSynchronousCreation: boolean;
```

- *Type:* boolean

If set to true, the CloudFormation resource will wait until the job is completed, WARNING: if the snapshot has a big load of data, the cloud formation resource might take a long time to finish leading to high costs.

---

##### `expired`<sup>Optional</sup> <a name="expired" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsProps.property.expired"></a>

```typescript
public readonly expired: boolean;
```

- *Type:* boolean

Indicates whether the restore job expired.

---

##### `failed`<sup>Optional</sup> <a name="failed" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsProps.property.failed"></a>

```typescript
public readonly failed: boolean;
```

- *Type:* boolean

Indicates whether the restore job failed.

---

##### `opLogInc`<sup>Optional</sup> <a name="opLogInc" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsProps.property.opLogInc"></a>

```typescript
public readonly opLogInc: string;
```

- *Type:* string

Oplog operation number from which to you want to restore this snapshot.

This is the second part of an Oplog timestamp.

---

##### `opLogTs`<sup>Optional</sup> <a name="opLogTs" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsProps.property.opLogTs"></a>

```typescript
public readonly opLogTs: string;
```

- *Type:* string

Timestamp in the number of seconds that have elapsed since the UNIX epoch from which to you want to restore this snapshot.

This is the first part of an Oplog timestamp.

---

##### `pointInTimeUtcSeconds`<sup>Optional</sup> <a name="pointInTimeUtcSeconds" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsProps.property.pointInTimeUtcSeconds"></a>

```typescript
public readonly pointInTimeUtcSeconds: number;
```

- *Type:* number

If you performed a Point-in-Time restores at a time specified by a Unix time in seconds since epoch, pointInTimeUTCSeconds indicates the Unix time used.

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided default is used.

---

##### `synchronousCreationOptions`<sup>Optional</sup> <a name="synchronousCreationOptions" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsProps.property.synchronousCreationOptions"></a>

```typescript
public readonly synchronousCreationOptions: SynchronousCreationOptions;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.SynchronousCreationOptions">SynchronousCreationOptions</a>

Options that needs to be set to control the synchronous creation flow, this options need to be set if EnableSynchronousCreation is se to TRUE.

---

##### `targetClusterName`<sup>Optional</sup> <a name="targetClusterName" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsProps.property.targetClusterName"></a>

```typescript
public readonly targetClusterName: string;
```

- *Type:* string

Name of the target Atlas cluster to which the restore job restores the snapshot.

Only visible if deliveryType is automated.

---

##### `targetProjectId`<sup>Optional</sup> <a name="targetProjectId" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsProps.property.targetProjectId"></a>

```typescript
public readonly targetProjectId: string;
```

- *Type:* string

Name of the target Atlas project of the restore job.

Only visible if deliveryType is automated.

---

### CfnCloudBackupScheduleProps <a name="CfnCloudBackupScheduleProps" id="awscdk-resources-mongodbatlas.CfnCloudBackupScheduleProps"></a>

An example resource schema demonstrating some basic constructs and validation rules.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnCloudBackupScheduleProps.Initializer"></a>

```typescript
import { CfnCloudBackupScheduleProps } from 'awscdk-resources-mongodbatlas'

const cfnCloudBackupScheduleProps: CfnCloudBackupScheduleProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupScheduleProps.property.clusterName">clusterName</a></code> | <code>string</code> | The name of the Atlas cluster that contains the snapshots you want to retrieve. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupScheduleProps.property.projectId">projectId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies your project. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupScheduleProps.property.autoExportEnabled">autoExportEnabled</a></code> | <code>boolean</code> | Flag that indicates whether automatic export of cloud backup snapshots to the AWS bucket is enabled. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupScheduleProps.property.copySettings">copySettings</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupCopySettingView">ApiAtlasDiskBackupCopySettingView</a>[]</code> | List that contains a document for each copy setting item in the desired backup policy. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupScheduleProps.property.deleteCopiedBackups">deleteCopiedBackups</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ApiDeleteCopiedBackupsView">ApiDeleteCopiedBackupsView</a>[]</code> | List that contains a document for each deleted copy setting whose backup copies you want to delete. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupScheduleProps.property.export">export</a></code> | <code><a href="#awscdk-resources-mongodbatlas.Export">Export</a></code> | Policy for automatically exporting cloud backup snapshots. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupScheduleProps.property.id">id</a></code> | <code>string</code> | Unique identifier of the snapshot. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupScheduleProps.property.links">links</a></code> | <code><a href="#awscdk-resources-mongodbatlas.Link">Link</a>[]</code> | List of one or more Uniform Resource Locators (URLs) that point to API sub-resources, related API resources, or both. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupScheduleProps.property.policies">policies</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ApiPolicyView">ApiPolicyView</a>[]</code> | Rules set for this backup schedule. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupScheduleProps.property.profile">profile</a></code> | <code>string</code> | Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided default is used. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupScheduleProps.property.referenceHourOfDay">referenceHourOfDay</a></code> | <code>number</code> | UTC Hour of day between 0 and 23 representing which hour of the day that Atlas takes a snapshot. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupScheduleProps.property.referenceMinuteOfHour">referenceMinuteOfHour</a></code> | <code>number</code> | UTC Minute of day between 0 and 59 representing which minute of the referenceHourOfDay that Atlas takes the snapshot. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupScheduleProps.property.restoreWindowDays">restoreWindowDays</a></code> | <code>number</code> | Number of days back in time you can restore to with Continuous Cloud Backup accuracy. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupScheduleProps.property.updateSnapshots">updateSnapshots</a></code> | <code>boolean</code> | Flag indicating if updates to retention in the backup policy were applied to snapshots that Atlas took earlier. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupScheduleProps.property.useOrgAndGroupNamesInExportPrefix">useOrgAndGroupNamesInExportPrefix</a></code> | <code>boolean</code> | Specify true to use organization and project names instead of organization and project UUIDs in the path for the metadata files that Atlas uploads to your S3 bucket after it finishes exporting the snapshots. |

---

##### `clusterName`<sup>Required</sup> <a name="clusterName" id="awscdk-resources-mongodbatlas.CfnCloudBackupScheduleProps.property.clusterName"></a>

```typescript
public readonly clusterName: string;
```

- *Type:* string

The name of the Atlas cluster that contains the snapshots you want to retrieve.

---

##### `projectId`<sup>Required</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.CfnCloudBackupScheduleProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies your project.

---

##### `autoExportEnabled`<sup>Optional</sup> <a name="autoExportEnabled" id="awscdk-resources-mongodbatlas.CfnCloudBackupScheduleProps.property.autoExportEnabled"></a>

```typescript
public readonly autoExportEnabled: boolean;
```

- *Type:* boolean

Flag that indicates whether automatic export of cloud backup snapshots to the AWS bucket is enabled.

---

##### `copySettings`<sup>Optional</sup> <a name="copySettings" id="awscdk-resources-mongodbatlas.CfnCloudBackupScheduleProps.property.copySettings"></a>

```typescript
public readonly copySettings: ApiAtlasDiskBackupCopySettingView[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupCopySettingView">ApiAtlasDiskBackupCopySettingView</a>[]

List that contains a document for each copy setting item in the desired backup policy.

---

##### `deleteCopiedBackups`<sup>Optional</sup> <a name="deleteCopiedBackups" id="awscdk-resources-mongodbatlas.CfnCloudBackupScheduleProps.property.deleteCopiedBackups"></a>

```typescript
public readonly deleteCopiedBackups: ApiDeleteCopiedBackupsView[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ApiDeleteCopiedBackupsView">ApiDeleteCopiedBackupsView</a>[]

List that contains a document for each deleted copy setting whose backup copies you want to delete.

---

##### `export`<sup>Optional</sup> <a name="export" id="awscdk-resources-mongodbatlas.CfnCloudBackupScheduleProps.property.export"></a>

```typescript
public readonly export: Export;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.Export">Export</a>

Policy for automatically exporting cloud backup snapshots.

---

##### `id`<sup>Optional</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnCloudBackupScheduleProps.property.id"></a>

```typescript
public readonly id: string;
```

- *Type:* string

Unique identifier of the snapshot.

---

##### `links`<sup>Optional</sup> <a name="links" id="awscdk-resources-mongodbatlas.CfnCloudBackupScheduleProps.property.links"></a>

```typescript
public readonly links: Link[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.Link">Link</a>[]

List of one or more Uniform Resource Locators (URLs) that point to API sub-resources, related API resources, or both.

RFC 5988 outlines these relationships.

---

##### `policies`<sup>Optional</sup> <a name="policies" id="awscdk-resources-mongodbatlas.CfnCloudBackupScheduleProps.property.policies"></a>

```typescript
public readonly policies: ApiPolicyView[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ApiPolicyView">ApiPolicyView</a>[]

Rules set for this backup schedule.

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.CfnCloudBackupScheduleProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided default is used.

---

##### `referenceHourOfDay`<sup>Optional</sup> <a name="referenceHourOfDay" id="awscdk-resources-mongodbatlas.CfnCloudBackupScheduleProps.property.referenceHourOfDay"></a>

```typescript
public readonly referenceHourOfDay: number;
```

- *Type:* number

UTC Hour of day between 0 and 23 representing which hour of the day that Atlas takes a snapshot.

---

##### `referenceMinuteOfHour`<sup>Optional</sup> <a name="referenceMinuteOfHour" id="awscdk-resources-mongodbatlas.CfnCloudBackupScheduleProps.property.referenceMinuteOfHour"></a>

```typescript
public readonly referenceMinuteOfHour: number;
```

- *Type:* number

UTC Minute of day between 0 and 59 representing which minute of the referenceHourOfDay that Atlas takes the snapshot.

---

##### `restoreWindowDays`<sup>Optional</sup> <a name="restoreWindowDays" id="awscdk-resources-mongodbatlas.CfnCloudBackupScheduleProps.property.restoreWindowDays"></a>

```typescript
public readonly restoreWindowDays: number;
```

- *Type:* number

Number of days back in time you can restore to with Continuous Cloud Backup accuracy.

Must be a positive, non-zero integer.

---

##### `updateSnapshots`<sup>Optional</sup> <a name="updateSnapshots" id="awscdk-resources-mongodbatlas.CfnCloudBackupScheduleProps.property.updateSnapshots"></a>

```typescript
public readonly updateSnapshots: boolean;
```

- *Type:* boolean

Flag indicating if updates to retention in the backup policy were applied to snapshots that Atlas took earlier.

---

##### `useOrgAndGroupNamesInExportPrefix`<sup>Optional</sup> <a name="useOrgAndGroupNamesInExportPrefix" id="awscdk-resources-mongodbatlas.CfnCloudBackupScheduleProps.property.useOrgAndGroupNamesInExportPrefix"></a>

```typescript
public readonly useOrgAndGroupNamesInExportPrefix: boolean;
```

- *Type:* boolean

Specify true to use organization and project names instead of organization and project UUIDs in the path for the metadata files that Atlas uploads to your S3 bucket after it finishes exporting the snapshots.

---

### CfnCloudBackupSnapshotExportBucketProps <a name="CfnCloudBackupSnapshotExportBucketProps" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucketProps"></a>

The exportBuckets resource allows you to grant Atlas access to the specified bucket for exporting backup snapshots.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucketProps.Initializer"></a>

```typescript
import { CfnCloudBackupSnapshotExportBucketProps } from 'awscdk-resources-mongodbatlas'

const cfnCloudBackupSnapshotExportBucketProps: CfnCloudBackupSnapshotExportBucketProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucketProps.property.bucketName">bucketName</a></code> | <code>string</code> | Human-readable label that identifies the AWS bucket that the role is authorized to access. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucketProps.property.iamRoleId">iamRoleId</a></code> | <code>string</code> | Unique 24-hexadecimal character string that identifies the AWS IAM role that MongoDB Cloud uses to access the AWS S3 bucket. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucketProps.property.projectId">projectId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies your project. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucketProps.property.profile">profile</a></code> | <code>string</code> | The profile is defined in AWS Secret manager. |

---

##### `bucketName`<sup>Required</sup> <a name="bucketName" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucketProps.property.bucketName"></a>

```typescript
public readonly bucketName: string;
```

- *Type:* string

Human-readable label that identifies the AWS bucket that the role is authorized to access.

---

##### `iamRoleId`<sup>Required</sup> <a name="iamRoleId" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucketProps.property.iamRoleId"></a>

```typescript
public readonly iamRoleId: string;
```

- *Type:* string

Unique 24-hexadecimal character string that identifies the AWS IAM role that MongoDB Cloud uses to access the AWS S3 bucket.

---

##### `projectId`<sup>Required</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucketProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies your project.

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotExportBucketProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

The profile is defined in AWS Secret manager.

See [Secret Manager Profile setup](../../../examples/profile-secret.yaml).

---

### CfnCloudBackupSnapshotProps <a name="CfnCloudBackupSnapshotProps" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotProps"></a>

Returns, takes, and removes Cloud Backup snapshots.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotProps.Initializer"></a>

```typescript
import { CfnCloudBackupSnapshotProps } from 'awscdk-resources-mongodbatlas'

const cfnCloudBackupSnapshotProps: CfnCloudBackupSnapshotProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotProps.property.instanceName">instanceName</a></code> | <code>string</code> | The instance name of the Serverless/Cluster whose snapshot you want to restore or you want to retrieve restore snapshot. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotProps.property.instanceType">instanceType</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotPropsInstanceType">CfnCloudBackupSnapshotPropsInstanceType</a></code> | Type of instance specified on the Instance Name serverless or cluster. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotProps.property.projectId">projectId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies your project. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotProps.property.description">description</a></code> | <code>string</code> | Human-readable phrase or sentence that explains the purpose of the snapshot. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotProps.property.frequencyType">frequencyType</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotPropsFrequencyType">CfnCloudBackupSnapshotPropsFrequencyType</a></code> | Human-readable label that identifies how often this snapshot triggers. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotProps.property.includeCount">includeCount</a></code> | <code>boolean</code> | Flag that indicates whether the response returns the total number of items (**totalCount**) in the response. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotProps.property.itemsPerPage">itemsPerPage</a></code> | <code>number</code> | Number of items that the response returns per page. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotProps.property.members">members</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotMemberView">ApiAtlasDiskBackupShardedClusterSnapshotMemberView</a>[]</code> | List that includes the snapshots and the cloud provider that stores the snapshots. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotProps.property.pageNum">pageNum</a></code> | <code>number</code> | Number of the page that displays the current set of the total objects that the response returns. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotProps.property.policyItems">policyItems</a></code> | <code>string[]</code> | List that contains unique identifiers for the policy items. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotProps.property.profile">profile</a></code> | <code>string</code> | The profile is defined in AWS Secret manager. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotProps.property.results">results</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotView">ApiAtlasDiskBackupShardedClusterSnapshotView</a>[]</code> | List of returned documents that MongoDB Cloud provides when completing this request. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotProps.property.retentionInDays">retentionInDays</a></code> | <code>number</code> | Number of days that MongoDB Cloud should retain the on-demand snapshot. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotProps.property.snapshotType">snapshotType</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotPropsSnapshotType">CfnCloudBackupSnapshotPropsSnapshotType</a></code> | Human-readable label that identifies when this snapshot triggers. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotProps.property.totalCount">totalCount</a></code> | <code>number</code> | Number of documents returned in this response. |

---

##### `instanceName`<sup>Required</sup> <a name="instanceName" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotProps.property.instanceName"></a>

```typescript
public readonly instanceName: string;
```

- *Type:* string

The instance name of the Serverless/Cluster whose snapshot you want to restore or you want to retrieve restore snapshot.

---

##### `instanceType`<sup>Required</sup> <a name="instanceType" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotProps.property.instanceType"></a>

```typescript
public readonly instanceType: CfnCloudBackupSnapshotPropsInstanceType;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotPropsInstanceType">CfnCloudBackupSnapshotPropsInstanceType</a>

Type of instance specified on the Instance Name serverless or cluster.

---

##### `projectId`<sup>Required</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies your project.

---

##### `description`<sup>Optional</sup> <a name="description" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotProps.property.description"></a>

```typescript
public readonly description: string;
```

- *Type:* string

Human-readable phrase or sentence that explains the purpose of the snapshot.

The resource returns this parameter when `"status": "onDemand"`.

---

##### `frequencyType`<sup>Optional</sup> <a name="frequencyType" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotProps.property.frequencyType"></a>

```typescript
public readonly frequencyType: CfnCloudBackupSnapshotPropsFrequencyType;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotPropsFrequencyType">CfnCloudBackupSnapshotPropsFrequencyType</a>

Human-readable label that identifies how often this snapshot triggers.

---

##### `includeCount`<sup>Optional</sup> <a name="includeCount" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotProps.property.includeCount"></a>

```typescript
public readonly includeCount: boolean;
```

- *Type:* boolean

Flag that indicates whether the response returns the total number of items (**totalCount**) in the response.

---

##### `itemsPerPage`<sup>Optional</sup> <a name="itemsPerPage" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotProps.property.itemsPerPage"></a>

```typescript
public readonly itemsPerPage: number;
```

- *Type:* number

Number of items that the response returns per page.

---

##### `members`<sup>Optional</sup> <a name="members" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotProps.property.members"></a>

```typescript
public readonly members: ApiAtlasDiskBackupShardedClusterSnapshotMemberView[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotMemberView">ApiAtlasDiskBackupShardedClusterSnapshotMemberView</a>[]

List that includes the snapshots and the cloud provider that stores the snapshots.

The resource returns this parameter when `"type" : "SHARDED_CLUSTER"`.

---

##### `pageNum`<sup>Optional</sup> <a name="pageNum" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotProps.property.pageNum"></a>

```typescript
public readonly pageNum: number;
```

- *Type:* number

Number of the page that displays the current set of the total objects that the response returns.

---

##### `policyItems`<sup>Optional</sup> <a name="policyItems" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotProps.property.policyItems"></a>

```typescript
public readonly policyItems: string[];
```

- *Type:* string[]

List that contains unique identifiers for the policy items.

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

The profile is defined in AWS Secret manager.

See [Secret Manager Profile setup](../../../examples/profile-secret.yaml).

---

##### `results`<sup>Optional</sup> <a name="results" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotProps.property.results"></a>

```typescript
public readonly results: ApiAtlasDiskBackupShardedClusterSnapshotView[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotView">ApiAtlasDiskBackupShardedClusterSnapshotView</a>[]

List of returned documents that MongoDB Cloud provides when completing this request.

---

##### `retentionInDays`<sup>Optional</sup> <a name="retentionInDays" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotProps.property.retentionInDays"></a>

```typescript
public readonly retentionInDays: number;
```

- *Type:* number

Number of days that MongoDB Cloud should retain the on-demand snapshot.

Must be at least **1**

---

##### `snapshotType`<sup>Optional</sup> <a name="snapshotType" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotProps.property.snapshotType"></a>

```typescript
public readonly snapshotType: CfnCloudBackupSnapshotPropsSnapshotType;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotPropsSnapshotType">CfnCloudBackupSnapshotPropsSnapshotType</a>

Human-readable label that identifies when this snapshot triggers.

---

##### `totalCount`<sup>Optional</sup> <a name="totalCount" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotProps.property.totalCount"></a>

```typescript
public readonly totalCount: number;
```

- *Type:* number

Number of documents returned in this response.

---

### CfnClusterOutageSimulationProps <a name="CfnClusterOutageSimulationProps" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulationProps"></a>

An example resource schema demonstrating some basic constructs and validation rules.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulationProps.Initializer"></a>

```typescript
import { CfnClusterOutageSimulationProps } from 'awscdk-resources-mongodbatlas'

const cfnClusterOutageSimulationProps: CfnClusterOutageSimulationProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterOutageSimulationProps.property.clusterName">clusterName</a></code> | <code>string</code> | Human-readable label that identifies the cluster . |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterOutageSimulationProps.property.outageFilters">outageFilters</a></code> | <code><a href="#awscdk-resources-mongodbatlas.Filter">Filter</a>[]</code> | List of settings that configure your cluster regions. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterOutageSimulationProps.property.profile">profile</a></code> | <code>string</code> | The profile is defined in AWS Secret manager. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterOutageSimulationProps.property.projectId">projectId</a></code> | <code>string</code> | Human-readable label that identifies the project. |

---

##### `clusterName`<sup>Required</sup> <a name="clusterName" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulationProps.property.clusterName"></a>

```typescript
public readonly clusterName: string;
```

- *Type:* string

Human-readable label that identifies the cluster .

---

##### `outageFilters`<sup>Required</sup> <a name="outageFilters" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulationProps.property.outageFilters"></a>

```typescript
public readonly outageFilters: Filter[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.Filter">Filter</a>[]

List of settings that configure your cluster regions.

For Global Clusters, each object in the array represents a zone where your clusters nodes deploy. For non-Global replica sets and sharded clusters, this array has one object representing where your clusters nodes deploy.

---

##### `profile`<sup>Required</sup> <a name="profile" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulationProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

The profile is defined in AWS Secret manager.

See [Secret Manager Profile setup](../../../examples/profile-secret.yaml).

---

##### `projectId`<sup>Required</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.CfnClusterOutageSimulationProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

Human-readable label that identifies the project.

---

### CfnClusterProps <a name="CfnClusterProps" id="awscdk-resources-mongodbatlas.CfnClusterProps"></a>

The cluster resource provides access to your cluster configurations.

The resource lets you create, edit and delete clusters. The resource requires your Project ID.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnClusterProps.Initializer"></a>

```typescript
import { CfnClusterProps } from 'awscdk-resources-mongodbatlas'

const cfnClusterProps: CfnClusterProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterProps.property.name">name</a></code> | <code>string</code> | Human-readable label that identifies the advanced cluster. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterProps.property.projectId">projectId</a></code> | <code>string</code> | Unique identifier of the project the cluster belongs to. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterProps.property.advancedSettings">advancedSettings</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ProcessArgs">ProcessArgs</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterProps.property.backupEnabled">backupEnabled</a></code> | <code>boolean</code> | Flag that indicates whether the cluster can perform backups. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterProps.property.biConnector">biConnector</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnClusterPropsBiConnector">CfnClusterPropsBiConnector</a></code> | Settings needed to configure the MongoDB Connector for Business Intelligence for this cluster. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterProps.property.clusterType">clusterType</a></code> | <code>string</code> | Configuration of nodes that comprise the cluster. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterProps.property.diskSizeGb">diskSizeGb</a></code> | <code>number</code> | Storage capacity that the host's root volume possesses expressed in gigabytes. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterProps.property.encryptionAtRestProvider">encryptionAtRestProvider</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnClusterPropsEncryptionAtRestProvider">CfnClusterPropsEncryptionAtRestProvider</a></code> | Cloud service provider that manages your customer keys to provide an additional layer of encryption at rest for the cluster. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterProps.property.labels">labels</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnClusterPropsLabels">CfnClusterPropsLabels</a>[]</code> | Collection of key-value pairs between 1 to 255 characters in length that tag and categorize the cluster. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterProps.property.mongoDbMajorVersion">mongoDbMajorVersion</a></code> | <code>string</code> | Major MongoDB version of the cluster. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterProps.property.paused">paused</a></code> | <code>boolean</code> | Flag that indicates whether the cluster is paused or not. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterProps.property.pitEnabled">pitEnabled</a></code> | <code>boolean</code> | Flag that indicates whether the cluster uses continuous cloud backups. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterProps.property.profile">profile</a></code> | <code>string</code> | Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided default is used. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterProps.property.replicationSpecs">replicationSpecs</a></code> | <code><a href="#awscdk-resources-mongodbatlas.AdvancedReplicationSpec">AdvancedReplicationSpec</a>[]</code> | List of settings that configure your cluster regions. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterProps.property.rootCertType">rootCertType</a></code> | <code>string</code> | Root Certificate Authority that MongoDB Cloud cluster uses. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterProps.property.tags">tags</a></code> | <code><a href="#awscdk-resources-mongodbatlas.Tag">Tag</a>[]</code> | List of settings that configure your cluster regions. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterProps.property.terminationProtectionEnabled">terminationProtectionEnabled</a></code> | <code>boolean</code> | Flag that indicates whether termination protection is enabled on the cluster. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterProps.property.versionReleaseSystem">versionReleaseSystem</a></code> | <code>string</code> | Method by which the cluster maintains the MongoDB versions. |

---

##### `name`<sup>Required</sup> <a name="name" id="awscdk-resources-mongodbatlas.CfnClusterProps.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Human-readable label that identifies the advanced cluster.

---

##### `projectId`<sup>Required</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.CfnClusterProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

Unique identifier of the project the cluster belongs to.

---

##### `advancedSettings`<sup>Optional</sup> <a name="advancedSettings" id="awscdk-resources-mongodbatlas.CfnClusterProps.property.advancedSettings"></a>

```typescript
public readonly advancedSettings: ProcessArgs;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ProcessArgs">ProcessArgs</a>

---

##### `backupEnabled`<sup>Optional</sup> <a name="backupEnabled" id="awscdk-resources-mongodbatlas.CfnClusterProps.property.backupEnabled"></a>

```typescript
public readonly backupEnabled: boolean;
```

- *Type:* boolean

Flag that indicates whether the cluster can perform backups.

If set to true, the cluster can perform backups. You must set this value to true for NVMe clusters. Backup uses Cloud Backups for dedicated clusters and Shared Cluster Backups for tenant clusters. If set to false, the cluster doesn't use backups.

---

##### `biConnector`<sup>Optional</sup> <a name="biConnector" id="awscdk-resources-mongodbatlas.CfnClusterProps.property.biConnector"></a>

```typescript
public readonly biConnector: CfnClusterPropsBiConnector;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnClusterPropsBiConnector">CfnClusterPropsBiConnector</a>

Settings needed to configure the MongoDB Connector for Business Intelligence for this cluster.

---

##### `clusterType`<sup>Optional</sup> <a name="clusterType" id="awscdk-resources-mongodbatlas.CfnClusterProps.property.clusterType"></a>

```typescript
public readonly clusterType: string;
```

- *Type:* string

Configuration of nodes that comprise the cluster.

---

##### `diskSizeGb`<sup>Optional</sup> <a name="diskSizeGb" id="awscdk-resources-mongodbatlas.CfnClusterProps.property.diskSizeGb"></a>

```typescript
public readonly diskSizeGb: number;
```

- *Type:* number

Storage capacity that the host's root volume possesses expressed in gigabytes.

Increase this number to add capacity. MongoDB Cloud requires this parameter if you set replicationSpecs. If you specify a disk size below the minimum (10 GB), this parameter defaults to the minimum disk size value. Storage charge calculations depend on whether you choose the default value or a custom value. The maximum value for disk storage cannot exceed 50 times the maximum RAM for the selected cluster. If you require more storage space, consider upgrading your cluster to a higher tier.

---

##### `encryptionAtRestProvider`<sup>Optional</sup> <a name="encryptionAtRestProvider" id="awscdk-resources-mongodbatlas.CfnClusterProps.property.encryptionAtRestProvider"></a>

```typescript
public readonly encryptionAtRestProvider: CfnClusterPropsEncryptionAtRestProvider;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnClusterPropsEncryptionAtRestProvider">CfnClusterPropsEncryptionAtRestProvider</a>

Cloud service provider that manages your customer keys to provide an additional layer of encryption at rest for the cluster.

To enable customer key management for encryption at rest, the cluster replicationSpecs[n].regionConfigs[m].{type}Specs.instanceSize setting must be M10 or higher and "backupEnabled" : false or omitted entirely.

---

##### `labels`<sup>Optional</sup> <a name="labels" id="awscdk-resources-mongodbatlas.CfnClusterProps.property.labels"></a>

```typescript
public readonly labels: CfnClusterPropsLabels[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnClusterPropsLabels">CfnClusterPropsLabels</a>[]

Collection of key-value pairs between 1 to 255 characters in length that tag and categorize the cluster.

The MongoDB Cloud console doesn't display your labels.

---

##### `mongoDbMajorVersion`<sup>Optional</sup> <a name="mongoDbMajorVersion" id="awscdk-resources-mongodbatlas.CfnClusterProps.property.mongoDbMajorVersion"></a>

```typescript
public readonly mongoDbMajorVersion: string;
```

- *Type:* string

Major MongoDB version of the cluster.

MongoDB Cloud deploys the cluster with the latest stable release of the specified version.

---

##### `paused`<sup>Optional</sup> <a name="paused" id="awscdk-resources-mongodbatlas.CfnClusterProps.property.paused"></a>

```typescript
public readonly paused: boolean;
```

- *Type:* boolean

Flag that indicates whether the cluster is paused or not.

---

##### `pitEnabled`<sup>Optional</sup> <a name="pitEnabled" id="awscdk-resources-mongodbatlas.CfnClusterProps.property.pitEnabled"></a>

```typescript
public readonly pitEnabled: boolean;
```

- *Type:* boolean

Flag that indicates whether the cluster uses continuous cloud backups.

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.CfnClusterProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided default is used.

---

##### `replicationSpecs`<sup>Optional</sup> <a name="replicationSpecs" id="awscdk-resources-mongodbatlas.CfnClusterProps.property.replicationSpecs"></a>

```typescript
public readonly replicationSpecs: AdvancedReplicationSpec[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.AdvancedReplicationSpec">AdvancedReplicationSpec</a>[]

List of settings that configure your cluster regions.

For Global Clusters, each object in the array represents a zone where your clusters nodes deploy. For non-Global replica sets and sharded clusters, this array has one object representing where your clusters nodes deploy.

---

##### `rootCertType`<sup>Optional</sup> <a name="rootCertType" id="awscdk-resources-mongodbatlas.CfnClusterProps.property.rootCertType"></a>

```typescript
public readonly rootCertType: string;
```

- *Type:* string

Root Certificate Authority that MongoDB Cloud cluster uses.

MongoDB Cloud supports Internet Security Research Group.

---

##### `tags`<sup>Optional</sup> <a name="tags" id="awscdk-resources-mongodbatlas.CfnClusterProps.property.tags"></a>

```typescript
public readonly tags: Tag[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.Tag">Tag</a>[]

List of settings that configure your cluster regions.

For Global Clusters, each object in the array represents a zone where your clusters nodes deploy. For non-Global replica sets and sharded clusters, this array has one object representing where your clusters nodes deploy.

---

##### `terminationProtectionEnabled`<sup>Optional</sup> <a name="terminationProtectionEnabled" id="awscdk-resources-mongodbatlas.CfnClusterProps.property.terminationProtectionEnabled"></a>

```typescript
public readonly terminationProtectionEnabled: boolean;
```

- *Type:* boolean

Flag that indicates whether termination protection is enabled on the cluster.

If set to true, MongoDB Cloud won't delete the cluster. If set to false, MongoDB Cloud will delete the cluster.

---

##### `versionReleaseSystem`<sup>Optional</sup> <a name="versionReleaseSystem" id="awscdk-resources-mongodbatlas.CfnClusterProps.property.versionReleaseSystem"></a>

```typescript
public readonly versionReleaseSystem: string;
```

- *Type:* string

Method by which the cluster maintains the MongoDB versions.

If value is CONTINUOUS, you must not specify mongoDBMajorVersion

---

### CfnClusterPropsBiConnector <a name="CfnClusterPropsBiConnector" id="awscdk-resources-mongodbatlas.CfnClusterPropsBiConnector"></a>

Settings needed to configure the MongoDB Connector for Business Intelligence for this cluster.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnClusterPropsBiConnector.Initializer"></a>

```typescript
import { CfnClusterPropsBiConnector } from 'awscdk-resources-mongodbatlas'

const cfnClusterPropsBiConnector: CfnClusterPropsBiConnector = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterPropsBiConnector.property.enabled">enabled</a></code> | <code>boolean</code> | Flag that indicates whether MongoDB Connector for Business Intelligence is enabled on the specified cluster. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterPropsBiConnector.property.readPreference">readPreference</a></code> | <code>string</code> | Data source node designated for the MongoDB Connector for Business Intelligence on MongoDB Cloud. |

---

##### `enabled`<sup>Optional</sup> <a name="enabled" id="awscdk-resources-mongodbatlas.CfnClusterPropsBiConnector.property.enabled"></a>

```typescript
public readonly enabled: boolean;
```

- *Type:* boolean

Flag that indicates whether MongoDB Connector for Business Intelligence is enabled on the specified cluster.

---

##### `readPreference`<sup>Optional</sup> <a name="readPreference" id="awscdk-resources-mongodbatlas.CfnClusterPropsBiConnector.property.readPreference"></a>

```typescript
public readonly readPreference: string;
```

- *Type:* string
- *Default:* ANALYTICS node, or SECONDARY if there are no ANALYTICS nodes.

Data source node designated for the MongoDB Connector for Business Intelligence on MongoDB Cloud.

The MongoDB Connector for Business Intelligence on MongoDB Cloud reads data from the primary, secondary, or analytics node based on your read preferences. Defaults to ANALYTICS node, or SECONDARY if there are no ANALYTICS nodes.

---

### CfnClusterPropsLabels <a name="CfnClusterPropsLabels" id="awscdk-resources-mongodbatlas.CfnClusterPropsLabels"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnClusterPropsLabels.Initializer"></a>

```typescript
import { CfnClusterPropsLabels } from 'awscdk-resources-mongodbatlas'

const cfnClusterPropsLabels: CfnClusterPropsLabels = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterPropsLabels.property.key">key</a></code> | <code>string</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterPropsLabels.property.value">value</a></code> | <code>string</code> | *No description.* |

---

##### `key`<sup>Optional</sup> <a name="key" id="awscdk-resources-mongodbatlas.CfnClusterPropsLabels.property.key"></a>

```typescript
public readonly key: string;
```

- *Type:* string

---

##### `value`<sup>Optional</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnClusterPropsLabels.property.value"></a>

```typescript
public readonly value: string;
```

- *Type:* string

---

### CfnCustomDbRoleProps <a name="CfnCustomDbRoleProps" id="awscdk-resources-mongodbatlas.CfnCustomDbRoleProps"></a>

Returns, adds, edits, and removes custom database user privilege roles.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnCustomDbRoleProps.Initializer"></a>

```typescript
import { CfnCustomDbRoleProps } from 'awscdk-resources-mongodbatlas'

const cfnCustomDbRoleProps: CfnCustomDbRoleProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDbRoleProps.property.projectId">projectId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies your project. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDbRoleProps.property.roleName">roleName</a></code> | <code>string</code> | Human-readable label that identifies the role for the request. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDbRoleProps.property.actions">actions</a></code> | <code><a href="#awscdk-resources-mongodbatlas.Action">Action</a>[]</code> | List of the individual privilege actions that the role grants. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDbRoleProps.property.inheritedRoles">inheritedRoles</a></code> | <code><a href="#awscdk-resources-mongodbatlas.InheritedRole">InheritedRole</a>[]</code> | List of the built-in roles that this custom role inherits. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDbRoleProps.property.profile">profile</a></code> | <code>string</code> | The profile is defined in AWS Secret manager. |

---

##### `projectId`<sup>Required</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.CfnCustomDbRoleProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies your project.

---

##### `roleName`<sup>Required</sup> <a name="roleName" id="awscdk-resources-mongodbatlas.CfnCustomDbRoleProps.property.roleName"></a>

```typescript
public readonly roleName: string;
```

- *Type:* string

Human-readable label that identifies the role for the request.

This name must be unique for this custom role in this project.

---

##### `actions`<sup>Optional</sup> <a name="actions" id="awscdk-resources-mongodbatlas.CfnCustomDbRoleProps.property.actions"></a>

```typescript
public readonly actions: Action[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.Action">Action</a>[]

List of the individual privilege actions that the role grants.

---

##### `inheritedRoles`<sup>Optional</sup> <a name="inheritedRoles" id="awscdk-resources-mongodbatlas.CfnCustomDbRoleProps.property.inheritedRoles"></a>

```typescript
public readonly inheritedRoles: InheritedRole[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.InheritedRole">InheritedRole</a>[]

List of the built-in roles that this custom role inherits.

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.CfnCustomDbRoleProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

The profile is defined in AWS Secret manager.

See [Secret Manager Profile setup](../../../examples/profile-secret.yaml).

---

### CfnCustomDnsConfigurationClusterAwsProps <a name="CfnCustomDnsConfigurationClusterAwsProps" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAwsProps"></a>

An example resource schema demonstrating some basic constructs and validation rules.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAwsProps.Initializer"></a>

```typescript
import { CfnCustomDnsConfigurationClusterAwsProps } from 'awscdk-resources-mongodbatlas'

const cfnCustomDnsConfigurationClusterAwsProps: CfnCustomDnsConfigurationClusterAwsProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAwsProps.property.projectId">projectId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies your project. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAwsProps.property.enabled">enabled</a></code> | <code>boolean</code> | Flag that indicates whether the project's clusters deployed to Amazon Web Services (AWS) use a custom Domain Name System (DNS). |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAwsProps.property.profile">profile</a></code> | <code>string</code> | The profile is defined in AWS Secret manager. |

---

##### `projectId`<sup>Required</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAwsProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies your project.

---

##### `enabled`<sup>Optional</sup> <a name="enabled" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAwsProps.property.enabled"></a>

```typescript
public readonly enabled: boolean;
```

- *Type:* boolean

Flag that indicates whether the project's clusters deployed to Amazon Web Services (AWS) use a custom Domain Name System (DNS).

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.CfnCustomDnsConfigurationClusterAwsProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

The profile is defined in AWS Secret manager.

See [Secret Manager Profile setup](../../../examples/profile-secret.yaml).

---

### CfnDatabaseUserProps <a name="CfnDatabaseUserProps" id="awscdk-resources-mongodbatlas.CfnDatabaseUserProps"></a>

Returns, adds, edits, and removes database users.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnDatabaseUserProps.Initializer"></a>

```typescript
import { CfnDatabaseUserProps } from 'awscdk-resources-mongodbatlas'

const cfnDatabaseUserProps: CfnDatabaseUserProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUserProps.property.databaseName">databaseName</a></code> | <code>string</code> | MongoDB database against which the MongoDB database user authenticates. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUserProps.property.projectId">projectId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies your Atlas Project. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUserProps.property.roles">roles</a></code> | <code><a href="#awscdk-resources-mongodbatlas.RoleDefinition">RoleDefinition</a>[]</code> | List that provides the pairings of one role with one applicable database. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUserProps.property.username">username</a></code> | <code>string</code> | Human-readable label that represents the user that authenticates to MongoDB. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUserProps.property.awsiamType">awsiamType</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUserPropsAwsiamType">CfnDatabaseUserPropsAwsiamType</a></code> | Human-readable label that indicates whether the new database user authenticates with the Amazon Web Services (AWS) Identity and Access Management (IAM) credentials associated with the user or the user's role. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUserProps.property.deleteAfterDate">deleteAfterDate</a></code> | <code>string</code> | Date and time when MongoDB Cloud deletes the user. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUserProps.property.labels">labels</a></code> | <code><a href="#awscdk-resources-mongodbatlas.LabelDefinition">LabelDefinition</a>[]</code> | List that contains the key-value pairs for tagging and categorizing the MongoDB database user. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUserProps.property.ldapAuthType">ldapAuthType</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUserPropsLdapAuthType">CfnDatabaseUserPropsLdapAuthType</a></code> | Method by which the provided username is authenticated. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUserProps.property.password">password</a></code> | <code>string</code> | The user’s password. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUserProps.property.profile">profile</a></code> | <code>string</code> | Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided `default` is used. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUserProps.property.scopes">scopes</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ScopeDefinition">ScopeDefinition</a>[]</code> | List that contains clusters and MongoDB Atlas Data Lakes that this database user can access. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUserProps.property.x509Type">x509Type</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUserPropsX509Type">CfnDatabaseUserPropsX509Type</a></code> | Method that briefs who owns the certificate provided. |

---

##### `databaseName`<sup>Required</sup> <a name="databaseName" id="awscdk-resources-mongodbatlas.CfnDatabaseUserProps.property.databaseName"></a>

```typescript
public readonly databaseName: string;
```

- *Type:* string

MongoDB database against which the MongoDB database user authenticates.

MongoDB database users must provide both a username and authentication database to log into MongoDB.  Default value is `admin`.

---

##### `projectId`<sup>Required</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.CfnDatabaseUserProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies your Atlas Project.

---

##### `roles`<sup>Required</sup> <a name="roles" id="awscdk-resources-mongodbatlas.CfnDatabaseUserProps.property.roles"></a>

```typescript
public readonly roles: RoleDefinition[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.RoleDefinition">RoleDefinition</a>[]

List that provides the pairings of one role with one applicable database.

---

##### `username`<sup>Required</sup> <a name="username" id="awscdk-resources-mongodbatlas.CfnDatabaseUserProps.property.username"></a>

```typescript
public readonly username: string;
```

- *Type:* string

Human-readable label that represents the user that authenticates to MongoDB.

The format of this label depends on the method of authentication. This will be USER_ARN or ROLE_ARN if AWSIAMType is USER or ROLE. Refer https://www.mongodb.com/docs/atlas/reference/api-resources-spec/#tag/Database-Users/operation/createDatabaseUser for details.

---

##### `awsiamType`<sup>Optional</sup> <a name="awsiamType" id="awscdk-resources-mongodbatlas.CfnDatabaseUserProps.property.awsiamType"></a>

```typescript
public readonly awsiamType: CfnDatabaseUserPropsAwsiamType;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnDatabaseUserPropsAwsiamType">CfnDatabaseUserPropsAwsiamType</a>

Human-readable label that indicates whether the new database user authenticates with the Amazon Web Services (AWS) Identity and Access Management (IAM) credentials associated with the user or the user's role.

Default value is `NONE`.

---

##### `deleteAfterDate`<sup>Optional</sup> <a name="deleteAfterDate" id="awscdk-resources-mongodbatlas.CfnDatabaseUserProps.property.deleteAfterDate"></a>

```typescript
public readonly deleteAfterDate: string;
```

- *Type:* string

Date and time when MongoDB Cloud deletes the user.

This parameter expresses its value in the ISO 8601 timestamp format in UTC and can include the time zone designation. You must specify a future date that falls within one week of making the Application Programming Interface (API) request.

---

##### `labels`<sup>Optional</sup> <a name="labels" id="awscdk-resources-mongodbatlas.CfnDatabaseUserProps.property.labels"></a>

```typescript
public readonly labels: LabelDefinition[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.LabelDefinition">LabelDefinition</a>[]

List that contains the key-value pairs for tagging and categorizing the MongoDB database user.

The labels that you define do not appear in the console.

---

##### `ldapAuthType`<sup>Optional</sup> <a name="ldapAuthType" id="awscdk-resources-mongodbatlas.CfnDatabaseUserProps.property.ldapAuthType"></a>

```typescript
public readonly ldapAuthType: CfnDatabaseUserPropsLdapAuthType;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnDatabaseUserPropsLdapAuthType">CfnDatabaseUserPropsLdapAuthType</a>

Method by which the provided username is authenticated.

Default value is `NONE`.

---

##### `password`<sup>Optional</sup> <a name="password" id="awscdk-resources-mongodbatlas.CfnDatabaseUserProps.property.password"></a>

```typescript
public readonly password: string;
```

- *Type:* string

The user’s password.

This field is not included in the entity returned from the server.

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.CfnDatabaseUserProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided `default` is used.

---

##### `scopes`<sup>Optional</sup> <a name="scopes" id="awscdk-resources-mongodbatlas.CfnDatabaseUserProps.property.scopes"></a>

```typescript
public readonly scopes: ScopeDefinition[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ScopeDefinition">ScopeDefinition</a>[]

List that contains clusters and MongoDB Atlas Data Lakes that this database user can access.

If omitted, MongoDB Cloud grants the database user access to all the clusters and MongoDB Atlas Data Lakes in the project.

---

##### `x509Type`<sup>Optional</sup> <a name="x509Type" id="awscdk-resources-mongodbatlas.CfnDatabaseUserProps.property.x509Type"></a>

```typescript
public readonly x509Type: CfnDatabaseUserPropsX509Type;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnDatabaseUserPropsX509Type">CfnDatabaseUserPropsX509Type</a>

Method that briefs who owns the certificate provided.

Default value is `NONE`.

---

### CfnDataLakePipelineProps <a name="CfnDataLakePipelineProps" id="awscdk-resources-mongodbatlas.CfnDataLakePipelineProps"></a>

An example resource schema demonstrating some basic constructs and validation rules.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnDataLakePipelineProps.Initializer"></a>

```typescript
import { CfnDataLakePipelineProps } from 'awscdk-resources-mongodbatlas'

const cfnDataLakePipelineProps: CfnDataLakePipelineProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakePipelineProps.property.name">name</a></code> | <code>string</code> | Name of this Data Lake Pipeline. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakePipelineProps.property.projectId">projectId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies your project. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakePipelineProps.property.sink">sink</a></code> | <code><a href="#awscdk-resources-mongodbatlas.Sink">Sink</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakePipelineProps.property.transformations">transformations</a></code> | <code><a href="#awscdk-resources-mongodbatlas.Transformations">Transformations</a>[]</code> | Ingestion destination of a Data Lake Pipeline. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakePipelineProps.property.profile">profile</a></code> | <code>string</code> | Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided default is used. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakePipelineProps.property.source">source</a></code> | <code><a href="#awscdk-resources-mongodbatlas.Source">Source</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakePipelineProps.property.state">state</a></code> | <code>string</code> | State of the Data Lake Pipeline. |

---

##### `name`<sup>Required</sup> <a name="name" id="awscdk-resources-mongodbatlas.CfnDataLakePipelineProps.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Name of this Data Lake Pipeline.

---

##### `projectId`<sup>Required</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.CfnDataLakePipelineProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies your project.

---

##### `sink`<sup>Required</sup> <a name="sink" id="awscdk-resources-mongodbatlas.CfnDataLakePipelineProps.property.sink"></a>

```typescript
public readonly sink: Sink;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.Sink">Sink</a>

---

##### `transformations`<sup>Required</sup> <a name="transformations" id="awscdk-resources-mongodbatlas.CfnDataLakePipelineProps.property.transformations"></a>

```typescript
public readonly transformations: Transformations[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.Transformations">Transformations</a>[]

Ingestion destination of a Data Lake Pipeline.

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.CfnDataLakePipelineProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided default is used.

---

##### `source`<sup>Optional</sup> <a name="source" id="awscdk-resources-mongodbatlas.CfnDataLakePipelineProps.property.source"></a>

```typescript
public readonly source: Source;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.Source">Source</a>

---

##### `state`<sup>Optional</sup> <a name="state" id="awscdk-resources-mongodbatlas.CfnDataLakePipelineProps.property.state"></a>

```typescript
public readonly state: string;
```

- *Type:* string

State of the Data Lake Pipeline.

---

### CfnDataLakesProps <a name="CfnDataLakesProps" id="awscdk-resources-mongodbatlas.CfnDataLakesProps"></a>

Returns, adds, edits, and removes Federated Database Instances.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnDataLakesProps.Initializer"></a>

```typescript
import { CfnDataLakesProps } from 'awscdk-resources-mongodbatlas'

const cfnDataLakesProps: CfnDataLakesProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakesProps.property.cloudProviderConfig">cloudProviderConfig</a></code> | <code><a href="#awscdk-resources-mongodbatlas.DataLakeCloudProviderConfigView">DataLakeCloudProviderConfigView</a></code> | Cloud provider linked to this data lake. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakesProps.property.dataProcessRegion">dataProcessRegion</a></code> | <code><a href="#awscdk-resources-mongodbatlas.DataLakeDataProcessRegionView">DataLakeDataProcessRegionView</a></code> | Information about the cloud provider region to which the data lake routes client connections. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakesProps.property.endDate">endDate</a></code> | <code>number</code> | Timestamp that specifies the end point for the range of log messages to download. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakesProps.property.profile">profile</a></code> | <code>string</code> | The profile is defined in AWS Secret manager. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakesProps.property.projectId">projectId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies your project. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakesProps.property.skipRoleValidation">skipRoleValidation</a></code> | <code>boolean</code> | Flag that indicates whether this request should check if the requesting IAM role can read from the S3 bucket. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakesProps.property.storage">storage</a></code> | <code><a href="#awscdk-resources-mongodbatlas.DataLakeStorageView">DataLakeStorageView</a></code> | Configuration information for each data store and its mapping to MongoDB Cloud databases. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDataLakesProps.property.tenantName">tenantName</a></code> | <code>string</code> | Human-readable label that identifies the Federated Database to remove. |

---

##### `cloudProviderConfig`<sup>Optional</sup> <a name="cloudProviderConfig" id="awscdk-resources-mongodbatlas.CfnDataLakesProps.property.cloudProviderConfig"></a>

```typescript
public readonly cloudProviderConfig: DataLakeCloudProviderConfigView;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.DataLakeCloudProviderConfigView">DataLakeCloudProviderConfigView</a>

Cloud provider linked to this data lake.

---

##### `dataProcessRegion`<sup>Optional</sup> <a name="dataProcessRegion" id="awscdk-resources-mongodbatlas.CfnDataLakesProps.property.dataProcessRegion"></a>

```typescript
public readonly dataProcessRegion: DataLakeDataProcessRegionView;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.DataLakeDataProcessRegionView">DataLakeDataProcessRegionView</a>

Information about the cloud provider region to which the data lake routes client connections.

MongoDB Cloud supports AWS only.

---

##### `endDate`<sup>Optional</sup> <a name="endDate" id="awscdk-resources-mongodbatlas.CfnDataLakesProps.property.endDate"></a>

```typescript
public readonly endDate: number;
```

- *Type:* number

Timestamp that specifies the end point for the range of log messages to download.

MongoDB Cloud expresses this timestamp in the number of seconds that have elapsed since the UNIX epoch.

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.CfnDataLakesProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

The profile is defined in AWS Secret manager.

See [Secret Manager Profile setup](../../../examples/profile-secret.yaml).

---

##### `projectId`<sup>Optional</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.CfnDataLakesProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies your project.

---

##### `skipRoleValidation`<sup>Optional</sup> <a name="skipRoleValidation" id="awscdk-resources-mongodbatlas.CfnDataLakesProps.property.skipRoleValidation"></a>

```typescript
public readonly skipRoleValidation: boolean;
```

- *Type:* boolean

Flag that indicates whether this request should check if the requesting IAM role can read from the S3 bucket.

AWS checks if the role can list the objects in the bucket before writing to it. Some IAM roles only need write permissions. This flag allows you to skip that check.

---

##### `storage`<sup>Optional</sup> <a name="storage" id="awscdk-resources-mongodbatlas.CfnDataLakesProps.property.storage"></a>

```typescript
public readonly storage: DataLakeStorageView;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.DataLakeStorageView">DataLakeStorageView</a>

Configuration information for each data store and its mapping to MongoDB Cloud databases.

---

##### `tenantName`<sup>Optional</sup> <a name="tenantName" id="awscdk-resources-mongodbatlas.CfnDataLakesProps.property.tenantName"></a>

```typescript
public readonly tenantName: string;
```

- *Type:* string

Human-readable label that identifies the Federated Database to remove.

---

### CfnEncryptionAtRestProps <a name="CfnEncryptionAtRestProps" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRestProps"></a>

Returns and edits the Encryption at Rest using Customer Key Management configuration.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRestProps.Initializer"></a>

```typescript
import { CfnEncryptionAtRestProps } from 'awscdk-resources-mongodbatlas'

const cfnEncryptionAtRestProps: CfnEncryptionAtRestProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnEncryptionAtRestProps.property.awsKms">awsKms</a></code> | <code><a href="#awscdk-resources-mongodbatlas.AwsKmsConfiguration">AwsKmsConfiguration</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnEncryptionAtRestProps.property.projectId">projectId</a></code> | <code>string</code> | Unique identifier of the Atlas project to which the user belongs. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnEncryptionAtRestProps.property.profile">profile</a></code> | <code>string</code> | The profile is defined in AWS Secret manager. |

---

##### `awsKms`<sup>Required</sup> <a name="awsKms" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRestProps.property.awsKms"></a>

```typescript
public readonly awsKms: AwsKmsConfiguration;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.AwsKmsConfiguration">AwsKmsConfiguration</a>

---

##### `projectId`<sup>Required</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRestProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

Unique identifier of the Atlas project to which the user belongs.

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.CfnEncryptionAtRestProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

The profile is defined in AWS Secret manager.

See [Secret Manager Profile setup](../../../examples/profile-secret.yaml).

---

### CfnFederatedDatabaseInstanceProps <a name="CfnFederatedDatabaseInstanceProps" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstanceProps"></a>

Returns, adds, edits, and removes Federated Database Instances.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstanceProps.Initializer"></a>

```typescript
import { CfnFederatedDatabaseInstanceProps } from 'awscdk-resources-mongodbatlas'

const cfnFederatedDatabaseInstanceProps: CfnFederatedDatabaseInstanceProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstanceProps.property.projectId">projectId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies your project. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstanceProps.property.tenantName">tenantName</a></code> | <code>string</code> | Human-readable label that identifies the data federation. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstanceProps.property.cloudProviderConfig">cloudProviderConfig</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CloudProviderConfig">CloudProviderConfig</a></code> | Cloud provider linked to this data lake. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstanceProps.property.dataProcessRegion">dataProcessRegion</a></code> | <code><a href="#awscdk-resources-mongodbatlas.DataProcessRegion">DataProcessRegion</a></code> | Information about the cloud provider region to which the data lake routes client connections. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstanceProps.property.profile">profile</a></code> | <code>string</code> | The profile is defined in AWS Secret manager. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstanceProps.property.skipRoleValidation">skipRoleValidation</a></code> | <code>boolean</code> | Flag that indicates whether this request should check if the requesting IAM role can read from the S3 bucket. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstanceProps.property.storage">storage</a></code> | <code><a href="#awscdk-resources-mongodbatlas.Storage">Storage</a></code> | Configuration information for each data store and its mapping to MongoDB Cloud databases. |

---

##### `projectId`<sup>Required</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstanceProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies your project.

---

##### `tenantName`<sup>Required</sup> <a name="tenantName" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstanceProps.property.tenantName"></a>

```typescript
public readonly tenantName: string;
```

- *Type:* string

Human-readable label that identifies the data federation.

---

##### `cloudProviderConfig`<sup>Optional</sup> <a name="cloudProviderConfig" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstanceProps.property.cloudProviderConfig"></a>

```typescript
public readonly cloudProviderConfig: CloudProviderConfig;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CloudProviderConfig">CloudProviderConfig</a>

Cloud provider linked to this data lake.

---

##### `dataProcessRegion`<sup>Optional</sup> <a name="dataProcessRegion" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstanceProps.property.dataProcessRegion"></a>

```typescript
public readonly dataProcessRegion: DataProcessRegion;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.DataProcessRegion">DataProcessRegion</a>

Information about the cloud provider region to which the data lake routes client connections.

MongoDB Cloud supports AWS only.

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstanceProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

The profile is defined in AWS Secret manager.

See [Secret Manager Profile setup](../../../examples/profile-secret.yaml).

---

##### `skipRoleValidation`<sup>Optional</sup> <a name="skipRoleValidation" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstanceProps.property.skipRoleValidation"></a>

```typescript
public readonly skipRoleValidation: boolean;
```

- *Type:* boolean

Flag that indicates whether this request should check if the requesting IAM role can read from the S3 bucket.

AWS checks if the role can list the objects in the bucket before writing to it. Some IAM roles only need write permissions. This flag allows you to skip that check.

---

##### `storage`<sup>Optional</sup> <a name="storage" id="awscdk-resources-mongodbatlas.CfnFederatedDatabaseInstanceProps.property.storage"></a>

```typescript
public readonly storage: Storage;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.Storage">Storage</a>

Configuration information for each data store and its mapping to MongoDB Cloud databases.

---

### CfnFederatedQueryLimitProps <a name="CfnFederatedQueryLimitProps" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimitProps"></a>

Query limit for one federated database instance.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimitProps.Initializer"></a>

```typescript
import { CfnFederatedQueryLimitProps } from 'awscdk-resources-mongodbatlas'

const cfnFederatedQueryLimitProps: CfnFederatedQueryLimitProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimitProps.property.limitName">limitName</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimitPropsLimitName">CfnFederatedQueryLimitPropsLimitName</a></code> | Human-readable label that identifies this data federation instance limit. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimitProps.property.projectId">projectId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies your project. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimitProps.property.tenantName">tenantName</a></code> | <code>string</code> | Human-readable label that identifies the data federated database instance to which the query limit applies. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimitProps.property.value">value</a></code> | <code>string</code> | Amount to set the limit to. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimitProps.property.overrunPolicy">overrunPolicy</a></code> | <code>string</code> | Only used for Data Federation limits. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimitProps.property.profile">profile</a></code> | <code>string</code> | Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided default is used. |

---

##### `limitName`<sup>Required</sup> <a name="limitName" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimitProps.property.limitName"></a>

```typescript
public readonly limitName: CfnFederatedQueryLimitPropsLimitName;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimitPropsLimitName">CfnFederatedQueryLimitPropsLimitName</a>

Human-readable label that identifies this data federation instance limit.

---

##### `projectId`<sup>Required</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimitProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies your project.

---

##### `tenantName`<sup>Required</sup> <a name="tenantName" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimitProps.property.tenantName"></a>

```typescript
public readonly tenantName: string;
```

- *Type:* string

Human-readable label that identifies the data federated database instance to which the query limit applies.

---

##### `value`<sup>Required</sup> <a name="value" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimitProps.property.value"></a>

```typescript
public readonly value: string;
```

- *Type:* string

Amount to set the limit to.

---

##### `overrunPolicy`<sup>Optional</sup> <a name="overrunPolicy" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimitProps.property.overrunPolicy"></a>

```typescript
public readonly overrunPolicy: string;
```

- *Type:* string

Only used for Data Federation limits.

Action to take when the usage limit is exceeded. If limit span is set to QUERY, this is ignored because MongoDB Cloud stops the query when it exceeds the usage limit. "enum" : [ "BLOCK", "BLOCK_AND_KILL" ]

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimitProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided default is used.

---

### CfnFederatedSettingsOrgRoleMappingProps <a name="CfnFederatedSettingsOrgRoleMappingProps" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMappingProps"></a>

Returns, adds, edits, and removes federation-related features such as role mappings and connected organization configurations.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMappingProps.Initializer"></a>

```typescript
import { CfnFederatedSettingsOrgRoleMappingProps } from 'awscdk-resources-mongodbatlas'

const cfnFederatedSettingsOrgRoleMappingProps: CfnFederatedSettingsOrgRoleMappingProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMappingProps.property.externalGroupName">externalGroupName</a></code> | <code>string</code> | Unique human-readable label that identifies the identity provider group to whichthis role mapping applies. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMappingProps.property.federationSettingsId">federationSettingsId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies your federation. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMappingProps.property.orgId">orgId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies the organization that contains your projects. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMappingProps.property.roleAssignments">roleAssignments</a></code> | <code><a href="#awscdk-resources-mongodbatlas.RoleAssignment">RoleAssignment</a>[]</code> | Atlas roles and the unique identifiers of the groups and organizations associated with each role. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMappingProps.property.profile">profile</a></code> | <code>string</code> | The profile is defined in AWS Secret manager. |

---

##### `externalGroupName`<sup>Required</sup> <a name="externalGroupName" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMappingProps.property.externalGroupName"></a>

```typescript
public readonly externalGroupName: string;
```

- *Type:* string

Unique human-readable label that identifies the identity provider group to whichthis role mapping applies.

---

##### `federationSettingsId`<sup>Required</sup> <a name="federationSettingsId" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMappingProps.property.federationSettingsId"></a>

```typescript
public readonly federationSettingsId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies your federation.

---

##### `orgId`<sup>Required</sup> <a name="orgId" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMappingProps.property.orgId"></a>

```typescript
public readonly orgId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies the organization that contains your projects.

---

##### `roleAssignments`<sup>Required</sup> <a name="roleAssignments" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMappingProps.property.roleAssignments"></a>

```typescript
public readonly roleAssignments: RoleAssignment[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.RoleAssignment">RoleAssignment</a>[]

Atlas roles and the unique identifiers of the groups and organizations associated with each role.

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.CfnFederatedSettingsOrgRoleMappingProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

The profile is defined in AWS Secret manager.

See [Secret Manager Profile setup](../../../examples/profile-secret.yaml).

---

### CfnGlobalClusterConfigProps <a name="CfnGlobalClusterConfigProps" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfigProps"></a>

Returns, adds, and removes Global Cluster managed namespaces and custom zone mappings.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfigProps.Initializer"></a>

```typescript
import { CfnGlobalClusterConfigProps } from 'awscdk-resources-mongodbatlas'

const cfnGlobalClusterConfigProps: CfnGlobalClusterConfigProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnGlobalClusterConfigProps.property.clusterName">clusterName</a></code> | <code>string</code> | The name of the Atlas cluster that contains the snapshots you want to retrieve. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnGlobalClusterConfigProps.property.projectId">projectId</a></code> | <code>string</code> | The unique identifier of the project for the Atlas cluster. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnGlobalClusterConfigProps.property.customZoneMappings">customZoneMappings</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ZoneMapping">ZoneMapping</a>[]</code> | List that contains comma-separated key value pairs to map zones to geographic regions. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnGlobalClusterConfigProps.property.managedNamespaces">managedNamespaces</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ManagedNamespace">ManagedNamespace</a>[]</code> | List that contains comma-separated key value pairs to map zones to geographic regions. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnGlobalClusterConfigProps.property.profile">profile</a></code> | <code>string</code> | The profile is defined in AWS Secret manager. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnGlobalClusterConfigProps.property.removeAllZoneMapping">removeAllZoneMapping</a></code> | <code>boolean</code> | Flag that indicates whether all custom zone mapping to be deleted during delete. |

---

##### `clusterName`<sup>Required</sup> <a name="clusterName" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfigProps.property.clusterName"></a>

```typescript
public readonly clusterName: string;
```

- *Type:* string

The name of the Atlas cluster that contains the snapshots you want to retrieve.

---

##### `projectId`<sup>Required</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfigProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

The unique identifier of the project for the Atlas cluster.

---

##### `customZoneMappings`<sup>Optional</sup> <a name="customZoneMappings" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfigProps.property.customZoneMappings"></a>

```typescript
public readonly customZoneMappings: ZoneMapping[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ZoneMapping">ZoneMapping</a>[]

List that contains comma-separated key value pairs to map zones to geographic regions.

These pairs map an ISO 3166-1a2 location code, with an ISO 3166-2 subdivision code when possible, to the human-readable label for the desired custom zone. MongoDB Cloud maps the ISO 3166-1a2 code to the nearest geographical zone by default. Include this parameter to override the default mappings.

This parameter returns an empty object if no custom zones exist.

---

##### `managedNamespaces`<sup>Optional</sup> <a name="managedNamespaces" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfigProps.property.managedNamespaces"></a>

```typescript
public readonly managedNamespaces: ManagedNamespace[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ManagedNamespace">ManagedNamespace</a>[]

List that contains comma-separated key value pairs to map zones to geographic regions.

These pairs map an ISO 3166-1a2 location code, with an ISO 3166-2 subdivision code when possible, to the human-readable label for the desired custom zone. MongoDB Cloud maps the ISO 3166-1a2 code to the nearest geographical zone by default. Include this parameter to override the default mappings.

This parameter returns an empty object if no custom zones exist.

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfigProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

The profile is defined in AWS Secret manager.

See [Secret Manager Profile setup](../../../examples/profile-secret.yaml).

---

##### `removeAllZoneMapping`<sup>Optional</sup> <a name="removeAllZoneMapping" id="awscdk-resources-mongodbatlas.CfnGlobalClusterConfigProps.property.removeAllZoneMapping"></a>

```typescript
public readonly removeAllZoneMapping: boolean;
```

- *Type:* boolean

Flag that indicates whether all custom zone mapping to be deleted during delete.

---

### CfnLdapConfigurationProps <a name="CfnLdapConfigurationProps" id="awscdk-resources-mongodbatlas.CfnLdapConfigurationProps"></a>

Returns, edits, verifies, and removes LDAP configurations.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnLdapConfigurationProps.Initializer"></a>

```typescript
import { CfnLdapConfigurationProps } from 'awscdk-resources-mongodbatlas'

const cfnLdapConfigurationProps: CfnLdapConfigurationProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapConfigurationProps.property.bindPassword">bindPassword</a></code> | <code>string</code> | Password that MongoDB Cloud uses to authenticate the **bindUsername**. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapConfigurationProps.property.bindUsername">bindUsername</a></code> | <code>string</code> | Full Distinguished Name (DN) of the Lightweight Directory Access Protocol (LDAP) user that MongoDB Cloud uses to connect to the LDAP host. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapConfigurationProps.property.hostname">hostname</a></code> | <code>string</code> | Human-readable label that identifies the hostname or Internet Protocol (IP) address of the Lightweight Directory Access Protocol (LDAP) host. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapConfigurationProps.property.port">port</a></code> | <code>number</code> | Port to which the Lightweight Directory Access Protocol (LDAP) host listens for client connections. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapConfigurationProps.property.projectId">projectId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies your project. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapConfigurationProps.property.authenticationEnabled">authenticationEnabled</a></code> | <code>boolean</code> | Flag that indicates whether users can authenticate using an Lightweight Directory Access Protocol (LDAP) host. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapConfigurationProps.property.authorizationEnabled">authorizationEnabled</a></code> | <code>boolean</code> | Flag that indicates whether users can authorize access to MongoDB Cloud resources using an Lightweight Directory Access Protocol (LDAP) host. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapConfigurationProps.property.authzQueryTemplate">authzQueryTemplate</a></code> | <code>string</code> | Lightweight Directory Access Protocol (LDAP) query template that MongoDB Cloud runs to obtain the LDAP groups associated with the authenticated user. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapConfigurationProps.property.caCertificate">caCertificate</a></code> | <code>string</code> | Certificate Authority (CA) certificate that MongoDB Cloud uses to verify the identity of the Lightweight Directory Access Protocol (LDAP) host. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapConfigurationProps.property.profile">profile</a></code> | <code>string</code> | Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided default is used. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapConfigurationProps.property.status">status</a></code> | <code>string</code> | The current status of the LDAP over TLS/SSL configuration. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapConfigurationProps.property.userToDnMapping">userToDnMapping</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasNdsUserToDnMappingView">ApiAtlasNdsUserToDnMappingView</a>[]</code> | User-to-Distinguished Name (DN) map that MongoDB Cloud uses to transform a Lightweight Directory Access Protocol (LDAP) username into an LDAP DN. |

---

##### `bindPassword`<sup>Required</sup> <a name="bindPassword" id="awscdk-resources-mongodbatlas.CfnLdapConfigurationProps.property.bindPassword"></a>

```typescript
public readonly bindPassword: string;
```

- *Type:* string

Password that MongoDB Cloud uses to authenticate the **bindUsername**.

---

##### `bindUsername`<sup>Required</sup> <a name="bindUsername" id="awscdk-resources-mongodbatlas.CfnLdapConfigurationProps.property.bindUsername"></a>

```typescript
public readonly bindUsername: string;
```

- *Type:* string

Full Distinguished Name (DN) of the Lightweight Directory Access Protocol (LDAP) user that MongoDB Cloud uses to connect to the LDAP host.

LDAP distinguished names must be formatted according to RFC 2253.

---

##### `hostname`<sup>Required</sup> <a name="hostname" id="awscdk-resources-mongodbatlas.CfnLdapConfigurationProps.property.hostname"></a>

```typescript
public readonly hostname: string;
```

- *Type:* string

Human-readable label that identifies the hostname or Internet Protocol (IP) address of the Lightweight Directory Access Protocol (LDAP) host.

This host must have access to the internet or have a Virtual Private Cloud (VPC) peering connection to your cluster.

---

##### `port`<sup>Required</sup> <a name="port" id="awscdk-resources-mongodbatlas.CfnLdapConfigurationProps.property.port"></a>

```typescript
public readonly port: number;
```

- *Type:* number

Port to which the Lightweight Directory Access Protocol (LDAP) host listens for client connections.

---

##### `projectId`<sup>Required</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.CfnLdapConfigurationProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies your project.

---

##### `authenticationEnabled`<sup>Optional</sup> <a name="authenticationEnabled" id="awscdk-resources-mongodbatlas.CfnLdapConfigurationProps.property.authenticationEnabled"></a>

```typescript
public readonly authenticationEnabled: boolean;
```

- *Type:* boolean

Flag that indicates whether users can authenticate using an Lightweight Directory Access Protocol (LDAP) host.

---

##### `authorizationEnabled`<sup>Optional</sup> <a name="authorizationEnabled" id="awscdk-resources-mongodbatlas.CfnLdapConfigurationProps.property.authorizationEnabled"></a>

```typescript
public readonly authorizationEnabled: boolean;
```

- *Type:* boolean

Flag that indicates whether users can authorize access to MongoDB Cloud resources using an Lightweight Directory Access Protocol (LDAP) host.

---

##### `authzQueryTemplate`<sup>Optional</sup> <a name="authzQueryTemplate" id="awscdk-resources-mongodbatlas.CfnLdapConfigurationProps.property.authzQueryTemplate"></a>

```typescript
public readonly authzQueryTemplate: string;
```

- *Type:* string

Lightweight Directory Access Protocol (LDAP) query template that MongoDB Cloud runs to obtain the LDAP groups associated with the authenticated user.

MongoDB Cloud uses this parameter only for user authorization. Use the `{USER}` placeholder in the Uniform Resource Locator (URL) to substitute the authenticated username. The query relates to the host specified with the hostname. Format this query according to [RFC 4515](https://tools.ietf.org/search/rfc4515) and [RFC 4516](https://datatracker.ietf.org/doc/html/rfc4516).

---

##### `caCertificate`<sup>Optional</sup> <a name="caCertificate" id="awscdk-resources-mongodbatlas.CfnLdapConfigurationProps.property.caCertificate"></a>

```typescript
public readonly caCertificate: string;
```

- *Type:* string

Certificate Authority (CA) certificate that MongoDB Cloud uses to verify the identity of the Lightweight Directory Access Protocol (LDAP) host.

MongoDB Cloud allows self-signed certificates. To delete an assigned value, pass an empty string: `"caCertificate": ""`

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.CfnLdapConfigurationProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided default is used.

---

##### `status`<sup>Optional</sup> <a name="status" id="awscdk-resources-mongodbatlas.CfnLdapConfigurationProps.property.status"></a>

```typescript
public readonly status: string;
```

- *Type:* string

The current status of the LDAP over TLS/SSL configuration.

---

##### `userToDnMapping`<sup>Optional</sup> <a name="userToDnMapping" id="awscdk-resources-mongodbatlas.CfnLdapConfigurationProps.property.userToDnMapping"></a>

```typescript
public readonly userToDnMapping: ApiAtlasNdsUserToDnMappingView[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ApiAtlasNdsUserToDnMappingView">ApiAtlasNdsUserToDnMappingView</a>[]

User-to-Distinguished Name (DN) map that MongoDB Cloud uses to transform a Lightweight Directory Access Protocol (LDAP) username into an LDAP DN.

---

### CfnLdapVerifyProps <a name="CfnLdapVerifyProps" id="awscdk-resources-mongodbatlas.CfnLdapVerifyProps"></a>

Requests a verification of an LDAP configuration over TLS for an Atlas project.

Pass the requestId in the response object to the Verify |ldap| Configuration endpoint to get the status of a verification request. Atlas retains only the most recent request for each project.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnLdapVerifyProps.Initializer"></a>

```typescript
import { CfnLdapVerifyProps } from 'awscdk-resources-mongodbatlas'

const cfnLdapVerifyProps: CfnLdapVerifyProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapVerifyProps.property.bindPassword">bindPassword</a></code> | <code>string</code> | Password that MongoDB Cloud uses to authenticate the **bindUsername**. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapVerifyProps.property.bindUsername">bindUsername</a></code> | <code>string</code> | Full Distinguished Name (DN) of the Lightweight Directory Access Protocol (LDAP) user that MongoDB Cloud uses to connect to the LDAP host. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapVerifyProps.property.hostName">hostName</a></code> | <code>string</code> | Human-readable label that identifies the hostname or Internet Protocol (IP) address of the Lightweight Directory Access Protocol (LDAP) host. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapVerifyProps.property.port">port</a></code> | <code>number</code> | Port to which the Lightweight Directory Access Protocol (LDAP) host listens for client connections. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapVerifyProps.property.projectId">projectId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies your project. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapVerifyProps.property.authzQueryTemplate">authzQueryTemplate</a></code> | <code>string</code> | Lightweight Directory Access Protocol (LDAP) query template that MongoDB Cloud runs to obtain the LDAP groups associated with the authenticated user. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapVerifyProps.property.caCertificate">caCertificate</a></code> | <code>string</code> | Certificate Authority (CA) certificate that MongoDB Cloud uses to verify the identity of the Lightweight Directory Access Protocol (LDAP) host. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapVerifyProps.property.profile">profile</a></code> | <code>string</code> | Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided default is used. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnLdapVerifyProps.property.validations">validations</a></code> | <code><a href="#awscdk-resources-mongodbatlas.Validation">Validation</a>[]</code> | List of validation messages related to the verification of the provided LDAP over TLS configuration details. |

---

##### `bindPassword`<sup>Required</sup> <a name="bindPassword" id="awscdk-resources-mongodbatlas.CfnLdapVerifyProps.property.bindPassword"></a>

```typescript
public readonly bindPassword: string;
```

- *Type:* string

Password that MongoDB Cloud uses to authenticate the **bindUsername**.

---

##### `bindUsername`<sup>Required</sup> <a name="bindUsername" id="awscdk-resources-mongodbatlas.CfnLdapVerifyProps.property.bindUsername"></a>

```typescript
public readonly bindUsername: string;
```

- *Type:* string

Full Distinguished Name (DN) of the Lightweight Directory Access Protocol (LDAP) user that MongoDB Cloud uses to connect to the LDAP host.

LDAP distinguished names must be formatted according to RFC 2253.

---

##### `hostName`<sup>Required</sup> <a name="hostName" id="awscdk-resources-mongodbatlas.CfnLdapVerifyProps.property.hostName"></a>

```typescript
public readonly hostName: string;
```

- *Type:* string

Human-readable label that identifies the hostname or Internet Protocol (IP) address of the Lightweight Directory Access Protocol (LDAP) host.

This host must have access to the internet or have a Virtual Private Cloud (VPC) peering connection to your cluster.

---

##### `port`<sup>Required</sup> <a name="port" id="awscdk-resources-mongodbatlas.CfnLdapVerifyProps.property.port"></a>

```typescript
public readonly port: number;
```

- *Type:* number

Port to which the Lightweight Directory Access Protocol (LDAP) host listens for client connections.

---

##### `projectId`<sup>Required</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.CfnLdapVerifyProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies your project.

---

##### `authzQueryTemplate`<sup>Optional</sup> <a name="authzQueryTemplate" id="awscdk-resources-mongodbatlas.CfnLdapVerifyProps.property.authzQueryTemplate"></a>

```typescript
public readonly authzQueryTemplate: string;
```

- *Type:* string

Lightweight Directory Access Protocol (LDAP) query template that MongoDB Cloud runs to obtain the LDAP groups associated with the authenticated user.

MongoDB Cloud uses this parameter only for user authorization. Use the `{USER}` placeholder in the Uniform Resource Locator (URL) to substitute the authenticated username. The query relates to the host specified with the hostname. Format this query according to [RFC 4515](https://tools.ietf.org/search/rfc4515) and [RFC 4516](https://datatracker.ietf.org/doc/html/rfc4516).

---

##### `caCertificate`<sup>Optional</sup> <a name="caCertificate" id="awscdk-resources-mongodbatlas.CfnLdapVerifyProps.property.caCertificate"></a>

```typescript
public readonly caCertificate: string;
```

- *Type:* string

Certificate Authority (CA) certificate that MongoDB Cloud uses to verify the identity of the Lightweight Directory Access Protocol (LDAP) host.

MongoDB Cloud allows self-signed certificates. To delete an assigned value, pass an empty string: `"caCertificate": ""`

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.CfnLdapVerifyProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided default is used.

---

##### `validations`<sup>Optional</sup> <a name="validations" id="awscdk-resources-mongodbatlas.CfnLdapVerifyProps.property.validations"></a>

```typescript
public readonly validations: Validation[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.Validation">Validation</a>[]

List of validation messages related to the verification of the provided LDAP over TLS configuration details.

The array contains a document for each test that Atlas runs. Atlas stops running tests after the first failure.

---

### CfnMaintenanceWindowProps <a name="CfnMaintenanceWindowProps" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindowProps"></a>

The maintenanceWindow resource provides access to retrieve or update the current Atlas project maintenance window.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindowProps.Initializer"></a>

```typescript
import { CfnMaintenanceWindowProps } from 'awscdk-resources-mongodbatlas'

const cfnMaintenanceWindowProps: CfnMaintenanceWindowProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnMaintenanceWindowProps.property.hourOfDay">hourOfDay</a></code> | <code>number</code> | Zero-based integer that represents the hour of the of the day that the maintenance window starts according to a 24-hour clock. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnMaintenanceWindowProps.property.autoDeferOnceEnabled">autoDeferOnceEnabled</a></code> | <code>boolean</code> | Flag that indicates whether MongoDB Cloud should defer all maintenance windows for one week after you enable them. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnMaintenanceWindowProps.property.dayOfWeek">dayOfWeek</a></code> | <code>number</code> | One-based integer that represents the day of the week that the maintenance window starts. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnMaintenanceWindowProps.property.profile">profile</a></code> | <code>string</code> | The profile is defined in AWS Secret manager. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnMaintenanceWindowProps.property.projectId">projectId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies your project. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnMaintenanceWindowProps.property.startAsap">startAsap</a></code> | <code>boolean</code> | Flag that indicates whether MongoDB Cloud starts the maintenance window immediately upon receiving this request. |

---

##### `hourOfDay`<sup>Required</sup> <a name="hourOfDay" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindowProps.property.hourOfDay"></a>

```typescript
public readonly hourOfDay: number;
```

- *Type:* number

Zero-based integer that represents the hour of the of the day that the maintenance window starts according to a 24-hour clock.

Use `0` for midnight and `12` for noon.

---

##### `autoDeferOnceEnabled`<sup>Optional</sup> <a name="autoDeferOnceEnabled" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindowProps.property.autoDeferOnceEnabled"></a>

```typescript
public readonly autoDeferOnceEnabled: boolean;
```

- *Type:* boolean

Flag that indicates whether MongoDB Cloud should defer all maintenance windows for one week after you enable them.

---

##### `dayOfWeek`<sup>Optional</sup> <a name="dayOfWeek" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindowProps.property.dayOfWeek"></a>

```typescript
public readonly dayOfWeek: number;
```

- *Type:* number

One-based integer that represents the day of the week that the maintenance window starts.

| Value | Day of Week |
|---|---|
| `1` | Sunday |
| `2` | Monday |
| `3` | Tuesday |
| `4` | Wednesday |
| `5` | Thursday |
| `6` | Friday |
| `7` | Saturday |

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindowProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

The profile is defined in AWS Secret manager.

See [Secret Manager Profile setup](../../../examples/profile-secret.yaml)

---

##### `projectId`<sup>Optional</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindowProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies your project.

---

##### `startAsap`<sup>Optional</sup> <a name="startAsap" id="awscdk-resources-mongodbatlas.CfnMaintenanceWindowProps.property.startAsap"></a>

```typescript
public readonly startAsap: boolean;
```

- *Type:* boolean

Flag that indicates whether MongoDB Cloud starts the maintenance window immediately upon receiving this request.

To start the maintenance window immediately for your project, MongoDB Cloud must have maintenance scheduled and you must set a maintenance window. This flag resets to `false` after MongoDB Cloud completes maintenance.

---

### CfnNetworkContainerProps <a name="CfnNetworkContainerProps" id="awscdk-resources-mongodbatlas.CfnNetworkContainerProps"></a>

Returns, adds, edits, and removes network peering containers.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnNetworkContainerProps.Initializer"></a>

```typescript
import { CfnNetworkContainerProps } from 'awscdk-resources-mongodbatlas'

const cfnNetworkContainerProps: CfnNetworkContainerProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkContainerProps.property.atlasCidrBlock">atlasCidrBlock</a></code> | <code>string</code> | IP addresses expressed in Classless Inter-Domain Routing (CIDR) notation that MongoDB Cloud uses for the network peering containers in your project. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkContainerProps.property.projectId">projectId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies your project. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkContainerProps.property.regionName">regionName</a></code> | <code>string</code> | Geographic area that Amazon Web Services (AWS) defines to which MongoDB Cloud deployed this network peering container. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkContainerProps.property.profile">profile</a></code> | <code>string</code> | The profile is defined in AWS Secret manager. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkContainerProps.property.provisioned">provisioned</a></code> | <code>boolean</code> | Boolean flag that indicates whether MongoDB Cloud clusters exist in the specified network peering container. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkContainerProps.property.vpcId">vpcId</a></code> | <code>string</code> | Unique string that identifies the MongoDB Cloud VPC on AWS. |

---

##### `atlasCidrBlock`<sup>Required</sup> <a name="atlasCidrBlock" id="awscdk-resources-mongodbatlas.CfnNetworkContainerProps.property.atlasCidrBlock"></a>

```typescript
public readonly atlasCidrBlock: string;
```

- *Type:* string

IP addresses expressed in Classless Inter-Domain Routing (CIDR) notation that MongoDB Cloud uses for the network peering containers in your project.

MongoDB Cloud assigns all of the project's clusters deployed to this cloud provider an IP address from this range. MongoDB Cloud locks this value if an M10 or greater cluster or a network peering connection exists in this project.
These CIDR blocks must fall within the ranges reserved per RFC 1918. AWS further limits the block to between the /24 and /21 ranges.
To modify the CIDR block, the target project cannot have:
- Any M10 or greater clusters
- Any other VPC peering connections
You can also create a new project and create a network peering connection to set the desired MongoDB Cloud network peering container CIDR block for that project. MongoDB Cloud limits the number of MongoDB nodes per network peering connection based on the CIDR block and the region selected for the project.
Example: A project in an Amazon Web Services (AWS) region supporting three availability zones and an MongoDB CIDR network peering container block of limit of /24 equals 27 three-node replica sets.

---

##### `projectId`<sup>Required</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.CfnNetworkContainerProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies your project.

---

##### `regionName`<sup>Required</sup> <a name="regionName" id="awscdk-resources-mongodbatlas.CfnNetworkContainerProps.property.regionName"></a>

```typescript
public readonly regionName: string;
```

- *Type:* string

Geographic area that Amazon Web Services (AWS) defines to which MongoDB Cloud deployed this network peering container.

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.CfnNetworkContainerProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

The profile is defined in AWS Secret manager.

See [Secret Manager Profile setup](../../../examples/profile-secret.yaml).

---

##### `provisioned`<sup>Optional</sup> <a name="provisioned" id="awscdk-resources-mongodbatlas.CfnNetworkContainerProps.property.provisioned"></a>

```typescript
public readonly provisioned: boolean;
```

- *Type:* boolean

Boolean flag that indicates whether MongoDB Cloud clusters exist in the specified network peering container.

---

##### `vpcId`<sup>Optional</sup> <a name="vpcId" id="awscdk-resources-mongodbatlas.CfnNetworkContainerProps.property.vpcId"></a>

```typescript
public readonly vpcId: string;
```

- *Type:* string

Unique string that identifies the MongoDB Cloud VPC on AWS.

---

### CfnNetworkPeeringProps <a name="CfnNetworkPeeringProps" id="awscdk-resources-mongodbatlas.CfnNetworkPeeringProps"></a>

Returns, adds, edits, and removes network peering containers and peering connections.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnNetworkPeeringProps.Initializer"></a>

```typescript
import { CfnNetworkPeeringProps } from 'awscdk-resources-mongodbatlas'

const cfnNetworkPeeringProps: CfnNetworkPeeringProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkPeeringProps.property.containerId">containerId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies the MongoDB Cloud network container that contains the specified network peering connection. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkPeeringProps.property.projectId">projectId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies your project. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkPeeringProps.property.vpcId">vpcId</a></code> | <code>string</code> | Unique string that identifies the VPC on Amazon Web Services (AWS) that you want to peer with the MongoDB Cloud VPC. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkPeeringProps.property.accepterRegionName">accepterRegionName</a></code> | <code>string</code> | Amazon Web Services (AWS) region where the Virtual Peering Connection (VPC) that you peered with the MongoDB Cloud VPC resides. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkPeeringProps.property.awsAccountId">awsAccountId</a></code> | <code>string</code> | Unique twelve-digit string that identifies the Amazon Web Services (AWS) account that owns the VPC that you peered with the MongoDB Cloud VPC. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkPeeringProps.property.profile">profile</a></code> | <code>string</code> | The profile is defined in AWS Secret manager. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnNetworkPeeringProps.property.routeTableCidrBlock">routeTableCidrBlock</a></code> | <code>string</code> | Internet Protocol (IP) addresses expressed in Classless Inter-Domain Routing (CIDR) notation of the VPC's subnet that you want to peer with the MongoDB Cloud VPC. |

---

##### `containerId`<sup>Required</sup> <a name="containerId" id="awscdk-resources-mongodbatlas.CfnNetworkPeeringProps.property.containerId"></a>

```typescript
public readonly containerId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies the MongoDB Cloud network container that contains the specified network peering connection.

---

##### `projectId`<sup>Required</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.CfnNetworkPeeringProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies your project.

---

##### `vpcId`<sup>Required</sup> <a name="vpcId" id="awscdk-resources-mongodbatlas.CfnNetworkPeeringProps.property.vpcId"></a>

```typescript
public readonly vpcId: string;
```

- *Type:* string

Unique string that identifies the VPC on Amazon Web Services (AWS) that you want to peer with the MongoDB Cloud VPC.

---

##### `accepterRegionName`<sup>Optional</sup> <a name="accepterRegionName" id="awscdk-resources-mongodbatlas.CfnNetworkPeeringProps.property.accepterRegionName"></a>

```typescript
public readonly accepterRegionName: string;
```

- *Type:* string

Amazon Web Services (AWS) region where the Virtual Peering Connection (VPC) that you peered with the MongoDB Cloud VPC resides.

The resource returns null if your VPC and the MongoDB Cloud VPC reside in the same region.

---

##### `awsAccountId`<sup>Optional</sup> <a name="awsAccountId" id="awscdk-resources-mongodbatlas.CfnNetworkPeeringProps.property.awsAccountId"></a>

```typescript
public readonly awsAccountId: string;
```

- *Type:* string

Unique twelve-digit string that identifies the Amazon Web Services (AWS) account that owns the VPC that you peered with the MongoDB Cloud VPC.

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.CfnNetworkPeeringProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

The profile is defined in AWS Secret manager.

See [Secret Manager Profile setup](../../../examples/profile-secret.yaml).

---

##### `routeTableCidrBlock`<sup>Optional</sup> <a name="routeTableCidrBlock" id="awscdk-resources-mongodbatlas.CfnNetworkPeeringProps.property.routeTableCidrBlock"></a>

```typescript
public readonly routeTableCidrBlock: string;
```

- *Type:* string

Internet Protocol (IP) addresses expressed in Classless Inter-Domain Routing (CIDR) notation of the VPC's subnet that you want to peer with the MongoDB Cloud VPC.

---

### CfnOnlineArchiveProps <a name="CfnOnlineArchiveProps" id="awscdk-resources-mongodbatlas.CfnOnlineArchiveProps"></a>

Returns, adds, edits, or removes an online archive.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnOnlineArchiveProps.Initializer"></a>

```typescript
import { CfnOnlineArchiveProps } from 'awscdk-resources-mongodbatlas'

const cfnOnlineArchiveProps: CfnOnlineArchiveProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchiveProps.property.clusterName">clusterName</a></code> | <code>string</code> | Human-readable label that identifies the cluster that contains the collection from which you want to remove an online archive. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchiveProps.property.criteria">criteria</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CriteriaView">CriteriaView</a></code> | Rules by which MongoDB MongoDB Cloud archives data. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchiveProps.property.collectionType">collectionType</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchivePropsCollectionType">CfnOnlineArchivePropsCollectionType</a></code> | Classification of MongoDB database collection that you want to return. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchiveProps.property.collName">collName</a></code> | <code>string</code> | Human-readable label that identifies the collection for which you created the online archive. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchiveProps.property.dbName">dbName</a></code> | <code>string</code> | Human-readable label of the database that contains the collection that contains the online archive. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchiveProps.property.includeCount">includeCount</a></code> | <code>boolean</code> | Flag that indicates whether the response returns the total number of items (**totalCount**) in the response. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchiveProps.property.itemsPerPage">itemsPerPage</a></code> | <code>number</code> | Number of items that the response returns per page. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchiveProps.property.pageNum">pageNum</a></code> | <code>number</code> | Number of the page that displays the current set of the total objects that the response returns. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchiveProps.property.partitionFields">partitionFields</a></code> | <code><a href="#awscdk-resources-mongodbatlas.PartitionFieldView">PartitionFieldView</a>[]</code> | List that contains document parameters to use to logically divide data within a collection. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchiveProps.property.profile">profile</a></code> | <code>string</code> | The profile is defined in AWS Secret manager. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchiveProps.property.projectId">projectId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies your project. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchiveProps.property.schedule">schedule</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ScheduleView">ScheduleView</a></code> | Regular frequency and duration when archiving process occurs. |

---

##### `clusterName`<sup>Required</sup> <a name="clusterName" id="awscdk-resources-mongodbatlas.CfnOnlineArchiveProps.property.clusterName"></a>

```typescript
public readonly clusterName: string;
```

- *Type:* string

Human-readable label that identifies the cluster that contains the collection from which you want to remove an online archive.

---

##### `criteria`<sup>Required</sup> <a name="criteria" id="awscdk-resources-mongodbatlas.CfnOnlineArchiveProps.property.criteria"></a>

```typescript
public readonly criteria: CriteriaView;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CriteriaView">CriteriaView</a>

Rules by which MongoDB MongoDB Cloud archives data.

Use the **criteria.type** field to choose how MongoDB Cloud selects data to archive. Choose data using the age of the data or a MongoDB query.
**"criteria.type": "DATE"** selects documents to archive based on a date.
**"criteria.type": "CUSTOM"** selects documents to archive based on a custom JSON query. MongoDB Cloud doesn't support **"criteria.type": "CUSTOM"** when **"collectionType": "TIMESERIES"**.

---

##### `collectionType`<sup>Optional</sup> <a name="collectionType" id="awscdk-resources-mongodbatlas.CfnOnlineArchiveProps.property.collectionType"></a>

```typescript
public readonly collectionType: CfnOnlineArchivePropsCollectionType;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnOnlineArchivePropsCollectionType">CfnOnlineArchivePropsCollectionType</a>

Classification of MongoDB database collection that you want to return.

If you set this parameter to `TIMESERIES`, set `"criteria.type" : "date"` and `"criteria.dateFormat" : "ISODATE"`.

---

##### `collName`<sup>Optional</sup> <a name="collName" id="awscdk-resources-mongodbatlas.CfnOnlineArchiveProps.property.collName"></a>

```typescript
public readonly collName: string;
```

- *Type:* string

Human-readable label that identifies the collection for which you created the online archive.

---

##### `dbName`<sup>Optional</sup> <a name="dbName" id="awscdk-resources-mongodbatlas.CfnOnlineArchiveProps.property.dbName"></a>

```typescript
public readonly dbName: string;
```

- *Type:* string

Human-readable label of the database that contains the collection that contains the online archive.

---

##### `includeCount`<sup>Optional</sup> <a name="includeCount" id="awscdk-resources-mongodbatlas.CfnOnlineArchiveProps.property.includeCount"></a>

```typescript
public readonly includeCount: boolean;
```

- *Type:* boolean

Flag that indicates whether the response returns the total number of items (**totalCount**) in the response.

---

##### `itemsPerPage`<sup>Optional</sup> <a name="itemsPerPage" id="awscdk-resources-mongodbatlas.CfnOnlineArchiveProps.property.itemsPerPage"></a>

```typescript
public readonly itemsPerPage: number;
```

- *Type:* number

Number of items that the response returns per page.

---

##### `pageNum`<sup>Optional</sup> <a name="pageNum" id="awscdk-resources-mongodbatlas.CfnOnlineArchiveProps.property.pageNum"></a>

```typescript
public readonly pageNum: number;
```

- *Type:* number

Number of the page that displays the current set of the total objects that the response returns.

---

##### `partitionFields`<sup>Optional</sup> <a name="partitionFields" id="awscdk-resources-mongodbatlas.CfnOnlineArchiveProps.property.partitionFields"></a>

```typescript
public readonly partitionFields: PartitionFieldView[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.PartitionFieldView">PartitionFieldView</a>[]

List that contains document parameters to use to logically divide data within a collection.

Partitions provide a coarse level of filtering of the underlying collection data. To divide your data, specify up to two parameters that you frequently query. Any queries that don't use these parameters result in a full collection scan of all archived documents. This takes more time and increase your costs.

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.CfnOnlineArchiveProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

The profile is defined in AWS Secret manager.

See [Secret Manager Profile setup](../../../examples/profile-secret.yaml).

---

##### `projectId`<sup>Optional</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.CfnOnlineArchiveProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies your project.

---

##### `schedule`<sup>Optional</sup> <a name="schedule" id="awscdk-resources-mongodbatlas.CfnOnlineArchiveProps.property.schedule"></a>

```typescript
public readonly schedule: ScheduleView;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ScheduleView">ScheduleView</a>

Regular frequency and duration when archiving process occurs.

---

### CfnOrganizationProps <a name="CfnOrganizationProps" id="awscdk-resources-mongodbatlas.CfnOrganizationProps"></a>

Returns, adds, and edits organizational units in MongoDB Cloud.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnOrganizationProps.Initializer"></a>

```typescript
import { CfnOrganizationProps } from 'awscdk-resources-mongodbatlas'

const cfnOrganizationProps: CfnOrganizationProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrganizationProps.property.awsSecretName">awsSecretName</a></code> | <code>string</code> | AwsSecretName used to set newly created Org credentials information. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrganizationProps.property.name">name</a></code> | <code>string</code> | Human-readable label that identifies the organization. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrganizationProps.property.orgOwnerId">orgOwnerId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies the MongoDB Cloud user that you want to assign the Organization Owner role. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrganizationProps.property.apiAccessListRequired">apiAccessListRequired</a></code> | <code>boolean</code> | Flag that indicates whether to require API operations to originate from an IP Address added to the API access list for the specified organization. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrganizationProps.property.apiKey">apiKey</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ApiKey">ApiKey</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrganizationProps.property.federatedSettingsId">federatedSettingsId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies the federation to link the newly created organization to. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrganizationProps.property.isDeleted">isDeleted</a></code> | <code>boolean</code> | Flag that indicates whether this organization has been deleted. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrganizationProps.property.multiFactorAuthRequired">multiFactorAuthRequired</a></code> | <code>boolean</code> | Flag that indicates whether to require users to set up Multi-Factor Authentication (MFA) before accessing the specified organization. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrganizationProps.property.profile">profile</a></code> | <code>string</code> | Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided default is used. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrganizationProps.property.restrictEmployeeAccess">restrictEmployeeAccess</a></code> | <code>boolean</code> | Flag that indicates whether to block MongoDB Support from accessing Atlas infrastructure for any deployment in the specified organization without explicit permission. |

---

##### `awsSecretName`<sup>Required</sup> <a name="awsSecretName" id="awscdk-resources-mongodbatlas.CfnOrganizationProps.property.awsSecretName"></a>

```typescript
public readonly awsSecretName: string;
```

- *Type:* string

AwsSecretName used to set newly created Org credentials information.

---

##### `name`<sup>Required</sup> <a name="name" id="awscdk-resources-mongodbatlas.CfnOrganizationProps.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Human-readable label that identifies the organization.

---

##### `orgOwnerId`<sup>Required</sup> <a name="orgOwnerId" id="awscdk-resources-mongodbatlas.CfnOrganizationProps.property.orgOwnerId"></a>

```typescript
public readonly orgOwnerId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies the MongoDB Cloud user that you want to assign the Organization Owner role.

This user must be a member of the same organization as the calling API key. If you provide federationSettingsId, this user must instead have the Organization Owner role on an organization in the specified federation. This parameter is required only when you authenticate with Programmatic API Keys.

---

##### `apiAccessListRequired`<sup>Optional</sup> <a name="apiAccessListRequired" id="awscdk-resources-mongodbatlas.CfnOrganizationProps.property.apiAccessListRequired"></a>

```typescript
public readonly apiAccessListRequired: boolean;
```

- *Type:* boolean

Flag that indicates whether to require API operations to originate from an IP Address added to the API access list for the specified organization.

---

##### `apiKey`<sup>Optional</sup> <a name="apiKey" id="awscdk-resources-mongodbatlas.CfnOrganizationProps.property.apiKey"></a>

```typescript
public readonly apiKey: ApiKey;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ApiKey">ApiKey</a>

---

##### `federatedSettingsId`<sup>Optional</sup> <a name="federatedSettingsId" id="awscdk-resources-mongodbatlas.CfnOrganizationProps.property.federatedSettingsId"></a>

```typescript
public readonly federatedSettingsId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies the federation to link the newly created organization to.

If specified, the proposed Organization Owner of the new organization must have the Organization Owner role in an organization associated with the federation.

---

##### `isDeleted`<sup>Optional</sup> <a name="isDeleted" id="awscdk-resources-mongodbatlas.CfnOrganizationProps.property.isDeleted"></a>

```typescript
public readonly isDeleted: boolean;
```

- *Type:* boolean

Flag that indicates whether this organization has been deleted.

---

##### `multiFactorAuthRequired`<sup>Optional</sup> <a name="multiFactorAuthRequired" id="awscdk-resources-mongodbatlas.CfnOrganizationProps.property.multiFactorAuthRequired"></a>

```typescript
public readonly multiFactorAuthRequired: boolean;
```

- *Type:* boolean

Flag that indicates whether to require users to set up Multi-Factor Authentication (MFA) before accessing the specified organization.

To learn more, see: https://www.mongodb.com/docs/atlas/security-multi-factor-authentication/.

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.CfnOrganizationProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided default is used.

---

##### `restrictEmployeeAccess`<sup>Optional</sup> <a name="restrictEmployeeAccess" id="awscdk-resources-mongodbatlas.CfnOrganizationProps.property.restrictEmployeeAccess"></a>

```typescript
public readonly restrictEmployeeAccess: boolean;
```

- *Type:* boolean

Flag that indicates whether to block MongoDB Support from accessing Atlas infrastructure for any deployment in the specified organization without explicit permission.

Once this setting is turned on, you can grant MongoDB Support a 24-hour bypass access to the Atlas deployment to resolve support issues. To learn more, see: https://www.mongodb.com/docs/atlas/security-restrict-support-access/.

---

### CfnOrgInvitationProps <a name="CfnOrgInvitationProps" id="awscdk-resources-mongodbatlas.CfnOrgInvitationProps"></a>

Returns, adds, and edits organizational units in MongoDB Cloud.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnOrgInvitationProps.Initializer"></a>

```typescript
import { CfnOrgInvitationProps } from 'awscdk-resources-mongodbatlas'

const cfnOrgInvitationProps: CfnOrgInvitationProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitationProps.property.profile">profile</a></code> | <code>string</code> | Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided default is used. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitationProps.property.includeCount">includeCount</a></code> | <code>boolean</code> | Flag that indicates whether the response returns the total number of items (**totalCount**) in the response. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitationProps.property.invitationId">invitationId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies the invitation. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitationProps.property.itemsPerPage">itemsPerPage</a></code> | <code>number</code> | Number of items that the response returns per page. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitationProps.property.orgId">orgId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies the organization that contains your projects. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitationProps.property.orgName">orgName</a></code> | <code>string</code> | Human-readable label that identifies this organization. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitationProps.property.pageNum">pageNum</a></code> | <code>number</code> | Number of the page that displays the current set of the total objects that the response returns. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitationProps.property.roles">roles</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitationPropsRoles">CfnOrgInvitationPropsRoles</a>[]</code> | One or more organization or project level roles to assign to the MongoDB Cloud user. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitationProps.property.teamIds">teamIds</a></code> | <code>string[]</code> | List of unique 24-hexadecimal digit strings that identifies each team. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitationProps.property.totalCount">totalCount</a></code> | <code>number</code> | Number of documents returned in this response. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitationProps.property.username">username</a></code> | <code>string</code> | Email address of the MongoDB Cloud user invited to join the organization. |

---

##### `profile`<sup>Required</sup> <a name="profile" id="awscdk-resources-mongodbatlas.CfnOrgInvitationProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided default is used.

---

##### `includeCount`<sup>Optional</sup> <a name="includeCount" id="awscdk-resources-mongodbatlas.CfnOrgInvitationProps.property.includeCount"></a>

```typescript
public readonly includeCount: boolean;
```

- *Type:* boolean

Flag that indicates whether the response returns the total number of items (**totalCount**) in the response.

---

##### `invitationId`<sup>Optional</sup> <a name="invitationId" id="awscdk-resources-mongodbatlas.CfnOrgInvitationProps.property.invitationId"></a>

```typescript
public readonly invitationId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies the invitation.

---

##### `itemsPerPage`<sup>Optional</sup> <a name="itemsPerPage" id="awscdk-resources-mongodbatlas.CfnOrgInvitationProps.property.itemsPerPage"></a>

```typescript
public readonly itemsPerPage: number;
```

- *Type:* number

Number of items that the response returns per page.

---

##### `orgId`<sup>Optional</sup> <a name="orgId" id="awscdk-resources-mongodbatlas.CfnOrgInvitationProps.property.orgId"></a>

```typescript
public readonly orgId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies the organization that contains your projects.

---

##### `orgName`<sup>Optional</sup> <a name="orgName" id="awscdk-resources-mongodbatlas.CfnOrgInvitationProps.property.orgName"></a>

```typescript
public readonly orgName: string;
```

- *Type:* string

Human-readable label that identifies this organization.

---

##### `pageNum`<sup>Optional</sup> <a name="pageNum" id="awscdk-resources-mongodbatlas.CfnOrgInvitationProps.property.pageNum"></a>

```typescript
public readonly pageNum: number;
```

- *Type:* number

Number of the page that displays the current set of the total objects that the response returns.

---

##### `roles`<sup>Optional</sup> <a name="roles" id="awscdk-resources-mongodbatlas.CfnOrgInvitationProps.property.roles"></a>

```typescript
public readonly roles: CfnOrgInvitationPropsRoles[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnOrgInvitationPropsRoles">CfnOrgInvitationPropsRoles</a>[]

One or more organization or project level roles to assign to the MongoDB Cloud user.

---

##### `teamIds`<sup>Optional</sup> <a name="teamIds" id="awscdk-resources-mongodbatlas.CfnOrgInvitationProps.property.teamIds"></a>

```typescript
public readonly teamIds: string[];
```

- *Type:* string[]

List of unique 24-hexadecimal digit strings that identifies each team.

---

##### `totalCount`<sup>Optional</sup> <a name="totalCount" id="awscdk-resources-mongodbatlas.CfnOrgInvitationProps.property.totalCount"></a>

```typescript
public readonly totalCount: number;
```

- *Type:* number

Number of documents returned in this response.

---

##### `username`<sup>Optional</sup> <a name="username" id="awscdk-resources-mongodbatlas.CfnOrgInvitationProps.property.username"></a>

```typescript
public readonly username: string;
```

- *Type:* string

Email address of the MongoDB Cloud user invited to join the organization.

---

### CfnPrivateEndpointAdlProps <a name="CfnPrivateEndpointAdlProps" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdlProps"></a>

Adds one private endpoint for Federated Database Instances and Online Archives to the specified projects.

To use this resource, the requesting API Key must have the Project Atlas Admin or Project Charts Admin roles. This resource doesn't require the API Key to have an Access List.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdlProps.Initializer"></a>

```typescript
import { CfnPrivateEndpointAdlProps } from 'awscdk-resources-mongodbatlas'

const cfnPrivateEndpointAdlProps: CfnPrivateEndpointAdlProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAdlProps.property.projectId">projectId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies your project. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAdlProps.property.provider">provider</a></code> | <code>string</code> | Human-readable label that identifies the cloud service provider. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAdlProps.property.comment">comment</a></code> | <code>string</code> | Human-readable string to associate with this private endpoint. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAdlProps.property.endpointId">endpointId</a></code> | <code>string</code> | Unique 22-character alphanumeric string that identifies the private endpoint. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAdlProps.property.profile">profile</a></code> | <code>string</code> | Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided default is used. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAdlProps.property.type">type</a></code> | <code>string</code> | Human-readable label that identifies the resource type associated with this private endpoint. |

---

##### `projectId`<sup>Required</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdlProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies your project.

---

##### `provider`<sup>Required</sup> <a name="provider" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdlProps.property.provider"></a>

```typescript
public readonly provider: string;
```

- *Type:* string

Human-readable label that identifies the cloud service provider.

Atlas Data Lake supports Amazon Web Services only.

---

##### `comment`<sup>Optional</sup> <a name="comment" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdlProps.property.comment"></a>

```typescript
public readonly comment: string;
```

- *Type:* string

Human-readable string to associate with this private endpoint.

---

##### `endpointId`<sup>Optional</sup> <a name="endpointId" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdlProps.property.endpointId"></a>

```typescript
public readonly endpointId: string;
```

- *Type:* string

Unique 22-character alphanumeric string that identifies the private endpoint.

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdlProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided default is used.

---

##### `type`<sup>Optional</sup> <a name="type" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAdlProps.property.type"></a>

```typescript
public readonly type: string;
```

- *Type:* string

Human-readable label that identifies the resource type associated with this private endpoint.

---

### CfnPrivateEndpointAwsProps <a name="CfnPrivateEndpointAwsProps" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAwsProps"></a>

Creates one private endpoint for the specified cloud service provider.

At this current version only AWS is supported

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAwsProps.Initializer"></a>

```typescript
import { CfnPrivateEndpointAwsProps } from 'awscdk-resources-mongodbatlas'

const cfnPrivateEndpointAwsProps: CfnPrivateEndpointAwsProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAwsProps.property.endpointServiceId">endpointServiceId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies the private endpoint service for which you want to create a private endpoint. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAwsProps.property.projectId">projectId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies your project. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAwsProps.property.connectionStatus">connectionStatus</a></code> | <code>string</code> | State of the Amazon Web Service PrivateLink connection when MongoDB Cloud received this request. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAwsProps.property.enforceConnectionSuccess">enforceConnectionSuccess</a></code> | <code>boolean</code> | If this proper is set to TRUE, the cloud formation resource will return success Only if the private connection is Succeeded. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAwsProps.property.errorMessage">errorMessage</a></code> | <code>string</code> | Error message returned when requesting private connection resource. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAwsProps.property.id">id</a></code> | <code>string</code> | Unique string that identifies the private endpoint. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointAwsProps.property.profile">profile</a></code> | <code>string</code> | The profile is defined in AWS Secret manager. |

---

##### `endpointServiceId`<sup>Required</sup> <a name="endpointServiceId" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAwsProps.property.endpointServiceId"></a>

```typescript
public readonly endpointServiceId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies the private endpoint service for which you want to create a private endpoint.

---

##### `projectId`<sup>Required</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAwsProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies your project.

---

##### `connectionStatus`<sup>Optional</sup> <a name="connectionStatus" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAwsProps.property.connectionStatus"></a>

```typescript
public readonly connectionStatus: string;
```

- *Type:* string

State of the Amazon Web Service PrivateLink connection when MongoDB Cloud received this request.

---

##### `enforceConnectionSuccess`<sup>Optional</sup> <a name="enforceConnectionSuccess" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAwsProps.property.enforceConnectionSuccess"></a>

```typescript
public readonly enforceConnectionSuccess: boolean;
```

- *Type:* boolean

If this proper is set to TRUE, the cloud formation resource will return success Only if the private connection is Succeeded.

---

##### `errorMessage`<sup>Optional</sup> <a name="errorMessage" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAwsProps.property.errorMessage"></a>

```typescript
public readonly errorMessage: string;
```

- *Type:* string

Error message returned when requesting private connection resource.

The resource returns null if the request succeeded.

---

##### `id`<sup>Optional</sup> <a name="id" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAwsProps.property.id"></a>

```typescript
public readonly id: string;
```

- *Type:* string

Unique string that identifies the private endpoint.

for AWS is the VPC endpoint ID, example: vpce-xxxxxxxx

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointAwsProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

The profile is defined in AWS Secret manager.

See [Secret Manager Profile setup (../../../examples/profile-secret.yaml)

---

### CfnPrivateEndpointProps <a name="CfnPrivateEndpointProps" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointProps"></a>

The Private Endpoint creation flow consists of the creation of three related resources in the next order: 1.

Atlas Private Endpoint Service 2. Aws VPC private Endpoint 3. Atlas Private Endpoint

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointProps.Initializer"></a>

```typescript
import { CfnPrivateEndpointProps } from 'awscdk-resources-mongodbatlas'

const cfnPrivateEndpointProps: CfnPrivateEndpointProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointProps.property.groupId">groupId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies your project. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointProps.property.region">region</a></code> | <code>string</code> | Aws Region. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointProps.property.endpointServiceName">endpointServiceName</a></code> | <code>string</code> | Name of the AWS PrivateLink endpoint service. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointProps.property.errorMessage">errorMessage</a></code> | <code>string</code> | Error message pertaining to the AWS PrivateLink connection. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointProps.property.privateEndpoints">privateEndpoints</a></code> | <code><a href="#awscdk-resources-mongodbatlas.PrivateEndpoint">PrivateEndpoint</a>[]</code> | List of private endpoint associated to the service. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointProps.property.profile">profile</a></code> | <code>string</code> | The profile is defined in AWS Secret manager. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointProps.property.status">status</a></code> | <code>string</code> | Status of the Atlas PrivateEndpoint service connection. |

---

##### `groupId`<sup>Required</sup> <a name="groupId" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointProps.property.groupId"></a>

```typescript
public readonly groupId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies your project.

---

##### `region`<sup>Required</sup> <a name="region" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointProps.property.region"></a>

```typescript
public readonly region: string;
```

- *Type:* string

Aws Region.

---

##### `endpointServiceName`<sup>Optional</sup> <a name="endpointServiceName" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointProps.property.endpointServiceName"></a>

```typescript
public readonly endpointServiceName: string;
```

- *Type:* string

Name of the AWS PrivateLink endpoint service.

Atlas returns null while it is creating the endpoint service.

---

##### `errorMessage`<sup>Optional</sup> <a name="errorMessage" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointProps.property.errorMessage"></a>

```typescript
public readonly errorMessage: string;
```

- *Type:* string

Error message pertaining to the AWS PrivateLink connection.

Returns null if there are no errors.

---

##### `privateEndpoints`<sup>Optional</sup> <a name="privateEndpoints" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointProps.property.privateEndpoints"></a>

```typescript
public readonly privateEndpoints: PrivateEndpoint[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.PrivateEndpoint">PrivateEndpoint</a>[]

List of private endpoint associated to the service.

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

The profile is defined in AWS Secret manager.

See [Secret Manager Profile setup (../../../examples/profile-secret.yaml)

---

##### `status`<sup>Optional</sup> <a name="status" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointProps.property.status"></a>

```typescript
public readonly status: string;
```

- *Type:* string

Status of the Atlas PrivateEndpoint service connection.

---

### CfnPrivateEndPointRegionalModeProps <a name="CfnPrivateEndPointRegionalModeProps" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalModeProps"></a>

An example resource schema demonstrating some basic constructs and validation rules.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalModeProps.Initializer"></a>

```typescript
import { CfnPrivateEndPointRegionalModeProps } from 'awscdk-resources-mongodbatlas'

const cfnPrivateEndPointRegionalModeProps: CfnPrivateEndPointRegionalModeProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalModeProps.property.projectId">projectId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies your project. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalModeProps.property.profile">profile</a></code> | <code>string</code> | Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided default is used. |

---

##### `projectId`<sup>Required</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalModeProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies your project.

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.CfnPrivateEndPointRegionalModeProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided default is used.

---

### CfnPrivateEndpointServiceProps <a name="CfnPrivateEndpointServiceProps" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointServiceProps"></a>

Creates one private endpoint service for the specified cloud service provider.

This cloud service provider manages the private endpoint service for the project. When you create a private endpoint service, MongoDB Cloud creates a network container in the project for the cloud provider for which you create the private endpoint service if one doesn't already exist.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointServiceProps.Initializer"></a>

```typescript
import { CfnPrivateEndpointServiceProps } from 'awscdk-resources-mongodbatlas'

const cfnPrivateEndpointServiceProps: CfnPrivateEndpointServiceProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointServiceProps.property.cloudProvider">cloudProvider</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointServicePropsCloudProvider">CfnPrivateEndpointServicePropsCloudProvider</a></code> | Cloud service provider that manages this private endpoint, default : AWS. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointServiceProps.property.projectId">projectId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies your project. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointServiceProps.property.region">region</a></code> | <code>string</code> | Aws Region. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointServiceProps.property.profile">profile</a></code> | <code>string</code> | The profile is defined in AWS Secret manager. |

---

##### `cloudProvider`<sup>Required</sup> <a name="cloudProvider" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointServiceProps.property.cloudProvider"></a>

```typescript
public readonly cloudProvider: CfnPrivateEndpointServicePropsCloudProvider;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointServicePropsCloudProvider">CfnPrivateEndpointServicePropsCloudProvider</a>

Cloud service provider that manages this private endpoint, default : AWS.

---

##### `projectId`<sup>Required</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointServiceProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies your project.

---

##### `region`<sup>Required</sup> <a name="region" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointServiceProps.property.region"></a>

```typescript
public readonly region: string;
```

- *Type:* string

Aws Region.

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointServiceProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

The profile is defined in AWS Secret manager.

See [Secret Manager Profile setup (../../../examples/profile-secret.yaml)

---

### CfnPrivatelinkEndpointServiceDataFederationOnlineArchiveProps <a name="CfnPrivatelinkEndpointServiceDataFederationOnlineArchiveProps" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchiveProps"></a>

Adds one private endpoint for Federated Database Instances and Online Archives to the specified projects.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchiveProps.Initializer"></a>

```typescript
import { CfnPrivatelinkEndpointServiceDataFederationOnlineArchiveProps } from 'awscdk-resources-mongodbatlas'

const cfnPrivatelinkEndpointServiceDataFederationOnlineArchiveProps: CfnPrivatelinkEndpointServiceDataFederationOnlineArchiveProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchiveProps.property.endpointId">endpointId</a></code> | <code>string</code> | Unique 22-character alphanumeric string that identifies the private endpoint.Reg ex ^vpce-[0-9a-f]{17}$ . |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchiveProps.property.projectId">projectId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies your project. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchiveProps.property.comment">comment</a></code> | <code>string</code> | Human-readable string to associate with this private endpoint. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchiveProps.property.profile">profile</a></code> | <code>string</code> | Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided default is used. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchiveProps.property.type">type</a></code> | <code>string</code> | Human-readable label that identifies the resource type associated with this private endpoint. |

---

##### `endpointId`<sup>Required</sup> <a name="endpointId" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchiveProps.property.endpointId"></a>

```typescript
public readonly endpointId: string;
```

- *Type:* string

Unique 22-character alphanumeric string that identifies the private endpoint.Reg ex ^vpce-[0-9a-f]{17}$ .

Atlas Data Lake supports Amazon Web Services private endpoints using the AWS PrivateLink feature.

---

##### `projectId`<sup>Required</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchiveProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies your project.

---

##### `comment`<sup>Optional</sup> <a name="comment" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchiveProps.property.comment"></a>

```typescript
public readonly comment: string;
```

- *Type:* string

Human-readable string to associate with this private endpoint.

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchiveProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided default is used.

---

##### `type`<sup>Optional</sup> <a name="type" id="awscdk-resources-mongodbatlas.CfnPrivatelinkEndpointServiceDataFederationOnlineArchiveProps.property.type"></a>

```typescript
public readonly type: string;
```

- *Type:* string

Human-readable label that identifies the resource type associated with this private endpoint.

---

### CfnProjectInvitationProps <a name="CfnProjectInvitationProps" id="awscdk-resources-mongodbatlas.CfnProjectInvitationProps"></a>

Returns, adds, and edits collections of clusters and users in MongoDB Cloud.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnProjectInvitationProps.Initializer"></a>

```typescript
import { CfnProjectInvitationProps } from 'awscdk-resources-mongodbatlas'

const cfnProjectInvitationProps: CfnProjectInvitationProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitationProps.property.invitationId">invitationId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies the invitation. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitationProps.property.pageNum">pageNum</a></code> | <code>number</code> | Number of the page that displays the current set of the total objects that the response returns. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitationProps.property.profile">profile</a></code> | <code>string</code> | The profile is defined in AWS Secret manager. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitationProps.property.projectId">projectId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies your project. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitationProps.property.roles">roles</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitationPropsRoles">CfnProjectInvitationPropsRoles</a>[]</code> | One or more organization or project level roles to assign to the MongoDB Cloud user. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitationProps.property.totalCount">totalCount</a></code> | <code>number</code> | Number of documents returned in this response. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitationProps.property.username">username</a></code> | <code>string</code> | Email address of the user account invited to this project. |

---

##### `invitationId`<sup>Optional</sup> <a name="invitationId" id="awscdk-resources-mongodbatlas.CfnProjectInvitationProps.property.invitationId"></a>

```typescript
public readonly invitationId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies the invitation.

---

##### `pageNum`<sup>Optional</sup> <a name="pageNum" id="awscdk-resources-mongodbatlas.CfnProjectInvitationProps.property.pageNum"></a>

```typescript
public readonly pageNum: number;
```

- *Type:* number

Number of the page that displays the current set of the total objects that the response returns.

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.CfnProjectInvitationProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

The profile is defined in AWS Secret manager.

See [Secret Manager Profile setup](../../../examples/profile-secret.yaml).

---

##### `projectId`<sup>Optional</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.CfnProjectInvitationProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies your project.

---

##### `roles`<sup>Optional</sup> <a name="roles" id="awscdk-resources-mongodbatlas.CfnProjectInvitationProps.property.roles"></a>

```typescript
public readonly roles: CfnProjectInvitationPropsRoles[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnProjectInvitationPropsRoles">CfnProjectInvitationPropsRoles</a>[]

One or more organization or project level roles to assign to the MongoDB Cloud user.

---

##### `totalCount`<sup>Optional</sup> <a name="totalCount" id="awscdk-resources-mongodbatlas.CfnProjectInvitationProps.property.totalCount"></a>

```typescript
public readonly totalCount: number;
```

- *Type:* number

Number of documents returned in this response.

---

##### `username`<sup>Optional</sup> <a name="username" id="awscdk-resources-mongodbatlas.CfnProjectInvitationProps.property.username"></a>

```typescript
public readonly username: string;
```

- *Type:* string

Email address of the user account invited to this project.

---

### CfnProjectIpAccessListProps <a name="CfnProjectIpAccessListProps" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessListProps"></a>

Returns, adds, edits, and removes network access limits to database deployments in MongoDB Cloud.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessListProps.Initializer"></a>

```typescript
import { CfnProjectIpAccessListProps } from 'awscdk-resources-mongodbatlas'

const cfnProjectIpAccessListProps: CfnProjectIpAccessListProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectIpAccessListProps.property.projectId">projectId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies your project. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectIpAccessListProps.property.accessList">accessList</a></code> | <code><a href="#awscdk-resources-mongodbatlas.AccessListDefinition">AccessListDefinition</a>[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectIpAccessListProps.property.listOptions">listOptions</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ListOptions">ListOptions</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectIpAccessListProps.property.profile">profile</a></code> | <code>string</code> | Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided default is used. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectIpAccessListProps.property.totalCount">totalCount</a></code> | <code>number</code> | Number of documents returned in this response. |

---

##### `projectId`<sup>Required</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessListProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies your project.

---

##### `accessList`<sup>Optional</sup> <a name="accessList" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessListProps.property.accessList"></a>

```typescript
public readonly accessList: AccessListDefinition[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.AccessListDefinition">AccessListDefinition</a>[]

---

##### `listOptions`<sup>Optional</sup> <a name="listOptions" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessListProps.property.listOptions"></a>

```typescript
public readonly listOptions: ListOptions;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ListOptions">ListOptions</a>

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessListProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided default is used.

---

##### `totalCount`<sup>Optional</sup> <a name="totalCount" id="awscdk-resources-mongodbatlas.CfnProjectIpAccessListProps.property.totalCount"></a>

```typescript
public readonly totalCount: number;
```

- *Type:* number

Number of documents returned in this response.

---

### CfnProjectProps <a name="CfnProjectProps" id="awscdk-resources-mongodbatlas.CfnProjectProps"></a>

Retrieves or creates projects in any given Atlas organization.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnProjectProps.Initializer"></a>

```typescript
import { CfnProjectProps } from 'awscdk-resources-mongodbatlas'

const cfnProjectProps: CfnProjectProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectProps.property.name">name</a></code> | <code>string</code> | Name of the project to create. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectProps.property.orgId">orgId</a></code> | <code>string</code> | Unique identifier of the organization within which to create the project. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectProps.property.profile">profile</a></code> | <code>string</code> | Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided default is used. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectProps.property.projectApiKeys">projectApiKeys</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ProjectApiKey">ProjectApiKey</a>[]</code> | API keys that you assigned to the specified project. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectProps.property.projectSettings">projectSettings</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ProjectSettings">ProjectSettings</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectProps.property.projectTeams">projectTeams</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ProjectTeam">ProjectTeam</a>[]</code> | Teams to which the authenticated user has access in the project specified using its unique 24-hexadecimal digit identifier. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectProps.property.regionUsageRestrictions">regionUsageRestrictions</a></code> | <code>string</code> | Region usage restrictions that designate the project's AWS region.Enum: "GOV_REGIONS_ONLY" "COMMERCIAL_FEDRAMP_REGIONS_ONLY" "NONE". |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectProps.property.tags">tags</a></code> | <code>any</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectProps.property.withDefaultAlertsSettings">withDefaultAlertsSettings</a></code> | <code>boolean</code> | Flag that indicates whether to create the project with default alert settings. |

---

##### `name`<sup>Required</sup> <a name="name" id="awscdk-resources-mongodbatlas.CfnProjectProps.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Name of the project to create.

---

##### `orgId`<sup>Required</sup> <a name="orgId" id="awscdk-resources-mongodbatlas.CfnProjectProps.property.orgId"></a>

```typescript
public readonly orgId: string;
```

- *Type:* string

Unique identifier of the organization within which to create the project.

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.CfnProjectProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided default is used.

---

##### `projectApiKeys`<sup>Optional</sup> <a name="projectApiKeys" id="awscdk-resources-mongodbatlas.CfnProjectProps.property.projectApiKeys"></a>

```typescript
public readonly projectApiKeys: ProjectApiKey[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ProjectApiKey">ProjectApiKey</a>[]

API keys that you assigned to the specified project.

---

##### `projectSettings`<sup>Optional</sup> <a name="projectSettings" id="awscdk-resources-mongodbatlas.CfnProjectProps.property.projectSettings"></a>

```typescript
public readonly projectSettings: ProjectSettings;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ProjectSettings">ProjectSettings</a>

---

##### `projectTeams`<sup>Optional</sup> <a name="projectTeams" id="awscdk-resources-mongodbatlas.CfnProjectProps.property.projectTeams"></a>

```typescript
public readonly projectTeams: ProjectTeam[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ProjectTeam">ProjectTeam</a>[]

Teams to which the authenticated user has access in the project specified using its unique 24-hexadecimal digit identifier.

---

##### `regionUsageRestrictions`<sup>Optional</sup> <a name="regionUsageRestrictions" id="awscdk-resources-mongodbatlas.CfnProjectProps.property.regionUsageRestrictions"></a>

```typescript
public readonly regionUsageRestrictions: string;
```

- *Type:* string

Region usage restrictions that designate the project's AWS region.Enum: "GOV_REGIONS_ONLY" "COMMERCIAL_FEDRAMP_REGIONS_ONLY" "NONE".

---

##### `tags`<sup>Optional</sup> <a name="tags" id="awscdk-resources-mongodbatlas.CfnProjectProps.property.tags"></a>

```typescript
public readonly tags: any;
```

- *Type:* any

---

##### `withDefaultAlertsSettings`<sup>Optional</sup> <a name="withDefaultAlertsSettings" id="awscdk-resources-mongodbatlas.CfnProjectProps.property.withDefaultAlertsSettings"></a>

```typescript
public readonly withDefaultAlertsSettings: boolean;
```

- *Type:* boolean

Flag that indicates whether to create the project with default alert settings.

---

### CfnSearchDeploymentProps <a name="CfnSearchDeploymentProps" id="awscdk-resources-mongodbatlas.CfnSearchDeploymentProps"></a>

The resource lets you create, edit and delete dedicated search nodes in a cluster.

For details on supported cloud providers and existing limitations you can visit the Search Node Documentation: https://www.mongodb.com/docs/atlas/cluster-config/multi-cloud-distribution/#search-nodes-for-workload-isolation. Only a single search deployment resource can be defined for each cluster.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnSearchDeploymentProps.Initializer"></a>

```typescript
import { CfnSearchDeploymentProps } from 'awscdk-resources-mongodbatlas'

const cfnSearchDeploymentProps: CfnSearchDeploymentProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchDeploymentProps.property.clusterName">clusterName</a></code> | <code>string</code> | Label that identifies the cluster to return the search nodes for. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchDeploymentProps.property.projectId">projectId</a></code> | <code>string</code> | Unique 24-hexadecimal character string that identifies the project. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchDeploymentProps.property.specs">specs</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ApiSearchDeploymentSpec">ApiSearchDeploymentSpec</a>[]</code> | List of settings that configure the search nodes for your cluster. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchDeploymentProps.property.profile">profile</a></code> | <code>string</code> | Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided default is used. |

---

##### `clusterName`<sup>Required</sup> <a name="clusterName" id="awscdk-resources-mongodbatlas.CfnSearchDeploymentProps.property.clusterName"></a>

```typescript
public readonly clusterName: string;
```

- *Type:* string

Label that identifies the cluster to return the search nodes for.

---

##### `projectId`<sup>Required</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.CfnSearchDeploymentProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

Unique 24-hexadecimal character string that identifies the project.

---

##### `specs`<sup>Required</sup> <a name="specs" id="awscdk-resources-mongodbatlas.CfnSearchDeploymentProps.property.specs"></a>

```typescript
public readonly specs: ApiSearchDeploymentSpec[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ApiSearchDeploymentSpec">ApiSearchDeploymentSpec</a>[]

List of settings that configure the search nodes for your cluster.

This list is currently limited to defining a single element.

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.CfnSearchDeploymentProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided default is used.

---

### CfnSearchIndexProps <a name="CfnSearchIndexProps" id="awscdk-resources-mongodbatlas.CfnSearchIndexProps"></a>

Returns, adds, edits, and removes Atlas Search indexes.

Also returns and updates user-defined analyzers.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnSearchIndexProps.Initializer"></a>

```typescript
import { CfnSearchIndexProps } from 'awscdk-resources-mongodbatlas'

const cfnSearchIndexProps: CfnSearchIndexProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndexProps.property.clusterName">clusterName</a></code> | <code>string</code> | Name of the cluster that contains the database and collection with one or more Application Search indexes. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndexProps.property.collectionName">collectionName</a></code> | <code>string</code> | Human-readable label that identifies the collection that contains one or more Atlas Search indexes. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndexProps.property.database">database</a></code> | <code>string</code> | Human-readable label that identifies the database that contains the collection with one or more Atlas Search indexes. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndexProps.property.analyzer">analyzer</a></code> | <code>string</code> | Specific pre-defined method chosen to convert database field text into searchable words. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndexProps.property.analyzers">analyzers</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasFtsAnalyzersViewManual">ApiAtlasFtsAnalyzersViewManual</a>[]</code> | List of user-defined methods to convert database field text into searchable words. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndexProps.property.fields">fields</a></code> | <code>string</code> | Array of [Fields](https://www.mongodb.com/docs/atlas/atlas-search/field-types/knn-vector/#std-label-fts-data-types-knn-vector) to configure this vectorSearch index. Stringify json representation of field with types and properties. Required for vector indexes. It must contain at least one **vector** type field. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndexProps.property.mappings">mappings</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasFtsMappingsViewManual">ApiAtlasFtsMappingsViewManual</a></code> | Index specifications for the collection's fields. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndexProps.property.name">name</a></code> | <code>string</code> | Human-readable label that identifies this index. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndexProps.property.profile">profile</a></code> | <code>string</code> | The profile is defined in AWS Secret manager. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndexProps.property.projectId">projectId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies your project. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndexProps.property.searchAnalyzer">searchAnalyzer</a></code> | <code>string</code> | Method applied to identify words when searching this index. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndexProps.property.synonyms">synonyms</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasFtsSynonymMappingDefinitionView">ApiAtlasFtsSynonymMappingDefinitionView</a>[]</code> | Rule sets that map words to their synonyms in this index. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnSearchIndexProps.property.type">type</a></code> | <code>string</code> | Type of index: **search** or **vectorSearch**. |

---

##### `clusterName`<sup>Required</sup> <a name="clusterName" id="awscdk-resources-mongodbatlas.CfnSearchIndexProps.property.clusterName"></a>

```typescript
public readonly clusterName: string;
```

- *Type:* string

Name of the cluster that contains the database and collection with one or more Application Search indexes.

---

##### `collectionName`<sup>Required</sup> <a name="collectionName" id="awscdk-resources-mongodbatlas.CfnSearchIndexProps.property.collectionName"></a>

```typescript
public readonly collectionName: string;
```

- *Type:* string

Human-readable label that identifies the collection that contains one or more Atlas Search indexes.

---

##### `database`<sup>Required</sup> <a name="database" id="awscdk-resources-mongodbatlas.CfnSearchIndexProps.property.database"></a>

```typescript
public readonly database: string;
```

- *Type:* string

Human-readable label that identifies the database that contains the collection with one or more Atlas Search indexes.

---

##### `analyzer`<sup>Optional</sup> <a name="analyzer" id="awscdk-resources-mongodbatlas.CfnSearchIndexProps.property.analyzer"></a>

```typescript
public readonly analyzer: string;
```

- *Type:* string

Specific pre-defined method chosen to convert database field text into searchable words.

This conversion reduces the text of fields into the smallest units of text. These units are called a **term** or **token**. This process, known as tokenization, involves a variety of changes made to the text in fields:

- extracting words
- removing punctuation
- removing accents
- changing to lowercase
- removing common words
- reducing words to their root form (stemming)
- changing words to their base form (lemmatization)
MongoDB Cloud uses the selected process to build the Atlas Search index.

---

##### `analyzers`<sup>Optional</sup> <a name="analyzers" id="awscdk-resources-mongodbatlas.CfnSearchIndexProps.property.analyzers"></a>

```typescript
public readonly analyzers: ApiAtlasFtsAnalyzersViewManual[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ApiAtlasFtsAnalyzersViewManual">ApiAtlasFtsAnalyzersViewManual</a>[]

List of user-defined methods to convert database field text into searchable words.

---

##### `fields`<sup>Optional</sup> <a name="fields" id="awscdk-resources-mongodbatlas.CfnSearchIndexProps.property.fields"></a>

```typescript
public readonly fields: string;
```

- *Type:* string

Array of [Fields](https://www.mongodb.com/docs/atlas/atlas-search/field-types/knn-vector/#std-label-fts-data-types-knn-vector) to configure this vectorSearch index. Stringify json representation of field with types and properties. Required for vector indexes. It must contain at least one **vector** type field.

---

##### `mappings`<sup>Optional</sup> <a name="mappings" id="awscdk-resources-mongodbatlas.CfnSearchIndexProps.property.mappings"></a>

```typescript
public readonly mappings: ApiAtlasFtsMappingsViewManual;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ApiAtlasFtsMappingsViewManual">ApiAtlasFtsMappingsViewManual</a>

Index specifications for the collection's fields.

---

##### `name`<sup>Optional</sup> <a name="name" id="awscdk-resources-mongodbatlas.CfnSearchIndexProps.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Human-readable label that identifies this index.

Within each namespace, names of all indexes in the namespace must be unique.

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.CfnSearchIndexProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

The profile is defined in AWS Secret manager.

See [Secret Manager Profile setup](../../../examples/profile-secret.yaml).

---

##### `projectId`<sup>Optional</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.CfnSearchIndexProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies your project.

---

##### `searchAnalyzer`<sup>Optional</sup> <a name="searchAnalyzer" id="awscdk-resources-mongodbatlas.CfnSearchIndexProps.property.searchAnalyzer"></a>

```typescript
public readonly searchAnalyzer: string;
```

- *Type:* string

Method applied to identify words when searching this index.

---

##### `synonyms`<sup>Optional</sup> <a name="synonyms" id="awscdk-resources-mongodbatlas.CfnSearchIndexProps.property.synonyms"></a>

```typescript
public readonly synonyms: ApiAtlasFtsSynonymMappingDefinitionView[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ApiAtlasFtsSynonymMappingDefinitionView">ApiAtlasFtsSynonymMappingDefinitionView</a>[]

Rule sets that map words to their synonyms in this index.

---

##### `type`<sup>Optional</sup> <a name="type" id="awscdk-resources-mongodbatlas.CfnSearchIndexProps.property.type"></a>

```typescript
public readonly type: string;
```

- *Type:* string

Type of index: **search** or **vectorSearch**.

Default type is **search**.

---

### CfnServerlessInstanceProps <a name="CfnServerlessInstanceProps" id="awscdk-resources-mongodbatlas.CfnServerlessInstanceProps"></a>

Returns, adds, edits, and removes serverless instances.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnServerlessInstanceProps.Initializer"></a>

```typescript
import { CfnServerlessInstanceProps } from 'awscdk-resources-mongodbatlas'

const cfnServerlessInstanceProps: CfnServerlessInstanceProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstanceProps.property.connectionStrings">connectionStrings</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ServerlessInstanceConnectionStrings">ServerlessInstanceConnectionStrings</a></code> | Collection of Uniform Resource Locators that point to the MongoDB database. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstanceProps.property.continuousBackupEnabled">continuousBackupEnabled</a></code> | <code>boolean</code> | Flag that indicates whether the serverless instances uses Serverless Continuous Backup. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstanceProps.property.includeCount">includeCount</a></code> | <code>boolean</code> | Flag that indicates whether the response returns the total number of items (**totalCount**) in the response. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstanceProps.property.itemsPerPage">itemsPerPage</a></code> | <code>number</code> | Number of items that the response returns per page. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstanceProps.property.name">name</a></code> | <code>string</code> | Human-readable label that identifies the serverless instance. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstanceProps.property.pageNum">pageNum</a></code> | <code>number</code> | Number of the page that displays the current set of the total objects that the response returns. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstanceProps.property.profile">profile</a></code> | <code>string</code> | Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided default is used. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstanceProps.property.projectId">projectId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies your project. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstanceProps.property.providerSettings">providerSettings</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ServerlessInstanceProviderSettings">ServerlessInstanceProviderSettings</a></code> | Group of settings that configure the provisioned MongoDB serverless instance. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessInstanceProps.property.terminationProtectionEnabled">terminationProtectionEnabled</a></code> | <code>boolean</code> | Flag that indicates whether termination protection is enabled on the serverless instance. |

---

##### `connectionStrings`<sup>Optional</sup> <a name="connectionStrings" id="awscdk-resources-mongodbatlas.CfnServerlessInstanceProps.property.connectionStrings"></a>

```typescript
public readonly connectionStrings: ServerlessInstanceConnectionStrings;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ServerlessInstanceConnectionStrings">ServerlessInstanceConnectionStrings</a>

Collection of Uniform Resource Locators that point to the MongoDB database.

---

##### `continuousBackupEnabled`<sup>Optional</sup> <a name="continuousBackupEnabled" id="awscdk-resources-mongodbatlas.CfnServerlessInstanceProps.property.continuousBackupEnabled"></a>

```typescript
public readonly continuousBackupEnabled: boolean;
```

- *Type:* boolean

Flag that indicates whether the serverless instances uses Serverless Continuous Backup.

If this parameter is false, the serverless instance uses Basic Backup. | Option | Description | |---|---| | Serverless Continuous Backup | Atlas takes incremental snapshots of the data in your serverless instance every six hours and lets you restore the data from a selected point in time within the last 72 hours. Atlas also takes daily snapshots and retains these daily snapshots for 35 days. To learn more, see Serverless Instance Costs. | | Basic Backup | Atlas takes incremental snapshots of the data in your serverless instance every six hours and retains only the two most recent snapshots. You can use this option for free.

---

##### `includeCount`<sup>Optional</sup> <a name="includeCount" id="awscdk-resources-mongodbatlas.CfnServerlessInstanceProps.property.includeCount"></a>

```typescript
public readonly includeCount: boolean;
```

- *Type:* boolean

Flag that indicates whether the response returns the total number of items (**totalCount**) in the response.

---

##### `itemsPerPage`<sup>Optional</sup> <a name="itemsPerPage" id="awscdk-resources-mongodbatlas.CfnServerlessInstanceProps.property.itemsPerPage"></a>

```typescript
public readonly itemsPerPage: number;
```

- *Type:* number

Number of items that the response returns per page.

---

##### `name`<sup>Optional</sup> <a name="name" id="awscdk-resources-mongodbatlas.CfnServerlessInstanceProps.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Human-readable label that identifies the serverless instance.

---

##### `pageNum`<sup>Optional</sup> <a name="pageNum" id="awscdk-resources-mongodbatlas.CfnServerlessInstanceProps.property.pageNum"></a>

```typescript
public readonly pageNum: number;
```

- *Type:* number

Number of the page that displays the current set of the total objects that the response returns.

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.CfnServerlessInstanceProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided default is used.

---

##### `projectId`<sup>Optional</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.CfnServerlessInstanceProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies your project.

---

##### `providerSettings`<sup>Optional</sup> <a name="providerSettings" id="awscdk-resources-mongodbatlas.CfnServerlessInstanceProps.property.providerSettings"></a>

```typescript
public readonly providerSettings: ServerlessInstanceProviderSettings;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ServerlessInstanceProviderSettings">ServerlessInstanceProviderSettings</a>

Group of settings that configure the provisioned MongoDB serverless instance.

The options available relate to the cloud service provider.

---

##### `terminationProtectionEnabled`<sup>Optional</sup> <a name="terminationProtectionEnabled" id="awscdk-resources-mongodbatlas.CfnServerlessInstanceProps.property.terminationProtectionEnabled"></a>

```typescript
public readonly terminationProtectionEnabled: boolean;
```

- *Type:* boolean

Flag that indicates whether termination protection is enabled on the serverless instance.

If set to true, MongoDB Cloud won't delete the serverless instance. If set to false, MongoDB cloud will delete the serverless instance."

---

### CfnServerlessPrivateEndpointProps <a name="CfnServerlessPrivateEndpointProps" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpointProps"></a>

Returns, adds, edits, and removes private endpoints for serverless instances.

To learn more, see the Atlas Administration API tab on the following tutorial.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpointProps.Initializer"></a>

```typescript
import { CfnServerlessPrivateEndpointProps } from 'awscdk-resources-mongodbatlas'

const cfnServerlessPrivateEndpointProps: CfnServerlessPrivateEndpointProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpointProps.property.instanceName">instanceName</a></code> | <code>string</code> | Human-readable label that identifies the serverless instance for which the tenant endpoint will be created. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpointProps.property.projectId">projectId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies your project. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpointProps.property.awsPrivateEndpointConfigurationProperties">awsPrivateEndpointConfigurationProperties</a></code> | <code><a href="#awscdk-resources-mongodbatlas.AwsPrivateEndpointConfig">AwsPrivateEndpointConfig</a></code> | Properties used to configure Aws private endpoint. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpointProps.property.cloudProviderEndpointId">cloudProviderEndpointId</a></code> | <code>string</code> | Unique string that identifies the private endpoint's network interface. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpointProps.property.comment">comment</a></code> | <code>string</code> | Human-readable comment associated with the private endpoint. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpointProps.property.createAndAssignAwsPrivateEndpoint">createAndAssignAwsPrivateEndpoint</a></code> | <code>boolean</code> | If true the resource will create the aws private endpoint and assign the Endpoint ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpointProps.property.privateEndpointIpAddress">privateEndpointIpAddress</a></code> | <code>string</code> | IPv4 address of the private endpoint in your Azure VNet that someone added to this private endpoint service. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpointProps.property.profile">profile</a></code> | <code>string</code> | Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided default is used. |

---

##### `instanceName`<sup>Required</sup> <a name="instanceName" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpointProps.property.instanceName"></a>

```typescript
public readonly instanceName: string;
```

- *Type:* string

Human-readable label that identifies the serverless instance for which the tenant endpoint will be created.

---

##### `projectId`<sup>Required</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpointProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies your project.

---

##### `awsPrivateEndpointConfigurationProperties`<sup>Optional</sup> <a name="awsPrivateEndpointConfigurationProperties" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpointProps.property.awsPrivateEndpointConfigurationProperties"></a>

```typescript
public readonly awsPrivateEndpointConfigurationProperties: AwsPrivateEndpointConfig;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.AwsPrivateEndpointConfig">AwsPrivateEndpointConfig</a>

Properties used to configure Aws private endpoint.

---

##### `cloudProviderEndpointId`<sup>Optional</sup> <a name="cloudProviderEndpointId" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpointProps.property.cloudProviderEndpointId"></a>

```typescript
public readonly cloudProviderEndpointId: string;
```

- *Type:* string

Unique string that identifies the private endpoint's network interface.

---

##### `comment`<sup>Optional</sup> <a name="comment" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpointProps.property.comment"></a>

```typescript
public readonly comment: string;
```

- *Type:* string

Human-readable comment associated with the private endpoint.

---

##### `createAndAssignAwsPrivateEndpoint`<sup>Optional</sup> <a name="createAndAssignAwsPrivateEndpoint" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpointProps.property.createAndAssignAwsPrivateEndpoint"></a>

```typescript
public readonly createAndAssignAwsPrivateEndpoint: boolean;
```

- *Type:* boolean

If true the resource will create the aws private endpoint and assign the Endpoint ID.

---

##### `privateEndpointIpAddress`<sup>Optional</sup> <a name="privateEndpointIpAddress" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpointProps.property.privateEndpointIpAddress"></a>

```typescript
public readonly privateEndpointIpAddress: string;
```

- *Type:* string

IPv4 address of the private endpoint in your Azure VNet that someone added to this private endpoint service.

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.CfnServerlessPrivateEndpointProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided default is used.

---

### CfnStreamConnectionProps <a name="CfnStreamConnectionProps" id="awscdk-resources-mongodbatlas.CfnStreamConnectionProps"></a>

Returns, adds, edits, and removes one connection for a stream instance in the specified project.

To use this resource, the requesting API Key must have the Project Owner roles.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnStreamConnectionProps.Initializer"></a>

```typescript
import { CfnStreamConnectionProps } from 'awscdk-resources-mongodbatlas'

const cfnStreamConnectionProps: CfnStreamConnectionProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnectionProps.property.connectionName">connectionName</a></code> | <code>string</code> | Human-readable label that identifies the stream connection. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnectionProps.property.instanceName">instanceName</a></code> | <code>string</code> | Human-readable label that identifies the stream instance. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnectionProps.property.projectId">projectId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies your project. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnectionProps.property.type">type</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnectionPropsType">CfnStreamConnectionPropsType</a></code> | Type of the connection. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnectionProps.property.authentication">authentication</a></code> | <code><a href="#awscdk-resources-mongodbatlas.StreamsKafkaAuthentication">StreamsKafkaAuthentication</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnectionProps.property.bootstrapServers">bootstrapServers</a></code> | <code>string</code> | Comma separated list of server addresses. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnectionProps.property.clusterName">clusterName</a></code> | <code>string</code> | Name of the cluster configured for this connection. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnectionProps.property.config">config</a></code> | <code>any</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnectionProps.property.dbRoleToExecute">dbRoleToExecute</a></code> | <code><a href="#awscdk-resources-mongodbatlas.DbRoleToExecute">DbRoleToExecute</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnectionProps.property.profile">profile</a></code> | <code>string</code> | Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided default is used. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnectionProps.property.security">security</a></code> | <code><a href="#awscdk-resources-mongodbatlas.StreamsKafkaSecurity">StreamsKafkaSecurity</a></code> | *No description.* |

---

##### `connectionName`<sup>Required</sup> <a name="connectionName" id="awscdk-resources-mongodbatlas.CfnStreamConnectionProps.property.connectionName"></a>

```typescript
public readonly connectionName: string;
```

- *Type:* string

Human-readable label that identifies the stream connection.

In the case of the Sample type, this is the name of the sample source.

---

##### `instanceName`<sup>Required</sup> <a name="instanceName" id="awscdk-resources-mongodbatlas.CfnStreamConnectionProps.property.instanceName"></a>

```typescript
public readonly instanceName: string;
```

- *Type:* string

Human-readable label that identifies the stream instance.

---

##### `projectId`<sup>Required</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.CfnStreamConnectionProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies your project.

Use the [/groups](#tag/Projects/operation/listProjects) endpoint to retrieve all projects to which the authenticated user has access.

**NOTE**: Groups and projects are synonymous terms. Your group id is the same as your project id. For existing groups, your group/project id remains the same. The resource and corresponding endpoints use the term groups.

---

##### `type`<sup>Required</sup> <a name="type" id="awscdk-resources-mongodbatlas.CfnStreamConnectionProps.property.type"></a>

```typescript
public readonly type: CfnStreamConnectionPropsType;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnStreamConnectionPropsType">CfnStreamConnectionPropsType</a>

Type of the connection.

Can be either Cluster, Kafka, or Sample.

---

##### `authentication`<sup>Optional</sup> <a name="authentication" id="awscdk-resources-mongodbatlas.CfnStreamConnectionProps.property.authentication"></a>

```typescript
public readonly authentication: StreamsKafkaAuthentication;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.StreamsKafkaAuthentication">StreamsKafkaAuthentication</a>

---

##### `bootstrapServers`<sup>Optional</sup> <a name="bootstrapServers" id="awscdk-resources-mongodbatlas.CfnStreamConnectionProps.property.bootstrapServers"></a>

```typescript
public readonly bootstrapServers: string;
```

- *Type:* string

Comma separated list of server addresses.

---

##### `clusterName`<sup>Optional</sup> <a name="clusterName" id="awscdk-resources-mongodbatlas.CfnStreamConnectionProps.property.clusterName"></a>

```typescript
public readonly clusterName: string;
```

- *Type:* string

Name of the cluster configured for this connection.

---

##### `config`<sup>Optional</sup> <a name="config" id="awscdk-resources-mongodbatlas.CfnStreamConnectionProps.property.config"></a>

```typescript
public readonly config: any;
```

- *Type:* any

---

##### `dbRoleToExecute`<sup>Optional</sup> <a name="dbRoleToExecute" id="awscdk-resources-mongodbatlas.CfnStreamConnectionProps.property.dbRoleToExecute"></a>

```typescript
public readonly dbRoleToExecute: DbRoleToExecute;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.DbRoleToExecute">DbRoleToExecute</a>

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.CfnStreamConnectionProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided default is used.

---

##### `security`<sup>Optional</sup> <a name="security" id="awscdk-resources-mongodbatlas.CfnStreamConnectionProps.property.security"></a>

```typescript
public readonly security: StreamsKafkaSecurity;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.StreamsKafkaSecurity">StreamsKafkaSecurity</a>

---

### CfnStreamInstanceProps <a name="CfnStreamInstanceProps" id="awscdk-resources-mongodbatlas.CfnStreamInstanceProps"></a>

Returns, adds, edits, and removes Atlas Stream Processing Instances.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnStreamInstanceProps.Initializer"></a>

```typescript
import { CfnStreamInstanceProps } from 'awscdk-resources-mongodbatlas'

const cfnStreamInstanceProps: CfnStreamInstanceProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamInstanceProps.property.dataProcessRegion">dataProcessRegion</a></code> | <code><a href="#awscdk-resources-mongodbatlas.StreamsDataProcessRegion">StreamsDataProcessRegion</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamInstanceProps.property.instanceName">instanceName</a></code> | <code>string</code> | Human-readable label that identifies the stream connection. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamInstanceProps.property.projectId">projectId</a></code> | <code>string</code> | Unique 24-hexadecimal character string that identifies the project. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamInstanceProps.property.streamConfig">streamConfig</a></code> | <code><a href="#awscdk-resources-mongodbatlas.StreamConfig">StreamConfig</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamInstanceProps.property.connections">connections</a></code> | <code><a href="#awscdk-resources-mongodbatlas.StreamsConnection">StreamsConnection</a>[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamInstanceProps.property.profile">profile</a></code> | <code>string</code> | The profile is defined in AWS Secret manager. |

---

##### `dataProcessRegion`<sup>Required</sup> <a name="dataProcessRegion" id="awscdk-resources-mongodbatlas.CfnStreamInstanceProps.property.dataProcessRegion"></a>

```typescript
public readonly dataProcessRegion: StreamsDataProcessRegion;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.StreamsDataProcessRegion">StreamsDataProcessRegion</a>

---

##### `instanceName`<sup>Required</sup> <a name="instanceName" id="awscdk-resources-mongodbatlas.CfnStreamInstanceProps.property.instanceName"></a>

```typescript
public readonly instanceName: string;
```

- *Type:* string

Human-readable label that identifies the stream connection.

---

##### `projectId`<sup>Required</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.CfnStreamInstanceProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

Unique 24-hexadecimal character string that identifies the project.

---

##### `streamConfig`<sup>Required</sup> <a name="streamConfig" id="awscdk-resources-mongodbatlas.CfnStreamInstanceProps.property.streamConfig"></a>

```typescript
public readonly streamConfig: StreamConfig;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.StreamConfig">StreamConfig</a>

---

##### `connections`<sup>Optional</sup> <a name="connections" id="awscdk-resources-mongodbatlas.CfnStreamInstanceProps.property.connections"></a>

```typescript
public readonly connections: StreamsConnection[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.StreamsConnection">StreamsConnection</a>[]

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.CfnStreamInstanceProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

The profile is defined in AWS Secret manager.

See [Secret Manager Profile setup](../../../examples/profile-secret.yaml).

---

### CfnTeamsProps <a name="CfnTeamsProps" id="awscdk-resources-mongodbatlas.CfnTeamsProps"></a>

Adds one team to the specified project.

All members of the team share the same project access. To use this resource, the requesting API Key must have the Project User Admin role. This resource doesn't require the API Key to have an Access List.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnTeamsProps.Initializer"></a>

```typescript
import { CfnTeamsProps } from 'awscdk-resources-mongodbatlas'

const cfnTeamsProps: CfnTeamsProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTeamsProps.property.name">name</a></code> | <code>string</code> | Unique 24-hexadecimal character string that identifies the team. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTeamsProps.property.orgId">orgId</a></code> | <code>string</code> | Unique 24-hexadecimal character string that identifies the team. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTeamsProps.property.profile">profile</a></code> | <code>string</code> | The profile is defined in AWS Secret manager. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTeamsProps.property.projectId">projectId</a></code> | <code>string</code> | Unique 24-hexadecimal character string that identifies the project. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTeamsProps.property.roleNames">roleNames</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnTeamsPropsRoleNames">CfnTeamsPropsRoleNames</a>[]</code> | One or more organization- or project-level roles to assign to the MongoDB Cloud user. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTeamsProps.property.usernames">usernames</a></code> | <code>string[]</code> | One or more organization- or project-level roles to assign to the MongoDB Cloud user. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTeamsProps.property.users">users</a></code> | <code><a href="#awscdk-resources-mongodbatlas.AtlasUser">AtlasUser</a>[]</code> | List of returned documents that MongoDB Cloud provides when completing this request. |

---

##### `name`<sup>Optional</sup> <a name="name" id="awscdk-resources-mongodbatlas.CfnTeamsProps.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Unique 24-hexadecimal character string that identifies the team.

---

##### `orgId`<sup>Optional</sup> <a name="orgId" id="awscdk-resources-mongodbatlas.CfnTeamsProps.property.orgId"></a>

```typescript
public readonly orgId: string;
```

- *Type:* string

Unique 24-hexadecimal character string that identifies the team.

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.CfnTeamsProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

The profile is defined in AWS Secret manager.

See [Secret Manager Profile setup](../../../examples/profile-secret.yaml).

---

##### `projectId`<sup>Optional</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.CfnTeamsProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

Unique 24-hexadecimal character string that identifies the project.

---

##### `roleNames`<sup>Optional</sup> <a name="roleNames" id="awscdk-resources-mongodbatlas.CfnTeamsProps.property.roleNames"></a>

```typescript
public readonly roleNames: CfnTeamsPropsRoleNames[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnTeamsPropsRoleNames">CfnTeamsPropsRoleNames</a>[]

One or more organization- or project-level roles to assign to the MongoDB Cloud user.

---

##### `usernames`<sup>Optional</sup> <a name="usernames" id="awscdk-resources-mongodbatlas.CfnTeamsProps.property.usernames"></a>

```typescript
public readonly usernames: string[];
```

- *Type:* string[]

One or more organization- or project-level roles to assign to the MongoDB Cloud user.

---

##### `users`<sup>Optional</sup> <a name="users" id="awscdk-resources-mongodbatlas.CfnTeamsProps.property.users"></a>

```typescript
public readonly users: AtlasUser[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.AtlasUser">AtlasUser</a>[]

List of returned documents that MongoDB Cloud provides when completing this request.

---

### CfnThirdPartyIntegrationProps <a name="CfnThirdPartyIntegrationProps" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationProps"></a>

Returns, adds, edits, and removes third-party service integration configurations.

MongoDB Cloud sends alerts to each third-party service that you configure.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationProps.Initializer"></a>

```typescript
import { CfnThirdPartyIntegrationProps } from 'awscdk-resources-mongodbatlas'

const cfnThirdPartyIntegrationProps: CfnThirdPartyIntegrationProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationProps.property.apiKey">apiKey</a></code> | <code>string</code> | Key that allows MongoDB Cloud to access your Opsgenie/Datadog account. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationProps.property.apiToken">apiToken</a></code> | <code>string</code> | Key that allows MongoDB Cloud to access your Slack account. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationProps.property.channelName">channelName</a></code> | <code>string</code> | Name of the Slack channel to which MongoDB Cloud sends alert notifications. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationProps.property.enabled">enabled</a></code> | <code>boolean</code> | Flag that indicates whether someone has activated the Prometheus integration. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationProps.property.listenAddress">listenAddress</a></code> | <code>string</code> | Combination of IPv4 address and Internet Assigned Numbers Authority (IANA) port or the IANA port alone to which Prometheus binds to ingest MongoDB metrics. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationProps.property.microsoftTeamsWebhookUrl">microsoftTeamsWebhookUrl</a></code> | <code>string</code> | Endpoint web address of the Microsoft Teams webhook to which MongoDB Cloud sends notifications. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationProps.property.password">password</a></code> | <code>string</code> | Password required for your integration with Prometheus. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationProps.property.profile">profile</a></code> | <code>string</code> | The profile is defined in AWS Secret manager. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationProps.property.projectId">projectId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies your project. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationProps.property.region">region</a></code> | <code>string</code> | Two-letter code that indicates which regional URL MongoDB uses to access the Opsgenie/Datadog API. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationProps.property.routingKey">routingKey</a></code> | <code>string</code> | Routing key associated with your Splunk On-Call account. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationProps.property.scheme">scheme</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationPropsScheme">CfnThirdPartyIntegrationPropsScheme</a></code> | Security Scheme to apply to HyperText Transfer Protocol (HTTP) traffic between Prometheus and MongoDB Cloud. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationProps.property.secret">secret</a></code> | <code>string</code> | Parameter returned if someone configure this webhook with a secret. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationProps.property.serviceDiscovery">serviceDiscovery</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationPropsServiceDiscovery">CfnThirdPartyIntegrationPropsServiceDiscovery</a></code> | Desired method to discover the Prometheus service. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationProps.property.serviceKey">serviceKey</a></code> | <code>string</code> | Service key associated with your PagerDuty account. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationProps.property.teamName">teamName</a></code> | <code>string</code> | Human-readable label that identifies your Slack team. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationProps.property.tlsPemPath">tlsPemPath</a></code> | <code>string</code> | Root-relative path to the Transport Layer Security (TLS) Privacy Enhanced Mail (PEM) key and certificate file on the host. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationProps.property.type">type</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationPropsType">CfnThirdPartyIntegrationPropsType</a></code> | Human-readable label that identifies the service to which you want to integrate with MongoDB Cloud. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationProps.property.url">url</a></code> | <code>string</code> | Endpoint web address to which MongoDB Cloud sends notifications. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationProps.property.userName">userName</a></code> | <code>string</code> | Human-readable label that identifies your Prometheus incoming webhook. |

---

##### `apiKey`<sup>Optional</sup> <a name="apiKey" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationProps.property.apiKey"></a>

```typescript
public readonly apiKey: string;
```

- *Type:* string

Key that allows MongoDB Cloud to access your Opsgenie/Datadog account.

---

##### `apiToken`<sup>Optional</sup> <a name="apiToken" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationProps.property.apiToken"></a>

```typescript
public readonly apiToken: string;
```

- *Type:* string

Key that allows MongoDB Cloud to access your Slack account.

---

##### `channelName`<sup>Optional</sup> <a name="channelName" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationProps.property.channelName"></a>

```typescript
public readonly channelName: string;
```

- *Type:* string

Name of the Slack channel to which MongoDB Cloud sends alert notifications.

---

##### `enabled`<sup>Optional</sup> <a name="enabled" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationProps.property.enabled"></a>

```typescript
public readonly enabled: boolean;
```

- *Type:* boolean

Flag that indicates whether someone has activated the Prometheus integration.

---

##### `listenAddress`<sup>Optional</sup> <a name="listenAddress" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationProps.property.listenAddress"></a>

```typescript
public readonly listenAddress: string;
```

- *Type:* string

Combination of IPv4 address and Internet Assigned Numbers Authority (IANA) port or the IANA port alone to which Prometheus binds to ingest MongoDB metrics.

---

##### `microsoftTeamsWebhookUrl`<sup>Optional</sup> <a name="microsoftTeamsWebhookUrl" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationProps.property.microsoftTeamsWebhookUrl"></a>

```typescript
public readonly microsoftTeamsWebhookUrl: string;
```

- *Type:* string

Endpoint web address of the Microsoft Teams webhook to which MongoDB Cloud sends notifications.

---

##### `password`<sup>Optional</sup> <a name="password" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationProps.property.password"></a>

```typescript
public readonly password: string;
```

- *Type:* string

Password required for your integration with Prometheus.

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

The profile is defined in AWS Secret manager.

See [Secret Manager Profile setup](../../../examples/profile-secret.yaml).

---

##### `projectId`<sup>Optional</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies your project.

---

##### `region`<sup>Optional</sup> <a name="region" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationProps.property.region"></a>

```typescript
public readonly region: string;
```

- *Type:* string

Two-letter code that indicates which regional URL MongoDB uses to access the Opsgenie/Datadog API.

---

##### `routingKey`<sup>Optional</sup> <a name="routingKey" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationProps.property.routingKey"></a>

```typescript
public readonly routingKey: string;
```

- *Type:* string

Routing key associated with your Splunk On-Call account.

---

##### `scheme`<sup>Optional</sup> <a name="scheme" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationProps.property.scheme"></a>

```typescript
public readonly scheme: CfnThirdPartyIntegrationPropsScheme;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationPropsScheme">CfnThirdPartyIntegrationPropsScheme</a>

Security Scheme to apply to HyperText Transfer Protocol (HTTP) traffic between Prometheus and MongoDB Cloud.

---

##### `secret`<sup>Optional</sup> <a name="secret" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationProps.property.secret"></a>

```typescript
public readonly secret: string;
```

- *Type:* string

Parameter returned if someone configure this webhook with a secret.

---

##### `serviceDiscovery`<sup>Optional</sup> <a name="serviceDiscovery" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationProps.property.serviceDiscovery"></a>

```typescript
public readonly serviceDiscovery: CfnThirdPartyIntegrationPropsServiceDiscovery;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationPropsServiceDiscovery">CfnThirdPartyIntegrationPropsServiceDiscovery</a>

Desired method to discover the Prometheus service.

---

##### `serviceKey`<sup>Optional</sup> <a name="serviceKey" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationProps.property.serviceKey"></a>

```typescript
public readonly serviceKey: string;
```

- *Type:* string

Service key associated with your PagerDuty account.

---

##### `teamName`<sup>Optional</sup> <a name="teamName" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationProps.property.teamName"></a>

```typescript
public readonly teamName: string;
```

- *Type:* string

Human-readable label that identifies your Slack team.

Set this parameter when you configure a legacy Slack integration.

---

##### `tlsPemPath`<sup>Optional</sup> <a name="tlsPemPath" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationProps.property.tlsPemPath"></a>

```typescript
public readonly tlsPemPath: string;
```

- *Type:* string

Root-relative path to the Transport Layer Security (TLS) Privacy Enhanced Mail (PEM) key and certificate file on the host.

---

##### `type`<sup>Optional</sup> <a name="type" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationProps.property.type"></a>

```typescript
public readonly type: CfnThirdPartyIntegrationPropsType;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationPropsType">CfnThirdPartyIntegrationPropsType</a>

Human-readable label that identifies the service to which you want to integrate with MongoDB Cloud.

The value must match the third-party service integration type.

---

##### `url`<sup>Optional</sup> <a name="url" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationProps.property.url"></a>

```typescript
public readonly url: string;
```

- *Type:* string

Endpoint web address to which MongoDB Cloud sends notifications.

---

##### `userName`<sup>Optional</sup> <a name="userName" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationProps.property.userName"></a>

```typescript
public readonly userName: string;
```

- *Type:* string

Human-readable label that identifies your Prometheus incoming webhook.

---

### CfnTriggerProps <a name="CfnTriggerProps" id="awscdk-resources-mongodbatlas.CfnTriggerProps"></a>

View and manage your application's [triggers](https://www.mongodb.com/docs/atlas/app-services/triggers/overview/).

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnTriggerProps.Initializer"></a>

```typescript
import { CfnTriggerProps } from 'awscdk-resources-mongodbatlas'

const cfnTriggerProps: CfnTriggerProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTriggerProps.property.appId">appId</a></code> | <code>string</code> | App Services Application ID. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTriggerProps.property.name">name</a></code> | <code>string</code> | The trigger's name. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTriggerProps.property.projectId">projectId</a></code> | <code>string</code> | Project Id for application services. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTriggerProps.property.type">type</a></code> | <code>string</code> | The trigger's type. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTriggerProps.property.authTrigger">authTrigger</a></code> | <code><a href="#awscdk-resources-mongodbatlas.AuthConfig">AuthConfig</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTriggerProps.property.databaseTrigger">databaseTrigger</a></code> | <code><a href="#awscdk-resources-mongodbatlas.DatabaseConfig">DatabaseConfig</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTriggerProps.property.disabled">disabled</a></code> | <code>boolean</code> | If `true`, the trigger is disabled and does not listen for events or execute. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTriggerProps.property.eventProcessors">eventProcessors</a></code> | <code><a href="#awscdk-resources-mongodbatlas.Event">Event</a></code> | An object where each field name is an event processor ID and each value is an object that configures its corresponding event processor. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTriggerProps.property.functionId">functionId</a></code> | <code>string</code> | The ID of the function that the trigger calls when it fires. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTriggerProps.property.functionName">functionName</a></code> | <code>string</code> | The name of the function that the trigger calls when it fires, i.e. the function described by `function_id`. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTriggerProps.property.profile">profile</a></code> | <code>string</code> | The profile is defined in AWS Secret manager. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTriggerProps.property.scheduleTrigger">scheduleTrigger</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ScheduleConfig">ScheduleConfig</a></code> | *No description.* |

---

##### `appId`<sup>Required</sup> <a name="appId" id="awscdk-resources-mongodbatlas.CfnTriggerProps.property.appId"></a>

```typescript
public readonly appId: string;
```

- *Type:* string

App Services Application ID.

---

##### `name`<sup>Required</sup> <a name="name" id="awscdk-resources-mongodbatlas.CfnTriggerProps.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The trigger's name.

---

##### `projectId`<sup>Required</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.CfnTriggerProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

Project Id for application services.

---

##### `type`<sup>Required</sup> <a name="type" id="awscdk-resources-mongodbatlas.CfnTriggerProps.property.type"></a>

```typescript
public readonly type: string;
```

- *Type:* string

The trigger's type.

---

##### `authTrigger`<sup>Optional</sup> <a name="authTrigger" id="awscdk-resources-mongodbatlas.CfnTriggerProps.property.authTrigger"></a>

```typescript
public readonly authTrigger: AuthConfig;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.AuthConfig">AuthConfig</a>

---

##### `databaseTrigger`<sup>Optional</sup> <a name="databaseTrigger" id="awscdk-resources-mongodbatlas.CfnTriggerProps.property.databaseTrigger"></a>

```typescript
public readonly databaseTrigger: DatabaseConfig;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.DatabaseConfig">DatabaseConfig</a>

---

##### `disabled`<sup>Optional</sup> <a name="disabled" id="awscdk-resources-mongodbatlas.CfnTriggerProps.property.disabled"></a>

```typescript
public readonly disabled: boolean;
```

- *Type:* boolean

If `true`, the trigger is disabled and does not listen for events or execute.

---

##### `eventProcessors`<sup>Optional</sup> <a name="eventProcessors" id="awscdk-resources-mongodbatlas.CfnTriggerProps.property.eventProcessors"></a>

```typescript
public readonly eventProcessors: Event;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.Event">Event</a>

An object where each field name is an event processor ID and each value is an object that configures its corresponding event processor.

For an example configuration object, see
[Send Trigger Events to AWS
EventBridge](https://www.mongodb.com/docs/realm/triggers/examples/send-events-aws-eventbridge#std-label-event_processor_example).

---

##### `functionId`<sup>Optional</sup> <a name="functionId" id="awscdk-resources-mongodbatlas.CfnTriggerProps.property.functionId"></a>

```typescript
public readonly functionId: string;
```

- *Type:* string

The ID of the function that the trigger calls when it fires.

This value is the same as `event_processors.FUNCTION.function_id`.
You can either define the value here or in `event_processors.FUNCTION.function_id`.
The App Services backend duplicates the value to the configuration location where you did not define it.

For example, if you define `function_id`, the backend duplicates it to `event_processors.FUNCTION.function_id`.

---

##### `functionName`<sup>Optional</sup> <a name="functionName" id="awscdk-resources-mongodbatlas.CfnTriggerProps.property.functionName"></a>

```typescript
public readonly functionName: string;
```

- *Type:* string

The name of the function that the trigger calls when it fires, i.e. the function described by `function_id`.

This value is the same as `event_processors.FUNCTION.function_name`.
You can either define the value here or in `event_processors.FUNCTION.function_name`.
The App Services backend duplicates the value to the configuration location where you did not define it.

For example, if you define `function_name`, the backend duplicates it to `event_processors.FUNCTION.function_name`.

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.CfnTriggerProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

The profile is defined in AWS Secret manager.

See [Secret Manager Profile setup](../../../examples/profile-secret.yaml).

---

##### `scheduleTrigger`<sup>Optional</sup> <a name="scheduleTrigger" id="awscdk-resources-mongodbatlas.CfnTriggerProps.property.scheduleTrigger"></a>

```typescript
public readonly scheduleTrigger: ScheduleConfig;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ScheduleConfig">ScheduleConfig</a>

---

### CfnX509AuthenticationDatabaseUserProps <a name="CfnX509AuthenticationDatabaseUserProps" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUserProps"></a>

Generates one X.509 certificate for the specified MongoDB user. Atlas manages the certificate and MongoDB user that belong to one project. To use this resource, the requesting API Key must have the Project Atlas Admin role. This resource doesn't require the API Key to have an Access List.

To get MongoDB Cloud to generate a managed certificate for a database user, set `"x509Type" : "MANAGED"` on the desired MongoDB Database User.

If you are managing your own Certificate Authority (CA) in Self-Managed X.509 mode, you must generate certificates for database users using your own CA.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUserProps.Initializer"></a>

```typescript
import { CfnX509AuthenticationDatabaseUserProps } from 'awscdk-resources-mongodbatlas'

const cfnX509AuthenticationDatabaseUserProps: CfnX509AuthenticationDatabaseUserProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUserProps.property.customerX509">customerX509</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CustomerX509">CustomerX509</a></code> | CustomerX509 represents Customer-managed X.509 configuration for an Atlas project. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUserProps.property.monthsUntilExpiration">monthsUntilExpiration</a></code> | <code>number</code> | A number of months that the created certificate is valid for before expiry, up to 24 months.default 3. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUserProps.property.profile">profile</a></code> | <code>string</code> | Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided default is used. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUserProps.property.projectId">projectId</a></code> | <code>string</code> | The unique identifier for the project . |
| <code><a href="#awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUserProps.property.totalCount">totalCount</a></code> | <code>number</code> | Total number of unexpired certificates returned in this response. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUserProps.property.userName">userName</a></code> | <code>string</code> | Username of the database user to create a certificate for. |

---

##### `customerX509`<sup>Optional</sup> <a name="customerX509" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUserProps.property.customerX509"></a>

```typescript
public readonly customerX509: CustomerX509;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CustomerX509">CustomerX509</a>

CustomerX509 represents Customer-managed X.509 configuration for an Atlas project.

---

##### `monthsUntilExpiration`<sup>Optional</sup> <a name="monthsUntilExpiration" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUserProps.property.monthsUntilExpiration"></a>

```typescript
public readonly monthsUntilExpiration: number;
```

- *Type:* number

A number of months that the created certificate is valid for before expiry, up to 24 months.default 3.

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUserProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

Profile used to provide credentials information, (a secret with the cfn/atlas/profile/{Profile}, is required), if not provided default is used.

---

##### `projectId`<sup>Optional</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUserProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

The unique identifier for the project .

---

##### `totalCount`<sup>Optional</sup> <a name="totalCount" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUserProps.property.totalCount"></a>

```typescript
public readonly totalCount: number;
```

- *Type:* number

Total number of unexpired certificates returned in this response.

---

##### `userName`<sup>Optional</sup> <a name="userName" id="awscdk-resources-mongodbatlas.CfnX509AuthenticationDatabaseUserProps.property.userName"></a>

```typescript
public readonly userName: string;
```

- *Type:* string

Username of the database user to create a certificate for.

---

### CloudProviderConfig <a name="CloudProviderConfig" id="awscdk-resources-mongodbatlas.CloudProviderConfig"></a>

Cloud provider linked to this data lake..

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CloudProviderConfig.Initializer"></a>

```typescript
import { CloudProviderConfig } from 'awscdk-resources-mongodbatlas'

const cloudProviderConfig: CloudProviderConfig = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CloudProviderConfig.property.externalId">externalId</a></code> | <code>string</code> | Unique identifier of the role that the data lake can use to access the data stores.Required if specifying cloudProviderConfig. |
| <code><a href="#awscdk-resources-mongodbatlas.CloudProviderConfig.property.iamAssumedRoleArn">iamAssumedRoleArn</a></code> | <code>string</code> | Amazon Resource Name (ARN) of the Identity and Access Management (IAM) role that the data lake assumes when accessing data stores. |
| <code><a href="#awscdk-resources-mongodbatlas.CloudProviderConfig.property.iamUserArn">iamUserArn</a></code> | <code>string</code> | Amazon Resource Name (ARN) of the user that the data lake assumes when accessing data stores. |
| <code><a href="#awscdk-resources-mongodbatlas.CloudProviderConfig.property.roleId">roleId</a></code> | <code>string</code> | Unique identifier of the role that the data lake can use to access the data stores.Required if specifying cloudProviderConfig. |
| <code><a href="#awscdk-resources-mongodbatlas.CloudProviderConfig.property.testS3Bucket">testS3Bucket</a></code> | <code>string</code> | Name of the S3 data bucket that the provided role ID is authorized to access.Required if specifying cloudProviderConfig. |

---

##### `externalId`<sup>Optional</sup> <a name="externalId" id="awscdk-resources-mongodbatlas.CloudProviderConfig.property.externalId"></a>

```typescript
public readonly externalId: string;
```

- *Type:* string

Unique identifier of the role that the data lake can use to access the data stores.Required if specifying cloudProviderConfig.

---

##### `iamAssumedRoleArn`<sup>Optional</sup> <a name="iamAssumedRoleArn" id="awscdk-resources-mongodbatlas.CloudProviderConfig.property.iamAssumedRoleArn"></a>

```typescript
public readonly iamAssumedRoleArn: string;
```

- *Type:* string

Amazon Resource Name (ARN) of the Identity and Access Management (IAM) role that the data lake assumes when accessing data stores.

---

##### `iamUserArn`<sup>Optional</sup> <a name="iamUserArn" id="awscdk-resources-mongodbatlas.CloudProviderConfig.property.iamUserArn"></a>

```typescript
public readonly iamUserArn: string;
```

- *Type:* string

Amazon Resource Name (ARN) of the user that the data lake assumes when accessing data stores.

---

##### `roleId`<sup>Optional</sup> <a name="roleId" id="awscdk-resources-mongodbatlas.CloudProviderConfig.property.roleId"></a>

```typescript
public readonly roleId: string;
```

- *Type:* string

Unique identifier of the role that the data lake can use to access the data stores.Required if specifying cloudProviderConfig.

---

##### `testS3Bucket`<sup>Optional</sup> <a name="testS3Bucket" id="awscdk-resources-mongodbatlas.CloudProviderConfig.property.testS3Bucket"></a>

```typescript
public readonly testS3Bucket: string;
```

- *Type:* string

Name of the S3 data bucket that the provided role ID is authorized to access.Required if specifying cloudProviderConfig.

---

### ClusterProps <a name="ClusterProps" id="awscdk-resources-mongodbatlas.ClusterProps"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.ClusterProps.Initializer"></a>

```typescript
import { ClusterProps } from 'awscdk-resources-mongodbatlas'

const clusterProps: ClusterProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.ClusterProps.property.advancedSettings">advancedSettings</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ProcessArgs">ProcessArgs</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.ClusterProps.property.backupEnabled">backupEnabled</a></code> | <code>boolean</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.ClusterProps.property.biConnector">biConnector</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnClusterPropsBiConnector">CfnClusterPropsBiConnector</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.ClusterProps.property.clusterType">clusterType</a></code> | <code>string</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.ClusterProps.property.connectionStrings">connectionStrings</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ConnectionStrings">ConnectionStrings</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.ClusterProps.property.diskSizeGb">diskSizeGb</a></code> | <code>number</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.ClusterProps.property.encryptionAtRestProvider">encryptionAtRestProvider</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnClusterPropsEncryptionAtRestProvider">CfnClusterPropsEncryptionAtRestProvider</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.ClusterProps.property.labels">labels</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnClusterPropsLabels">CfnClusterPropsLabels</a>[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.ClusterProps.property.mongoDbMajorVersion">mongoDbMajorVersion</a></code> | <code>string</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.ClusterProps.property.name">name</a></code> | <code>string</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.ClusterProps.property.paused">paused</a></code> | <code>boolean</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.ClusterProps.property.pitEnabled">pitEnabled</a></code> | <code>boolean</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.ClusterProps.property.projectId">projectId</a></code> | <code>string</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.ClusterProps.property.replicationSpecs">replicationSpecs</a></code> | <code><a href="#awscdk-resources-mongodbatlas.AdvancedReplicationSpec">AdvancedReplicationSpec</a>[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.ClusterProps.property.rootCertType">rootCertType</a></code> | <code>string</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.ClusterProps.property.terminationProtectionEnabled">terminationProtectionEnabled</a></code> | <code>boolean</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.ClusterProps.property.versionReleaseSystem">versionReleaseSystem</a></code> | <code>string</code> | *No description.* |

---

##### `advancedSettings`<sup>Optional</sup> <a name="advancedSettings" id="awscdk-resources-mongodbatlas.ClusterProps.property.advancedSettings"></a>

```typescript
public readonly advancedSettings: ProcessArgs;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ProcessArgs">ProcessArgs</a>

---

##### `backupEnabled`<sup>Optional</sup> <a name="backupEnabled" id="awscdk-resources-mongodbatlas.ClusterProps.property.backupEnabled"></a>

```typescript
public readonly backupEnabled: boolean;
```

- *Type:* boolean

---

##### `biConnector`<sup>Optional</sup> <a name="biConnector" id="awscdk-resources-mongodbatlas.ClusterProps.property.biConnector"></a>

```typescript
public readonly biConnector: CfnClusterPropsBiConnector;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnClusterPropsBiConnector">CfnClusterPropsBiConnector</a>

---

##### `clusterType`<sup>Optional</sup> <a name="clusterType" id="awscdk-resources-mongodbatlas.ClusterProps.property.clusterType"></a>

```typescript
public readonly clusterType: string;
```

- *Type:* string

---

##### `connectionStrings`<sup>Optional</sup> <a name="connectionStrings" id="awscdk-resources-mongodbatlas.ClusterProps.property.connectionStrings"></a>

```typescript
public readonly connectionStrings: ConnectionStrings;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ConnectionStrings">ConnectionStrings</a>
- *Default:* REPLICASET

---

##### `diskSizeGb`<sup>Optional</sup> <a name="diskSizeGb" id="awscdk-resources-mongodbatlas.ClusterProps.property.diskSizeGb"></a>

```typescript
public readonly diskSizeGb: number;
```

- *Type:* number

---

##### `encryptionAtRestProvider`<sup>Optional</sup> <a name="encryptionAtRestProvider" id="awscdk-resources-mongodbatlas.ClusterProps.property.encryptionAtRestProvider"></a>

```typescript
public readonly encryptionAtRestProvider: CfnClusterPropsEncryptionAtRestProvider;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnClusterPropsEncryptionAtRestProvider">CfnClusterPropsEncryptionAtRestProvider</a>

---

##### `labels`<sup>Optional</sup> <a name="labels" id="awscdk-resources-mongodbatlas.ClusterProps.property.labels"></a>

```typescript
public readonly labels: CfnClusterPropsLabels[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnClusterPropsLabels">CfnClusterPropsLabels</a>[]

---

##### `mongoDbMajorVersion`<sup>Optional</sup> <a name="mongoDbMajorVersion" id="awscdk-resources-mongodbatlas.ClusterProps.property.mongoDbMajorVersion"></a>

```typescript
public readonly mongoDbMajorVersion: string;
```

- *Type:* string

---

##### `name`<sup>Optional</sup> <a name="name" id="awscdk-resources-mongodbatlas.ClusterProps.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

---

##### `paused`<sup>Optional</sup> <a name="paused" id="awscdk-resources-mongodbatlas.ClusterProps.property.paused"></a>

```typescript
public readonly paused: boolean;
```

- *Type:* boolean
- *Default:* auto-generated

---

##### `pitEnabled`<sup>Optional</sup> <a name="pitEnabled" id="awscdk-resources-mongodbatlas.ClusterProps.property.pitEnabled"></a>

```typescript
public readonly pitEnabled: boolean;
```

- *Type:* boolean

---

##### `projectId`<sup>Optional</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.ClusterProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

---

##### `replicationSpecs`<sup>Optional</sup> <a name="replicationSpecs" id="awscdk-resources-mongodbatlas.ClusterProps.property.replicationSpecs"></a>

```typescript
public readonly replicationSpecs: AdvancedReplicationSpec[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.AdvancedReplicationSpec">AdvancedReplicationSpec</a>[]

---

##### `rootCertType`<sup>Optional</sup> <a name="rootCertType" id="awscdk-resources-mongodbatlas.ClusterProps.property.rootCertType"></a>

```typescript
public readonly rootCertType: string;
```

- *Type:* string

---

##### `terminationProtectionEnabled`<sup>Optional</sup> <a name="terminationProtectionEnabled" id="awscdk-resources-mongodbatlas.ClusterProps.property.terminationProtectionEnabled"></a>

```typescript
public readonly terminationProtectionEnabled: boolean;
```

- *Type:* boolean

---

##### `versionReleaseSystem`<sup>Optional</sup> <a name="versionReleaseSystem" id="awscdk-resources-mongodbatlas.ClusterProps.property.versionReleaseSystem"></a>

```typescript
public readonly versionReleaseSystem: string;
```

- *Type:* string

---

### Collection <a name="Collection" id="awscdk-resources-mongodbatlas.Collection"></a>

Array of collections and data sources that map to a stores data store.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.Collection.Initializer"></a>

```typescript
import { Collection } from 'awscdk-resources-mongodbatlas'

const collection: Collection = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.Collection.property.dataSources">dataSources</a></code> | <code><a href="#awscdk-resources-mongodbatlas.DataSource">DataSource</a>[]</code> | Array that contains the data stores that map to a collection for this data lake. |
| <code><a href="#awscdk-resources-mongodbatlas.Collection.property.name">name</a></code> | <code>string</code> | *No description.* |

---

##### `dataSources`<sup>Optional</sup> <a name="dataSources" id="awscdk-resources-mongodbatlas.Collection.property.dataSources"></a>

```typescript
public readonly dataSources: DataSource[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.DataSource">DataSource</a>[]

Array that contains the data stores that map to a collection for this data lake.

---

##### `name`<sup>Optional</sup> <a name="name" id="awscdk-resources-mongodbatlas.Collection.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

---

### Compute <a name="Compute" id="awscdk-resources-mongodbatlas.Compute"></a>

Automatic Compute Scaling.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.Compute.Initializer"></a>

```typescript
import { Compute } from 'awscdk-resources-mongodbatlas'

const compute: Compute = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.Compute.property.enabled">enabled</a></code> | <code>boolean</code> | Flag that indicates whether someone enabled instance size auto-scaling. |
| <code><a href="#awscdk-resources-mongodbatlas.Compute.property.maxInstanceSize">maxInstanceSize</a></code> | <code>string</code> | Maximum instance size to which your cluster can automatically scale. |
| <code><a href="#awscdk-resources-mongodbatlas.Compute.property.minInstanceSize">minInstanceSize</a></code> | <code>string</code> | Minimum instance size to which your cluster can automatically scale. |
| <code><a href="#awscdk-resources-mongodbatlas.Compute.property.scaleDownEnabled">scaleDownEnabled</a></code> | <code>boolean</code> | Flag that indicates whether the instance size may scale down. |

---

##### `enabled`<sup>Optional</sup> <a name="enabled" id="awscdk-resources-mongodbatlas.Compute.property.enabled"></a>

```typescript
public readonly enabled: boolean;
```

- *Type:* boolean

Flag that indicates whether someone enabled instance size auto-scaling.

Set to true to enable instance size auto-scaling. If enabled, you must specify a value for replicationSpecs[n].regionConfigs[m].autoScaling.compute.maxInstanceSize.
Set to false to disable instance size automatic scaling.

---

##### `maxInstanceSize`<sup>Optional</sup> <a name="maxInstanceSize" id="awscdk-resources-mongodbatlas.Compute.property.maxInstanceSize"></a>

```typescript
public readonly maxInstanceSize: string;
```

- *Type:* string

Maximum instance size to which your cluster can automatically scale.

MongoDB Cloud requires this parameter if "replicationSpecs[n].regionConfigs[m].autoScaling.compute.enabled" : true.

---

##### `minInstanceSize`<sup>Optional</sup> <a name="minInstanceSize" id="awscdk-resources-mongodbatlas.Compute.property.minInstanceSize"></a>

```typescript
public readonly minInstanceSize: string;
```

- *Type:* string

Minimum instance size to which your cluster can automatically scale.

MongoDB Cloud requires this parameter if "replicationSpecs[n].regionConfigs[m].autoScaling.compute.enabled" : true.

---

##### `scaleDownEnabled`<sup>Optional</sup> <a name="scaleDownEnabled" id="awscdk-resources-mongodbatlas.Compute.property.scaleDownEnabled"></a>

```typescript
public readonly scaleDownEnabled: boolean;
```

- *Type:* boolean

Flag that indicates whether the instance size may scale down.

MongoDB Cloud requires this parameter if "replicationSpecs[n].regionConfigs[m].autoScaling.compute.enabled" : true. If you enable this option, specify a value for replicationSpecs[n].regionConfigs[m].autoScaling.compute.minInstanceSize.

---

### ConnectionStrings <a name="ConnectionStrings" id="awscdk-resources-mongodbatlas.ConnectionStrings"></a>

Collection of Uniform Resource Locators that point to the MongoDB database.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.ConnectionStrings.Initializer"></a>

```typescript
import { ConnectionStrings } from 'awscdk-resources-mongodbatlas'

const connectionStrings: ConnectionStrings = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.ConnectionStrings.property.private">private</a></code> | <code>string</code> | Network peering connection strings for each interface Virtual Private Cloud (VPC) endpoint that you configured to connect to this cluster. |
| <code><a href="#awscdk-resources-mongodbatlas.ConnectionStrings.property.privateEndpoints">privateEndpoints</a></code> | <code>string[]</code> | Private endpoint-aware connection strings that use AWS-hosted clusters with Amazon Web Services (AWS) PrivateLink. |
| <code><a href="#awscdk-resources-mongodbatlas.ConnectionStrings.property.privateEndpointsSrv">privateEndpointsSrv</a></code> | <code>string[]</code> | Private endpoint-aware connection strings that use AWS-hosted clusters with Amazon Web Services (AWS) PrivateLink. |
| <code><a href="#awscdk-resources-mongodbatlas.ConnectionStrings.property.privateSrv">privateSrv</a></code> | <code>string</code> | Network peering connection strings for each interface Virtual Private Cloud (VPC) endpoint that you configured to connect to this cluster. |
| <code><a href="#awscdk-resources-mongodbatlas.ConnectionStrings.property.srvShardOptimizedConnectionString">srvShardOptimizedConnectionString</a></code> | <code>string[]</code> | Private endpoint-aware connection string optimized for sharded clusters that uses the `mongodb+srv://` protocol to connect to MongoDB Cloud through a private endpoint. |
| <code><a href="#awscdk-resources-mongodbatlas.ConnectionStrings.property.standard">standard</a></code> | <code>string</code> | Public connection string that you can use to connect to this cluster. |
| <code><a href="#awscdk-resources-mongodbatlas.ConnectionStrings.property.standardSrv">standardSrv</a></code> | <code>string</code> | Public connection string that you can use to connect to this cluster. |

---

##### `private`<sup>Optional</sup> <a name="private" id="awscdk-resources-mongodbatlas.ConnectionStrings.property.private"></a>

```typescript
public readonly private: string;
```

- *Type:* string

Network peering connection strings for each interface Virtual Private Cloud (VPC) endpoint that you configured to connect to this cluster.

This connection string uses the mongodb+srv:// protocol. The resource returns this parameter once someone creates a network peering connection to this cluster. This protocol tells the application to look up the host seed list in the Domain Name System (DNS). This list synchronizes with the nodes in a cluster. If the connection string uses this Uniform Resource Identifier (URI) format, you don't need to append the seed list or change the URI if the nodes change. Use this URI format if your driver supports it. If it doesn't, use connectionStrings.private. For Amazon Web Services (AWS) clusters, this resource returns this parameter only if you enable custom DNS.

---

##### `privateEndpoints`<sup>Optional</sup> <a name="privateEndpoints" id="awscdk-resources-mongodbatlas.ConnectionStrings.property.privateEndpoints"></a>

```typescript
public readonly privateEndpoints: string[];
```

- *Type:* string[]

Private endpoint-aware connection strings that use AWS-hosted clusters with Amazon Web Services (AWS) PrivateLink.

Each key identifies an Amazon Web Services (AWS) interface endpoint. Each value identifies the related mongodb:// connection string that you use to connect to MongoDB Cloud through the interface endpoint that the key names.

---

##### `privateEndpointsSrv`<sup>Optional</sup> <a name="privateEndpointsSrv" id="awscdk-resources-mongodbatlas.ConnectionStrings.property.privateEndpointsSrv"></a>

```typescript
public readonly privateEndpointsSrv: string[];
```

- *Type:* string[]

Private endpoint-aware connection strings that use AWS-hosted clusters with Amazon Web Services (AWS) PrivateLink.

Each key identifies an Amazon Web Services (AWS) interface endpoint. Each value identifies the related mongodb:// connection string that you use to connect to Atlas through the interface endpoint that the key names.

---

##### `privateSrv`<sup>Optional</sup> <a name="privateSrv" id="awscdk-resources-mongodbatlas.ConnectionStrings.property.privateSrv"></a>

```typescript
public readonly privateSrv: string;
```

- *Type:* string

Network peering connection strings for each interface Virtual Private Cloud (VPC) endpoint that you configured to connect to this cluster.

This connection string uses the mongodb+srv:// protocol. The resource returns this parameter when someone creates a network peering connection to this cluster. This protocol tells the application to look up the host seed list in the Domain Name System (DNS). This list synchronizes with the nodes in a cluster. If the connection string uses this Uniform Resource Identifier (URI) format, you don't need to append the seed list or change the Uniform Resource Identifier (URI) if the nodes change. Use this Uniform Resource Identifier (URI) format if your driver supports it. If it doesn't, use connectionStrings.private. For Amazon Web Services (AWS) clusters, this parameter returns only if you enable custom DNS.

---

##### `srvShardOptimizedConnectionString`<sup>Optional</sup> <a name="srvShardOptimizedConnectionString" id="awscdk-resources-mongodbatlas.ConnectionStrings.property.srvShardOptimizedConnectionString"></a>

```typescript
public readonly srvShardOptimizedConnectionString: string[];
```

- *Type:* string[]

Private endpoint-aware connection string optimized for sharded clusters that uses the `mongodb+srv://` protocol to connect to MongoDB Cloud through a private endpoint.

If the connection string uses this Uniform Resource Identifier (URI) format, you don't need to change the Uniform Resource Identifier (URI) if the nodes change. Use this Uniform Resource Identifier (URI) format if your application and Atlas cluster supports it. If it doesn't, use and consult the documentation for connectionStrings.privateEndpoint[n].srvConnectionString.

---

##### `standard`<sup>Optional</sup> <a name="standard" id="awscdk-resources-mongodbatlas.ConnectionStrings.property.standard"></a>

```typescript
public readonly standard: string;
```

- *Type:* string

Public connection string that you can use to connect to this cluster.

This connection string uses the mongodb:// protocol.

---

##### `standardSrv`<sup>Optional</sup> <a name="standardSrv" id="awscdk-resources-mongodbatlas.ConnectionStrings.property.standardSrv"></a>

```typescript
public readonly standardSrv: string;
```

- *Type:* string

Public connection string that you can use to connect to this cluster.

This connection string uses the mongodb+srv:// protocol.

---

### CriteriaView <a name="CriteriaView" id="awscdk-resources-mongodbatlas.CriteriaView"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CriteriaView.Initializer"></a>

```typescript
import { CriteriaView } from 'awscdk-resources-mongodbatlas'

const criteriaView: CriteriaView = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CriteriaView.property.dateField">dateField</a></code> | <code>string</code> | Indexed database parameter that stores the date that determines when data moves to the online archive. |
| <code><a href="#awscdk-resources-mongodbatlas.CriteriaView.property.dateFormat">dateFormat</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CriteriaViewDateFormat">CriteriaViewDateFormat</a></code> | Syntax used to write the date after which data moves to the online archive. |
| <code><a href="#awscdk-resources-mongodbatlas.CriteriaView.property.expireAfterDays">expireAfterDays</a></code> | <code>number</code> | Number of days after the value in the criteria.dateField when MongoDB Cloud archives data in the specified cluster. Set this parameter when you set "criteria.type" : "DATE". |
| <code><a href="#awscdk-resources-mongodbatlas.CriteriaView.property.query">query</a></code> | <code>string</code> | MongoDB find query that selects documents to archive. |
| <code><a href="#awscdk-resources-mongodbatlas.CriteriaView.property.type">type</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CriteriaViewType">CriteriaViewType</a></code> | Means by which MongoDB Cloud selects data to archive. |

---

##### `dateField`<sup>Optional</sup> <a name="dateField" id="awscdk-resources-mongodbatlas.CriteriaView.property.dateField"></a>

```typescript
public readonly dateField: string;
```

- *Type:* string

Indexed database parameter that stores the date that determines when data moves to the online archive.

MongoDB Cloud archives the data when the current date exceeds the date in this database parameter plus the number of days specified through the expireAfterDays parameter. Set this parameter when you set "criteria.type" : "DATE".

---

##### `dateFormat`<sup>Optional</sup> <a name="dateFormat" id="awscdk-resources-mongodbatlas.CriteriaView.property.dateFormat"></a>

```typescript
public readonly dateFormat: CriteriaViewDateFormat;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CriteriaViewDateFormat">CriteriaViewDateFormat</a>

Syntax used to write the date after which data moves to the online archive.

Date can be expressed as ISO 8601 or Epoch timestamps. The Epoch timestamp can be expressed as nanoseconds, milliseconds, or seconds. Set this parameter when "criteria.type" : "DATE". You must set "criteria.type" : "DATE" if "collectionType": "TIMESERIES".

---

##### `expireAfterDays`<sup>Optional</sup> <a name="expireAfterDays" id="awscdk-resources-mongodbatlas.CriteriaView.property.expireAfterDays"></a>

```typescript
public readonly expireAfterDays: number;
```

- *Type:* number

Number of days after the value in the criteria.dateField when MongoDB Cloud archives data in the specified cluster. Set this parameter when you set "criteria.type" : "DATE".

---

##### `query`<sup>Optional</sup> <a name="query" id="awscdk-resources-mongodbatlas.CriteriaView.property.query"></a>

```typescript
public readonly query: string;
```

- *Type:* string

MongoDB find query that selects documents to archive.

The specified query follows the syntax of the db.collection.find(query) command. This query can't use the empty document ({}) to return all documents. Set this parameter when "criteria.type" : "CUSTOM".

---

##### `type`<sup>Optional</sup> <a name="type" id="awscdk-resources-mongodbatlas.CriteriaView.property.type"></a>

```typescript
public readonly type: CriteriaViewType;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CriteriaViewType">CriteriaViewType</a>

Means by which MongoDB Cloud selects data to archive.

Data can be chosen using the age of the data or a MongoDB query.
**DATE** selects documents to archive based on a date.
**CUSTOM** selects documents to archive based on a custom JSON query. MongoDB Cloud doesn't support **CUSTOM** when `"collectionType": "TIMESERIES"`.

---

### CustomerX509 <a name="CustomerX509" id="awscdk-resources-mongodbatlas.CustomerX509"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.CustomerX509.Initializer"></a>

```typescript
import { CustomerX509 } from 'awscdk-resources-mongodbatlas'

const customerX509: CustomerX509 = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CustomerX509.property.cas">cas</a></code> | <code>string</code> | PEM string containing one or more customer CAs for database user authentication. |

---

##### `cas`<sup>Optional</sup> <a name="cas" id="awscdk-resources-mongodbatlas.CustomerX509.property.cas"></a>

```typescript
public readonly cas: string;
```

- *Type:* string

PEM string containing one or more customer CAs for database user authentication.

---

### Database <a name="Database" id="awscdk-resources-mongodbatlas.Database"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.Database.Initializer"></a>

```typescript
import { Database } from 'awscdk-resources-mongodbatlas'

const database: Database = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.Database.property.collections">collections</a></code> | <code><a href="#awscdk-resources-mongodbatlas.Collection">Collection</a>[]</code> | Array of collections and data sources that map to a stores data store. |
| <code><a href="#awscdk-resources-mongodbatlas.Database.property.maxWildcardCollections">maxWildcardCollections</a></code> | <code>string</code> | Maximum number of wildcard collections in the database. |
| <code><a href="#awscdk-resources-mongodbatlas.Database.property.name">name</a></code> | <code>string</code> | Human-readable label that identifies the database to which the data lake maps data. |
| <code><a href="#awscdk-resources-mongodbatlas.Database.property.views">views</a></code> | <code><a href="#awscdk-resources-mongodbatlas.View">View</a>[]</code> | Array of aggregation pipelines that apply to the collection. |

---

##### `collections`<sup>Optional</sup> <a name="collections" id="awscdk-resources-mongodbatlas.Database.property.collections"></a>

```typescript
public readonly collections: Collection[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.Collection">Collection</a>[]

Array of collections and data sources that map to a stores data store.

---

##### `maxWildcardCollections`<sup>Optional</sup> <a name="maxWildcardCollections" id="awscdk-resources-mongodbatlas.Database.property.maxWildcardCollections"></a>

```typescript
public readonly maxWildcardCollections: string;
```

- *Type:* string

Maximum number of wildcard collections in the database.

This only applies to S3 data sources.

---

##### `name`<sup>Optional</sup> <a name="name" id="awscdk-resources-mongodbatlas.Database.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Human-readable label that identifies the database to which the data lake maps data.

---

##### `views`<sup>Optional</sup> <a name="views" id="awscdk-resources-mongodbatlas.Database.property.views"></a>

```typescript
public readonly views: View[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.View">View</a>[]

Array of aggregation pipelines that apply to the collection.

This only applies to S3 data sources.

---

### DatabaseConfig <a name="DatabaseConfig" id="awscdk-resources-mongodbatlas.DatabaseConfig"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.DatabaseConfig.Initializer"></a>

```typescript
import { DatabaseConfig } from 'awscdk-resources-mongodbatlas'

const databaseConfig: DatabaseConfig = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.DatabaseConfig.property.collection">collection</a></code> | <code>string</code> | The name of a collection in the specified database. |
| <code><a href="#awscdk-resources-mongodbatlas.DatabaseConfig.property.database">database</a></code> | <code>string</code> | The name of a database in the linked data source. |
| <code><a href="#awscdk-resources-mongodbatlas.DatabaseConfig.property.fullDocument">fullDocument</a></code> | <code>boolean</code> | If `true`, indicates that `UPDATE` change events should include the most current [majority-committed](https://www.mongodb.com/docs/manual/reference/read-concern-majority/) version of the modified document in the `fullDocument` field. |
| <code><a href="#awscdk-resources-mongodbatlas.DatabaseConfig.property.fullDocumentBeforeChange">fullDocumentBeforeChange</a></code> | <code>boolean</code> | If true, indicates that `UPDATE` change events should include a snapshot of the modified document from immediately before the update was applied. |
| <code><a href="#awscdk-resources-mongodbatlas.DatabaseConfig.property.match">match</a></code> | <code>string</code> | stringify version of a [$match](https://www.mongodb.com/docs/manual/reference/operator/aggregation/match) expression filters change events. The trigger will only fire if the expression evaluates to true for a given change event. |
| <code><a href="#awscdk-resources-mongodbatlas.DatabaseConfig.property.operationTypes">operationTypes</a></code> | <code><a href="#awscdk-resources-mongodbatlas.DatabaseConfigOperationTypes">DatabaseConfigOperationTypes</a>[]</code> | The type(s) of MongoDB change event that the trigger listens for. |
| <code><a href="#awscdk-resources-mongodbatlas.DatabaseConfig.property.project">project</a></code> | <code>string</code> | stringify version of a [$project](https://www.mongodb.com/docs/manual/reference/operator/aggregation/project/) expressions to limit the data included in each event. |
| <code><a href="#awscdk-resources-mongodbatlas.DatabaseConfig.property.serviceId">serviceId</a></code> | <code>string</code> | The _id value of a linked MongoDB data source. |
| <code><a href="#awscdk-resources-mongodbatlas.DatabaseConfig.property.skipCatchupEvents">skipCatchupEvents</a></code> | <code>boolean</code> | If `true`, enabling the Trigger after it was disabled will not invoke events that occurred while the Trigger was disabled. |
| <code><a href="#awscdk-resources-mongodbatlas.DatabaseConfig.property.tolerateResumeErrors">tolerateResumeErrors</a></code> | <code>boolean</code> | If `true`, when this Trigger's resume token cannot be found in the cluster's oplog, the Trigger automatically resumes processing events at the next relevant change stream event. |
| <code><a href="#awscdk-resources-mongodbatlas.DatabaseConfig.property.unordered">unordered</a></code> | <code>boolean</code> | If `true`, event ordering is disabled and this Trigger can process events in parallel. |

---

##### `collection`<sup>Optional</sup> <a name="collection" id="awscdk-resources-mongodbatlas.DatabaseConfig.property.collection"></a>

```typescript
public readonly collection: string;
```

- *Type:* string

The name of a collection in the specified database.

The
trigger listens to events from this collection.

---

##### `database`<sup>Optional</sup> <a name="database" id="awscdk-resources-mongodbatlas.DatabaseConfig.property.database"></a>

```typescript
public readonly database: string;
```

- *Type:* string

The name of a database in the linked data source.

---

##### `fullDocument`<sup>Optional</sup> <a name="fullDocument" id="awscdk-resources-mongodbatlas.DatabaseConfig.property.fullDocument"></a>

```typescript
public readonly fullDocument: boolean;
```

- *Type:* boolean

If `true`, indicates that `UPDATE` change events should include the most current [majority-committed](https://www.mongodb.com/docs/manual/reference/read-concern-majority/) version of the modified document in the `fullDocument` field.

---

##### `fullDocumentBeforeChange`<sup>Optional</sup> <a name="fullDocumentBeforeChange" id="awscdk-resources-mongodbatlas.DatabaseConfig.property.fullDocumentBeforeChange"></a>

```typescript
public readonly fullDocumentBeforeChange: boolean;
```

- *Type:* boolean

If true, indicates that `UPDATE` change events should include a snapshot of the modified document from immediately before the update was applied.

You must enable [document
preimages](https://www.mongodb.com/docs/atlas/app-services/mongodb/preimages/)
for your cluster to include these snapshots.

---

##### `match`<sup>Optional</sup> <a name="match" id="awscdk-resources-mongodbatlas.DatabaseConfig.property.match"></a>

```typescript
public readonly match: string;
```

- *Type:* string

stringify version of a [$match](https://www.mongodb.com/docs/manual/reference/operator/aggregation/match) expression filters change events. The trigger will only fire if the expression evaluates to true for a given change event.

---

##### `operationTypes`<sup>Optional</sup> <a name="operationTypes" id="awscdk-resources-mongodbatlas.DatabaseConfig.property.operationTypes"></a>

```typescript
public readonly operationTypes: DatabaseConfigOperationTypes[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.DatabaseConfigOperationTypes">DatabaseConfigOperationTypes</a>[]

The type(s) of MongoDB change event that the trigger listens for.

---

##### `project`<sup>Optional</sup> <a name="project" id="awscdk-resources-mongodbatlas.DatabaseConfig.property.project"></a>

```typescript
public readonly project: string;
```

- *Type:* string

stringify version of a [$project](https://www.mongodb.com/docs/manual/reference/operator/aggregation/project/) expressions to limit the data included in each event.

---

##### `serviceId`<sup>Optional</sup> <a name="serviceId" id="awscdk-resources-mongodbatlas.DatabaseConfig.property.serviceId"></a>

```typescript
public readonly serviceId: string;
```

- *Type:* string

The _id value of a linked MongoDB data source.

See [Get a Data Source](#operation/adminGetService).

---

##### `skipCatchupEvents`<sup>Optional</sup> <a name="skipCatchupEvents" id="awscdk-resources-mongodbatlas.DatabaseConfig.property.skipCatchupEvents"></a>

```typescript
public readonly skipCatchupEvents: boolean;
```

- *Type:* boolean

If `true`, enabling the Trigger after it was disabled will not invoke events that occurred while the Trigger was disabled.

---

##### `tolerateResumeErrors`<sup>Optional</sup> <a name="tolerateResumeErrors" id="awscdk-resources-mongodbatlas.DatabaseConfig.property.tolerateResumeErrors"></a>

```typescript
public readonly tolerateResumeErrors: boolean;
```

- *Type:* boolean

If `true`, when this Trigger's resume token cannot be found in the cluster's oplog, the Trigger automatically resumes processing events at the next relevant change stream event.

All change stream events from when the Trigger was suspended until the Trigger
resumes execution do not have the Trigger fire for them.

---

##### `unordered`<sup>Optional</sup> <a name="unordered" id="awscdk-resources-mongodbatlas.DatabaseConfig.property.unordered"></a>

```typescript
public readonly unordered: boolean;
```

- *Type:* boolean

If `true`, event ordering is disabled and this Trigger can process events in parallel.

If `false`, event
ordering is enabled and the Trigger executes events
serially.

---

### DatabaseUserProps <a name="DatabaseUserProps" id="awscdk-resources-mongodbatlas.DatabaseUserProps"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.DatabaseUserProps.Initializer"></a>

```typescript
import { DatabaseUserProps } from 'awscdk-resources-mongodbatlas'

const databaseUserProps: DatabaseUserProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.DatabaseUserProps.property.awsiamType">awsiamType</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUserPropsAwsiamType">CfnDatabaseUserPropsAwsiamType</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.DatabaseUserProps.property.databaseName">databaseName</a></code> | <code>string</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.DatabaseUserProps.property.deleteAfterDate">deleteAfterDate</a></code> | <code>string</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.DatabaseUserProps.property.labels">labels</a></code> | <code><a href="#awscdk-resources-mongodbatlas.LabelDefinition">LabelDefinition</a>[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.DatabaseUserProps.property.ldapAuthType">ldapAuthType</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUserPropsLdapAuthType">CfnDatabaseUserPropsLdapAuthType</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.DatabaseUserProps.property.password">password</a></code> | <code>string</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.DatabaseUserProps.property.projectId">projectId</a></code> | <code>string</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.DatabaseUserProps.property.roles">roles</a></code> | <code><a href="#awscdk-resources-mongodbatlas.RoleDefinition">RoleDefinition</a>[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.DatabaseUserProps.property.scopes">scopes</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ScopeDefinition">ScopeDefinition</a>[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.DatabaseUserProps.property.username">username</a></code> | <code>string</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.DatabaseUserProps.property.x509Type">x509Type</a></code> | <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUserPropsX509Type">CfnDatabaseUserPropsX509Type</a></code> | *No description.* |

---

##### `awsiamType`<sup>Optional</sup> <a name="awsiamType" id="awscdk-resources-mongodbatlas.DatabaseUserProps.property.awsiamType"></a>

```typescript
public readonly awsiamType: CfnDatabaseUserPropsAwsiamType;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnDatabaseUserPropsAwsiamType">CfnDatabaseUserPropsAwsiamType</a>

---

##### `databaseName`<sup>Optional</sup> <a name="databaseName" id="awscdk-resources-mongodbatlas.DatabaseUserProps.property.databaseName"></a>

```typescript
public readonly databaseName: string;
```

- *Type:* string

---

##### `deleteAfterDate`<sup>Optional</sup> <a name="deleteAfterDate" id="awscdk-resources-mongodbatlas.DatabaseUserProps.property.deleteAfterDate"></a>

```typescript
public readonly deleteAfterDate: string;
```

- *Type:* string

---

##### `labels`<sup>Optional</sup> <a name="labels" id="awscdk-resources-mongodbatlas.DatabaseUserProps.property.labels"></a>

```typescript
public readonly labels: LabelDefinition[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.LabelDefinition">LabelDefinition</a>[]
- *Default:* admin

---

##### `ldapAuthType`<sup>Optional</sup> <a name="ldapAuthType" id="awscdk-resources-mongodbatlas.DatabaseUserProps.property.ldapAuthType"></a>

```typescript
public readonly ldapAuthType: CfnDatabaseUserPropsLdapAuthType;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnDatabaseUserPropsLdapAuthType">CfnDatabaseUserPropsLdapAuthType</a>

---

##### `password`<sup>Optional</sup> <a name="password" id="awscdk-resources-mongodbatlas.DatabaseUserProps.property.password"></a>

```typescript
public readonly password: string;
```

- *Type:* string

---

##### `projectId`<sup>Optional</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.DatabaseUserProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string
- *Default:* cdk-pwd

---

##### `roles`<sup>Optional</sup> <a name="roles" id="awscdk-resources-mongodbatlas.DatabaseUserProps.property.roles"></a>

```typescript
public readonly roles: RoleDefinition[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.RoleDefinition">RoleDefinition</a>[]

---

##### `scopes`<sup>Optional</sup> <a name="scopes" id="awscdk-resources-mongodbatlas.DatabaseUserProps.property.scopes"></a>

```typescript
public readonly scopes: ScopeDefinition[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ScopeDefinition">ScopeDefinition</a>[]

---

##### `username`<sup>Optional</sup> <a name="username" id="awscdk-resources-mongodbatlas.DatabaseUserProps.property.username"></a>

```typescript
public readonly username: string;
```

- *Type:* string
- *Default:* cdk-user

---

##### `x509Type`<sup>Optional</sup> <a name="x509Type" id="awscdk-resources-mongodbatlas.DatabaseUserProps.property.x509Type"></a>

```typescript
public readonly x509Type: CfnDatabaseUserPropsX509Type;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.CfnDatabaseUserPropsX509Type">CfnDatabaseUserPropsX509Type</a>

---

### DatadogIntegrationProps <a name="DatadogIntegrationProps" id="awscdk-resources-mongodbatlas.DatadogIntegrationProps"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.DatadogIntegrationProps.Initializer"></a>

```typescript
import { DatadogIntegrationProps } from 'awscdk-resources-mongodbatlas'

const datadogIntegrationProps: DatadogIntegrationProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.DatadogIntegrationProps.property.projectId">projectId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies your project. |
| <code><a href="#awscdk-resources-mongodbatlas.DatadogIntegrationProps.property.profile">profile</a></code> | <code>string</code> | Atlas API keys. |
| <code><a href="#awscdk-resources-mongodbatlas.DatadogIntegrationProps.property.apiKey">apiKey</a></code> | <code>string</code> | Key that allows MongoDB Cloud to access your Datadog account. |
| <code><a href="#awscdk-resources-mongodbatlas.DatadogIntegrationProps.property.region">region</a></code> | <code><a href="#awscdk-resources-mongodbatlas.DatadogRegion">DatadogRegion</a></code> | Two-letter code that indicates which regional URL MongoDB uses to access the Datadog API. |

---

##### `projectId`<sup>Required</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.DatadogIntegrationProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies your project.

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.DatadogIntegrationProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

Atlas API keys.

---

##### `apiKey`<sup>Required</sup> <a name="apiKey" id="awscdk-resources-mongodbatlas.DatadogIntegrationProps.property.apiKey"></a>

```typescript
public readonly apiKey: string;
```

- *Type:* string

Key that allows MongoDB Cloud to access your Datadog account.

---

##### `region`<sup>Required</sup> <a name="region" id="awscdk-resources-mongodbatlas.DatadogIntegrationProps.property.region"></a>

```typescript
public readonly region: DatadogRegion;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.DatadogRegion">DatadogRegion</a>

Two-letter code that indicates which regional URL MongoDB uses to access the Datadog API.

---

### DataLakeAwsCloudProviderConfigView <a name="DataLakeAwsCloudProviderConfigView" id="awscdk-resources-mongodbatlas.DataLakeAwsCloudProviderConfigView"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.DataLakeAwsCloudProviderConfigView.Initializer"></a>

```typescript
import { DataLakeAwsCloudProviderConfigView } from 'awscdk-resources-mongodbatlas'

const dataLakeAwsCloudProviderConfigView: DataLakeAwsCloudProviderConfigView = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeAwsCloudProviderConfigView.property.externalId">externalId</a></code> | <code>string</code> | Unique identifier associated with the Identity and Access Management (IAM) role that the data lake assumes when accessing the data stores. |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeAwsCloudProviderConfigView.property.iamAssumedRoleArn">iamAssumedRoleArn</a></code> | <code>string</code> | Amazon Resource Name (ARN) of the Identity and Access Management (IAM) role that the data lake assumes when accessing data stores. |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeAwsCloudProviderConfigView.property.iamUserArn">iamUserArn</a></code> | <code>string</code> | Amazon Resource Name (ARN) of the user that the data lake assumes when accessing data stores. |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeAwsCloudProviderConfigView.property.roleId">roleId</a></code> | <code>string</code> | Unique identifier of the role that the data lake can use to access the data stores.Required if specifying cloudProviderConfig. |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeAwsCloudProviderConfigView.property.testS3Bucket">testS3Bucket</a></code> | <code>string</code> | Name of the S3 data bucket that the provided role ID is authorized to access.Required if specifying cloudProviderConfig. |

---

##### `externalId`<sup>Optional</sup> <a name="externalId" id="awscdk-resources-mongodbatlas.DataLakeAwsCloudProviderConfigView.property.externalId"></a>

```typescript
public readonly externalId: string;
```

- *Type:* string

Unique identifier associated with the Identity and Access Management (IAM) role that the data lake assumes when accessing the data stores.

---

##### `iamAssumedRoleArn`<sup>Optional</sup> <a name="iamAssumedRoleArn" id="awscdk-resources-mongodbatlas.DataLakeAwsCloudProviderConfigView.property.iamAssumedRoleArn"></a>

```typescript
public readonly iamAssumedRoleArn: string;
```

- *Type:* string

Amazon Resource Name (ARN) of the Identity and Access Management (IAM) role that the data lake assumes when accessing data stores.

---

##### `iamUserArn`<sup>Optional</sup> <a name="iamUserArn" id="awscdk-resources-mongodbatlas.DataLakeAwsCloudProviderConfigView.property.iamUserArn"></a>

```typescript
public readonly iamUserArn: string;
```

- *Type:* string

Amazon Resource Name (ARN) of the user that the data lake assumes when accessing data stores.

---

##### `roleId`<sup>Optional</sup> <a name="roleId" id="awscdk-resources-mongodbatlas.DataLakeAwsCloudProviderConfigView.property.roleId"></a>

```typescript
public readonly roleId: string;
```

- *Type:* string

Unique identifier of the role that the data lake can use to access the data stores.Required if specifying cloudProviderConfig.

---

##### `testS3Bucket`<sup>Optional</sup> <a name="testS3Bucket" id="awscdk-resources-mongodbatlas.DataLakeAwsCloudProviderConfigView.property.testS3Bucket"></a>

```typescript
public readonly testS3Bucket: string;
```

- *Type:* string

Name of the S3 data bucket that the provided role ID is authorized to access.Required if specifying cloudProviderConfig.

---

### DataLakeCloudProviderConfigView <a name="DataLakeCloudProviderConfigView" id="awscdk-resources-mongodbatlas.DataLakeCloudProviderConfigView"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.DataLakeCloudProviderConfigView.Initializer"></a>

```typescript
import { DataLakeCloudProviderConfigView } from 'awscdk-resources-mongodbatlas'

const dataLakeCloudProviderConfigView: DataLakeCloudProviderConfigView = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeCloudProviderConfigView.property.aws">aws</a></code> | <code><a href="#awscdk-resources-mongodbatlas.DataLakeAwsCloudProviderConfigView">DataLakeAwsCloudProviderConfigView</a></code> | Name of the cloud service that hosts the data lake's data stores. |

---

##### `aws`<sup>Optional</sup> <a name="aws" id="awscdk-resources-mongodbatlas.DataLakeCloudProviderConfigView.property.aws"></a>

```typescript
public readonly aws: DataLakeAwsCloudProviderConfigView;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.DataLakeAwsCloudProviderConfigView">DataLakeAwsCloudProviderConfigView</a>

Name of the cloud service that hosts the data lake's data stores.

---

### DataLakeDatabaseCollectionView <a name="DataLakeDatabaseCollectionView" id="awscdk-resources-mongodbatlas.DataLakeDatabaseCollectionView"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.DataLakeDatabaseCollectionView.Initializer"></a>

```typescript
import { DataLakeDatabaseCollectionView } from 'awscdk-resources-mongodbatlas'

const dataLakeDatabaseCollectionView: DataLakeDatabaseCollectionView = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeDatabaseCollectionView.property.dataSources">dataSources</a></code> | <code><a href="#awscdk-resources-mongodbatlas.DataLakeDatabaseDataSourceView">DataLakeDatabaseDataSourceView</a>[]</code> | Array that contains the data stores that map to a collection for this data lake. |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeDatabaseCollectionView.property.name">name</a></code> | <code>string</code> | Human-readable label that identifies the collection to which MongoDB Cloud maps the data in the data stores. |

---

##### `dataSources`<sup>Optional</sup> <a name="dataSources" id="awscdk-resources-mongodbatlas.DataLakeDatabaseCollectionView.property.dataSources"></a>

```typescript
public readonly dataSources: DataLakeDatabaseDataSourceView[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.DataLakeDatabaseDataSourceView">DataLakeDatabaseDataSourceView</a>[]

Array that contains the data stores that map to a collection for this data lake.

---

##### `name`<sup>Optional</sup> <a name="name" id="awscdk-resources-mongodbatlas.DataLakeDatabaseCollectionView.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Human-readable label that identifies the collection to which MongoDB Cloud maps the data in the data stores.

---

### DataLakeDatabaseDataSourceView <a name="DataLakeDatabaseDataSourceView" id="awscdk-resources-mongodbatlas.DataLakeDatabaseDataSourceView"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.DataLakeDatabaseDataSourceView.Initializer"></a>

```typescript
import { DataLakeDatabaseDataSourceView } from 'awscdk-resources-mongodbatlas'

const dataLakeDatabaseDataSourceView: DataLakeDatabaseDataSourceView = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeDatabaseDataSourceView.property.allowInsecure">allowInsecure</a></code> | <code>boolean</code> | Flag that validates the scheme in the specified URLs. |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeDatabaseDataSourceView.property.collection">collection</a></code> | <code>string</code> | Human-readable label that identifies the collection in the database. |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeDatabaseDataSourceView.property.collectionRegex">collectionRegex</a></code> | <code>string</code> | Regex pattern to use for creating the wildcard (*) collection. |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeDatabaseDataSourceView.property.database">database</a></code> | <code>string</code> | Human-readable label that identifies the database, which contains the collection in the cluster. |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeDatabaseDataSourceView.property.defaultFormat">defaultFormat</a></code> | <code><a href="#awscdk-resources-mongodbatlas.DataLakeDatabaseDataSourceViewDefaultFormat">DataLakeDatabaseDataSourceViewDefaultFormat</a></code> | File format that MongoDB Cloud uses if it encounters a file without a file extension while searching **storeName**. |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeDatabaseDataSourceView.property.path">path</a></code> | <code>string</code> | File path that controls how MongoDB Cloud searches for and parses files in the **storeName** before mapping them to a collection.Specify ``/`` to capture all files and folders from the ``prefix`` path. |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeDatabaseDataSourceView.property.storeName">storeName</a></code> | <code>string</code> | Human-readable label that identifies the data store that MongoDB Cloud maps to the collection. |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeDatabaseDataSourceView.property.urls">urls</a></code> | <code>string[]</code> | URLs of the publicly accessible data files. |

---

##### `allowInsecure`<sup>Optional</sup> <a name="allowInsecure" id="awscdk-resources-mongodbatlas.DataLakeDatabaseDataSourceView.property.allowInsecure"></a>

```typescript
public readonly allowInsecure: boolean;
```

- *Type:* boolean

Flag that validates the scheme in the specified URLs.

If `true`, allows insecure `HTTP` scheme, doesn't verify the server's certificate chain and hostname, and accepts any certificate with any hostname presented by the server. If `false`, allows secure `HTTPS` scheme only.

---

##### `collection`<sup>Optional</sup> <a name="collection" id="awscdk-resources-mongodbatlas.DataLakeDatabaseDataSourceView.property.collection"></a>

```typescript
public readonly collection: string;
```

- *Type:* string

Human-readable label that identifies the collection in the database.

For creating a wildcard (`*`) collection, you must omit this parameter.

---

##### `collectionRegex`<sup>Optional</sup> <a name="collectionRegex" id="awscdk-resources-mongodbatlas.DataLakeDatabaseDataSourceView.property.collectionRegex"></a>

```typescript
public readonly collectionRegex: string;
```

- *Type:* string

Regex pattern to use for creating the wildcard (*) collection.

To learn more about the regex syntax, see [Go programming language](https://pkg.go.dev/regexp).

---

##### `database`<sup>Optional</sup> <a name="database" id="awscdk-resources-mongodbatlas.DataLakeDatabaseDataSourceView.property.database"></a>

```typescript
public readonly database: string;
```

- *Type:* string

Human-readable label that identifies the database, which contains the collection in the cluster.

You must omit this parameter to generate wildcard (`*`) collections for dynamically generated databases.

---

##### `defaultFormat`<sup>Optional</sup> <a name="defaultFormat" id="awscdk-resources-mongodbatlas.DataLakeDatabaseDataSourceView.property.defaultFormat"></a>

```typescript
public readonly defaultFormat: DataLakeDatabaseDataSourceViewDefaultFormat;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.DataLakeDatabaseDataSourceViewDefaultFormat">DataLakeDatabaseDataSourceViewDefaultFormat</a>

File format that MongoDB Cloud uses if it encounters a file without a file extension while searching **storeName**.

---

##### `path`<sup>Optional</sup> <a name="path" id="awscdk-resources-mongodbatlas.DataLakeDatabaseDataSourceView.property.path"></a>

```typescript
public readonly path: string;
```

- *Type:* string

File path that controls how MongoDB Cloud searches for and parses files in the **storeName** before mapping them to a collection.Specify ``/`` to capture all files and folders from the ``prefix`` path.

---

##### `storeName`<sup>Optional</sup> <a name="storeName" id="awscdk-resources-mongodbatlas.DataLakeDatabaseDataSourceView.property.storeName"></a>

```typescript
public readonly storeName: string;
```

- *Type:* string

Human-readable label that identifies the data store that MongoDB Cloud maps to the collection.

---

##### `urls`<sup>Optional</sup> <a name="urls" id="awscdk-resources-mongodbatlas.DataLakeDatabaseDataSourceView.property.urls"></a>

```typescript
public readonly urls: string[];
```

- *Type:* string[]

URLs of the publicly accessible data files.

You can't specify URLs that require authentication. Atlas Data Lake creates a partition for each URL. If empty or omitted, Data Lake uses the URLs from the store specified in the **dataSources.storeName** parameter.

---

### DataLakeDatabaseView <a name="DataLakeDatabaseView" id="awscdk-resources-mongodbatlas.DataLakeDatabaseView"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.DataLakeDatabaseView.Initializer"></a>

```typescript
import { DataLakeDatabaseView } from 'awscdk-resources-mongodbatlas'

const dataLakeDatabaseView: DataLakeDatabaseView = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeDatabaseView.property.collections">collections</a></code> | <code><a href="#awscdk-resources-mongodbatlas.DataLakeDatabaseCollectionView">DataLakeDatabaseCollectionView</a>[]</code> | Array of collections and data sources that map to a ``stores`` data store. |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeDatabaseView.property.maxWildcardCollections">maxWildcardCollections</a></code> | <code>number</code> | Maximum number of wildcard collections in the database. |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeDatabaseView.property.name">name</a></code> | <code>string</code> | Human-readable label that identifies the database to which the data lake maps data. |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeDatabaseView.property.views">views</a></code> | <code><a href="#awscdk-resources-mongodbatlas.DataLakeViewView">DataLakeViewView</a>[]</code> | Array of aggregation pipelines that apply to the collection. |

---

##### `collections`<sup>Optional</sup> <a name="collections" id="awscdk-resources-mongodbatlas.DataLakeDatabaseView.property.collections"></a>

```typescript
public readonly collections: DataLakeDatabaseCollectionView[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.DataLakeDatabaseCollectionView">DataLakeDatabaseCollectionView</a>[]

Array of collections and data sources that map to a ``stores`` data store.

---

##### `maxWildcardCollections`<sup>Optional</sup> <a name="maxWildcardCollections" id="awscdk-resources-mongodbatlas.DataLakeDatabaseView.property.maxWildcardCollections"></a>

```typescript
public readonly maxWildcardCollections: number;
```

- *Type:* number

Maximum number of wildcard collections in the database.

This only applies to S3 data sources.

---

##### `name`<sup>Optional</sup> <a name="name" id="awscdk-resources-mongodbatlas.DataLakeDatabaseView.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Human-readable label that identifies the database to which the data lake maps data.

---

##### `views`<sup>Optional</sup> <a name="views" id="awscdk-resources-mongodbatlas.DataLakeDatabaseView.property.views"></a>

```typescript
public readonly views: DataLakeViewView[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.DataLakeViewView">DataLakeViewView</a>[]

Array of aggregation pipelines that apply to the collection.

This only applies to S3 data sources.

---

### DataLakeDataProcessRegionView <a name="DataLakeDataProcessRegionView" id="awscdk-resources-mongodbatlas.DataLakeDataProcessRegionView"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.DataLakeDataProcessRegionView.Initializer"></a>

```typescript
import { DataLakeDataProcessRegionView } from 'awscdk-resources-mongodbatlas'

const dataLakeDataProcessRegionView: DataLakeDataProcessRegionView = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeDataProcessRegionView.property.cloudProvider">cloudProvider</a></code> | <code><a href="#awscdk-resources-mongodbatlas.DataLakeDataProcessRegionViewCloudProvider">DataLakeDataProcessRegionViewCloudProvider</a></code> | Name of the cloud service that hosts the data lake's data stores. |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeDataProcessRegionView.property.region">region</a></code> | <code><a href="#awscdk-resources-mongodbatlas.DataLakeDataProcessRegionViewRegion">DataLakeDataProcessRegionViewRegion</a></code> | Name of the region to which the data lake routes client connections. |

---

##### `cloudProvider`<sup>Optional</sup> <a name="cloudProvider" id="awscdk-resources-mongodbatlas.DataLakeDataProcessRegionView.property.cloudProvider"></a>

```typescript
public readonly cloudProvider: DataLakeDataProcessRegionViewCloudProvider;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.DataLakeDataProcessRegionViewCloudProvider">DataLakeDataProcessRegionViewCloudProvider</a>

Name of the cloud service that hosts the data lake's data stores.

---

##### `region`<sup>Optional</sup> <a name="region" id="awscdk-resources-mongodbatlas.DataLakeDataProcessRegionView.property.region"></a>

```typescript
public readonly region: DataLakeDataProcessRegionViewRegion;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.DataLakeDataProcessRegionViewRegion">DataLakeDataProcessRegionViewRegion</a>

Name of the region to which the data lake routes client connections.

---

### DataLakeStorageView <a name="DataLakeStorageView" id="awscdk-resources-mongodbatlas.DataLakeStorageView"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.DataLakeStorageView.Initializer"></a>

```typescript
import { DataLakeStorageView } from 'awscdk-resources-mongodbatlas'

const dataLakeStorageView: DataLakeStorageView = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeStorageView.property.databases">databases</a></code> | <code><a href="#awscdk-resources-mongodbatlas.DataLakeDatabaseView">DataLakeDatabaseView</a>[]</code> | Array that contains the queryable databases and collections for this data lake. |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeStorageView.property.stores">stores</a></code> | <code><a href="#awscdk-resources-mongodbatlas.StoreDetail">StoreDetail</a>[]</code> | Array that contains the data stores for the data lake. |

---

##### `databases`<sup>Optional</sup> <a name="databases" id="awscdk-resources-mongodbatlas.DataLakeStorageView.property.databases"></a>

```typescript
public readonly databases: DataLakeDatabaseView[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.DataLakeDatabaseView">DataLakeDatabaseView</a>[]

Array that contains the queryable databases and collections for this data lake.

---

##### `stores`<sup>Optional</sup> <a name="stores" id="awscdk-resources-mongodbatlas.DataLakeStorageView.property.stores"></a>

```typescript
public readonly stores: StoreDetail[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.StoreDetail">StoreDetail</a>[]

Array that contains the data stores for the data lake.

---

### DataLakeViewView <a name="DataLakeViewView" id="awscdk-resources-mongodbatlas.DataLakeViewView"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.DataLakeViewView.Initializer"></a>

```typescript
import { DataLakeViewView } from 'awscdk-resources-mongodbatlas'

const dataLakeViewView: DataLakeViewView = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeViewView.property.name">name</a></code> | <code>string</code> | Human-readable label that identifies the view, which corresponds to an aggregation pipeline on a collection. |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeViewView.property.pipeline">pipeline</a></code> | <code>string</code> | Aggregation pipeline stages to apply to the source collection. |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeViewView.property.source">source</a></code> | <code>string</code> | Human-readable label that identifies the source collection for the view. |

---

##### `name`<sup>Optional</sup> <a name="name" id="awscdk-resources-mongodbatlas.DataLakeViewView.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Human-readable label that identifies the view, which corresponds to an aggregation pipeline on a collection.

---

##### `pipeline`<sup>Optional</sup> <a name="pipeline" id="awscdk-resources-mongodbatlas.DataLakeViewView.property.pipeline"></a>

```typescript
public readonly pipeline: string;
```

- *Type:* string

Aggregation pipeline stages to apply to the source collection.

---

##### `source`<sup>Optional</sup> <a name="source" id="awscdk-resources-mongodbatlas.DataLakeViewView.property.source"></a>

```typescript
public readonly source: string;
```

- *Type:* string

Human-readable label that identifies the source collection for the view.

---

### DataProcessRegion <a name="DataProcessRegion" id="awscdk-resources-mongodbatlas.DataProcessRegion"></a>

Information about the cloud provider region to which the data lake routes client connections.

MongoDB Cloud supports AWS only.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.DataProcessRegion.Initializer"></a>

```typescript
import { DataProcessRegion } from 'awscdk-resources-mongodbatlas'

const dataProcessRegion: DataProcessRegion = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.DataProcessRegion.property.region">region</a></code> | <code>string</code> | Name of the region to which the data lake routes client connections. |
| <code><a href="#awscdk-resources-mongodbatlas.DataProcessRegion.property.cloudProvider">cloudProvider</a></code> | <code>string</code> | Name of the cloud service that hosts the data lake's data stores. |

---

##### `region`<sup>Required</sup> <a name="region" id="awscdk-resources-mongodbatlas.DataProcessRegion.property.region"></a>

```typescript
public readonly region: string;
```

- *Type:* string

Name of the region to which the data lake routes client connections.

---

##### `cloudProvider`<sup>Optional</sup> <a name="cloudProvider" id="awscdk-resources-mongodbatlas.DataProcessRegion.property.cloudProvider"></a>

```typescript
public readonly cloudProvider: string;
```

- *Type:* string

Name of the cloud service that hosts the data lake's data stores.

---

### DataSource <a name="DataSource" id="awscdk-resources-mongodbatlas.DataSource"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.DataSource.Initializer"></a>

```typescript
import { DataSource } from 'awscdk-resources-mongodbatlas'

const dataSource: DataSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.DataSource.property.allowInsecure">allowInsecure</a></code> | <code>boolean</code> | Flag that validates the scheme in the specified URLs. |
| <code><a href="#awscdk-resources-mongodbatlas.DataSource.property.collection">collection</a></code> | <code>string</code> | Human-readable label that identifies the collection in the database. |
| <code><a href="#awscdk-resources-mongodbatlas.DataSource.property.collectionRegex">collectionRegex</a></code> | <code>string</code> | Regex pattern to use for creating the wildcard (*) collection. |
| <code><a href="#awscdk-resources-mongodbatlas.DataSource.property.database">database</a></code> | <code>string</code> | Human-readable label that identifies the database, which contains the collection in the cluster. |
| <code><a href="#awscdk-resources-mongodbatlas.DataSource.property.databaseRegex">databaseRegex</a></code> | <code>string</code> | Regex pattern to use for creating the wildcard (*) collection. |
| <code><a href="#awscdk-resources-mongodbatlas.DataSource.property.defaultFormat">defaultFormat</a></code> | <code>string</code> | File format that MongoDB Cloud uses if it encounters a file without a file extension while searching storeName.Enum: ".avro" ".avro.bz2" ".avro.gz" ".bson" ".bson.bz2" ".bson.gz" ".bsonx" ".csv" ".csv.bz2" ".csv.gz" ".json" ".json.bz2" ".json.gz" ".orc" ".parquet" ".tsv" ".tsv.bz2" ".tsv.gz". |
| <code><a href="#awscdk-resources-mongodbatlas.DataSource.property.path">path</a></code> | <code>string</code> | File path that controls how MongoDB Cloud searches for and parses files in the storeName before mapping them to a collection.Specify / to capture all files and folders from the prefix path. |
| <code><a href="#awscdk-resources-mongodbatlas.DataSource.property.provenanceFieldName">provenanceFieldName</a></code> | <code>string</code> | Name for the field that includes the provenance of the documents in the results. |
| <code><a href="#awscdk-resources-mongodbatlas.DataSource.property.storeName">storeName</a></code> | <code>string</code> | Human-readable label that identifies the data store that MongoDB Cloud maps to the collection. |
| <code><a href="#awscdk-resources-mongodbatlas.DataSource.property.urls">urls</a></code> | <code>string[]</code> | URLs of the publicly accessible data files. |

---

##### `allowInsecure`<sup>Optional</sup> <a name="allowInsecure" id="awscdk-resources-mongodbatlas.DataSource.property.allowInsecure"></a>

```typescript
public readonly allowInsecure: boolean;
```

- *Type:* boolean

Flag that validates the scheme in the specified URLs.

If true, allows insecure HTTP scheme, doesn't verify the server's certificate chain and hostname, and accepts any certificate with any hostname presented by the server. If false, allows secure HTTPS scheme only.

---

##### `collection`<sup>Optional</sup> <a name="collection" id="awscdk-resources-mongodbatlas.DataSource.property.collection"></a>

```typescript
public readonly collection: string;
```

- *Type:* string

Human-readable label that identifies the collection in the database.

For creating a wildcard (*) collection, you must omit this parameter.

---

##### `collectionRegex`<sup>Optional</sup> <a name="collectionRegex" id="awscdk-resources-mongodbatlas.DataSource.property.collectionRegex"></a>

```typescript
public readonly collectionRegex: string;
```

- *Type:* string

Regex pattern to use for creating the wildcard (*) collection.

To learn more about the regex syntax, see Go programming language.( https://pkg.go.dev/regexp ).

---

##### `database`<sup>Optional</sup> <a name="database" id="awscdk-resources-mongodbatlas.DataSource.property.database"></a>

```typescript
public readonly database: string;
```

- *Type:* string

Human-readable label that identifies the database, which contains the collection in the cluster.

You must omit this parameter to generate wildcard (*) collections for dynamically generated databases.

---

##### `databaseRegex`<sup>Optional</sup> <a name="databaseRegex" id="awscdk-resources-mongodbatlas.DataSource.property.databaseRegex"></a>

```typescript
public readonly databaseRegex: string;
```

- *Type:* string

Regex pattern to use for creating the wildcard (*) collection.

To learn more about the regex syntax, see Go programming language.( https://pkg.go.dev/regexp ).

---

##### `defaultFormat`<sup>Optional</sup> <a name="defaultFormat" id="awscdk-resources-mongodbatlas.DataSource.property.defaultFormat"></a>

```typescript
public readonly defaultFormat: string;
```

- *Type:* string

File format that MongoDB Cloud uses if it encounters a file without a file extension while searching storeName.Enum: ".avro" ".avro.bz2" ".avro.gz" ".bson" ".bson.bz2" ".bson.gz" ".bsonx" ".csv" ".csv.bz2" ".csv.gz" ".json" ".json.bz2" ".json.gz" ".orc" ".parquet" ".tsv" ".tsv.bz2" ".tsv.gz".

---

##### `path`<sup>Optional</sup> <a name="path" id="awscdk-resources-mongodbatlas.DataSource.property.path"></a>

```typescript
public readonly path: string;
```

- *Type:* string

File path that controls how MongoDB Cloud searches for and parses files in the storeName before mapping them to a collection.Specify / to capture all files and folders from the prefix path.

---

##### `provenanceFieldName`<sup>Optional</sup> <a name="provenanceFieldName" id="awscdk-resources-mongodbatlas.DataSource.property.provenanceFieldName"></a>

```typescript
public readonly provenanceFieldName: string;
```

- *Type:* string

Name for the field that includes the provenance of the documents in the results.

MongoDB Cloud returns different fields in the results for each supported provider.

---

##### `storeName`<sup>Optional</sup> <a name="storeName" id="awscdk-resources-mongodbatlas.DataSource.property.storeName"></a>

```typescript
public readonly storeName: string;
```

- *Type:* string

Human-readable label that identifies the data store that MongoDB Cloud maps to the collection.

---

##### `urls`<sup>Optional</sup> <a name="urls" id="awscdk-resources-mongodbatlas.DataSource.property.urls"></a>

```typescript
public readonly urls: string[];
```

- *Type:* string[]

URLs of the publicly accessible data files.

You can't specify URLs that require authentication. Atlas Data Lake creates a partition for each URL. If empty or omitted, Data Lake uses the URLs from the store specified in the dataSources.storeName parameter.

---

### DbRoleToExecute <a name="DbRoleToExecute" id="awscdk-resources-mongodbatlas.DbRoleToExecute"></a>

The name of a Built in or Custom DB Role to connect to an Atlas Cluster.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.DbRoleToExecute.Initializer"></a>

```typescript
import { DbRoleToExecute } from 'awscdk-resources-mongodbatlas'

const dbRoleToExecute: DbRoleToExecute = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.DbRoleToExecute.property.role">role</a></code> | <code>string</code> | The name of the role to use. |
| <code><a href="#awscdk-resources-mongodbatlas.DbRoleToExecute.property.type">type</a></code> | <code><a href="#awscdk-resources-mongodbatlas.DbRoleToExecuteType">DbRoleToExecuteType</a></code> | Type of the DB role. |

---

##### `role`<sup>Optional</sup> <a name="role" id="awscdk-resources-mongodbatlas.DbRoleToExecute.property.role"></a>

```typescript
public readonly role: string;
```

- *Type:* string

The name of the role to use.

Can be a built in role or a custom role.

---

##### `type`<sup>Optional</sup> <a name="type" id="awscdk-resources-mongodbatlas.DbRoleToExecute.property.type"></a>

```typescript
public readonly type: DbRoleToExecuteType;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.DbRoleToExecuteType">DbRoleToExecuteType</a>

Type of the DB role.

Can be either BuiltIn or Custom.

---

### DiskGb <a name="DiskGb" id="awscdk-resources-mongodbatlas.DiskGb"></a>

Automatic cluster storage settings that apply to this cluster.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.DiskGb.Initializer"></a>

```typescript
import { DiskGb } from 'awscdk-resources-mongodbatlas'

const diskGb: DiskGb = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.DiskGb.property.enabled">enabled</a></code> | <code>boolean</code> | Flag that indicates whether this cluster enables disk auto-scaling. |

---

##### `enabled`<sup>Optional</sup> <a name="enabled" id="awscdk-resources-mongodbatlas.DiskGb.property.enabled"></a>

```typescript
public readonly enabled: boolean;
```

- *Type:* boolean

Flag that indicates whether this cluster enables disk auto-scaling.

The maximum memory allowed for the selected cluster tier and the oplog size can limit storage auto-scaling.

---

### EncryptionAtRestProps <a name="EncryptionAtRestProps" id="awscdk-resources-mongodbatlas.EncryptionAtRestProps"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.EncryptionAtRestProps.Initializer"></a>

```typescript
import { EncryptionAtRestProps } from 'awscdk-resources-mongodbatlas'

const encryptionAtRestProps: EncryptionAtRestProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.EncryptionAtRestProps.property.customerMasterKeyId">customerMasterKeyId</a></code> | <code>string</code> | The AWS customer master key used to encrypt and decrypt the MongoDB master keys. |
| <code><a href="#awscdk-resources-mongodbatlas.EncryptionAtRestProps.property.roleId">roleId</a></code> | <code>string</code> | ID of an AWS IAM role authorized to manage an AWS customer master key. |
| <code><a href="#awscdk-resources-mongodbatlas.EncryptionAtRestProps.property.enabledEncryptionAtRest">enabledEncryptionAtRest</a></code> | <code>boolean</code> | Specifies whether Encryption at Rest is enabled for an Atlas project. |
| <code><a href="#awscdk-resources-mongodbatlas.EncryptionAtRestProps.property.region">region</a></code> | <code>string</code> | The AWS region in which the AWS customer master key exists. |

---

##### `customerMasterKeyId`<sup>Required</sup> <a name="customerMasterKeyId" id="awscdk-resources-mongodbatlas.EncryptionAtRestProps.property.customerMasterKeyId"></a>

```typescript
public readonly customerMasterKeyId: string;
```

- *Type:* string

The AWS customer master key used to encrypt and decrypt the MongoDB master keys.

---

##### `roleId`<sup>Required</sup> <a name="roleId" id="awscdk-resources-mongodbatlas.EncryptionAtRestProps.property.roleId"></a>

```typescript
public readonly roleId: string;
```

- *Type:* string

ID of an AWS IAM role authorized to manage an AWS customer master key.

---

##### `enabledEncryptionAtRest`<sup>Optional</sup> <a name="enabledEncryptionAtRest" id="awscdk-resources-mongodbatlas.EncryptionAtRestProps.property.enabledEncryptionAtRest"></a>

```typescript
public readonly enabledEncryptionAtRest: boolean;
```

- *Type:* boolean

Specifies whether Encryption at Rest is enabled for an Atlas project.

To disable Encryption at Rest, pass only this parameter with a value of false. When you disable Encryption at Rest, Atlas also removes the configuration details.
Default Value: true

---

##### `region`<sup>Optional</sup> <a name="region" id="awscdk-resources-mongodbatlas.EncryptionAtRestProps.property.region"></a>

```typescript
public readonly region: string;
```

- *Type:* string

The AWS region in which the AWS customer master key exists.

---

### Event <a name="Event" id="awscdk-resources-mongodbatlas.Event"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.Event.Initializer"></a>

```typescript
import { Event } from 'awscdk-resources-mongodbatlas'

const event: Event = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.Event.property.awseventbridge">awseventbridge</a></code> | <code><a href="#awscdk-resources-mongodbatlas.EventAwseventbridge">EventAwseventbridge</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.Event.property.function">function</a></code> | <code><a href="#awscdk-resources-mongodbatlas.EventFunction">EventFunction</a></code> | *No description.* |

---

##### `awseventbridge`<sup>Optional</sup> <a name="awseventbridge" id="awscdk-resources-mongodbatlas.Event.property.awseventbridge"></a>

```typescript
public readonly awseventbridge: EventAwseventbridge;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.EventAwseventbridge">EventAwseventbridge</a>

---

##### `function`<sup>Optional</sup> <a name="function" id="awscdk-resources-mongodbatlas.Event.property.function"></a>

```typescript
public readonly function: EventFunction;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.EventFunction">EventFunction</a>

---

### EventAwseventbridge <a name="EventAwseventbridge" id="awscdk-resources-mongodbatlas.EventAwseventbridge"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.EventAwseventbridge.Initializer"></a>

```typescript
import { EventAwseventbridge } from 'awscdk-resources-mongodbatlas'

const eventAwseventbridge: EventAwseventbridge = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.EventAwseventbridge.property.awsConfig">awsConfig</a></code> | <code><a href="#awscdk-resources-mongodbatlas.EventAwseventbridgeAwsConfig">EventAwseventbridgeAwsConfig</a></code> | *No description.* |

---

##### `awsConfig`<sup>Optional</sup> <a name="awsConfig" id="awscdk-resources-mongodbatlas.EventAwseventbridge.property.awsConfig"></a>

```typescript
public readonly awsConfig: EventAwseventbridgeAwsConfig;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.EventAwseventbridgeAwsConfig">EventAwseventbridgeAwsConfig</a>

---

### EventAwseventbridgeAwsConfig <a name="EventAwseventbridgeAwsConfig" id="awscdk-resources-mongodbatlas.EventAwseventbridgeAwsConfig"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.EventAwseventbridgeAwsConfig.Initializer"></a>

```typescript
import { EventAwseventbridgeAwsConfig } from 'awscdk-resources-mongodbatlas'

const eventAwseventbridgeAwsConfig: EventAwseventbridgeAwsConfig = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.EventAwseventbridgeAwsConfig.property.accountId">accountId</a></code> | <code>string</code> | An AWS Account ID. |
| <code><a href="#awscdk-resources-mongodbatlas.EventAwseventbridgeAwsConfig.property.extendedJsonEnabled">extendedJsonEnabled</a></code> | <code>boolean</code> | If `true`, event objects are serialized using EJSON. |
| <code><a href="#awscdk-resources-mongodbatlas.EventAwseventbridgeAwsConfig.property.region">region</a></code> | <code>string</code> | An AWS region. |

---

##### `accountId`<sup>Optional</sup> <a name="accountId" id="awscdk-resources-mongodbatlas.EventAwseventbridgeAwsConfig.property.accountId"></a>

```typescript
public readonly accountId: string;
```

- *Type:* string

An AWS Account ID.

---

##### `extendedJsonEnabled`<sup>Optional</sup> <a name="extendedJsonEnabled" id="awscdk-resources-mongodbatlas.EventAwseventbridgeAwsConfig.property.extendedJsonEnabled"></a>

```typescript
public readonly extendedJsonEnabled: boolean;
```

- *Type:* boolean

If `true`, event objects are serialized using EJSON.

---

##### `region`<sup>Optional</sup> <a name="region" id="awscdk-resources-mongodbatlas.EventAwseventbridgeAwsConfig.property.region"></a>

```typescript
public readonly region: string;
```

- *Type:* string

An AWS region.

---

### EventFunction <a name="EventFunction" id="awscdk-resources-mongodbatlas.EventFunction"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.EventFunction.Initializer"></a>

```typescript
import { EventFunction } from 'awscdk-resources-mongodbatlas'

const eventFunction: EventFunction = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.EventFunction.property.funcConfig">funcConfig</a></code> | <code><a href="#awscdk-resources-mongodbatlas.EventFunctionFuncConfig">EventFunctionFuncConfig</a></code> | *No description.* |

---

##### `funcConfig`<sup>Optional</sup> <a name="funcConfig" id="awscdk-resources-mongodbatlas.EventFunction.property.funcConfig"></a>

```typescript
public readonly funcConfig: EventFunctionFuncConfig;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.EventFunctionFuncConfig">EventFunctionFuncConfig</a>

---

### EventFunctionFuncConfig <a name="EventFunctionFuncConfig" id="awscdk-resources-mongodbatlas.EventFunctionFuncConfig"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.EventFunctionFuncConfig.Initializer"></a>

```typescript
import { EventFunctionFuncConfig } from 'awscdk-resources-mongodbatlas'

const eventFunctionFuncConfig: EventFunctionFuncConfig = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.EventFunctionFuncConfig.property.functionId">functionId</a></code> | <code>string</code> | The ID of the function that the trigger calls when it fires. |
| <code><a href="#awscdk-resources-mongodbatlas.EventFunctionFuncConfig.property.functionName">functionName</a></code> | <code>string</code> | The name of the function that the trigger calls when it fires, i.e. the function described by `function_id`. |

---

##### `functionId`<sup>Optional</sup> <a name="functionId" id="awscdk-resources-mongodbatlas.EventFunctionFuncConfig.property.functionId"></a>

```typescript
public readonly functionId: string;
```

- *Type:* string

The ID of the function that the trigger calls when it fires.

This value is the same as the root-level `function_id`.
You can either define the value here or in `function_id`.
The App Services backend duplicates the value to the configuration location where you did not define it.

For example, if you define `event_processors.FUNCTION.function_id`, the backend duplicates it to `function_id`.

---

##### `functionName`<sup>Optional</sup> <a name="functionName" id="awscdk-resources-mongodbatlas.EventFunctionFuncConfig.property.functionName"></a>

```typescript
public readonly functionName: string;
```

- *Type:* string

The name of the function that the trigger calls when it fires, i.e. the function described by `function_id`.

This value is the same as the root-level `function_name`.
You can either define the value here or in `function_name`.
The App Services backend duplicates the value to the configuration location where you did not define it.

For example, if you define `event_processors.FUNCTION.function_name`, the backend duplicates it to `function_name`.

---

### Export <a name="Export" id="awscdk-resources-mongodbatlas.Export"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.Export.Initializer"></a>

```typescript
import { Export } from 'awscdk-resources-mongodbatlas'

const export: Export = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.Export.property.exportBucketId">exportBucketId</a></code> | <code>string</code> | Unique identifier of the AWS bucket to export the cloud backup snapshot to. |
| <code><a href="#awscdk-resources-mongodbatlas.Export.property.frequencyType">frequencyType</a></code> | <code>string</code> | Frequency associated with the export policy. |

---

##### `exportBucketId`<sup>Optional</sup> <a name="exportBucketId" id="awscdk-resources-mongodbatlas.Export.property.exportBucketId"></a>

```typescript
public readonly exportBucketId: string;
```

- *Type:* string

Unique identifier of the AWS bucket to export the cloud backup snapshot to.

---

##### `frequencyType`<sup>Optional</sup> <a name="frequencyType" id="awscdk-resources-mongodbatlas.Export.property.frequencyType"></a>

```typescript
public readonly frequencyType: string;
```

- *Type:* string

Frequency associated with the export policy.

Value can be daily, weekly, or monthly.

---

### Filter <a name="Filter" id="awscdk-resources-mongodbatlas.Filter"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.Filter.Initializer"></a>

```typescript
import { Filter } from 'awscdk-resources-mongodbatlas'

const filter: Filter = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.Filter.property.cloudProvider">cloudProvider</a></code> | <code><a href="#awscdk-resources-mongodbatlas.FilterCloudProvider">FilterCloudProvider</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.Filter.property.region">region</a></code> | <code>string</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.Filter.property.type">type</a></code> | <code>string</code> | *No description.* |

---

##### `cloudProvider`<sup>Optional</sup> <a name="cloudProvider" id="awscdk-resources-mongodbatlas.Filter.property.cloudProvider"></a>

```typescript
public readonly cloudProvider: FilterCloudProvider;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.FilterCloudProvider">FilterCloudProvider</a>

---

##### `region`<sup>Optional</sup> <a name="region" id="awscdk-resources-mongodbatlas.Filter.property.region"></a>

```typescript
public readonly region: string;
```

- *Type:* string

---

##### `type`<sup>Optional</sup> <a name="type" id="awscdk-resources-mongodbatlas.Filter.property.type"></a>

```typescript
public readonly type: string;
```

- *Type:* string

---

### InheritedRole <a name="InheritedRole" id="awscdk-resources-mongodbatlas.InheritedRole"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.InheritedRole.Initializer"></a>

```typescript
import { InheritedRole } from 'awscdk-resources-mongodbatlas'

const inheritedRole: InheritedRole = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.InheritedRole.property.db">db</a></code> | <code>string</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.InheritedRole.property.role">role</a></code> | <code>string</code> | *No description.* |

---

##### `db`<sup>Optional</sup> <a name="db" id="awscdk-resources-mongodbatlas.InheritedRole.property.db"></a>

```typescript
public readonly db: string;
```

- *Type:* string

---

##### `role`<sup>Optional</sup> <a name="role" id="awscdk-resources-mongodbatlas.InheritedRole.property.role"></a>

```typescript
public readonly role: string;
```

- *Type:* string

---

### IntegerThresholdView <a name="IntegerThresholdView" id="awscdk-resources-mongodbatlas.IntegerThresholdView"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.IntegerThresholdView.Initializer"></a>

```typescript
import { IntegerThresholdView } from 'awscdk-resources-mongodbatlas'

const integerThresholdView: IntegerThresholdView = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.IntegerThresholdView.property.operator">operator</a></code> | <code><a href="#awscdk-resources-mongodbatlas.IntegerThresholdViewOperator">IntegerThresholdViewOperator</a></code> | Comparison operator to apply when checking the current metric value. |
| <code><a href="#awscdk-resources-mongodbatlas.IntegerThresholdView.property.threshold">threshold</a></code> | <code>number</code> | Value of metric that, when exceeded, triggers an alert. |
| <code><a href="#awscdk-resources-mongodbatlas.IntegerThresholdView.property.units">units</a></code> | <code>string</code> | Element used to express the quantity. |

---

##### `operator`<sup>Optional</sup> <a name="operator" id="awscdk-resources-mongodbatlas.IntegerThresholdView.property.operator"></a>

```typescript
public readonly operator: IntegerThresholdViewOperator;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.IntegerThresholdViewOperator">IntegerThresholdViewOperator</a>

Comparison operator to apply when checking the current metric value.

---

##### `threshold`<sup>Optional</sup> <a name="threshold" id="awscdk-resources-mongodbatlas.IntegerThresholdView.property.threshold"></a>

```typescript
public readonly threshold: number;
```

- *Type:* number

Value of metric that, when exceeded, triggers an alert.

---

##### `units`<sup>Optional</sup> <a name="units" id="awscdk-resources-mongodbatlas.IntegerThresholdView.property.units"></a>

```typescript
public readonly units: string;
```

- *Type:* string

Element used to express the quantity.

This can be an element of time, storage capacity, and the like.

---

### IpAccessListProps <a name="IpAccessListProps" id="awscdk-resources-mongodbatlas.IpAccessListProps"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.IpAccessListProps.Initializer"></a>

```typescript
import { IpAccessListProps } from 'awscdk-resources-mongodbatlas'

const ipAccessListProps: IpAccessListProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.IpAccessListProps.property.accessList">accessList</a></code> | <code><a href="#awscdk-resources-mongodbatlas.AccessListDefinition">AccessListDefinition</a>[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.IpAccessListProps.property.listOptions">listOptions</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ListOptions">ListOptions</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.IpAccessListProps.property.projectId">projectId</a></code> | <code>string</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.IpAccessListProps.property.totalCount">totalCount</a></code> | <code>number</code> | *No description.* |

---

##### `accessList`<sup>Required</sup> <a name="accessList" id="awscdk-resources-mongodbatlas.IpAccessListProps.property.accessList"></a>

```typescript
public readonly accessList: AccessListDefinition[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.AccessListDefinition">AccessListDefinition</a>[]

---

##### `listOptions`<sup>Optional</sup> <a name="listOptions" id="awscdk-resources-mongodbatlas.IpAccessListProps.property.listOptions"></a>

```typescript
public readonly listOptions: ListOptions;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ListOptions">ListOptions</a>

---

##### `projectId`<sup>Optional</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.IpAccessListProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string
- *Default:* allow-all

---

##### `totalCount`<sup>Optional</sup> <a name="totalCount" id="awscdk-resources-mongodbatlas.IpAccessListProps.property.totalCount"></a>

```typescript
public readonly totalCount: number;
```

- *Type:* number

---

### LabelDefinition <a name="LabelDefinition" id="awscdk-resources-mongodbatlas.LabelDefinition"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.LabelDefinition.Initializer"></a>

```typescript
import { LabelDefinition } from 'awscdk-resources-mongodbatlas'

const labelDefinition: LabelDefinition = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.LabelDefinition.property.key">key</a></code> | <code>string</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.LabelDefinition.property.value">value</a></code> | <code>string</code> | *No description.* |

---

##### `key`<sup>Optional</sup> <a name="key" id="awscdk-resources-mongodbatlas.LabelDefinition.property.key"></a>

```typescript
public readonly key: string;
```

- *Type:* string

---

##### `value`<sup>Optional</sup> <a name="value" id="awscdk-resources-mongodbatlas.LabelDefinition.property.value"></a>

```typescript
public readonly value: string;
```

- *Type:* string

---

### Link <a name="Link" id="awscdk-resources-mongodbatlas.Link"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.Link.Initializer"></a>

```typescript
import { Link } from 'awscdk-resources-mongodbatlas'

const link: Link = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.Link.property.href">href</a></code> | <code>string</code> | Uniform Resource Locator (URL) that points another API resource to which this response has some relationship. |
| <code><a href="#awscdk-resources-mongodbatlas.Link.property.rel">rel</a></code> | <code>string</code> | Uniform Resource Locator (URL) that defines the semantic relationship between this resource and another API resource. |

---

##### `href`<sup>Optional</sup> <a name="href" id="awscdk-resources-mongodbatlas.Link.property.href"></a>

```typescript
public readonly href: string;
```

- *Type:* string

Uniform Resource Locator (URL) that points another API resource to which this response has some relationship.

This URL often begins with `https://mms.mongodb.com`.

---

##### `rel`<sup>Optional</sup> <a name="rel" id="awscdk-resources-mongodbatlas.Link.property.rel"></a>

```typescript
public readonly rel: string;
```

- *Type:* string

Uniform Resource Locator (URL) that defines the semantic relationship between this resource and another API resource.

This URL often begins with `https://mms.mongodb.com`.

---

### ListOptions <a name="ListOptions" id="awscdk-resources-mongodbatlas.ListOptions"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.ListOptions.Initializer"></a>

```typescript
import { ListOptions } from 'awscdk-resources-mongodbatlas'

const listOptions: ListOptions = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.ListOptions.property.includeCount">includeCount</a></code> | <code>boolean</code> | Flag that indicates whether the response returns the total number of items (totalCount) in the response. |
| <code><a href="#awscdk-resources-mongodbatlas.ListOptions.property.itemsPerPage">itemsPerPage</a></code> | <code>number</code> | Number of items that the response returns per page. |
| <code><a href="#awscdk-resources-mongodbatlas.ListOptions.property.pageNum">pageNum</a></code> | <code>number</code> | Number of the page that displays the current set of the total objects that the response returns. |

---

##### `includeCount`<sup>Optional</sup> <a name="includeCount" id="awscdk-resources-mongodbatlas.ListOptions.property.includeCount"></a>

```typescript
public readonly includeCount: boolean;
```

- *Type:* boolean

Flag that indicates whether the response returns the total number of items (totalCount) in the response.

---

##### `itemsPerPage`<sup>Optional</sup> <a name="itemsPerPage" id="awscdk-resources-mongodbatlas.ListOptions.property.itemsPerPage"></a>

```typescript
public readonly itemsPerPage: number;
```

- *Type:* number

Number of items that the response returns per page.

---

##### `pageNum`<sup>Optional</sup> <a name="pageNum" id="awscdk-resources-mongodbatlas.ListOptions.property.pageNum"></a>

```typescript
public readonly pageNum: number;
```

- *Type:* number

Number of the page that displays the current set of the total objects that the response returns.

---

### ManagedNamespace <a name="ManagedNamespace" id="awscdk-resources-mongodbatlas.ManagedNamespace"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.ManagedNamespace.Initializer"></a>

```typescript
import { ManagedNamespace } from 'awscdk-resources-mongodbatlas'

const managedNamespace: ManagedNamespace = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.ManagedNamespace.property.collection">collection</a></code> | <code>string</code> | Human-readable label of the collection to manage for this Global Cluster. |
| <code><a href="#awscdk-resources-mongodbatlas.ManagedNamespace.property.customShardKey">customShardKey</a></code> | <code>string</code> | Database parameter used to divide the *collection* into shards. |
| <code><a href="#awscdk-resources-mongodbatlas.ManagedNamespace.property.db">db</a></code> | <code>string</code> | Human-readable label of the database to manage for this Global Cluster. |
| <code><a href="#awscdk-resources-mongodbatlas.ManagedNamespace.property.isCustomShardKeyHashed">isCustomShardKeyHashed</a></code> | <code>boolean</code> | Flag that indicates whether someone hashed the custom shard key for the specified collection. |
| <code><a href="#awscdk-resources-mongodbatlas.ManagedNamespace.property.isShardKeyUnique">isShardKeyUnique</a></code> | <code>boolean</code> | Flag that indicates whether someone [hashed](https://www.mongodb.com/docs/manual/reference/method/sh.shardCollection/#hashed-shard-keys) the custom shard key. If this parameter returns `false`, this cluster uses [ranged sharding](https://www.mongodb.com/docs/manual/core/ranged-sharding/). |

---

##### `collection`<sup>Optional</sup> <a name="collection" id="awscdk-resources-mongodbatlas.ManagedNamespace.property.collection"></a>

```typescript
public readonly collection: string;
```

- *Type:* string

Human-readable label of the collection to manage for this Global Cluster.

---

##### `customShardKey`<sup>Optional</sup> <a name="customShardKey" id="awscdk-resources-mongodbatlas.ManagedNamespace.property.customShardKey"></a>

```typescript
public readonly customShardKey: string;
```

- *Type:* string

Database parameter used to divide the *collection* into shards.

Global clusters require a compound shard key. This compound shard key combines the location parameter and the user-selected custom key.

---

##### `db`<sup>Optional</sup> <a name="db" id="awscdk-resources-mongodbatlas.ManagedNamespace.property.db"></a>

```typescript
public readonly db: string;
```

- *Type:* string

Human-readable label of the database to manage for this Global Cluster.

---

##### `isCustomShardKeyHashed`<sup>Optional</sup> <a name="isCustomShardKeyHashed" id="awscdk-resources-mongodbatlas.ManagedNamespace.property.isCustomShardKeyHashed"></a>

```typescript
public readonly isCustomShardKeyHashed: boolean;
```

- *Type:* boolean

Flag that indicates whether someone hashed the custom shard key for the specified collection.

If you set this value to `false`, MongoDB Cloud uses ranged sharding.

---

##### `isShardKeyUnique`<sup>Optional</sup> <a name="isShardKeyUnique" id="awscdk-resources-mongodbatlas.ManagedNamespace.property.isShardKeyUnique"></a>

```typescript
public readonly isShardKeyUnique: boolean;
```

- *Type:* boolean

Flag that indicates whether someone [hashed](https://www.mongodb.com/docs/manual/reference/method/sh.shardCollection/#hashed-shard-keys) the custom shard key. If this parameter returns `false`, this cluster uses [ranged sharding](https://www.mongodb.com/docs/manual/core/ranged-sharding/).

---

### Matcher <a name="Matcher" id="awscdk-resources-mongodbatlas.Matcher"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.Matcher.Initializer"></a>

```typescript
import { Matcher } from 'awscdk-resources-mongodbatlas'

const matcher: Matcher = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.Matcher.property.fieldName">fieldName</a></code> | <code><a href="#awscdk-resources-mongodbatlas.MatcherFieldName">MatcherFieldName</a></code> | Name of the parameter in the target object that MongoDB Cloud checks. |
| <code><a href="#awscdk-resources-mongodbatlas.Matcher.property.operator">operator</a></code> | <code><a href="#awscdk-resources-mongodbatlas.MatcherOperator">MatcherOperator</a></code> | Comparison operator to apply when checking the current metric value against **matcher[n].value**. |
| <code><a href="#awscdk-resources-mongodbatlas.Matcher.property.value">value</a></code> | <code>string</code> | Value to match or exceed using the specified **matchers.operator**. |

---

##### `fieldName`<sup>Optional</sup> <a name="fieldName" id="awscdk-resources-mongodbatlas.Matcher.property.fieldName"></a>

```typescript
public readonly fieldName: MatcherFieldName;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.MatcherFieldName">MatcherFieldName</a>

Name of the parameter in the target object that MongoDB Cloud checks.

The parameter must match all rules for MongoDB Cloud to check for alert configurations.

---

##### `operator`<sup>Optional</sup> <a name="operator" id="awscdk-resources-mongodbatlas.Matcher.property.operator"></a>

```typescript
public readonly operator: MatcherOperator;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.MatcherOperator">MatcherOperator</a>

Comparison operator to apply when checking the current metric value against **matcher[n].value**.

---

##### `value`<sup>Optional</sup> <a name="value" id="awscdk-resources-mongodbatlas.Matcher.property.value"></a>

```typescript
public readonly value: string;
```

- *Type:* string

Value to match or exceed using the specified **matchers.operator**.

---

### MetricThresholdView <a name="MetricThresholdView" id="awscdk-resources-mongodbatlas.MetricThresholdView"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.MetricThresholdView.Initializer"></a>

```typescript
import { MetricThresholdView } from 'awscdk-resources-mongodbatlas'

const metricThresholdView: MetricThresholdView = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.MetricThresholdView.property.metricName">metricName</a></code> | <code>string</code> | Human-readable label that identifies the metric against which MongoDB Cloud checks the configured **metricThreshold.threshold**. |
| <code><a href="#awscdk-resources-mongodbatlas.MetricThresholdView.property.mode">mode</a></code> | <code><a href="#awscdk-resources-mongodbatlas.MetricThresholdViewMode">MetricThresholdViewMode</a></code> | MongoDB Cloud computes the current metric value as an average. |
| <code><a href="#awscdk-resources-mongodbatlas.MetricThresholdView.property.operator">operator</a></code> | <code><a href="#awscdk-resources-mongodbatlas.MetricThresholdViewOperator">MetricThresholdViewOperator</a></code> | Comparison operator to apply when checking the current metric value. |
| <code><a href="#awscdk-resources-mongodbatlas.MetricThresholdView.property.threshold">threshold</a></code> | <code>number</code> | Value of metric that, when exceeded, triggers an alert. |
| <code><a href="#awscdk-resources-mongodbatlas.MetricThresholdView.property.units">units</a></code> | <code>string</code> | Element used to express the quantity. |

---

##### `metricName`<sup>Optional</sup> <a name="metricName" id="awscdk-resources-mongodbatlas.MetricThresholdView.property.metricName"></a>

```typescript
public readonly metricName: string;
```

- *Type:* string

Human-readable label that identifies the metric against which MongoDB Cloud checks the configured **metricThreshold.threshold**.

---

##### `mode`<sup>Optional</sup> <a name="mode" id="awscdk-resources-mongodbatlas.MetricThresholdView.property.mode"></a>

```typescript
public readonly mode: MetricThresholdViewMode;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.MetricThresholdViewMode">MetricThresholdViewMode</a>

MongoDB Cloud computes the current metric value as an average.

---

##### `operator`<sup>Optional</sup> <a name="operator" id="awscdk-resources-mongodbatlas.MetricThresholdView.property.operator"></a>

```typescript
public readonly operator: MetricThresholdViewOperator;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.MetricThresholdViewOperator">MetricThresholdViewOperator</a>

Comparison operator to apply when checking the current metric value.

---

##### `threshold`<sup>Optional</sup> <a name="threshold" id="awscdk-resources-mongodbatlas.MetricThresholdView.property.threshold"></a>

```typescript
public readonly threshold: number;
```

- *Type:* number

Value of metric that, when exceeded, triggers an alert.

---

##### `units`<sup>Optional</sup> <a name="units" id="awscdk-resources-mongodbatlas.MetricThresholdView.property.units"></a>

```typescript
public readonly units: string;
```

- *Type:* string

Element used to express the quantity.

This can be an element of time, storage capacity, and the like.

---

### MicrosoftTeamsIntegrationProps <a name="MicrosoftTeamsIntegrationProps" id="awscdk-resources-mongodbatlas.MicrosoftTeamsIntegrationProps"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.MicrosoftTeamsIntegrationProps.Initializer"></a>

```typescript
import { MicrosoftTeamsIntegrationProps } from 'awscdk-resources-mongodbatlas'

const microsoftTeamsIntegrationProps: MicrosoftTeamsIntegrationProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.MicrosoftTeamsIntegrationProps.property.projectId">projectId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies your project. |
| <code><a href="#awscdk-resources-mongodbatlas.MicrosoftTeamsIntegrationProps.property.profile">profile</a></code> | <code>string</code> | Atlas API keys. |
| <code><a href="#awscdk-resources-mongodbatlas.MicrosoftTeamsIntegrationProps.property.microsoftTeamsWebhookUrl">microsoftTeamsWebhookUrl</a></code> | <code>string</code> | Endpoint web address of the Microsoft Teams webhook to which MongoDB Cloud sends notifications. |

---

##### `projectId`<sup>Required</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.MicrosoftTeamsIntegrationProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies your project.

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.MicrosoftTeamsIntegrationProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

Atlas API keys.

---

##### `microsoftTeamsWebhookUrl`<sup>Required</sup> <a name="microsoftTeamsWebhookUrl" id="awscdk-resources-mongodbatlas.MicrosoftTeamsIntegrationProps.property.microsoftTeamsWebhookUrl"></a>

```typescript
public readonly microsoftTeamsWebhookUrl: string;
```

- *Type:* string

Endpoint web address of the Microsoft Teams webhook to which MongoDB Cloud sends notifications.

---

### NotificationView <a name="NotificationView" id="awscdk-resources-mongodbatlas.NotificationView"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.NotificationView.Initializer"></a>

```typescript
import { NotificationView } from 'awscdk-resources-mongodbatlas'

const notificationView: NotificationView = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationView.property.apiToken">apiToken</a></code> | <code>string</code> | Slack API token or Bot token that MongoDB Cloud needs to send alert notifications via Slack. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationView.property.channelName">channelName</a></code> | <code>string</code> | Name of the Slack channel to which MongoDB Cloud sends alert notifications. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationView.property.datadogApiKey">datadogApiKey</a></code> | <code>string</code> | Datadog API Key that MongoDB Cloud needs to send alert notifications to Datadog. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationView.property.datadogRegion">datadogRegion</a></code> | <code><a href="#awscdk-resources-mongodbatlas.NotificationViewDatadogRegion">NotificationViewDatadogRegion</a></code> | Datadog region that indicates which API Uniform Resource Locator (URL) to use. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationView.property.delayMin">delayMin</a></code> | <code>number</code> | Number of minutes that MongoDB Cloud waits after detecting an alert condition before it sends out the first notification. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationView.property.emailAddress">emailAddress</a></code> | <code>string</code> | Email address to which MongoDB Cloud sends alert notifications. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationView.property.emailEnabled">emailEnabled</a></code> | <code>boolean</code> | Flag that indicates whether MongoDB Cloud should send email notifications. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationView.property.flowdockApiToken">flowdockApiToken</a></code> | <code>string</code> | Flowdock API token that MongoDB Cloud needs to send alert notifications to Flowdock. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationView.property.flowName">flowName</a></code> | <code>string</code> | Flowdock flow name to which MongoDB Cloud sends alert notifications. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationView.property.intervalMin">intervalMin</a></code> | <code>number</code> | Number of minutes to wait between successive notifications. MongoDB Cloud sends notifications until someone acknowledges the unacknowledged alert. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationView.property.microsoftTeamsWebhookUrl">microsoftTeamsWebhookUrl</a></code> | <code>string</code> | Microsoft Teams Webhook Uniform Resource Locator (URL) that MongoDB Cloud needs to send this notification via Microsoft Teams. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationView.property.mobileNumber">mobileNumber</a></code> | <code>string</code> | Mobile phone number to which MongoDB Cloud sends alert notifications. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationView.property.notificationToken">notificationToken</a></code> | <code>string</code> | HipChat API token that MongoDB Cloud needs to send alert notifications to HipChat. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationView.property.opsGenieApiKey">opsGenieApiKey</a></code> | <code>string</code> | API Key that MongoDB Cloud needs to send this notification via Opsgenie. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationView.property.opsGenieRegion">opsGenieRegion</a></code> | <code><a href="#awscdk-resources-mongodbatlas.NotificationViewOpsGenieRegion">NotificationViewOpsGenieRegion</a></code> | Opsgenie region that indicates which API Uniform Resource Locator (URL) to use. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationView.property.orgName">orgName</a></code> | <code>string</code> | Flowdock organization name to which MongoDB Cloud sends alert notifications. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationView.property.roles">roles</a></code> | <code><a href="#awscdk-resources-mongodbatlas.NotificationViewRoles">NotificationViewRoles</a>[]</code> | List that contains the one or more organization or project roles that receive the configured alert. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationView.property.roomName">roomName</a></code> | <code>string</code> | HipChat API room name to which MongoDB Cloud sends alert notifications. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationView.property.serviceKey">serviceKey</a></code> | <code>string</code> | PagerDuty service key that MongoDB Cloud needs to send notifications via PagerDuty. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationView.property.severity">severity</a></code> | <code><a href="#awscdk-resources-mongodbatlas.NotificationViewSeverity">NotificationViewSeverity</a></code> | Degree of seriousness given to this notification. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationView.property.smsEnabled">smsEnabled</a></code> | <code>boolean</code> | Flag that indicates whether MongoDB Cloud should send text message notifications. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationView.property.teamId">teamId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies one MongoDB Cloud team. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationView.property.teamName">teamName</a></code> | <code>string</code> | Name of the MongoDB Cloud team that receives this notification. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationView.property.typeName">typeName</a></code> | <code><a href="#awscdk-resources-mongodbatlas.NotificationViewTypeName">NotificationViewTypeName</a></code> | Human-readable label that displays the alert notification type. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationView.property.username">username</a></code> | <code>string</code> | MongoDB Cloud username of the person to whom MongoDB Cloud sends notifications. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationView.property.victorOpsApiKey">victorOpsApiKey</a></code> | <code>string</code> | API key that MongoDB Cloud needs to send alert notifications to Splunk On-Call. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationView.property.victorOpsRoutingKey">victorOpsRoutingKey</a></code> | <code>string</code> | Routing key that MongoDB Cloud needs to send alert notifications to Splunk On-Call. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationView.property.webhookSecret">webhookSecret</a></code> | <code>string</code> | An optional field for your webhook secret. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationView.property.webhookUrl">webhookUrl</a></code> | <code>string</code> | Your webhook URL. |

---

##### `apiToken`<sup>Optional</sup> <a name="apiToken" id="awscdk-resources-mongodbatlas.NotificationView.property.apiToken"></a>

```typescript
public readonly apiToken: string;
```

- *Type:* string

Slack API token or Bot token that MongoDB Cloud needs to send alert notifications via Slack.

The resource requires this parameter when '"notifications.typeName" : "SLACK"'. If the token later becomes invalid, MongoDB Cloud sends an email to the project owners. If the token remains invalid, MongoDB Cloud removes the token.

---

##### `channelName`<sup>Optional</sup> <a name="channelName" id="awscdk-resources-mongodbatlas.NotificationView.property.channelName"></a>

```typescript
public readonly channelName: string;
```

- *Type:* string

Name of the Slack channel to which MongoDB Cloud sends alert notifications.

The resource requires this parameter when '"notifications.typeName" : "SLACK"'.

---

##### `datadogApiKey`<sup>Optional</sup> <a name="datadogApiKey" id="awscdk-resources-mongodbatlas.NotificationView.property.datadogApiKey"></a>

```typescript
public readonly datadogApiKey: string;
```

- *Type:* string

Datadog API Key that MongoDB Cloud needs to send alert notifications to Datadog.

You can find this API key in the Datadog dashboard. The resource requires this parameter when '"notifications.typeName" : "DATADOG"'.

---

##### `datadogRegion`<sup>Optional</sup> <a name="datadogRegion" id="awscdk-resources-mongodbatlas.NotificationView.property.datadogRegion"></a>

```typescript
public readonly datadogRegion: NotificationViewDatadogRegion;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.NotificationViewDatadogRegion">NotificationViewDatadogRegion</a>

Datadog region that indicates which API Uniform Resource Locator (URL) to use.

The resource requires this parameter when '"notifications.typeName" : "DATADOG"'.

---

##### `delayMin`<sup>Optional</sup> <a name="delayMin" id="awscdk-resources-mongodbatlas.NotificationView.property.delayMin"></a>

```typescript
public readonly delayMin: number;
```

- *Type:* number

Number of minutes that MongoDB Cloud waits after detecting an alert condition before it sends out the first notification.

---

##### `emailAddress`<sup>Optional</sup> <a name="emailAddress" id="awscdk-resources-mongodbatlas.NotificationView.property.emailAddress"></a>

```typescript
public readonly emailAddress: string;
```

- *Type:* string

Email address to which MongoDB Cloud sends alert notifications.

The resource requires this parameter when '"notifications.typeName" : "EMAIL"'. You don't need to set this value to send emails to individual or groups of MongoDB Cloud users including:

- specific MongoDB Cloud users ('"notifications.typeName" : "USER"')
- MongoDB Cloud users with specific project roles ('"notifications.typeName" : "GROUP"')
- MongoDB Cloud users with specific organization roles ('"notifications.typeName" : "ORG"')
- MongoDB Cloud teams ('"notifications.typeName" : "TEAM"')

To send emails to one MongoDB Cloud user or grouping of users, set the **notifications.emailEnabled** parameter.

---

##### `emailEnabled`<sup>Optional</sup> <a name="emailEnabled" id="awscdk-resources-mongodbatlas.NotificationView.property.emailEnabled"></a>

```typescript
public readonly emailEnabled: boolean;
```

- *Type:* boolean

Flag that indicates whether MongoDB Cloud should send email notifications.

The resource requires this parameter when one of the following values have been set:

- '"notifications.typeName" : "ORG"'
- '"notifications.typeName" : "GROUP"'
- '"notifications.typeName" : "USER"'

---

##### `flowdockApiToken`<sup>Optional</sup> <a name="flowdockApiToken" id="awscdk-resources-mongodbatlas.NotificationView.property.flowdockApiToken"></a>

```typescript
public readonly flowdockApiToken: string;
```

- *Type:* string

Flowdock API token that MongoDB Cloud needs to send alert notifications to Flowdock.

The resource requires this parameter when '"notifications.typeName" : "FLOWDOCK"'. If the token later becomes invalid, MongoDB Cloud sends an email to the project owners. If the token remains invalid, MongoDB Cloud removes the token.

---

##### `flowName`<sup>Optional</sup> <a name="flowName" id="awscdk-resources-mongodbatlas.NotificationView.property.flowName"></a>

```typescript
public readonly flowName: string;
```

- *Type:* string

Flowdock flow name to which MongoDB Cloud sends alert notifications.

This name appears after the organization name in the Uniform Resource Locator (URL) path: 'www.flowdock.com/app/<organization-name>/<flow-name>'. The resource requires this parameter when '"notifications.typeName" : "FLOWDOCK"'.

---

##### `intervalMin`<sup>Optional</sup> <a name="intervalMin" id="awscdk-resources-mongodbatlas.NotificationView.property.intervalMin"></a>

```typescript
public readonly intervalMin: number;
```

- *Type:* number

Number of minutes to wait between successive notifications. MongoDB Cloud sends notifications until someone acknowledges the unacknowledged alert.

PagerDuty, VictorOps, and OpsGenie notifications don't return this element. Configure and manage the notification interval within each of those services.

---

##### `microsoftTeamsWebhookUrl`<sup>Optional</sup> <a name="microsoftTeamsWebhookUrl" id="awscdk-resources-mongodbatlas.NotificationView.property.microsoftTeamsWebhookUrl"></a>

```typescript
public readonly microsoftTeamsWebhookUrl: string;
```

- *Type:* string

Microsoft Teams Webhook Uniform Resource Locator (URL) that MongoDB Cloud needs to send this notification via Microsoft Teams.

The resource requires this parameter when '"notifications.typeName" : "MICROSOFT_TEAMS"'. If the URL later becomes invalid, MongoDB Cloud sends an email to the project owners. If the key remains invalid, MongoDB Cloud removes it.

---

##### `mobileNumber`<sup>Optional</sup> <a name="mobileNumber" id="awscdk-resources-mongodbatlas.NotificationView.property.mobileNumber"></a>

```typescript
public readonly mobileNumber: string;
```

- *Type:* string

Mobile phone number to which MongoDB Cloud sends alert notifications.

The resource requires this parameter when '"notifications.typeName" : "SMS"'.

---

##### `notificationToken`<sup>Optional</sup> <a name="notificationToken" id="awscdk-resources-mongodbatlas.NotificationView.property.notificationToken"></a>

```typescript
public readonly notificationToken: string;
```

- *Type:* string

HipChat API token that MongoDB Cloud needs to send alert notifications to HipChat.

The resource requires this parameter when '"notifications.typeName" : "HIP_CHAT"'". If the token later becomes invalid, MongoDB Cloud sends an email to the project owners. If the token remains invalid, MongoDB Cloud removes it.

---

##### `opsGenieApiKey`<sup>Optional</sup> <a name="opsGenieApiKey" id="awscdk-resources-mongodbatlas.NotificationView.property.opsGenieApiKey"></a>

```typescript
public readonly opsGenieApiKey: string;
```

- *Type:* string

API Key that MongoDB Cloud needs to send this notification via Opsgenie.

The resource requires this parameter when '"notifications.typeName" : "OPS_GENIE"'. If the key later becomes invalid, MongoDB Cloud sends an email to the project owners. If the key remains invalid, MongoDB Cloud removes it.

---

##### `opsGenieRegion`<sup>Optional</sup> <a name="opsGenieRegion" id="awscdk-resources-mongodbatlas.NotificationView.property.opsGenieRegion"></a>

```typescript
public readonly opsGenieRegion: NotificationViewOpsGenieRegion;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.NotificationViewOpsGenieRegion">NotificationViewOpsGenieRegion</a>

Opsgenie region that indicates which API Uniform Resource Locator (URL) to use.

---

##### `orgName`<sup>Optional</sup> <a name="orgName" id="awscdk-resources-mongodbatlas.NotificationView.property.orgName"></a>

```typescript
public readonly orgName: string;
```

- *Type:* string

Flowdock organization name to which MongoDB Cloud sends alert notifications.

This name appears after 'www.flowdock.com/app/' in the Uniform Resource Locator (URL) path. The resource requires this parameter when '"notifications.typeName" : "FLOWDOCK"'.

---

##### `roles`<sup>Optional</sup> <a name="roles" id="awscdk-resources-mongodbatlas.NotificationView.property.roles"></a>

```typescript
public readonly roles: NotificationViewRoles[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.NotificationViewRoles">NotificationViewRoles</a>[]

List that contains the one or more organization or project roles that receive the configured alert.

The resource requires this parameter when '"notifications.typeName" : "GROUP"' or '"notifications.typeName" : "ORG"'. If you include this parameter, MongoDB Cloud sends alerts only to users assigned the roles you specify in the array. If you omit this parameter, MongoDB Cloud sends alerts to users assigned any role.

---

##### `roomName`<sup>Optional</sup> <a name="roomName" id="awscdk-resources-mongodbatlas.NotificationView.property.roomName"></a>

```typescript
public readonly roomName: string;
```

- *Type:* string

HipChat API room name to which MongoDB Cloud sends alert notifications.

The resource requires this parameter when '"notifications.typeName" : "HIP_CHAT"'".

---

##### `serviceKey`<sup>Optional</sup> <a name="serviceKey" id="awscdk-resources-mongodbatlas.NotificationView.property.serviceKey"></a>

```typescript
public readonly serviceKey: string;
```

- *Type:* string

PagerDuty service key that MongoDB Cloud needs to send notifications via PagerDuty.

The resource requires this parameter when '"notifications.typeName" : "PAGER_DUTY"'. If the key later becomes invalid, MongoDB Cloud sends an email to the project owners. If the key remains invalid, MongoDB Cloud removes it.

---

##### `severity`<sup>Optional</sup> <a name="severity" id="awscdk-resources-mongodbatlas.NotificationView.property.severity"></a>

```typescript
public readonly severity: NotificationViewSeverity;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.NotificationViewSeverity">NotificationViewSeverity</a>

Degree of seriousness given to this notification.

---

##### `smsEnabled`<sup>Optional</sup> <a name="smsEnabled" id="awscdk-resources-mongodbatlas.NotificationView.property.smsEnabled"></a>

```typescript
public readonly smsEnabled: boolean;
```

- *Type:* boolean

Flag that indicates whether MongoDB Cloud should send text message notifications.

The resource requires this parameter when one of the following values have been set:

- '"notifications.typeName" : "ORG"'
- '"notifications.typeName" : "GROUP"'
- '"notifications.typeName" : "USER"'

---

##### `teamId`<sup>Optional</sup> <a name="teamId" id="awscdk-resources-mongodbatlas.NotificationView.property.teamId"></a>

```typescript
public readonly teamId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies one MongoDB Cloud team.

The resource requires this parameter when '"notifications.typeName" : "TEAM"'.

---

##### `teamName`<sup>Optional</sup> <a name="teamName" id="awscdk-resources-mongodbatlas.NotificationView.property.teamName"></a>

```typescript
public readonly teamName: string;
```

- *Type:* string

Name of the MongoDB Cloud team that receives this notification.

The resource requires this parameter when '"notifications.typeName" : "TEAM"'.

---

##### `typeName`<sup>Optional</sup> <a name="typeName" id="awscdk-resources-mongodbatlas.NotificationView.property.typeName"></a>

```typescript
public readonly typeName: NotificationViewTypeName;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.NotificationViewTypeName">NotificationViewTypeName</a>

Human-readable label that displays the alert notification type.

---

##### `username`<sup>Optional</sup> <a name="username" id="awscdk-resources-mongodbatlas.NotificationView.property.username"></a>

```typescript
public readonly username: string;
```

- *Type:* string

MongoDB Cloud username of the person to whom MongoDB Cloud sends notifications.

Specify only MongoDB Cloud users who belong to the project that owns the alert configuration. The resource requires this parameter when '"notifications.typeName" : "USER"'.

---

##### `victorOpsApiKey`<sup>Optional</sup> <a name="victorOpsApiKey" id="awscdk-resources-mongodbatlas.NotificationView.property.victorOpsApiKey"></a>

```typescript
public readonly victorOpsApiKey: string;
```

- *Type:* string

API key that MongoDB Cloud needs to send alert notifications to Splunk On-Call.

The resource requires this parameter when '"notifications.typeName" : "VICTOR_OPS"'. If the key later becomes invalid, MongoDB Cloud sends an email to the project owners. If the key remains invalid, MongoDB Cloud removes it.

---

##### `victorOpsRoutingKey`<sup>Optional</sup> <a name="victorOpsRoutingKey" id="awscdk-resources-mongodbatlas.NotificationView.property.victorOpsRoutingKey"></a>

```typescript
public readonly victorOpsRoutingKey: string;
```

- *Type:* string

Routing key that MongoDB Cloud needs to send alert notifications to Splunk On-Call.

The resource requires this parameter when '"notifications.typeName" : "VICTOR_OPS"'. If the key later becomes invalid, MongoDB Cloud sends an email to the project owners. If the key remains invalid, MongoDB Cloud removes it.

---

##### `webhookSecret`<sup>Optional</sup> <a name="webhookSecret" id="awscdk-resources-mongodbatlas.NotificationView.property.webhookSecret"></a>

```typescript
public readonly webhookSecret: string;
```

- *Type:* string

An optional field for your webhook secret.

---

##### `webhookUrl`<sup>Optional</sup> <a name="webhookUrl" id="awscdk-resources-mongodbatlas.NotificationView.property.webhookUrl"></a>

```typescript
public readonly webhookUrl: string;
```

- *Type:* string

Your webhook URL.

---

### PagerDutyIntegrationProps <a name="PagerDutyIntegrationProps" id="awscdk-resources-mongodbatlas.PagerDutyIntegrationProps"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.PagerDutyIntegrationProps.Initializer"></a>

```typescript
import { PagerDutyIntegrationProps } from 'awscdk-resources-mongodbatlas'

const pagerDutyIntegrationProps: PagerDutyIntegrationProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.PagerDutyIntegrationProps.property.projectId">projectId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies your project. |
| <code><a href="#awscdk-resources-mongodbatlas.PagerDutyIntegrationProps.property.profile">profile</a></code> | <code>string</code> | Atlas API keys. |
| <code><a href="#awscdk-resources-mongodbatlas.PagerDutyIntegrationProps.property.region">region</a></code> | <code><a href="#awscdk-resources-mongodbatlas.PagerDutyRegion">PagerDutyRegion</a></code> | PagerDuty region that indicates the API Uniform Resource Locator (URL) to use. |
| <code><a href="#awscdk-resources-mongodbatlas.PagerDutyIntegrationProps.property.serviceKey">serviceKey</a></code> | <code>string</code> | Service key associated with your PagerDuty account. |

---

##### `projectId`<sup>Required</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.PagerDutyIntegrationProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies your project.

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.PagerDutyIntegrationProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

Atlas API keys.

---

##### `region`<sup>Required</sup> <a name="region" id="awscdk-resources-mongodbatlas.PagerDutyIntegrationProps.property.region"></a>

```typescript
public readonly region: PagerDutyRegion;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.PagerDutyRegion">PagerDutyRegion</a>

PagerDuty region that indicates the API Uniform Resource Locator (URL) to use.

---

##### `serviceKey`<sup>Required</sup> <a name="serviceKey" id="awscdk-resources-mongodbatlas.PagerDutyIntegrationProps.property.serviceKey"></a>

```typescript
public readonly serviceKey: string;
```

- *Type:* string

Service key associated with your PagerDuty account.

---

### PartitionFields <a name="PartitionFields" id="awscdk-resources-mongodbatlas.PartitionFields"></a>

Ordered fields used to physically organize data in the destination.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.PartitionFields.Initializer"></a>

```typescript
import { PartitionFields } from 'awscdk-resources-mongodbatlas'

const partitionFields: PartitionFields = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.PartitionFields.property.fieldName">fieldName</a></code> | <code>string</code> | Human-readable label that identifies the field name used to partition data. |
| <code><a href="#awscdk-resources-mongodbatlas.PartitionFields.property.order">order</a></code> | <code>number</code> | Sequence in which MongoDB Cloud slices the collection data to create partitions. |

---

##### `fieldName`<sup>Optional</sup> <a name="fieldName" id="awscdk-resources-mongodbatlas.PartitionFields.property.fieldName"></a>

```typescript
public readonly fieldName: string;
```

- *Type:* string

Human-readable label that identifies the field name used to partition data.

---

##### `order`<sup>Optional</sup> <a name="order" id="awscdk-resources-mongodbatlas.PartitionFields.property.order"></a>

```typescript
public readonly order: number;
```

- *Type:* number

Sequence in which MongoDB Cloud slices the collection data to create partitions.

The resource expresses this sequence starting with zero.

---

### PartitionFieldView <a name="PartitionFieldView" id="awscdk-resources-mongodbatlas.PartitionFieldView"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.PartitionFieldView.Initializer"></a>

```typescript
import { PartitionFieldView } from 'awscdk-resources-mongodbatlas'

const partitionFieldView: PartitionFieldView = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.PartitionFieldView.property.fieldName">fieldName</a></code> | <code>string</code> | Human-readable label that identifies the parameter that MongoDB Cloud uses to partition data. |
| <code><a href="#awscdk-resources-mongodbatlas.PartitionFieldView.property.fieldType">fieldType</a></code> | <code><a href="#awscdk-resources-mongodbatlas.PartitionFieldViewFieldType">PartitionFieldViewFieldType</a></code> | Data type of the parameter that that MongoDB Cloud uses to partition data. |
| <code><a href="#awscdk-resources-mongodbatlas.PartitionFieldView.property.order">order</a></code> | <code>number</code> | Sequence in which MongoDB Cloud slices the collection data to create partitions. |

---

##### `fieldName`<sup>Optional</sup> <a name="fieldName" id="awscdk-resources-mongodbatlas.PartitionFieldView.property.fieldName"></a>

```typescript
public readonly fieldName: string;
```

- *Type:* string

Human-readable label that identifies the parameter that MongoDB Cloud uses to partition data.

To specify a nested parameter, use the dot notation.

---

##### `fieldType`<sup>Optional</sup> <a name="fieldType" id="awscdk-resources-mongodbatlas.PartitionFieldView.property.fieldType"></a>

```typescript
public readonly fieldType: PartitionFieldViewFieldType;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.PartitionFieldViewFieldType">PartitionFieldViewFieldType</a>

Data type of the parameter that that MongoDB Cloud uses to partition data.

Partition parameters of type [UUID](http://bsonspec.org/spec.html) must be of binary subtype 4. MongoDB Cloud skips partition parameters of type UUID with subtype 3.

---

##### `order`<sup>Optional</sup> <a name="order" id="awscdk-resources-mongodbatlas.PartitionFieldView.property.order"></a>

```typescript
public readonly order: number;
```

- *Type:* number

Sequence in which MongoDB Cloud slices the collection data to create partitions.

The resource expresses this sequence starting with zero. The value of the **criteria.dateField** parameter defaults as the first item in the partition sequence.

---

### PrivateEndpoint <a name="PrivateEndpoint" id="awscdk-resources-mongodbatlas.PrivateEndpoint"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.PrivateEndpoint.Initializer"></a>

```typescript
import { PrivateEndpoint } from 'awscdk-resources-mongodbatlas'

const privateEndpoint: PrivateEndpoint = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.PrivateEndpoint.property.atlasPrivateEndpointStatus">atlasPrivateEndpointStatus</a></code> | <code>string</code> | Status of the Atlas PrivateEndpoint connection. |
| <code><a href="#awscdk-resources-mongodbatlas.PrivateEndpoint.property.awsPrivateEndpointStatus">awsPrivateEndpointStatus</a></code> | <code>string</code> | Status of the AWS PrivateEndpoint connection. |
| <code><a href="#awscdk-resources-mongodbatlas.PrivateEndpoint.property.interfaceEndpointId">interfaceEndpointId</a></code> | <code>string</code> | Unique identifiers of the interface endpoints in your VPC that you added to the AWS PrivateLink connection. |
| <code><a href="#awscdk-resources-mongodbatlas.PrivateEndpoint.property.subnetIds">subnetIds</a></code> | <code>string[]</code> | List of string representing the AWS VPC Subnet ID (like: subnet-xxxxxxxxxxxxxxxxx) (Used For Creating the AWS VPC Endpoint). |
| <code><a href="#awscdk-resources-mongodbatlas.PrivateEndpoint.property.vpcId">vpcId</a></code> | <code>string</code> | String Representing the AWS VPC ID (like: vpc-xxxxxxxxxxxxxxxx) (Used For Creating the AWS VPC Endpoint). |

---

##### `atlasPrivateEndpointStatus`<sup>Optional</sup> <a name="atlasPrivateEndpointStatus" id="awscdk-resources-mongodbatlas.PrivateEndpoint.property.atlasPrivateEndpointStatus"></a>

```typescript
public readonly atlasPrivateEndpointStatus: string;
```

- *Type:* string

Status of the Atlas PrivateEndpoint connection.

---

##### `awsPrivateEndpointStatus`<sup>Optional</sup> <a name="awsPrivateEndpointStatus" id="awscdk-resources-mongodbatlas.PrivateEndpoint.property.awsPrivateEndpointStatus"></a>

```typescript
public readonly awsPrivateEndpointStatus: string;
```

- *Type:* string

Status of the AWS PrivateEndpoint connection.

---

##### `interfaceEndpointId`<sup>Optional</sup> <a name="interfaceEndpointId" id="awscdk-resources-mongodbatlas.PrivateEndpoint.property.interfaceEndpointId"></a>

```typescript
public readonly interfaceEndpointId: string;
```

- *Type:* string

Unique identifiers of the interface endpoints in your VPC that you added to the AWS PrivateLink connection.

---

##### `subnetIds`<sup>Optional</sup> <a name="subnetIds" id="awscdk-resources-mongodbatlas.PrivateEndpoint.property.subnetIds"></a>

```typescript
public readonly subnetIds: string[];
```

- *Type:* string[]

List of string representing the AWS VPC Subnet ID (like: subnet-xxxxxxxxxxxxxxxxx) (Used For Creating the AWS VPC Endpoint).

---

##### `vpcId`<sup>Optional</sup> <a name="vpcId" id="awscdk-resources-mongodbatlas.PrivateEndpoint.property.vpcId"></a>

```typescript
public readonly vpcId: string;
```

- *Type:* string

String Representing the AWS VPC ID (like: vpc-xxxxxxxxxxxxxxxx) (Used For Creating the AWS VPC Endpoint).

---

### PrivateEndpointProps <a name="PrivateEndpointProps" id="awscdk-resources-mongodbatlas.PrivateEndpointProps"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.PrivateEndpointProps.Initializer"></a>

```typescript
import { PrivateEndpointProps } from 'awscdk-resources-mongodbatlas'

const privateEndpointProps: PrivateEndpointProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.PrivateEndpointProps.property.awsSubnetId">awsSubnetId</a></code> | <code>string</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.PrivateEndpointProps.property.awsVpcId">awsVpcId</a></code> | <code>string</code> | *No description.* |

---

##### `awsSubnetId`<sup>Required</sup> <a name="awsSubnetId" id="awscdk-resources-mongodbatlas.PrivateEndpointProps.property.awsSubnetId"></a>

```typescript
public readonly awsSubnetId: string;
```

- *Type:* string

---

##### `awsVpcId`<sup>Required</sup> <a name="awsVpcId" id="awscdk-resources-mongodbatlas.PrivateEndpointProps.property.awsVpcId"></a>

```typescript
public readonly awsVpcId: string;
```

- *Type:* string

---

### ProcessArgs <a name="ProcessArgs" id="awscdk-resources-mongodbatlas.ProcessArgs"></a>

Advanced configuration details to add for one cluster in the specified project.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.ProcessArgs.Initializer"></a>

```typescript
import { ProcessArgs } from 'awscdk-resources-mongodbatlas'

const processArgs: ProcessArgs = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.ProcessArgs.property.defaultReadConcern">defaultReadConcern</a></code> | <code>string</code> | Default level of acknowledgment requested from MongoDB for read operations set for this cluster. |
| <code><a href="#awscdk-resources-mongodbatlas.ProcessArgs.property.defaultWriteConcern">defaultWriteConcern</a></code> | <code>string</code> | Default level of acknowledgment requested from MongoDB for write operations set for this cluster. |
| <code><a href="#awscdk-resources-mongodbatlas.ProcessArgs.property.failIndexKeyTooLong">failIndexKeyTooLong</a></code> | <code>boolean</code> | Flag that indicates whether you can insert or update documents where all indexed entries don't exceed 1024 bytes. |
| <code><a href="#awscdk-resources-mongodbatlas.ProcessArgs.property.javascriptEnabled">javascriptEnabled</a></code> | <code>boolean</code> | Flag that indicates whether the cluster allows execution of operations that perform server-side executions of JavaScript. |
| <code><a href="#awscdk-resources-mongodbatlas.ProcessArgs.property.minimumEnabledTlsProtocol">minimumEnabledTlsProtocol</a></code> | <code>string</code> | Minimum Transport Layer Security (TLS) version that the cluster accepts for incoming connections. |
| <code><a href="#awscdk-resources-mongodbatlas.ProcessArgs.property.noTableScan">noTableScan</a></code> | <code>boolean</code> | Flag that indicates whether the cluster disables executing any query that requires a collection scan to return results. |
| <code><a href="#awscdk-resources-mongodbatlas.ProcessArgs.property.oplogMinRetentionHours">oplogMinRetentionHours</a></code> | <code>number</code> | Minimum retention window for cluster's oplog expressed in hours. |
| <code><a href="#awscdk-resources-mongodbatlas.ProcessArgs.property.oplogSizeMb">oplogSizeMb</a></code> | <code>number</code> | Storage limit of cluster's oplog expressed in megabytes. |
| <code><a href="#awscdk-resources-mongodbatlas.ProcessArgs.property.sampleRefreshIntervalBiConnector">sampleRefreshIntervalBiConnector</a></code> | <code>number</code> | Number of documents per database to sample when gathering schema information. |
| <code><a href="#awscdk-resources-mongodbatlas.ProcessArgs.property.sampleSizeBiConnector">sampleSizeBiConnector</a></code> | <code>number</code> | Interval in seconds at which the mongosqld process re-samples data to create its relational schema. |
| <code><a href="#awscdk-resources-mongodbatlas.ProcessArgs.property.transactionLifetimeLimitSeconds">transactionLifetimeLimitSeconds</a></code> | <code>number</code> | Lifetime, in seconds, of multi-document transactions. |

---

##### `defaultReadConcern`<sup>Optional</sup> <a name="defaultReadConcern" id="awscdk-resources-mongodbatlas.ProcessArgs.property.defaultReadConcern"></a>

```typescript
public readonly defaultReadConcern: string;
```

- *Type:* string

Default level of acknowledgment requested from MongoDB for read operations set for this cluster.

---

##### `defaultWriteConcern`<sup>Optional</sup> <a name="defaultWriteConcern" id="awscdk-resources-mongodbatlas.ProcessArgs.property.defaultWriteConcern"></a>

```typescript
public readonly defaultWriteConcern: string;
```

- *Type:* string

Default level of acknowledgment requested from MongoDB for write operations set for this cluster.

---

##### `failIndexKeyTooLong`<sup>Optional</sup> <a name="failIndexKeyTooLong" id="awscdk-resources-mongodbatlas.ProcessArgs.property.failIndexKeyTooLong"></a>

```typescript
public readonly failIndexKeyTooLong: boolean;
```

- *Type:* boolean

Flag that indicates whether you can insert or update documents where all indexed entries don't exceed 1024 bytes.

If you set this to false, mongod writes documents that exceed this limit but doesn't index them.

---

##### `javascriptEnabled`<sup>Optional</sup> <a name="javascriptEnabled" id="awscdk-resources-mongodbatlas.ProcessArgs.property.javascriptEnabled"></a>

```typescript
public readonly javascriptEnabled: boolean;
```

- *Type:* boolean

Flag that indicates whether the cluster allows execution of operations that perform server-side executions of JavaScript.

---

##### `minimumEnabledTlsProtocol`<sup>Optional</sup> <a name="minimumEnabledTlsProtocol" id="awscdk-resources-mongodbatlas.ProcessArgs.property.minimumEnabledTlsProtocol"></a>

```typescript
public readonly minimumEnabledTlsProtocol: string;
```

- *Type:* string

Minimum Transport Layer Security (TLS) version that the cluster accepts for incoming connections.

Clusters using TLS 1.0 or 1.1 should consider setting TLS 1.2 as the minimum TLS protocol version.

---

##### `noTableScan`<sup>Optional</sup> <a name="noTableScan" id="awscdk-resources-mongodbatlas.ProcessArgs.property.noTableScan"></a>

```typescript
public readonly noTableScan: boolean;
```

- *Type:* boolean

Flag that indicates whether the cluster disables executing any query that requires a collection scan to return results.

---

##### `oplogMinRetentionHours`<sup>Optional</sup> <a name="oplogMinRetentionHours" id="awscdk-resources-mongodbatlas.ProcessArgs.property.oplogMinRetentionHours"></a>

```typescript
public readonly oplogMinRetentionHours: number;
```

- *Type:* number

Minimum retention window for cluster's oplog expressed in hours.

A value of null indicates that the cluster uses the default minimum oplog window that MongoDB Cloud calculates.

---

##### `oplogSizeMb`<sup>Optional</sup> <a name="oplogSizeMb" id="awscdk-resources-mongodbatlas.ProcessArgs.property.oplogSizeMb"></a>

```typescript
public readonly oplogSizeMb: number;
```

- *Type:* number

Storage limit of cluster's oplog expressed in megabytes.

A value of null indicates that the cluster uses the default oplog size that MongoDB Cloud calculates.

---

##### `sampleRefreshIntervalBiConnector`<sup>Optional</sup> <a name="sampleRefreshIntervalBiConnector" id="awscdk-resources-mongodbatlas.ProcessArgs.property.sampleRefreshIntervalBiConnector"></a>

```typescript
public readonly sampleRefreshIntervalBiConnector: number;
```

- *Type:* number

Number of documents per database to sample when gathering schema information.

---

##### `sampleSizeBiConnector`<sup>Optional</sup> <a name="sampleSizeBiConnector" id="awscdk-resources-mongodbatlas.ProcessArgs.property.sampleSizeBiConnector"></a>

```typescript
public readonly sampleSizeBiConnector: number;
```

- *Type:* number

Interval in seconds at which the mongosqld process re-samples data to create its relational schema.

---

##### `transactionLifetimeLimitSeconds`<sup>Optional</sup> <a name="transactionLifetimeLimitSeconds" id="awscdk-resources-mongodbatlas.ProcessArgs.property.transactionLifetimeLimitSeconds"></a>

```typescript
public readonly transactionLifetimeLimitSeconds: number;
```

- *Type:* number

Lifetime, in seconds, of multi-document transactions.

Atlas considers the transactions that exceed this limit as expired and so aborts them through a periodic cleanup process.

---

### ProjectApiKey <a name="ProjectApiKey" id="awscdk-resources-mongodbatlas.ProjectApiKey"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.ProjectApiKey.Initializer"></a>

```typescript
import { ProjectApiKey } from 'awscdk-resources-mongodbatlas'

const projectApiKey: ProjectApiKey = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.ProjectApiKey.property.key">key</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies this organization API key assigned to this project. |
| <code><a href="#awscdk-resources-mongodbatlas.ProjectApiKey.property.roleNames">roleNames</a></code> | <code>string[]</code> | List of roles to grant this API key. |

---

##### `key`<sup>Optional</sup> <a name="key" id="awscdk-resources-mongodbatlas.ProjectApiKey.property.key"></a>

```typescript
public readonly key: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies this organization API key assigned to this project.

---

##### `roleNames`<sup>Optional</sup> <a name="roleNames" id="awscdk-resources-mongodbatlas.ProjectApiKey.property.roleNames"></a>

```typescript
public readonly roleNames: string[];
```

- *Type:* string[]

List of roles to grant this API key.

If you provide this list, provide a minimum of one role and ensure each role applies to this project.Items Enum: "ORG_OWNER" "ORG_MEMBER" "ORG_GROUP_CREATOR" "ORG_BILLING_ADMIN" "ORG_READ_ONLY" "ORG_TEAM_MEMBERS_ADMIN" "GROUP_ATLAS_ADMIN" "GROUP_AUTOMATION_ADMIN" "GROUP_BACKUP_ADMIN" "GROUP_MONITORING_ADMIN" "GROUP_OWNER" "GROUP_READ_ONLY" "GROUP_USER_ADMIN" "GROUP_BILLING_ADMIN" "GROUP_DATA_ACCESS_ADMIN" "GROUP_DATA_ACCESS_READ_ONLY" "GROUP_DATA_ACCESS_READ_WRITE" "GROUP_CHARTS_ADMIN" "GROUP_CLUSTER_MANAGER" "GROUP_SEARCH_INDEX_EDITOR"

---

### ProjectAssignment <a name="ProjectAssignment" id="awscdk-resources-mongodbatlas.ProjectAssignment"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.ProjectAssignment.Initializer"></a>

```typescript
import { ProjectAssignment } from 'awscdk-resources-mongodbatlas'

const projectAssignment: ProjectAssignment = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.ProjectAssignment.property.projectId">projectId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies the project in an organization. |
| <code><a href="#awscdk-resources-mongodbatlas.ProjectAssignment.property.roles">roles</a></code> | <code>string[]</code> | List of roles to grant this API key. |

---

##### `projectId`<sup>Optional</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.ProjectAssignment.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies the project in an organization.

---

##### `roles`<sup>Optional</sup> <a name="roles" id="awscdk-resources-mongodbatlas.ProjectAssignment.property.roles"></a>

```typescript
public readonly roles: string[];
```

- *Type:* string[]

List of roles to grant this API key.

If you provide this list, provide a minimum of one role and ensure each role applies to this organization.

---

### ProjectProps <a name="ProjectProps" id="awscdk-resources-mongodbatlas.ProjectProps"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.ProjectProps.Initializer"></a>

```typescript
import { ProjectProps } from 'awscdk-resources-mongodbatlas'

const projectProps: ProjectProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.ProjectProps.property.orgId">orgId</a></code> | <code>string</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.ProjectProps.property.clusterCount">clusterCount</a></code> | <code>number</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.ProjectProps.property.name">name</a></code> | <code>string</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.ProjectProps.property.projectApiKeys">projectApiKeys</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ProjectApiKey">ProjectApiKey</a>[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.ProjectProps.property.projectOwnerId">projectOwnerId</a></code> | <code>string</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.ProjectProps.property.projectSettings">projectSettings</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ProjectSettings">ProjectSettings</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.ProjectProps.property.projectTeams">projectTeams</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ProjectTeam">ProjectTeam</a>[]</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.ProjectProps.property.withDefaultAlertsSettings">withDefaultAlertsSettings</a></code> | <code>boolean</code> | *No description.* |

---

##### `orgId`<sup>Required</sup> <a name="orgId" id="awscdk-resources-mongodbatlas.ProjectProps.property.orgId"></a>

```typescript
public readonly orgId: string;
```

- *Type:* string
- *Default:* auto-generated

---

##### `clusterCount`<sup>Optional</sup> <a name="clusterCount" id="awscdk-resources-mongodbatlas.ProjectProps.property.clusterCount"></a>

```typescript
public readonly clusterCount: number;
```

- *Type:* number

---

##### `name`<sup>Optional</sup> <a name="name" id="awscdk-resources-mongodbatlas.ProjectProps.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

---

##### `projectApiKeys`<sup>Optional</sup> <a name="projectApiKeys" id="awscdk-resources-mongodbatlas.ProjectProps.property.projectApiKeys"></a>

```typescript
public readonly projectApiKeys: ProjectApiKey[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ProjectApiKey">ProjectApiKey</a>[]

---

##### `projectOwnerId`<sup>Optional</sup> <a name="projectOwnerId" id="awscdk-resources-mongodbatlas.ProjectProps.property.projectOwnerId"></a>

```typescript
public readonly projectOwnerId: string;
```

- *Type:* string

---

##### `projectSettings`<sup>Optional</sup> <a name="projectSettings" id="awscdk-resources-mongodbatlas.ProjectProps.property.projectSettings"></a>

```typescript
public readonly projectSettings: ProjectSettings;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ProjectSettings">ProjectSettings</a>

---

##### `projectTeams`<sup>Optional</sup> <a name="projectTeams" id="awscdk-resources-mongodbatlas.ProjectProps.property.projectTeams"></a>

```typescript
public readonly projectTeams: ProjectTeam[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ProjectTeam">ProjectTeam</a>[]

---

##### `withDefaultAlertsSettings`<sup>Optional</sup> <a name="withDefaultAlertsSettings" id="awscdk-resources-mongodbatlas.ProjectProps.property.withDefaultAlertsSettings"></a>

```typescript
public readonly withDefaultAlertsSettings: boolean;
```

- *Type:* boolean

---

### ProjectSettings <a name="ProjectSettings" id="awscdk-resources-mongodbatlas.ProjectSettings"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.ProjectSettings.Initializer"></a>

```typescript
import { ProjectSettings } from 'awscdk-resources-mongodbatlas'

const projectSettings: ProjectSettings = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.ProjectSettings.property.isCollectDatabaseSpecificsStatisticsEnabled">isCollectDatabaseSpecificsStatisticsEnabled</a></code> | <code>boolean</code> | Flag that indicates whether to collect database-specific metrics for the specified project. |
| <code><a href="#awscdk-resources-mongodbatlas.ProjectSettings.property.isDataExplorerEnabled">isDataExplorerEnabled</a></code> | <code>boolean</code> | Flag that indicates whether to enable the Data Explorer for the specified project. |
| <code><a href="#awscdk-resources-mongodbatlas.ProjectSettings.property.isExtendedStorageSizesEnabled">isExtendedStorageSizesEnabled</a></code> | <code>boolean</code> | Flag that indicates whether to enable extended storage sizes for the specified project. |
| <code><a href="#awscdk-resources-mongodbatlas.ProjectSettings.property.isPerformanceAdvisorEnabled">isPerformanceAdvisorEnabled</a></code> | <code>boolean</code> | Flag that indicates whether to enable the Performance Advisor and Profiler for the specified project. |
| <code><a href="#awscdk-resources-mongodbatlas.ProjectSettings.property.isRealtimePerformancePanelEnabled">isRealtimePerformancePanelEnabled</a></code> | <code>boolean</code> | Flag that indicates whether to enable the Real Time Performance Panel for the specified project. |
| <code><a href="#awscdk-resources-mongodbatlas.ProjectSettings.property.isSchemaAdvisorEnabled">isSchemaAdvisorEnabled</a></code> | <code>boolean</code> | Flag that indicates whether to enable the Schema Advisor for the specified project. |

---

##### `isCollectDatabaseSpecificsStatisticsEnabled`<sup>Optional</sup> <a name="isCollectDatabaseSpecificsStatisticsEnabled" id="awscdk-resources-mongodbatlas.ProjectSettings.property.isCollectDatabaseSpecificsStatisticsEnabled"></a>

```typescript
public readonly isCollectDatabaseSpecificsStatisticsEnabled: boolean;
```

- *Type:* boolean

Flag that indicates whether to collect database-specific metrics for the specified project.

---

##### `isDataExplorerEnabled`<sup>Optional</sup> <a name="isDataExplorerEnabled" id="awscdk-resources-mongodbatlas.ProjectSettings.property.isDataExplorerEnabled"></a>

```typescript
public readonly isDataExplorerEnabled: boolean;
```

- *Type:* boolean

Flag that indicates whether to enable the Data Explorer for the specified project.

---

##### `isExtendedStorageSizesEnabled`<sup>Optional</sup> <a name="isExtendedStorageSizesEnabled" id="awscdk-resources-mongodbatlas.ProjectSettings.property.isExtendedStorageSizesEnabled"></a>

```typescript
public readonly isExtendedStorageSizesEnabled: boolean;
```

- *Type:* boolean

Flag that indicates whether to enable extended storage sizes for the specified project.

---

##### `isPerformanceAdvisorEnabled`<sup>Optional</sup> <a name="isPerformanceAdvisorEnabled" id="awscdk-resources-mongodbatlas.ProjectSettings.property.isPerformanceAdvisorEnabled"></a>

```typescript
public readonly isPerformanceAdvisorEnabled: boolean;
```

- *Type:* boolean

Flag that indicates whether to enable the Performance Advisor and Profiler for the specified project.

---

##### `isRealtimePerformancePanelEnabled`<sup>Optional</sup> <a name="isRealtimePerformancePanelEnabled" id="awscdk-resources-mongodbatlas.ProjectSettings.property.isRealtimePerformancePanelEnabled"></a>

```typescript
public readonly isRealtimePerformancePanelEnabled: boolean;
```

- *Type:* boolean

Flag that indicates whether to enable the Real Time Performance Panel for the specified project.

---

##### `isSchemaAdvisorEnabled`<sup>Optional</sup> <a name="isSchemaAdvisorEnabled" id="awscdk-resources-mongodbatlas.ProjectSettings.property.isSchemaAdvisorEnabled"></a>

```typescript
public readonly isSchemaAdvisorEnabled: boolean;
```

- *Type:* boolean

Flag that indicates whether to enable the Schema Advisor for the specified project.

---

### ProjectTeam <a name="ProjectTeam" id="awscdk-resources-mongodbatlas.ProjectTeam"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.ProjectTeam.Initializer"></a>

```typescript
import { ProjectTeam } from 'awscdk-resources-mongodbatlas'

const projectTeam: ProjectTeam = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.ProjectTeam.property.roleNames">roleNames</a></code> | <code>string[]</code> | One or more organization- or project-level roles to assign to the MongoDB Cloud user. |
| <code><a href="#awscdk-resources-mongodbatlas.ProjectTeam.property.teamId">teamId</a></code> | <code>string</code> | Unique 24-hexadecimal character string that identifies the team. |

---

##### `roleNames`<sup>Optional</sup> <a name="roleNames" id="awscdk-resources-mongodbatlas.ProjectTeam.property.roleNames"></a>

```typescript
public readonly roleNames: string[];
```

- *Type:* string[]

One or more organization- or project-level roles to assign to the MongoDB Cloud user.

tems Enum: "GROUP_CLUSTER_MANAGER" "GROUP_DATA_ACCESS_ADMIN" "GROUP_DATA_ACCESS_READ_ONLY" "GROUP_DATA_ACCESS_READ_WRITE" "GROUP_OWNER" "GROUP_READ_ONLY"

---

##### `teamId`<sup>Optional</sup> <a name="teamId" id="awscdk-resources-mongodbatlas.ProjectTeam.property.teamId"></a>

```typescript
public readonly teamId: string;
```

- *Type:* string

Unique 24-hexadecimal character string that identifies the team.

string = 24 characters ^([a-f0-9]{24})$

---

### ReadPreference <a name="ReadPreference" id="awscdk-resources-mongodbatlas.ReadPreference"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.ReadPreference.Initializer"></a>

```typescript
import { ReadPreference } from 'awscdk-resources-mongodbatlas'

const readPreference: ReadPreference = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.ReadPreference.property.maxStalenessSeconds">maxStalenessSeconds</a></code> | <code>string</code> | Maximum replication lag, or staleness, for reads from secondaries. |
| <code><a href="#awscdk-resources-mongodbatlas.ReadPreference.property.mode">mode</a></code> | <code>string</code> | "primary" "primaryPreferred" "secondary" "secondaryPreferred" "nearest" Read preference mode that specifies to which replica set member to route the read requests. |
| <code><a href="#awscdk-resources-mongodbatlas.ReadPreference.property.tagSets">tagSets</a></code> | <code><a href="#awscdk-resources-mongodbatlas.TagSet">TagSet</a>[][]</code> | List that contains tag sets or tag specification documents. |

---

##### `maxStalenessSeconds`<sup>Optional</sup> <a name="maxStalenessSeconds" id="awscdk-resources-mongodbatlas.ReadPreference.property.maxStalenessSeconds"></a>

```typescript
public readonly maxStalenessSeconds: string;
```

- *Type:* string

Maximum replication lag, or staleness, for reads from secondaries.

---

##### `mode`<sup>Optional</sup> <a name="mode" id="awscdk-resources-mongodbatlas.ReadPreference.property.mode"></a>

```typescript
public readonly mode: string;
```

- *Type:* string

"primary" "primaryPreferred" "secondary" "secondaryPreferred" "nearest" Read preference mode that specifies to which replica set member to route the read requests.

---

##### `tagSets`<sup>Optional</sup> <a name="tagSets" id="awscdk-resources-mongodbatlas.ReadPreference.property.tagSets"></a>

```typescript
public readonly tagSets: TagSet[][];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.TagSet">TagSet</a>[][]

List that contains tag sets or tag specification documents.

If specified, Atlas Data Lake routes read requests to replica set member or members that are associated with the specified tags.

---

### Resource <a name="Resource" id="awscdk-resources-mongodbatlas.Resource"></a>

List of resources on which you grant the action.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.Resource.Initializer"></a>

```typescript
import { Resource } from 'awscdk-resources-mongodbatlas'

const resource: Resource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.Resource.property.cluster">cluster</a></code> | <code>boolean</code> | Flag that indicates whether to grant the action on the cluster resource. |
| <code><a href="#awscdk-resources-mongodbatlas.Resource.property.collection">collection</a></code> | <code>string</code> | Human-readable label that identifies the collection on which you grant the action to one MongoDB user. |
| <code><a href="#awscdk-resources-mongodbatlas.Resource.property.db">db</a></code> | <code>string</code> | Human-readable label that identifies the database on which you grant the action to one MongoDB user. |

---

##### `cluster`<sup>Optional</sup> <a name="cluster" id="awscdk-resources-mongodbatlas.Resource.property.cluster"></a>

```typescript
public readonly cluster: boolean;
```

- *Type:* boolean

Flag that indicates whether to grant the action on the cluster resource.

If true, MongoDB Cloud ignores the actions.resources.collection and actions.resources.db parameters.

---

##### `collection`<sup>Optional</sup> <a name="collection" id="awscdk-resources-mongodbatlas.Resource.property.collection"></a>

```typescript
public readonly collection: string;
```

- *Type:* string

Human-readable label that identifies the collection on which you grant the action to one MongoDB user.

If you don't set this parameter, you grant the action to all collections in the database specified in the actions.resources.db parameter. If you set "actions.resources.cluster" : true, MongoDB Cloud ignores this parameter.

---

##### `db`<sup>Optional</sup> <a name="db" id="awscdk-resources-mongodbatlas.Resource.property.db"></a>

```typescript
public readonly db: string;
```

- *Type:* string

Human-readable label that identifies the database on which you grant the action to one MongoDB user.

If you set "actions.resources.cluster" : true, MongoDB Cloud ignores this parameter.

---

### RoleAssignment <a name="RoleAssignment" id="awscdk-resources-mongodbatlas.RoleAssignment"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.RoleAssignment.Initializer"></a>

```typescript
import { RoleAssignment } from 'awscdk-resources-mongodbatlas'

const roleAssignment: RoleAssignment = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.RoleAssignment.property.orgId">orgId</a></code> | <code>string</code> | List that contains comma-separated key value pairs to map zones to geographic regions. |
| <code><a href="#awscdk-resources-mongodbatlas.RoleAssignment.property.projectId">projectId</a></code> | <code>string</code> | List that contains comma-separated key value pairs to map zones to geographic regions. |
| <code><a href="#awscdk-resources-mongodbatlas.RoleAssignment.property.role">role</a></code> | <code>string</code> | *No description.* |

---

##### `orgId`<sup>Optional</sup> <a name="orgId" id="awscdk-resources-mongodbatlas.RoleAssignment.property.orgId"></a>

```typescript
public readonly orgId: string;
```

- *Type:* string

List that contains comma-separated key value pairs to map zones to geographic regions.

These pairs map an ISO 3166-1a2 location code, with an ISO 3166-2 subdivision code when possible, to a unique 24-hexadecimal string that identifies the custom zone.

This parameter returns an empty object if no custom zones exist.

---

##### `projectId`<sup>Optional</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.RoleAssignment.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

List that contains comma-separated key value pairs to map zones to geographic regions.

These pairs map an ISO 3166-1a2 location code, with an ISO 3166-2 subdivision code when possible, to a unique 24-hexadecimal string that identifies the custom zone.

This parameter returns an empty object if no custom zones exist.

---

##### `role`<sup>Optional</sup> <a name="role" id="awscdk-resources-mongodbatlas.RoleAssignment.property.role"></a>

```typescript
public readonly role: string;
```

- *Type:* string

---

### RoleDefinition <a name="RoleDefinition" id="awscdk-resources-mongodbatlas.RoleDefinition"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.RoleDefinition.Initializer"></a>

```typescript
import { RoleDefinition } from 'awscdk-resources-mongodbatlas'

const roleDefinition: RoleDefinition = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.RoleDefinition.property.collectionName">collectionName</a></code> | <code>string</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.RoleDefinition.property.databaseName">databaseName</a></code> | <code>string</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.RoleDefinition.property.roleName">roleName</a></code> | <code>string</code> | *No description.* |

---

##### `collectionName`<sup>Optional</sup> <a name="collectionName" id="awscdk-resources-mongodbatlas.RoleDefinition.property.collectionName"></a>

```typescript
public readonly collectionName: string;
```

- *Type:* string

---

##### `databaseName`<sup>Optional</sup> <a name="databaseName" id="awscdk-resources-mongodbatlas.RoleDefinition.property.databaseName"></a>

```typescript
public readonly databaseName: string;
```

- *Type:* string

---

##### `roleName`<sup>Optional</sup> <a name="roleName" id="awscdk-resources-mongodbatlas.RoleDefinition.property.roleName"></a>

```typescript
public readonly roleName: string;
```

- *Type:* string

---

### ScheduleConfig <a name="ScheduleConfig" id="awscdk-resources-mongodbatlas.ScheduleConfig"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.ScheduleConfig.Initializer"></a>

```typescript
import { ScheduleConfig } from 'awscdk-resources-mongodbatlas'

const scheduleConfig: ScheduleConfig = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.ScheduleConfig.property.schedule">schedule</a></code> | <code>string</code> | A [cron expression](https://www.mongodb.com/docs/atlas/app-services/triggers/scheduled-triggers/#cron-expressions) that specifies when the trigger executes. |
| <code><a href="#awscdk-resources-mongodbatlas.ScheduleConfig.property.skipcatchupEvents">skipcatchupEvents</a></code> | <code>boolean</code> | If `true`, enabling the trigger after it was disabled will not invoke events that occurred while the trigger was disabled. |

---

##### `schedule`<sup>Optional</sup> <a name="schedule" id="awscdk-resources-mongodbatlas.ScheduleConfig.property.schedule"></a>

```typescript
public readonly schedule: string;
```

- *Type:* string

A [cron expression](https://www.mongodb.com/docs/atlas/app-services/triggers/scheduled-triggers/#cron-expressions) that specifies when the trigger executes.

---

##### `skipcatchupEvents`<sup>Optional</sup> <a name="skipcatchupEvents" id="awscdk-resources-mongodbatlas.ScheduleConfig.property.skipcatchupEvents"></a>

```typescript
public readonly skipcatchupEvents: boolean;
```

- *Type:* boolean

If `true`, enabling the trigger after it was disabled will not invoke events that occurred while the trigger was disabled.

---

### ScheduleView <a name="ScheduleView" id="awscdk-resources-mongodbatlas.ScheduleView"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.ScheduleView.Initializer"></a>

```typescript
import { ScheduleView } from 'awscdk-resources-mongodbatlas'

const scheduleView: ScheduleView = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.ScheduleView.property.dayOfMonth">dayOfMonth</a></code> | <code>number</code> | Day of the month when the scheduled archive starts. |
| <code><a href="#awscdk-resources-mongodbatlas.ScheduleView.property.dayOfWeek">dayOfWeek</a></code> | <code>number</code> | Day of the month when the scheduled archive starts. |
| <code><a href="#awscdk-resources-mongodbatlas.ScheduleView.property.endHour">endHour</a></code> | <code>number</code> | Hour of the day when the scheduled window to run one online archive ends. |
| <code><a href="#awscdk-resources-mongodbatlas.ScheduleView.property.endMinute">endMinute</a></code> | <code>number</code> | Minute of the hour when the scheduled window to run one online archive ends. |
| <code><a href="#awscdk-resources-mongodbatlas.ScheduleView.property.startHour">startHour</a></code> | <code>number</code> | Hour of the day when the when the scheduled window to run one online archive starts. |
| <code><a href="#awscdk-resources-mongodbatlas.ScheduleView.property.startMinute">startMinute</a></code> | <code>number</code> | Minute of the hour when the scheduled window to run one online archive starts. |
| <code><a href="#awscdk-resources-mongodbatlas.ScheduleView.property.type">type</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ScheduleViewType">ScheduleViewType</a></code> | *No description.* |

---

##### `dayOfMonth`<sup>Optional</sup> <a name="dayOfMonth" id="awscdk-resources-mongodbatlas.ScheduleView.property.dayOfMonth"></a>

```typescript
public readonly dayOfMonth: number;
```

- *Type:* number

Day of the month when the scheduled archive starts.

---

##### `dayOfWeek`<sup>Optional</sup> <a name="dayOfWeek" id="awscdk-resources-mongodbatlas.ScheduleView.property.dayOfWeek"></a>

```typescript
public readonly dayOfWeek: number;
```

- *Type:* number

Day of the month when the scheduled archive starts.

---

##### `endHour`<sup>Optional</sup> <a name="endHour" id="awscdk-resources-mongodbatlas.ScheduleView.property.endHour"></a>

```typescript
public readonly endHour: number;
```

- *Type:* number

Hour of the day when the scheduled window to run one online archive ends.

---

##### `endMinute`<sup>Optional</sup> <a name="endMinute" id="awscdk-resources-mongodbatlas.ScheduleView.property.endMinute"></a>

```typescript
public readonly endMinute: number;
```

- *Type:* number

Minute of the hour when the scheduled window to run one online archive ends.

---

##### `startHour`<sup>Optional</sup> <a name="startHour" id="awscdk-resources-mongodbatlas.ScheduleView.property.startHour"></a>

```typescript
public readonly startHour: number;
```

- *Type:* number

Hour of the day when the when the scheduled window to run one online archive starts.

---

##### `startMinute`<sup>Optional</sup> <a name="startMinute" id="awscdk-resources-mongodbatlas.ScheduleView.property.startMinute"></a>

```typescript
public readonly startMinute: number;
```

- *Type:* number

Minute of the hour when the scheduled window to run one online archive starts.

---

##### `type`<sup>Optional</sup> <a name="type" id="awscdk-resources-mongodbatlas.ScheduleView.property.type"></a>

```typescript
public readonly type: ScheduleViewType;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ScheduleViewType">ScheduleViewType</a>

---

### ScopeDefinition <a name="ScopeDefinition" id="awscdk-resources-mongodbatlas.ScopeDefinition"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.ScopeDefinition.Initializer"></a>

```typescript
import { ScopeDefinition } from 'awscdk-resources-mongodbatlas'

const scopeDefinition: ScopeDefinition = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.ScopeDefinition.property.name">name</a></code> | <code>string</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.ScopeDefinition.property.type">type</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ScopeDefinitionType">ScopeDefinitionType</a></code> | *No description.* |

---

##### `name`<sup>Optional</sup> <a name="name" id="awscdk-resources-mongodbatlas.ScopeDefinition.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

---

##### `type`<sup>Optional</sup> <a name="type" id="awscdk-resources-mongodbatlas.ScopeDefinition.property.type"></a>

```typescript
public readonly type: ScopeDefinitionType;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ScopeDefinitionType">ScopeDefinitionType</a>

---

### ServerlessInstanceConnectionStrings <a name="ServerlessInstanceConnectionStrings" id="awscdk-resources-mongodbatlas.ServerlessInstanceConnectionStrings"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.ServerlessInstanceConnectionStrings.Initializer"></a>

```typescript
import { ServerlessInstanceConnectionStrings } from 'awscdk-resources-mongodbatlas'

const serverlessInstanceConnectionStrings: ServerlessInstanceConnectionStrings = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.ServerlessInstanceConnectionStrings.property.privateEndpoint">privateEndpoint</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ServerlessInstancePrivateEndpoint">ServerlessInstancePrivateEndpoint</a>[]</code> | List of private endpoint connection strings that you can use to connect to this serverless instance through a private endpoint. |
| <code><a href="#awscdk-resources-mongodbatlas.ServerlessInstanceConnectionStrings.property.standardSrv">standardSrv</a></code> | <code>string</code> | Public connection string that you can use to connect to this serverless instance. |

---

##### `privateEndpoint`<sup>Optional</sup> <a name="privateEndpoint" id="awscdk-resources-mongodbatlas.ServerlessInstanceConnectionStrings.property.privateEndpoint"></a>

```typescript
public readonly privateEndpoint: ServerlessInstancePrivateEndpoint[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ServerlessInstancePrivateEndpoint">ServerlessInstancePrivateEndpoint</a>[]

List of private endpoint connection strings that you can use to connect to this serverless instance through a private endpoint.

This parameter returns only if you created a private endpoint for this serverless instance and it is AVAILABLE.

---

##### `standardSrv`<sup>Optional</sup> <a name="standardSrv" id="awscdk-resources-mongodbatlas.ServerlessInstanceConnectionStrings.property.standardSrv"></a>

```typescript
public readonly standardSrv: string;
```

- *Type:* string

Public connection string that you can use to connect to this serverless instance.

This connection string uses the `mongodb+srv://` protocol.

---

### ServerlessInstancePrivateEndpoint <a name="ServerlessInstancePrivateEndpoint" id="awscdk-resources-mongodbatlas.ServerlessInstancePrivateEndpoint"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.ServerlessInstancePrivateEndpoint.Initializer"></a>

```typescript
import { ServerlessInstancePrivateEndpoint } from 'awscdk-resources-mongodbatlas'

const serverlessInstancePrivateEndpoint: ServerlessInstancePrivateEndpoint = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.ServerlessInstancePrivateEndpoint.property.endpoints">endpoints</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ServerlessInstancePrivateEndpointEndpoint">ServerlessInstancePrivateEndpointEndpoint</a>[]</code> | List that contains the private endpoints through which you connect to MongoDB Cloud when you use **connectionStrings.privateEndpoint[n].srvConnectionString**. |
| <code><a href="#awscdk-resources-mongodbatlas.ServerlessInstancePrivateEndpoint.property.srvConnectionString">srvConnectionString</a></code> | <code>string</code> | Private endpoint-aware connection string that uses the `mongodb+srv://` protocol to connect to MongoDB Cloud through a private endpoint. |
| <code><a href="#awscdk-resources-mongodbatlas.ServerlessInstancePrivateEndpoint.property.type">type</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ServerlessInstancePrivateEndpointType">ServerlessInstancePrivateEndpointType</a></code> | MongoDB process type to which your application connects. |

---

##### `endpoints`<sup>Optional</sup> <a name="endpoints" id="awscdk-resources-mongodbatlas.ServerlessInstancePrivateEndpoint.property.endpoints"></a>

```typescript
public readonly endpoints: ServerlessInstancePrivateEndpointEndpoint[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ServerlessInstancePrivateEndpointEndpoint">ServerlessInstancePrivateEndpointEndpoint</a>[]

List that contains the private endpoints through which you connect to MongoDB Cloud when you use **connectionStrings.privateEndpoint[n].srvConnectionString**.

---

##### `srvConnectionString`<sup>Optional</sup> <a name="srvConnectionString" id="awscdk-resources-mongodbatlas.ServerlessInstancePrivateEndpoint.property.srvConnectionString"></a>

```typescript
public readonly srvConnectionString: string;
```

- *Type:* string

Private endpoint-aware connection string that uses the `mongodb+srv://` protocol to connect to MongoDB Cloud through a private endpoint.

The `mongodb+srv` protocol tells the driver to look up the seed list of hosts in the Domain Name System (DNS).

---

##### `type`<sup>Optional</sup> <a name="type" id="awscdk-resources-mongodbatlas.ServerlessInstancePrivateEndpoint.property.type"></a>

```typescript
public readonly type: ServerlessInstancePrivateEndpointType;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ServerlessInstancePrivateEndpointType">ServerlessInstancePrivateEndpointType</a>

MongoDB process type to which your application connects.

---

### ServerlessInstancePrivateEndpointEndpoint <a name="ServerlessInstancePrivateEndpointEndpoint" id="awscdk-resources-mongodbatlas.ServerlessInstancePrivateEndpointEndpoint"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.ServerlessInstancePrivateEndpointEndpoint.Initializer"></a>

```typescript
import { ServerlessInstancePrivateEndpointEndpoint } from 'awscdk-resources-mongodbatlas'

const serverlessInstancePrivateEndpointEndpoint: ServerlessInstancePrivateEndpointEndpoint = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.ServerlessInstancePrivateEndpointEndpoint.property.endpointId">endpointId</a></code> | <code>string</code> | Unique provider identifier of the private endpoint. |
| <code><a href="#awscdk-resources-mongodbatlas.ServerlessInstancePrivateEndpointEndpoint.property.providerName">providerName</a></code> | <code>string</code> | Cloud provider where the private endpoint is deployed. |
| <code><a href="#awscdk-resources-mongodbatlas.ServerlessInstancePrivateEndpointEndpoint.property.region">region</a></code> | <code>string</code> | Region where the private endpoint is deployed. |

---

##### `endpointId`<sup>Optional</sup> <a name="endpointId" id="awscdk-resources-mongodbatlas.ServerlessInstancePrivateEndpointEndpoint.property.endpointId"></a>

```typescript
public readonly endpointId: string;
```

- *Type:* string

Unique provider identifier of the private endpoint.

---

##### `providerName`<sup>Optional</sup> <a name="providerName" id="awscdk-resources-mongodbatlas.ServerlessInstancePrivateEndpointEndpoint.property.providerName"></a>

```typescript
public readonly providerName: string;
```

- *Type:* string

Cloud provider where the private endpoint is deployed.

---

##### `region`<sup>Optional</sup> <a name="region" id="awscdk-resources-mongodbatlas.ServerlessInstancePrivateEndpointEndpoint.property.region"></a>

```typescript
public readonly region: string;
```

- *Type:* string

Region where the private endpoint is deployed.

---

### ServerlessInstanceProviderSettings <a name="ServerlessInstanceProviderSettings" id="awscdk-resources-mongodbatlas.ServerlessInstanceProviderSettings"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.ServerlessInstanceProviderSettings.Initializer"></a>

```typescript
import { ServerlessInstanceProviderSettings } from 'awscdk-resources-mongodbatlas'

const serverlessInstanceProviderSettings: ServerlessInstanceProviderSettings = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.ServerlessInstanceProviderSettings.property.providerName">providerName</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ServerlessInstanceProviderSettingsProviderName">ServerlessInstanceProviderSettingsProviderName</a></code> | Human-readable label that identifies the cloud service provider. |
| <code><a href="#awscdk-resources-mongodbatlas.ServerlessInstanceProviderSettings.property.regionName">regionName</a></code> | <code>string</code> | Human-readable label that identifies the geographic location of your MongoDB serverless instance. |

---

##### `providerName`<sup>Optional</sup> <a name="providerName" id="awscdk-resources-mongodbatlas.ServerlessInstanceProviderSettings.property.providerName"></a>

```typescript
public readonly providerName: ServerlessInstanceProviderSettingsProviderName;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ServerlessInstanceProviderSettingsProviderName">ServerlessInstanceProviderSettingsProviderName</a>

Human-readable label that identifies the cloud service provider.

---

##### `regionName`<sup>Optional</sup> <a name="regionName" id="awscdk-resources-mongodbatlas.ServerlessInstanceProviderSettings.property.regionName"></a>

```typescript
public readonly regionName: string;
```

- *Type:* string

Human-readable label that identifies the geographic location of your MongoDB serverless instance.

The region you choose can affect network latency for clients accessing your databases. For a complete list of region names, see [AWS](https://docs.atlas.mongodb.com/reference/amazon-aws/#std-label-amazon-aws), [GCP](https://docs.atlas.mongodb.com/reference/google-gcp/), and [Azure](https://docs.atlas.mongodb.com/reference/microsoft-azure/).

---

### ServerlessPrivateEndpoint <a name="ServerlessPrivateEndpoint" id="awscdk-resources-mongodbatlas.ServerlessPrivateEndpoint"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.ServerlessPrivateEndpoint.Initializer"></a>

```typescript
import { ServerlessPrivateEndpoint } from 'awscdk-resources-mongodbatlas'

const serverlessPrivateEndpoint: ServerlessPrivateEndpoint = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.ServerlessPrivateEndpoint.property.atlasPrivateEndpointStatus">atlasPrivateEndpointStatus</a></code> | <code>string</code> | Status of the Atlas PrivateEndpoint connection. |
| <code><a href="#awscdk-resources-mongodbatlas.ServerlessPrivateEndpoint.property.awsPrivateEndpointStatus">awsPrivateEndpointStatus</a></code> | <code>string</code> | Status of the AWS PrivateEndpoint connection. |
| <code><a href="#awscdk-resources-mongodbatlas.ServerlessPrivateEndpoint.property.comment">comment</a></code> | <code>string</code> | string to represent the comment. |
| <code><a href="#awscdk-resources-mongodbatlas.ServerlessPrivateEndpoint.property.createAndAssignAWSPrivateEndpoint">createAndAssignAWSPrivateEndpoint</a></code> | <code>boolean</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.ServerlessPrivateEndpoint.property.interfaceEndpointId">interfaceEndpointId</a></code> | <code>string</code> | Unique identifiers of the interface endpoints in your VPC that you added to the AWS PrivateLink connection. |
| <code><a href="#awscdk-resources-mongodbatlas.ServerlessPrivateEndpoint.property.subnetIds">subnetIds</a></code> | <code>string[]</code> | List of string representing the AWS VPC Subnet ID (like: subnet-xxxxxxxxxxxxxxxxx) (Used For Creating the AWS VPC Endpoint). |
| <code><a href="#awscdk-resources-mongodbatlas.ServerlessPrivateEndpoint.property.vpcId">vpcId</a></code> | <code>string</code> | String Representing the AWS VPC ID (like: vpc-xxxxxxxxxxxxxxxx) (Used For Creating the AWS VPC Endpoint). |

---

##### `atlasPrivateEndpointStatus`<sup>Optional</sup> <a name="atlasPrivateEndpointStatus" id="awscdk-resources-mongodbatlas.ServerlessPrivateEndpoint.property.atlasPrivateEndpointStatus"></a>

```typescript
public readonly atlasPrivateEndpointStatus: string;
```

- *Type:* string

Status of the Atlas PrivateEndpoint connection.

---

##### `awsPrivateEndpointStatus`<sup>Optional</sup> <a name="awsPrivateEndpointStatus" id="awscdk-resources-mongodbatlas.ServerlessPrivateEndpoint.property.awsPrivateEndpointStatus"></a>

```typescript
public readonly awsPrivateEndpointStatus: string;
```

- *Type:* string

Status of the AWS PrivateEndpoint connection.

---

##### `comment`<sup>Optional</sup> <a name="comment" id="awscdk-resources-mongodbatlas.ServerlessPrivateEndpoint.property.comment"></a>

```typescript
public readonly comment: string;
```

- *Type:* string

string to represent the comment.

---

##### `createAndAssignAWSPrivateEndpoint`<sup>Optional</sup> <a name="createAndAssignAWSPrivateEndpoint" id="awscdk-resources-mongodbatlas.ServerlessPrivateEndpoint.property.createAndAssignAWSPrivateEndpoint"></a>

```typescript
public readonly createAndAssignAWSPrivateEndpoint: boolean;
```

- *Type:* boolean

---

##### `interfaceEndpointId`<sup>Optional</sup> <a name="interfaceEndpointId" id="awscdk-resources-mongodbatlas.ServerlessPrivateEndpoint.property.interfaceEndpointId"></a>

```typescript
public readonly interfaceEndpointId: string;
```

- *Type:* string

Unique identifiers of the interface endpoints in your VPC that you added to the AWS PrivateLink connection.

---

##### `subnetIds`<sup>Optional</sup> <a name="subnetIds" id="awscdk-resources-mongodbatlas.ServerlessPrivateEndpoint.property.subnetIds"></a>

```typescript
public readonly subnetIds: string[];
```

- *Type:* string[]

List of string representing the AWS VPC Subnet ID (like: subnet-xxxxxxxxxxxxxxxxx) (Used For Creating the AWS VPC Endpoint).

---

##### `vpcId`<sup>Optional</sup> <a name="vpcId" id="awscdk-resources-mongodbatlas.ServerlessPrivateEndpoint.property.vpcId"></a>

```typescript
public readonly vpcId: string;
```

- *Type:* string

String Representing the AWS VPC ID (like: vpc-xxxxxxxxxxxxxxxx) (Used For Creating the AWS VPC Endpoint).

---

### Sink <a name="Sink" id="awscdk-resources-mongodbatlas.Sink"></a>

Ingestion destination of a Data Lake Pipeline.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.Sink.Initializer"></a>

```typescript
import { Sink } from 'awscdk-resources-mongodbatlas'

const sink: Sink = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.Sink.property.metadataProvider">metadataProvider</a></code> | <code>string</code> | Target cloud provider for this Data Lake Pipeline. |
| <code><a href="#awscdk-resources-mongodbatlas.Sink.property.metadataRegion">metadataRegion</a></code> | <code>string</code> | Target cloud provider region for this Data Lake Pipeline. |
| <code><a href="#awscdk-resources-mongodbatlas.Sink.property.partitionFields">partitionFields</a></code> | <code><a href="#awscdk-resources-mongodbatlas.PartitionFields">PartitionFields</a>[]</code> | Ordered fields used to physically organize data in the destination. |
| <code><a href="#awscdk-resources-mongodbatlas.Sink.property.type">type</a></code> | <code><a href="#awscdk-resources-mongodbatlas.SinkType">SinkType</a></code> | Type of ingestion destination of this Data Lake Pipeline. |

---

##### `metadataProvider`<sup>Optional</sup> <a name="metadataProvider" id="awscdk-resources-mongodbatlas.Sink.property.metadataProvider"></a>

```typescript
public readonly metadataProvider: string;
```

- *Type:* string

Target cloud provider for this Data Lake Pipeline.

---

##### `metadataRegion`<sup>Optional</sup> <a name="metadataRegion" id="awscdk-resources-mongodbatlas.Sink.property.metadataRegion"></a>

```typescript
public readonly metadataRegion: string;
```

- *Type:* string

Target cloud provider region for this Data Lake Pipeline.

---

##### `partitionFields`<sup>Optional</sup> <a name="partitionFields" id="awscdk-resources-mongodbatlas.Sink.property.partitionFields"></a>

```typescript
public readonly partitionFields: PartitionFields[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.PartitionFields">PartitionFields</a>[]

Ordered fields used to physically organize data in the destination.

---

##### `type`<sup>Optional</sup> <a name="type" id="awscdk-resources-mongodbatlas.Sink.property.type"></a>

```typescript
public readonly type: SinkType;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.SinkType">SinkType</a>

Type of ingestion destination of this Data Lake Pipeline.

---

### Source <a name="Source" id="awscdk-resources-mongodbatlas.Source"></a>

Ingestion destination of a Data Lake Pipeline.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.Source.Initializer"></a>

```typescript
import { Source } from 'awscdk-resources-mongodbatlas'

const source: Source = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.Source.property.clusterName">clusterName</a></code> | <code>string</code> | Human-readable name that identifies the cluster. |
| <code><a href="#awscdk-resources-mongodbatlas.Source.property.collectionName">collectionName</a></code> | <code>string</code> | Human-readable name that identifies the collection. |
| <code><a href="#awscdk-resources-mongodbatlas.Source.property.databaseName">databaseName</a></code> | <code>string</code> | Human-readable name that identifies the database. |
| <code><a href="#awscdk-resources-mongodbatlas.Source.property.groupId">groupId</a></code> | <code>string</code> | Unique 24-hexadecimal character string that identifies the project. |
| <code><a href="#awscdk-resources-mongodbatlas.Source.property.type">type</a></code> | <code><a href="#awscdk-resources-mongodbatlas.SourceType">SourceType</a></code> | Type of ingestion source of this Data Lake Pipeline. |

---

##### `clusterName`<sup>Optional</sup> <a name="clusterName" id="awscdk-resources-mongodbatlas.Source.property.clusterName"></a>

```typescript
public readonly clusterName: string;
```

- *Type:* string

Human-readable name that identifies the cluster.

---

##### `collectionName`<sup>Optional</sup> <a name="collectionName" id="awscdk-resources-mongodbatlas.Source.property.collectionName"></a>

```typescript
public readonly collectionName: string;
```

- *Type:* string

Human-readable name that identifies the collection.

---

##### `databaseName`<sup>Optional</sup> <a name="databaseName" id="awscdk-resources-mongodbatlas.Source.property.databaseName"></a>

```typescript
public readonly databaseName: string;
```

- *Type:* string

Human-readable name that identifies the database.

---

##### `groupId`<sup>Optional</sup> <a name="groupId" id="awscdk-resources-mongodbatlas.Source.property.groupId"></a>

```typescript
public readonly groupId: string;
```

- *Type:* string

Unique 24-hexadecimal character string that identifies the project.

---

##### `type`<sup>Optional</sup> <a name="type" id="awscdk-resources-mongodbatlas.Source.property.type"></a>

```typescript
public readonly type: SourceType;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.SourceType">SourceType</a>

Type of ingestion source of this Data Lake Pipeline.

---

### Specs <a name="Specs" id="awscdk-resources-mongodbatlas.Specs"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.Specs.Initializer"></a>

```typescript
import { Specs } from 'awscdk-resources-mongodbatlas'

const specs: Specs = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.Specs.property.diskIops">diskIops</a></code> | <code>string</code> | Target throughput desired for storage attached to your AWS-provisioned cluster. Only change this parameter if you:. |
| <code><a href="#awscdk-resources-mongodbatlas.Specs.property.ebsVolumeType">ebsVolumeType</a></code> | <code>string</code> | Type of storage you want to attach to your AWS-provisioned cluster. |
| <code><a href="#awscdk-resources-mongodbatlas.Specs.property.instanceSize">instanceSize</a></code> | <code>string</code> | Hardware specification for the instance sizes in this region. |
| <code><a href="#awscdk-resources-mongodbatlas.Specs.property.nodeCount">nodeCount</a></code> | <code>number</code> | Number of read-only nodes for MongoDB Cloud deploys to the region. |

---

##### `diskIops`<sup>Optional</sup> <a name="diskIops" id="awscdk-resources-mongodbatlas.Specs.property.diskIops"></a>

```typescript
public readonly diskIops: string;
```

- *Type:* string

Target throughput desired for storage attached to your AWS-provisioned cluster. Only change this parameter if you:.

set "replicationSpecs[n].regionConfigs[m].providerName" : "AWS".
set "replicationSpecs[n].regionConfigs[m].electableSpecs.instanceSize" : "M30" or greater not including Mxx_NVME tiers.
The maximum input/output operations per second (IOPS) depend on the selected .instanceSize and .diskSizeGB. This parameter defaults to the cluster tier's standard IOPS value. Changing this value impacts cluster cost. MongoDB Cloud enforces minimum ratios of storage capacity to system memory for given cluster tiers. This keeps cluster performance consistent with large datasets.

Instance sizes M10 to M40 have a ratio of disk capacity to system memory of 60:1.
Instance sizes greater than M40 have a ratio of 120:1.

---

##### `ebsVolumeType`<sup>Optional</sup> <a name="ebsVolumeType" id="awscdk-resources-mongodbatlas.Specs.property.ebsVolumeType"></a>

```typescript
public readonly ebsVolumeType: string;
```

- *Type:* string

Type of storage you want to attach to your AWS-provisioned cluster.

STANDARD volume types can't exceed the default input/output operations per second (IOPS) rate for the selected volume size.

PROVISIONED volume types must fall within the allowable IOPS range for the selected volume size."

---

##### `instanceSize`<sup>Optional</sup> <a name="instanceSize" id="awscdk-resources-mongodbatlas.Specs.property.instanceSize"></a>

```typescript
public readonly instanceSize: string;
```

- *Type:* string

Hardware specification for the instance sizes in this region.

Each instance size has a default storage and memory capacity. The instance size you select applies to all the data-bearing hosts in your instance size. If you deploy a Global Cluster, you must choose a instance size of M30 or greater.

---

##### `nodeCount`<sup>Optional</sup> <a name="nodeCount" id="awscdk-resources-mongodbatlas.Specs.property.nodeCount"></a>

```typescript
public readonly nodeCount: number;
```

- *Type:* number

Number of read-only nodes for MongoDB Cloud deploys to the region.

Read-only nodes can never become the primary, but can enable local reads.

---

### Storage <a name="Storage" id="awscdk-resources-mongodbatlas.Storage"></a>

Configuration information for each data store and its mapping to MongoDB Cloud databases.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.Storage.Initializer"></a>

```typescript
import { Storage } from 'awscdk-resources-mongodbatlas'

const storage: Storage = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.Storage.property.databases">databases</a></code> | <code><a href="#awscdk-resources-mongodbatlas.Database">Database</a>[]</code> | Array that contains the queryable databases and collections for this data lake. |
| <code><a href="#awscdk-resources-mongodbatlas.Storage.property.stores">stores</a></code> | <code><a href="#awscdk-resources-mongodbatlas.Store">Store</a>[]</code> | Array that contains the data stores for the data lake. |

---

##### `databases`<sup>Optional</sup> <a name="databases" id="awscdk-resources-mongodbatlas.Storage.property.databases"></a>

```typescript
public readonly databases: Database[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.Database">Database</a>[]

Array that contains the queryable databases and collections for this data lake.

---

##### `stores`<sup>Optional</sup> <a name="stores" id="awscdk-resources-mongodbatlas.Storage.property.stores"></a>

```typescript
public readonly stores: Store[];
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.Store">Store</a>[]

Array that contains the data stores for the data lake.

---

### Store <a name="Store" id="awscdk-resources-mongodbatlas.Store"></a>

Array that contains the data stores for the data lake.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.Store.Initializer"></a>

```typescript
import { Store } from 'awscdk-resources-mongodbatlas'

const store: Store = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.Store.property.clusterName">clusterName</a></code> | <code>string</code> | Human-readable label of the MongoDB Cloud cluster on which the store is based. |
| <code><a href="#awscdk-resources-mongodbatlas.Store.property.name">name</a></code> | <code>string</code> | Human-readable label that identifies the data store. |
| <code><a href="#awscdk-resources-mongodbatlas.Store.property.projectId">projectId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies the project.Regex ^([a-f0-9]{24})$ . |
| <code><a href="#awscdk-resources-mongodbatlas.Store.property.provider">provider</a></code> | <code>string</code> | Allowed values atlas, http, online_archive, s3 and DataLakeAzureBlobStore. |
| <code><a href="#awscdk-resources-mongodbatlas.Store.property.readPreference">readPreference</a></code> | <code><a href="#awscdk-resources-mongodbatlas.ReadPreference">ReadPreference</a></code> | MongoDB Cloud cluster read preference, which describes how to route read requests to the cluster. |

---

##### `clusterName`<sup>Optional</sup> <a name="clusterName" id="awscdk-resources-mongodbatlas.Store.property.clusterName"></a>

```typescript
public readonly clusterName: string;
```

- *Type:* string

Human-readable label of the MongoDB Cloud cluster on which the store is based.

---

##### `name`<sup>Optional</sup> <a name="name" id="awscdk-resources-mongodbatlas.Store.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Human-readable label that identifies the data store.

The databases.[n].collections.[n].dataSources.[n].storeName field references this values as part of the mapping configuration. To use MongoDB Cloud as a data store, the data lake requires a serverless instance or an M10 or higher cluster.

---

##### `projectId`<sup>Optional</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.Store.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies the project.Regex ^([a-f0-9]{24})$ .

---

##### `provider`<sup>Optional</sup> <a name="provider" id="awscdk-resources-mongodbatlas.Store.property.provider"></a>

```typescript
public readonly provider: string;
```

- *Type:* string

Allowed values atlas, http, online_archive, s3 and DataLakeAzureBlobStore.

---

##### `readPreference`<sup>Optional</sup> <a name="readPreference" id="awscdk-resources-mongodbatlas.Store.property.readPreference"></a>

```typescript
public readonly readPreference: ReadPreference;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.ReadPreference">ReadPreference</a>

MongoDB Cloud cluster read preference, which describes how to route read requests to the cluster.

---

### StoreDetail <a name="StoreDetail" id="awscdk-resources-mongodbatlas.StoreDetail"></a>

Configuration information for each data store and its mapping to MongoDB Cloud databases.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.StoreDetail.Initializer"></a>

```typescript
import { StoreDetail } from 'awscdk-resources-mongodbatlas'

const storeDetail: StoreDetail = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.StoreDetail.property.additionalStorageClasses">additionalStorageClasses</a></code> | <code>string[]</code> | Human-readable label that identifies the Federated Database to update. |
| <code><a href="#awscdk-resources-mongodbatlas.StoreDetail.property.bucket">bucket</a></code> | <code>string</code> | Human-readable label that identifies the Federated Database to update. |
| <code><a href="#awscdk-resources-mongodbatlas.StoreDetail.property.delimiter">delimiter</a></code> | <code>string</code> | Human-readable label that identifies the Federated Database to update. |
| <code><a href="#awscdk-resources-mongodbatlas.StoreDetail.property.includeTags">includeTags</a></code> | <code>boolean</code> | Human-readable label that identifies the Federated Database to update. |
| <code><a href="#awscdk-resources-mongodbatlas.StoreDetail.property.name">name</a></code> | <code>string</code> | Human-readable label that identifies the data store. |
| <code><a href="#awscdk-resources-mongodbatlas.StoreDetail.property.prefix">prefix</a></code> | <code>string</code> | Human-readable label that identifies the Federated Database to update. |
| <code><a href="#awscdk-resources-mongodbatlas.StoreDetail.property.provider">provider</a></code> | <code>string</code> | Human-readable label that identifies the Federated Database to update. |
| <code><a href="#awscdk-resources-mongodbatlas.StoreDetail.property.region">region</a></code> | <code>string</code> | Human-readable label that identifies the Federated Database to update. |

---

##### `additionalStorageClasses`<sup>Optional</sup> <a name="additionalStorageClasses" id="awscdk-resources-mongodbatlas.StoreDetail.property.additionalStorageClasses"></a>

```typescript
public readonly additionalStorageClasses: string[];
```

- *Type:* string[]

Human-readable label that identifies the Federated Database to update.

---

##### `bucket`<sup>Optional</sup> <a name="bucket" id="awscdk-resources-mongodbatlas.StoreDetail.property.bucket"></a>

```typescript
public readonly bucket: string;
```

- *Type:* string

Human-readable label that identifies the Federated Database to update.

---

##### `delimiter`<sup>Optional</sup> <a name="delimiter" id="awscdk-resources-mongodbatlas.StoreDetail.property.delimiter"></a>

```typescript
public readonly delimiter: string;
```

- *Type:* string

Human-readable label that identifies the Federated Database to update.

---

##### `includeTags`<sup>Optional</sup> <a name="includeTags" id="awscdk-resources-mongodbatlas.StoreDetail.property.includeTags"></a>

```typescript
public readonly includeTags: boolean;
```

- *Type:* boolean

Human-readable label that identifies the Federated Database to update.

---

##### `name`<sup>Optional</sup> <a name="name" id="awscdk-resources-mongodbatlas.StoreDetail.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Human-readable label that identifies the data store.

---

##### `prefix`<sup>Optional</sup> <a name="prefix" id="awscdk-resources-mongodbatlas.StoreDetail.property.prefix"></a>

```typescript
public readonly prefix: string;
```

- *Type:* string

Human-readable label that identifies the Federated Database to update.

---

##### `provider`<sup>Optional</sup> <a name="provider" id="awscdk-resources-mongodbatlas.StoreDetail.property.provider"></a>

```typescript
public readonly provider: string;
```

- *Type:* string

Human-readable label that identifies the Federated Database to update.

---

##### `region`<sup>Optional</sup> <a name="region" id="awscdk-resources-mongodbatlas.StoreDetail.property.region"></a>

```typescript
public readonly region: string;
```

- *Type:* string

Human-readable label that identifies the Federated Database to update.

---

### StreamConfig <a name="StreamConfig" id="awscdk-resources-mongodbatlas.StreamConfig"></a>

Configuration options for an Atlas Stream Processing Instance.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.StreamConfig.Initializer"></a>

```typescript
import { StreamConfig } from 'awscdk-resources-mongodbatlas'

const streamConfig: StreamConfig = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.StreamConfig.property.tier">tier</a></code> | <code>string</code> | Selected tier for the Stream Instance. |

---

##### `tier`<sup>Optional</sup> <a name="tier" id="awscdk-resources-mongodbatlas.StreamConfig.property.tier"></a>

```typescript
public readonly tier: string;
```

- *Type:* string

Selected tier for the Stream Instance.

Configures Memory / VCPU allowances.

---

### StreamsConnection <a name="StreamsConnection" id="awscdk-resources-mongodbatlas.StreamsConnection"></a>

Settings that define a connection to an external data store.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.StreamsConnection.Initializer"></a>

```typescript
import { StreamsConnection } from 'awscdk-resources-mongodbatlas'

const streamsConnection: StreamsConnection = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.StreamsConnection.property.authentication">authentication</a></code> | <code><a href="#awscdk-resources-mongodbatlas.StreamsKafkaAuthentication">StreamsKafkaAuthentication</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.StreamsConnection.property.bootstrapServers">bootstrapServers</a></code> | <code>string</code> | Comma separated list of server addresses. |
| <code><a href="#awscdk-resources-mongodbatlas.StreamsConnection.property.clusterName">clusterName</a></code> | <code>string</code> | Name of the cluster configured for this connection. |
| <code><a href="#awscdk-resources-mongodbatlas.StreamsConnection.property.dbRoleToExecute">dbRoleToExecute</a></code> | <code><a href="#awscdk-resources-mongodbatlas.DbRoleToExecute">DbRoleToExecute</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.StreamsConnection.property.name">name</a></code> | <code>string</code> | Human-readable label that identifies the stream connection. |
| <code><a href="#awscdk-resources-mongodbatlas.StreamsConnection.property.security">security</a></code> | <code><a href="#awscdk-resources-mongodbatlas.StreamsKafkaSecurity">StreamsKafkaSecurity</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.StreamsConnection.property.type">type</a></code> | <code><a href="#awscdk-resources-mongodbatlas.StreamsConnectionType">StreamsConnectionType</a></code> | Type of the connection. |

---

##### `authentication`<sup>Optional</sup> <a name="authentication" id="awscdk-resources-mongodbatlas.StreamsConnection.property.authentication"></a>

```typescript
public readonly authentication: StreamsKafkaAuthentication;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.StreamsKafkaAuthentication">StreamsKafkaAuthentication</a>

---

##### `bootstrapServers`<sup>Optional</sup> <a name="bootstrapServers" id="awscdk-resources-mongodbatlas.StreamsConnection.property.bootstrapServers"></a>

```typescript
public readonly bootstrapServers: string;
```

- *Type:* string

Comma separated list of server addresses.

---

##### `clusterName`<sup>Optional</sup> <a name="clusterName" id="awscdk-resources-mongodbatlas.StreamsConnection.property.clusterName"></a>

```typescript
public readonly clusterName: string;
```

- *Type:* string

Name of the cluster configured for this connection.

---

##### `dbRoleToExecute`<sup>Optional</sup> <a name="dbRoleToExecute" id="awscdk-resources-mongodbatlas.StreamsConnection.property.dbRoleToExecute"></a>

```typescript
public readonly dbRoleToExecute: DbRoleToExecute;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.DbRoleToExecute">DbRoleToExecute</a>

---

##### `name`<sup>Optional</sup> <a name="name" id="awscdk-resources-mongodbatlas.StreamsConnection.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Human-readable label that identifies the stream connection.

---

##### `security`<sup>Optional</sup> <a name="security" id="awscdk-resources-mongodbatlas.StreamsConnection.property.security"></a>

```typescript
public readonly security: StreamsKafkaSecurity;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.StreamsKafkaSecurity">StreamsKafkaSecurity</a>

---

##### `type`<sup>Optional</sup> <a name="type" id="awscdk-resources-mongodbatlas.StreamsConnection.property.type"></a>

```typescript
public readonly type: StreamsConnectionType;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.StreamsConnectionType">StreamsConnectionType</a>

Type of the connection.

Can be either Cluster or Kafka.

---

### StreamsDataProcessRegion <a name="StreamsDataProcessRegion" id="awscdk-resources-mongodbatlas.StreamsDataProcessRegion"></a>

Information about the cloud provider region in which MongoDB Cloud processes the stream.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.StreamsDataProcessRegion.Initializer"></a>

```typescript
import { StreamsDataProcessRegion } from 'awscdk-resources-mongodbatlas'

const streamsDataProcessRegion: StreamsDataProcessRegion = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.StreamsDataProcessRegion.property.cloudProvider">cloudProvider</a></code> | <code><a href="#awscdk-resources-mongodbatlas.StreamsDataProcessRegionCloudProvider">StreamsDataProcessRegionCloudProvider</a></code> | Label that identifies the cloud service provider where MongoDB Cloud performs stream processing. |
| <code><a href="#awscdk-resources-mongodbatlas.StreamsDataProcessRegion.property.region">region</a></code> | <code>string</code> | *No description.* |

---

##### `cloudProvider`<sup>Required</sup> <a name="cloudProvider" id="awscdk-resources-mongodbatlas.StreamsDataProcessRegion.property.cloudProvider"></a>

```typescript
public readonly cloudProvider: StreamsDataProcessRegionCloudProvider;
```

- *Type:* <a href="#awscdk-resources-mongodbatlas.StreamsDataProcessRegionCloudProvider">StreamsDataProcessRegionCloudProvider</a>

Label that identifies the cloud service provider where MongoDB Cloud performs stream processing.

Currently, this parameter supports AWS only.

---

##### `region`<sup>Required</sup> <a name="region" id="awscdk-resources-mongodbatlas.StreamsDataProcessRegion.property.region"></a>

```typescript
public readonly region: string;
```

- *Type:* string

---

### StreamsKafkaAuthentication <a name="StreamsKafkaAuthentication" id="awscdk-resources-mongodbatlas.StreamsKafkaAuthentication"></a>

User credentials required to connect to a Kafka Cluster.

Includes the authentication type, as well as the parameters for that authentication mode.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.StreamsKafkaAuthentication.Initializer"></a>

```typescript
import { StreamsKafkaAuthentication } from 'awscdk-resources-mongodbatlas'

const streamsKafkaAuthentication: StreamsKafkaAuthentication = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.StreamsKafkaAuthentication.property.mechanism">mechanism</a></code> | <code>string</code> | Style of authentication. |
| <code><a href="#awscdk-resources-mongodbatlas.StreamsKafkaAuthentication.property.password">password</a></code> | <code>string</code> | Password of the account to connect to the Kafka cluster. |
| <code><a href="#awscdk-resources-mongodbatlas.StreamsKafkaAuthentication.property.username">username</a></code> | <code>string</code> | Username of the account to connect to the Kafka cluster. |

---

##### `mechanism`<sup>Optional</sup> <a name="mechanism" id="awscdk-resources-mongodbatlas.StreamsKafkaAuthentication.property.mechanism"></a>

```typescript
public readonly mechanism: string;
```

- *Type:* string

Style of authentication.

Can be one of PLAIN, SCRAM-256, or SCRAM-512.

---

##### `password`<sup>Optional</sup> <a name="password" id="awscdk-resources-mongodbatlas.StreamsKafkaAuthentication.property.password"></a>

```typescript
public readonly password: string;
```

- *Type:* string

Password of the account to connect to the Kafka cluster.

Review [AWS security best practices for CloudFormation](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/security-best-practices.html#creds) to manage credentials.

---

##### `username`<sup>Optional</sup> <a name="username" id="awscdk-resources-mongodbatlas.StreamsKafkaAuthentication.property.username"></a>

```typescript
public readonly username: string;
```

- *Type:* string

Username of the account to connect to the Kafka cluster.

---

### StreamsKafkaSecurity <a name="StreamsKafkaSecurity" id="awscdk-resources-mongodbatlas.StreamsKafkaSecurity"></a>

Properties for the secure transport connection to Kafka.

For SSL, this can include the trusted certificate to use.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.StreamsKafkaSecurity.Initializer"></a>

```typescript
import { StreamsKafkaSecurity } from 'awscdk-resources-mongodbatlas'

const streamsKafkaSecurity: StreamsKafkaSecurity = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.StreamsKafkaSecurity.property.brokerPublicCertificate">brokerPublicCertificate</a></code> | <code>string</code> | A trusted, public x509 certificate for connecting to Kafka over SSL. |
| <code><a href="#awscdk-resources-mongodbatlas.StreamsKafkaSecurity.property.protocol">protocol</a></code> | <code>string</code> | Describes the transport type. |

---

##### `brokerPublicCertificate`<sup>Optional</sup> <a name="brokerPublicCertificate" id="awscdk-resources-mongodbatlas.StreamsKafkaSecurity.property.brokerPublicCertificate"></a>

```typescript
public readonly brokerPublicCertificate: string;
```

- *Type:* string

A trusted, public x509 certificate for connecting to Kafka over SSL.

---

##### `protocol`<sup>Optional</sup> <a name="protocol" id="awscdk-resources-mongodbatlas.StreamsKafkaSecurity.property.protocol"></a>

```typescript
public readonly protocol: string;
```

- *Type:* string

Describes the transport type.

Can be either PLAINTEXT or SSL.

---

### SynchronousCreationOptions <a name="SynchronousCreationOptions" id="awscdk-resources-mongodbatlas.SynchronousCreationOptions"></a>

Options that needs to be set to control the synchronous creation flow, this options need to be set if EnableSynchronousCreation is se to TRUE.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.SynchronousCreationOptions.Initializer"></a>

```typescript
import { SynchronousCreationOptions } from 'awscdk-resources-mongodbatlas'

const synchronousCreationOptions: SynchronousCreationOptions = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.SynchronousCreationOptions.property.callbackDelaySeconds">callbackDelaySeconds</a></code> | <code>number</code> | Represents the time interval, measured in seconds, for the synchronous process to wait before checking again to verify if the job has been completed. |
| <code><a href="#awscdk-resources-mongodbatlas.SynchronousCreationOptions.property.returnSuccessIfTimeOut">returnSuccessIfTimeOut</a></code> | <code>boolean</code> | if set to true, the process will return success, in the event of a timeOut, default false. |
| <code><a href="#awscdk-resources-mongodbatlas.SynchronousCreationOptions.property.timeOutInSeconds">timeOutInSeconds</a></code> | <code>number</code> | The amount of time the process will wait until exiting with a success, default (1200 seconds). |

---

##### `callbackDelaySeconds`<sup>Optional</sup> <a name="callbackDelaySeconds" id="awscdk-resources-mongodbatlas.SynchronousCreationOptions.property.callbackDelaySeconds"></a>

```typescript
public readonly callbackDelaySeconds: number;
```

- *Type:* number

Represents the time interval, measured in seconds, for the synchronous process to wait before checking again to verify if the job has been completed.

example: if set to 20, it will chek every 20 seconds if the resource is completed, default (30 seconds)

---

##### `returnSuccessIfTimeOut`<sup>Optional</sup> <a name="returnSuccessIfTimeOut" id="awscdk-resources-mongodbatlas.SynchronousCreationOptions.property.returnSuccessIfTimeOut"></a>

```typescript
public readonly returnSuccessIfTimeOut: boolean;
```

- *Type:* boolean

if set to true, the process will return success, in the event of a timeOut, default false.

---

##### `timeOutInSeconds`<sup>Optional</sup> <a name="timeOutInSeconds" id="awscdk-resources-mongodbatlas.SynchronousCreationOptions.property.timeOutInSeconds"></a>

```typescript
public readonly timeOutInSeconds: number;
```

- *Type:* number

The amount of time the process will wait until exiting with a success, default (1200 seconds).

---

### SynonymSource <a name="SynonymSource" id="awscdk-resources-mongodbatlas.SynonymSource"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.SynonymSource.Initializer"></a>

```typescript
import { SynonymSource } from 'awscdk-resources-mongodbatlas'

const synonymSource: SynonymSource = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.SynonymSource.property.collection">collection</a></code> | <code>string</code> | Human-readable label that identifies the MongoDB collection that stores words and their applicable synonyms. |

---

##### `collection`<sup>Required</sup> <a name="collection" id="awscdk-resources-mongodbatlas.SynonymSource.property.collection"></a>

```typescript
public readonly collection: string;
```

- *Type:* string

Human-readable label that identifies the MongoDB collection that stores words and their applicable synonyms.

---

### Tag <a name="Tag" id="awscdk-resources-mongodbatlas.Tag"></a>

Advanced configuration details to add for one cluster in the specified project.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.Tag.Initializer"></a>

```typescript
import { Tag } from 'awscdk-resources-mongodbatlas'

const tag: Tag = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.Tag.property.key">key</a></code> | <code>string</code> | Constant that defines the set of the tag. |
| <code><a href="#awscdk-resources-mongodbatlas.Tag.property.value">value</a></code> | <code>string</code> | Variable that belongs to the set of the tag. |

---

##### `key`<sup>Optional</sup> <a name="key" id="awscdk-resources-mongodbatlas.Tag.property.key"></a>

```typescript
public readonly key: string;
```

- *Type:* string

Constant that defines the set of the tag.

For example, environment in the environment : production tag.

---

##### `value`<sup>Optional</sup> <a name="value" id="awscdk-resources-mongodbatlas.Tag.property.value"></a>

```typescript
public readonly value: string;
```

- *Type:* string

Variable that belongs to the set of the tag.

For example, production in the environment : production tag.

---

### TagSet <a name="TagSet" id="awscdk-resources-mongodbatlas.TagSet"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.TagSet.Initializer"></a>

```typescript
import { TagSet } from 'awscdk-resources-mongodbatlas'

const tagSet: TagSet = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.TagSet.property.name">name</a></code> | <code>string</code> | Human-readable label of the tag. |
| <code><a href="#awscdk-resources-mongodbatlas.TagSet.property.value">value</a></code> | <code>string</code> | Human-readable label of the tag. |

---

##### `name`<sup>Optional</sup> <a name="name" id="awscdk-resources-mongodbatlas.TagSet.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Human-readable label of the tag.

---

##### `value`<sup>Optional</sup> <a name="value" id="awscdk-resources-mongodbatlas.TagSet.property.value"></a>

```typescript
public readonly value: string;
```

- *Type:* string

Human-readable label of the tag.

---

### ThirdPartyIntegrationProps <a name="ThirdPartyIntegrationProps" id="awscdk-resources-mongodbatlas.ThirdPartyIntegrationProps"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.ThirdPartyIntegrationProps.Initializer"></a>

```typescript
import { ThirdPartyIntegrationProps } from 'awscdk-resources-mongodbatlas'

const thirdPartyIntegrationProps: ThirdPartyIntegrationProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.ThirdPartyIntegrationProps.property.projectId">projectId</a></code> | <code>string</code> | Unique 24-hexadecimal digit string that identifies your project. |
| <code><a href="#awscdk-resources-mongodbatlas.ThirdPartyIntegrationProps.property.profile">profile</a></code> | <code>string</code> | Atlas API keys. |

---

##### `projectId`<sup>Required</sup> <a name="projectId" id="awscdk-resources-mongodbatlas.ThirdPartyIntegrationProps.property.projectId"></a>

```typescript
public readonly projectId: string;
```

- *Type:* string

Unique 24-hexadecimal digit string that identifies your project.

---

##### `profile`<sup>Optional</sup> <a name="profile" id="awscdk-resources-mongodbatlas.ThirdPartyIntegrationProps.property.profile"></a>

```typescript
public readonly profile: string;
```

- *Type:* string

Atlas API keys.

---

### Transformations <a name="Transformations" id="awscdk-resources-mongodbatlas.Transformations"></a>

Ordered fields used to physically organize data in the destination.

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.Transformations.Initializer"></a>

```typescript
import { Transformations } from 'awscdk-resources-mongodbatlas'

const transformations: Transformations = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.Transformations.property.field">field</a></code> | <code>string</code> | Key in the document. |
| <code><a href="#awscdk-resources-mongodbatlas.Transformations.property.type">type</a></code> | <code>string</code> | Type of transformation applied during the export of the namespace in a Data Lake Pipeline. |

---

##### `field`<sup>Optional</sup> <a name="field" id="awscdk-resources-mongodbatlas.Transformations.property.field"></a>

```typescript
public readonly field: string;
```

- *Type:* string

Key in the document.

---

##### `type`<sup>Optional</sup> <a name="type" id="awscdk-resources-mongodbatlas.Transformations.property.type"></a>

```typescript
public readonly type: string;
```

- *Type:* string

Type of transformation applied during the export of the namespace in a Data Lake Pipeline.

---

### Validation <a name="Validation" id="awscdk-resources-mongodbatlas.Validation"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.Validation.Initializer"></a>

```typescript
import { Validation } from 'awscdk-resources-mongodbatlas'

const validation: Validation = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.Validation.property.status">status</a></code> | <code>string</code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.Validation.property.validationType">validationType</a></code> | <code>string</code> | *No description.* |

---

##### `status`<sup>Optional</sup> <a name="status" id="awscdk-resources-mongodbatlas.Validation.property.status"></a>

```typescript
public readonly status: string;
```

- *Type:* string

---

##### `validationType`<sup>Optional</sup> <a name="validationType" id="awscdk-resources-mongodbatlas.Validation.property.validationType"></a>

```typescript
public readonly validationType: string;
```

- *Type:* string

---

### View <a name="View" id="awscdk-resources-mongodbatlas.View"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.View.Initializer"></a>

```typescript
import { View } from 'awscdk-resources-mongodbatlas'

const view: View = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.View.property.name">name</a></code> | <code>string</code> | Human-readable label that identifies the view, which corresponds to an aggregation pipeline on a collection. |
| <code><a href="#awscdk-resources-mongodbatlas.View.property.pipeline">pipeline</a></code> | <code>string</code> | Aggregation pipeline stages to apply to the source collection. |
| <code><a href="#awscdk-resources-mongodbatlas.View.property.source">source</a></code> | <code>string</code> | Human-readable label that identifies the source collection for the view. |

---

##### `name`<sup>Optional</sup> <a name="name" id="awscdk-resources-mongodbatlas.View.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Human-readable label that identifies the view, which corresponds to an aggregation pipeline on a collection.

---

##### `pipeline`<sup>Optional</sup> <a name="pipeline" id="awscdk-resources-mongodbatlas.View.property.pipeline"></a>

```typescript
public readonly pipeline: string;
```

- *Type:* string

Aggregation pipeline stages to apply to the source collection.

---

##### `source`<sup>Optional</sup> <a name="source" id="awscdk-resources-mongodbatlas.View.property.source"></a>

```typescript
public readonly source: string;
```

- *Type:* string

Human-readable label that identifies the source collection for the view.

---

### ZoneMapping <a name="ZoneMapping" id="awscdk-resources-mongodbatlas.ZoneMapping"></a>

#### Initializer <a name="Initializer" id="awscdk-resources-mongodbatlas.ZoneMapping.Initializer"></a>

```typescript
import { ZoneMapping } from 'awscdk-resources-mongodbatlas'

const zoneMapping: ZoneMapping = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.ZoneMapping.property.location">location</a></code> | <code>string</code> | Code that represents a location that maps to a zone in your global cluster. |
| <code><a href="#awscdk-resources-mongodbatlas.ZoneMapping.property.zone">zone</a></code> | <code>string</code> | Human-readable label that identifies the zone in your global cluster. |

---

##### `location`<sup>Optional</sup> <a name="location" id="awscdk-resources-mongodbatlas.ZoneMapping.property.location"></a>

```typescript
public readonly location: string;
```

- *Type:* string

Code that represents a location that maps to a zone in your global cluster.

MongoDB Cloud represents this location with a ISO 3166-2 location and subdivision codes when possible.

---

##### `zone`<sup>Optional</sup> <a name="zone" id="awscdk-resources-mongodbatlas.ZoneMapping.property.zone"></a>

```typescript
public readonly zone: string;
```

- *Type:* string

Human-readable label that identifies the zone in your global cluster.

This zone maps to a location code.

---

## Classes <a name="Classes" id="Classes"></a>

### MongoAtlasBootstrapProps <a name="MongoAtlasBootstrapProps" id="awscdk-resources-mongodbatlas.MongoAtlasBootstrapProps"></a>

#### Initializers <a name="Initializers" id="awscdk-resources-mongodbatlas.MongoAtlasBootstrapProps.Initializer"></a>

```typescript
import { MongoAtlasBootstrapProps } from 'awscdk-resources-mongodbatlas'

new MongoAtlasBootstrapProps()
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |

---



#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.MongoAtlasBootstrapProps.property.roleName">roleName</a></code> | <code>string</code> | The IAM role name for CloudFormation Extension Execution. |
| <code><a href="#awscdk-resources-mongodbatlas.MongoAtlasBootstrapProps.property.secretProfile">secretProfile</a></code> | <code>string</code> | The secret profile name for MongoDB Atlas. |
| <code><a href="#awscdk-resources-mongodbatlas.MongoAtlasBootstrapProps.property.typesToActivate">typesToActivate</a></code> | <code>string[]</code> | List of strings representing mongoDB atlas types to activate. |

---

##### `roleName`<sup>Required</sup> <a name="roleName" id="awscdk-resources-mongodbatlas.MongoAtlasBootstrapProps.property.roleName"></a>

```typescript
public readonly roleName: string;
```

- *Type:* string
- *Default:* auto generat the name.

The IAM role name for CloudFormation Extension Execution.

> [https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/registry-public.html](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/registry-public.html)

---

##### `secretProfile`<sup>Required</sup> <a name="secretProfile" id="awscdk-resources-mongodbatlas.MongoAtlasBootstrapProps.property.secretProfile"></a>

```typescript
public readonly secretProfile: string;
```

- *Type:* string
- *Default:* generate a dummy secret.

The secret profile name for MongoDB Atlas.

> [https://github.com/mongodb/mongodbatlas-cloudformation-resources/tree/master#2-configure-your-profile](https://github.com/mongodb/mongodbatlas-cloudformation-resources/tree/master#2-configure-your-profile)

---

##### `typesToActivate`<sup>Optional</sup> <a name="typesToActivate" id="awscdk-resources-mongodbatlas.MongoAtlasBootstrapProps.property.typesToActivate"></a>

```typescript
public readonly typesToActivate: string[];
```

- *Type:* string[]

List of strings representing mongoDB atlas types to activate.

the exported AtlasBasicResources can be used for AtlasBasic resources
if not provided non resources will be activated

---

*Example*

```typescript
typesToActivate=["Cluster","Project"] this will actiate MongoDB::Atlas::Project && MongoDB::Atlas::Cluster
```




## Enums <a name="Enums" id="Enums"></a>

### AdvancedRegionConfigProviderName <a name="AdvancedRegionConfigProviderName" id="awscdk-resources-mongodbatlas.AdvancedRegionConfigProviderName"></a>

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.AdvancedRegionConfigProviderName.AWS">AWS</a></code> | AWS. |
| <code><a href="#awscdk-resources-mongodbatlas.AdvancedRegionConfigProviderName.GCP">GCP</a></code> | GCP. |
| <code><a href="#awscdk-resources-mongodbatlas.AdvancedRegionConfigProviderName.AZURE">AZURE</a></code> | AZURE. |
| <code><a href="#awscdk-resources-mongodbatlas.AdvancedRegionConfigProviderName.TENANT">TENANT</a></code> | TENANT. |

---

##### `AWS` <a name="AWS" id="awscdk-resources-mongodbatlas.AdvancedRegionConfigProviderName.AWS"></a>

AWS.

---


##### `GCP` <a name="GCP" id="awscdk-resources-mongodbatlas.AdvancedRegionConfigProviderName.GCP"></a>

GCP.

---


##### `AZURE` <a name="AZURE" id="awscdk-resources-mongodbatlas.AdvancedRegionConfigProviderName.AZURE"></a>

AZURE.

---


##### `TENANT` <a name="TENANT" id="awscdk-resources-mongodbatlas.AdvancedRegionConfigProviderName.TENANT"></a>

TENANT.

---


### ApiAtlasDiskBackupShardedClusterSnapshotMemberViewCloudProvider <a name="ApiAtlasDiskBackupShardedClusterSnapshotMemberViewCloudProvider" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotMemberViewCloudProvider"></a>

Human-readable label that identifies the cloud provider that stores this snapshot.

The resource returns this parameter when `"type": "replicaSet".`

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotMemberViewCloudProvider.AWS">AWS</a></code> | AWS. |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotMemberViewCloudProvider.AZURE">AZURE</a></code> | AZURE. |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotMemberViewCloudProvider.GCP">GCP</a></code> | GCP. |

---

##### `AWS` <a name="AWS" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotMemberViewCloudProvider.AWS"></a>

AWS.

---


##### `AZURE` <a name="AZURE" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotMemberViewCloudProvider.AZURE"></a>

AZURE.

---


##### `GCP` <a name="GCP" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotMemberViewCloudProvider.GCP"></a>

GCP.

---


### ApiAtlasDiskBackupShardedClusterSnapshotViewFrequencyType <a name="ApiAtlasDiskBackupShardedClusterSnapshotViewFrequencyType" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotViewFrequencyType"></a>

Human-readable label that identifies how often this snapshot triggers.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotViewFrequencyType.HOURLY">HOURLY</a></code> | hourly. |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotViewFrequencyType.DAILY">DAILY</a></code> | daily. |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotViewFrequencyType.WEEKLY">WEEKLY</a></code> | weekly. |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotViewFrequencyType.MONTHLY">MONTHLY</a></code> | monthly. |

---

##### `HOURLY` <a name="HOURLY" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotViewFrequencyType.HOURLY"></a>

hourly.

---


##### `DAILY` <a name="DAILY" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotViewFrequencyType.DAILY"></a>

daily.

---


##### `WEEKLY` <a name="WEEKLY" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotViewFrequencyType.WEEKLY"></a>

weekly.

---


##### `MONTHLY` <a name="MONTHLY" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotViewFrequencyType.MONTHLY"></a>

monthly.

---


### ApiAtlasDiskBackupShardedClusterSnapshotViewSnapshotType <a name="ApiAtlasDiskBackupShardedClusterSnapshotViewSnapshotType" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotViewSnapshotType"></a>

Human-readable label that identifies when this snapshot triggers.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotViewSnapshotType.ON_DEMAND">ON_DEMAND</a></code> | onDemand. |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotViewSnapshotType.SCHEDULED">SCHEDULED</a></code> | scheduled. |

---

##### `ON_DEMAND` <a name="ON_DEMAND" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotViewSnapshotType.ON_DEMAND"></a>

onDemand.

---


##### `SCHEDULED` <a name="SCHEDULED" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotViewSnapshotType.SCHEDULED"></a>

scheduled.

---


### ApiAtlasDiskBackupShardedClusterSnapshotViewStatus <a name="ApiAtlasDiskBackupShardedClusterSnapshotViewStatus" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotViewStatus"></a>

Human-readable label that indicates the stage of the backup process for this snapshot.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotViewStatus.QUEUED">QUEUED</a></code> | queued. |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotViewStatus.IN_PROGRESS">IN_PROGRESS</a></code> | inProgress. |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotViewStatus.COMPLETED">COMPLETED</a></code> | completed. |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotViewStatus.FAILED">FAILED</a></code> | failed. |

---

##### `QUEUED` <a name="QUEUED" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotViewStatus.QUEUED"></a>

queued.

---


##### `IN_PROGRESS` <a name="IN_PROGRESS" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotViewStatus.IN_PROGRESS"></a>

inProgress.

---


##### `COMPLETED` <a name="COMPLETED" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotViewStatus.COMPLETED"></a>

completed.

---


##### `FAILED` <a name="FAILED" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotViewStatus.FAILED"></a>

failed.

---


### ApiAtlasDiskBackupShardedClusterSnapshotViewType <a name="ApiAtlasDiskBackupShardedClusterSnapshotViewType" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotViewType"></a>

Human-readable label that categorizes the cluster as a replica set or sharded cluster.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotViewType.REPLICA_SET">REPLICA_SET</a></code> | REPLICA_SET. |
| <code><a href="#awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotViewType.SHARDED_CLUSTER">SHARDED_CLUSTER</a></code> | SHARDED_CLUSTER. |

---

##### `REPLICA_SET` <a name="REPLICA_SET" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotViewType.REPLICA_SET"></a>

REPLICA_SET.

---


##### `SHARDED_CLUSTER` <a name="SHARDED_CLUSTER" id="awscdk-resources-mongodbatlas.ApiAtlasDiskBackupShardedClusterSnapshotViewType.SHARDED_CLUSTER"></a>

SHARDED_CLUSTER.

---


### AtlasRoleRoleName <a name="AtlasRoleRoleName" id="awscdk-resources-mongodbatlas.AtlasRoleRoleName"></a>

Human-readable label that identifies the collection of privileges that MongoDB Cloud grants a specific API key, MongoDB Cloud user, or MongoDB Cloud team.

These roles include organization- and project-level roles.

Organization Roles

* ORG_OWNER
* ORG_MEMBER
* ORG_GROUP_CREATOR
* ORG_BILLING_ADMIN
* ORG_READ_ONLY

Project Roles

* GROUP_CLUSTER_MANAGER
* GROUP_DATA_ACCESS_ADMIN
* GROUP_DATA_ACCESS_READ_ONLY
* GROUP_DATA_ACCESS_READ_WRITE
* GROUP_OWNER
* GROUP_READ_ONLY

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasRoleRoleName.ORG_OWNER">ORG_OWNER</a></code> | ORG_OWNER. |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasRoleRoleName.ORG_MEMBER">ORG_MEMBER</a></code> | ORG_MEMBER. |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasRoleRoleName.ORG_GROUP_CREATOR">ORG_GROUP_CREATOR</a></code> | ORG_GROUP_CREATOR. |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasRoleRoleName.ORG_BILLING_ADMIN">ORG_BILLING_ADMIN</a></code> | ORG_BILLING_ADMIN. |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasRoleRoleName.ORG_READ_ONLY">ORG_READ_ONLY</a></code> | ORG_READ_ONLY. |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasRoleRoleName.GROUP_CLUSTER_MANAGER">GROUP_CLUSTER_MANAGER</a></code> | GROUP_CLUSTER_MANAGER. |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasRoleRoleName.GROUP_DATA_ACCESS_ADMIN">GROUP_DATA_ACCESS_ADMIN</a></code> | GROUP_DATA_ACCESS_ADMIN. |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasRoleRoleName.GROUP_DATA_ACCESS_READ_ONLY">GROUP_DATA_ACCESS_READ_ONLY</a></code> | GROUP_DATA_ACCESS_READ_ONLY. |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasRoleRoleName.GROUP_DATA_ACCESS_READ_WRITE">GROUP_DATA_ACCESS_READ_WRITE</a></code> | GROUP_DATA_ACCESS_READ_WRITE. |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasRoleRoleName.GROUP_OWNER">GROUP_OWNER</a></code> | GROUP_OWNER. |
| <code><a href="#awscdk-resources-mongodbatlas.AtlasRoleRoleName.GROUP_READ_ONLY">GROUP_READ_ONLY</a></code> | GROUP_READ_ONLY. |

---

##### `ORG_OWNER` <a name="ORG_OWNER" id="awscdk-resources-mongodbatlas.AtlasRoleRoleName.ORG_OWNER"></a>

ORG_OWNER.

---


##### `ORG_MEMBER` <a name="ORG_MEMBER" id="awscdk-resources-mongodbatlas.AtlasRoleRoleName.ORG_MEMBER"></a>

ORG_MEMBER.

---


##### `ORG_GROUP_CREATOR` <a name="ORG_GROUP_CREATOR" id="awscdk-resources-mongodbatlas.AtlasRoleRoleName.ORG_GROUP_CREATOR"></a>

ORG_GROUP_CREATOR.

---


##### `ORG_BILLING_ADMIN` <a name="ORG_BILLING_ADMIN" id="awscdk-resources-mongodbatlas.AtlasRoleRoleName.ORG_BILLING_ADMIN"></a>

ORG_BILLING_ADMIN.

---


##### `ORG_READ_ONLY` <a name="ORG_READ_ONLY" id="awscdk-resources-mongodbatlas.AtlasRoleRoleName.ORG_READ_ONLY"></a>

ORG_READ_ONLY.

---


##### `GROUP_CLUSTER_MANAGER` <a name="GROUP_CLUSTER_MANAGER" id="awscdk-resources-mongodbatlas.AtlasRoleRoleName.GROUP_CLUSTER_MANAGER"></a>

GROUP_CLUSTER_MANAGER.

---


##### `GROUP_DATA_ACCESS_ADMIN` <a name="GROUP_DATA_ACCESS_ADMIN" id="awscdk-resources-mongodbatlas.AtlasRoleRoleName.GROUP_DATA_ACCESS_ADMIN"></a>

GROUP_DATA_ACCESS_ADMIN.

---


##### `GROUP_DATA_ACCESS_READ_ONLY` <a name="GROUP_DATA_ACCESS_READ_ONLY" id="awscdk-resources-mongodbatlas.AtlasRoleRoleName.GROUP_DATA_ACCESS_READ_ONLY"></a>

GROUP_DATA_ACCESS_READ_ONLY.

---


##### `GROUP_DATA_ACCESS_READ_WRITE` <a name="GROUP_DATA_ACCESS_READ_WRITE" id="awscdk-resources-mongodbatlas.AtlasRoleRoleName.GROUP_DATA_ACCESS_READ_WRITE"></a>

GROUP_DATA_ACCESS_READ_WRITE.

---


##### `GROUP_OWNER` <a name="GROUP_OWNER" id="awscdk-resources-mongodbatlas.AtlasRoleRoleName.GROUP_OWNER"></a>

GROUP_OWNER.

---


##### `GROUP_READ_ONLY` <a name="GROUP_READ_ONLY" id="awscdk-resources-mongodbatlas.AtlasRoleRoleName.GROUP_READ_ONLY"></a>

GROUP_READ_ONLY.

---


### AuthConfigOperationType <a name="AuthConfigOperationType" id="awscdk-resources-mongodbatlas.AuthConfigOperationType"></a>

The type of authentication event that the trigger listens for.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.AuthConfigOperationType.LOGIN">LOGIN</a></code> | LOGIN. |
| <code><a href="#awscdk-resources-mongodbatlas.AuthConfigOperationType.CREATE">CREATE</a></code> | CREATE. |
| <code><a href="#awscdk-resources-mongodbatlas.AuthConfigOperationType.DELETE">DELETE</a></code> | DELETE. |

---

##### `LOGIN` <a name="LOGIN" id="awscdk-resources-mongodbatlas.AuthConfigOperationType.LOGIN"></a>

LOGIN.

---


##### `CREATE` <a name="CREATE" id="awscdk-resources-mongodbatlas.AuthConfigOperationType.CREATE"></a>

CREATE.

---


##### `DELETE` <a name="DELETE" id="awscdk-resources-mongodbatlas.AuthConfigOperationType.DELETE"></a>

DELETE.

---


### AuthConfigProviders <a name="AuthConfigProviders" id="awscdk-resources-mongodbatlas.AuthConfigProviders"></a>

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.AuthConfigProviders.ANON_USER">ANON_USER</a></code> | anon-user. |
| <code><a href="#awscdk-resources-mongodbatlas.AuthConfigProviders.API_KEY">API_KEY</a></code> | api-key. |
| <code><a href="#awscdk-resources-mongodbatlas.AuthConfigProviders.CUSTOM_TOKEN">CUSTOM_TOKEN</a></code> | custom-token. |
| <code><a href="#awscdk-resources-mongodbatlas.AuthConfigProviders.CUSTOM_FUNCTION">CUSTOM_FUNCTION</a></code> | custom-function. |
| <code><a href="#awscdk-resources-mongodbatlas.AuthConfigProviders.LOCAL_USERPASS">LOCAL_USERPASS</a></code> | local-userpass. |
| <code><a href="#awscdk-resources-mongodbatlas.AuthConfigProviders.OAUTH2_APPLE">OAUTH2_APPLE</a></code> | oauth2-apple. |
| <code><a href="#awscdk-resources-mongodbatlas.AuthConfigProviders.OAUTH2_FACEBOOK">OAUTH2_FACEBOOK</a></code> | oauth2-facebook. |
| <code><a href="#awscdk-resources-mongodbatlas.AuthConfigProviders.OAUTH2_GOOGLE">OAUTH2_GOOGLE</a></code> | oauth2-google. |

---

##### `ANON_USER` <a name="ANON_USER" id="awscdk-resources-mongodbatlas.AuthConfigProviders.ANON_USER"></a>

anon-user.

---


##### `API_KEY` <a name="API_KEY" id="awscdk-resources-mongodbatlas.AuthConfigProviders.API_KEY"></a>

api-key.

---


##### `CUSTOM_TOKEN` <a name="CUSTOM_TOKEN" id="awscdk-resources-mongodbatlas.AuthConfigProviders.CUSTOM_TOKEN"></a>

custom-token.

---


##### `CUSTOM_FUNCTION` <a name="CUSTOM_FUNCTION" id="awscdk-resources-mongodbatlas.AuthConfigProviders.CUSTOM_FUNCTION"></a>

custom-function.

---


##### `LOCAL_USERPASS` <a name="LOCAL_USERPASS" id="awscdk-resources-mongodbatlas.AuthConfigProviders.LOCAL_USERPASS"></a>

local-userpass.

---


##### `OAUTH2_APPLE` <a name="OAUTH2_APPLE" id="awscdk-resources-mongodbatlas.AuthConfigProviders.OAUTH2_APPLE"></a>

oauth2-apple.

---


##### `OAUTH2_FACEBOOK` <a name="OAUTH2_FACEBOOK" id="awscdk-resources-mongodbatlas.AuthConfigProviders.OAUTH2_FACEBOOK"></a>

oauth2-facebook.

---


##### `OAUTH2_GOOGLE` <a name="OAUTH2_GOOGLE" id="awscdk-resources-mongodbatlas.AuthConfigProviders.OAUTH2_GOOGLE"></a>

oauth2-google.

---


### CfnCloudBackUpRestoreJobsPropsDeliveryType <a name="CfnCloudBackUpRestoreJobsPropsDeliveryType" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsPropsDeliveryType"></a>

Type of restore job to create.The value can be any one of download,automated or point_in_time.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsPropsDeliveryType.DOWNLOAD">DOWNLOAD</a></code> | download. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsPropsDeliveryType.AUTOMATED">AUTOMATED</a></code> | automated. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsPropsDeliveryType.POINT_IN_TIME">POINT_IN_TIME</a></code> | pointInTime. |

---

##### `DOWNLOAD` <a name="DOWNLOAD" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsPropsDeliveryType.DOWNLOAD"></a>

download.

---


##### `AUTOMATED` <a name="AUTOMATED" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsPropsDeliveryType.AUTOMATED"></a>

automated.

---


##### `POINT_IN_TIME` <a name="POINT_IN_TIME" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsPropsDeliveryType.POINT_IN_TIME"></a>

pointInTime.

---


### CfnCloudBackUpRestoreJobsPropsInstanceType <a name="CfnCloudBackUpRestoreJobsPropsInstanceType" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsPropsInstanceType"></a>

Type of instance specified on the Instance Name serverless or cluster.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsPropsInstanceType.SERVERLESS">SERVERLESS</a></code> | serverless. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsPropsInstanceType.CLUSTER">CLUSTER</a></code> | cluster. |

---

##### `SERVERLESS` <a name="SERVERLESS" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsPropsInstanceType.SERVERLESS"></a>

serverless.

---


##### `CLUSTER` <a name="CLUSTER" id="awscdk-resources-mongodbatlas.CfnCloudBackUpRestoreJobsPropsInstanceType.CLUSTER"></a>

cluster.

---


### CfnCloudBackupSnapshotPropsFrequencyType <a name="CfnCloudBackupSnapshotPropsFrequencyType" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotPropsFrequencyType"></a>

Human-readable label that identifies how often this snapshot triggers.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotPropsFrequencyType.HOURLY">HOURLY</a></code> | hourly. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotPropsFrequencyType.DAILY">DAILY</a></code> | daily. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotPropsFrequencyType.WEEKLY">WEEKLY</a></code> | weekly. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotPropsFrequencyType.MONTHLY">MONTHLY</a></code> | monthly. |

---

##### `HOURLY` <a name="HOURLY" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotPropsFrequencyType.HOURLY"></a>

hourly.

---


##### `DAILY` <a name="DAILY" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotPropsFrequencyType.DAILY"></a>

daily.

---


##### `WEEKLY` <a name="WEEKLY" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotPropsFrequencyType.WEEKLY"></a>

weekly.

---


##### `MONTHLY` <a name="MONTHLY" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotPropsFrequencyType.MONTHLY"></a>

monthly.

---


### CfnCloudBackupSnapshotPropsInstanceType <a name="CfnCloudBackupSnapshotPropsInstanceType" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotPropsInstanceType"></a>

Type of instance specified on the Instance Name serverless or cluster.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotPropsInstanceType.SERVERLESS">SERVERLESS</a></code> | serverless. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotPropsInstanceType.CLUSTER">CLUSTER</a></code> | cluster. |

---

##### `SERVERLESS` <a name="SERVERLESS" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotPropsInstanceType.SERVERLESS"></a>

serverless.

---


##### `CLUSTER` <a name="CLUSTER" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotPropsInstanceType.CLUSTER"></a>

cluster.

---


### CfnCloudBackupSnapshotPropsSnapshotType <a name="CfnCloudBackupSnapshotPropsSnapshotType" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotPropsSnapshotType"></a>

Human-readable label that identifies when this snapshot triggers.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotPropsSnapshotType.ON_DEMAND">ON_DEMAND</a></code> | onDemand. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotPropsSnapshotType.SCHEDULED">SCHEDULED</a></code> | scheduled. |

---

##### `ON_DEMAND` <a name="ON_DEMAND" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotPropsSnapshotType.ON_DEMAND"></a>

onDemand.

---


##### `SCHEDULED` <a name="SCHEDULED" id="awscdk-resources-mongodbatlas.CfnCloudBackupSnapshotPropsSnapshotType.SCHEDULED"></a>

scheduled.

---


### CfnClusterPropsEncryptionAtRestProvider <a name="CfnClusterPropsEncryptionAtRestProvider" id="awscdk-resources-mongodbatlas.CfnClusterPropsEncryptionAtRestProvider"></a>

Cloud service provider that manages your customer keys to provide an additional layer of encryption at rest for the cluster.

To enable customer key management for encryption at rest, the cluster replicationSpecs[n].regionConfigs[m].{type}Specs.instanceSize setting must be M10 or higher and "backupEnabled" : false or omitted entirely.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterPropsEncryptionAtRestProvider.AWS">AWS</a></code> | AWS. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterPropsEncryptionAtRestProvider.GCP">GCP</a></code> | GCP. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterPropsEncryptionAtRestProvider.AZURE">AZURE</a></code> | AZURE. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnClusterPropsEncryptionAtRestProvider.NONE">NONE</a></code> | NONE. |

---

##### `AWS` <a name="AWS" id="awscdk-resources-mongodbatlas.CfnClusterPropsEncryptionAtRestProvider.AWS"></a>

AWS.

---


##### `GCP` <a name="GCP" id="awscdk-resources-mongodbatlas.CfnClusterPropsEncryptionAtRestProvider.GCP"></a>

GCP.

---


##### `AZURE` <a name="AZURE" id="awscdk-resources-mongodbatlas.CfnClusterPropsEncryptionAtRestProvider.AZURE"></a>

AZURE.

---


##### `NONE` <a name="NONE" id="awscdk-resources-mongodbatlas.CfnClusterPropsEncryptionAtRestProvider.NONE"></a>

NONE.

---


### CfnDatabaseUserPropsAwsiamType <a name="CfnDatabaseUserPropsAwsiamType" id="awscdk-resources-mongodbatlas.CfnDatabaseUserPropsAwsiamType"></a>

Human-readable label that indicates whether the new database user authenticates with the Amazon Web Services (AWS) Identity and Access Management (IAM) credentials associated with the user or the user's role.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUserPropsAwsiamType.NONE">NONE</a></code> | NONE. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUserPropsAwsiamType.USER">USER</a></code> | USER. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUserPropsAwsiamType.ROLE">ROLE</a></code> | ROLE. |

---

##### `NONE` <a name="NONE" id="awscdk-resources-mongodbatlas.CfnDatabaseUserPropsAwsiamType.NONE"></a>

NONE.

---


##### `USER` <a name="USER" id="awscdk-resources-mongodbatlas.CfnDatabaseUserPropsAwsiamType.USER"></a>

USER.

---


##### `ROLE` <a name="ROLE" id="awscdk-resources-mongodbatlas.CfnDatabaseUserPropsAwsiamType.ROLE"></a>

ROLE.

---


### CfnDatabaseUserPropsLdapAuthType <a name="CfnDatabaseUserPropsLdapAuthType" id="awscdk-resources-mongodbatlas.CfnDatabaseUserPropsLdapAuthType"></a>

Method by which the provided username is authenticated.

Default value is `NONE`.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUserPropsLdapAuthType.NONE">NONE</a></code> | NONE. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUserPropsLdapAuthType.USER">USER</a></code> | USER. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUserPropsLdapAuthType.GROUP">GROUP</a></code> | GROUP. |

---

##### `NONE` <a name="NONE" id="awscdk-resources-mongodbatlas.CfnDatabaseUserPropsLdapAuthType.NONE"></a>

NONE.

---


##### `USER` <a name="USER" id="awscdk-resources-mongodbatlas.CfnDatabaseUserPropsLdapAuthType.USER"></a>

USER.

---


##### `GROUP` <a name="GROUP" id="awscdk-resources-mongodbatlas.CfnDatabaseUserPropsLdapAuthType.GROUP"></a>

GROUP.

---


### CfnDatabaseUserPropsX509Type <a name="CfnDatabaseUserPropsX509Type" id="awscdk-resources-mongodbatlas.CfnDatabaseUserPropsX509Type"></a>

Method that briefs who owns the certificate provided.

Default value is `NONE`.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUserPropsX509Type.NONE">NONE</a></code> | NONE. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUserPropsX509Type.MANAGED">MANAGED</a></code> | MANAGED. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnDatabaseUserPropsX509Type.CUSTOMER">CUSTOMER</a></code> | CUSTOMER. |

---

##### `NONE` <a name="NONE" id="awscdk-resources-mongodbatlas.CfnDatabaseUserPropsX509Type.NONE"></a>

NONE.

---


##### `MANAGED` <a name="MANAGED" id="awscdk-resources-mongodbatlas.CfnDatabaseUserPropsX509Type.MANAGED"></a>

MANAGED.

---


##### `CUSTOMER` <a name="CUSTOMER" id="awscdk-resources-mongodbatlas.CfnDatabaseUserPropsX509Type.CUSTOMER"></a>

CUSTOMER.

---


### CfnFederatedQueryLimitPropsLimitName <a name="CfnFederatedQueryLimitPropsLimitName" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimitPropsLimitName"></a>

Human-readable label that identifies this data federation instance limit.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimitPropsLimitName.BYTES_PROCESSED_QUERY">BYTES_PROCESSED_QUERY</a></code> | bytesProcessed.query. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimitPropsLimitName.BYTES_PROCESSED_DAILY">BYTES_PROCESSED_DAILY</a></code> | bytesProcessed.daily. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimitPropsLimitName.BYTES_PROCESSED_WEEKLY">BYTES_PROCESSED_WEEKLY</a></code> | bytesProcessed.weekly. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnFederatedQueryLimitPropsLimitName.BYTES_PROCESSED_MONTHLY">BYTES_PROCESSED_MONTHLY</a></code> | bytesProcessed.monthly. |

---

##### `BYTES_PROCESSED_QUERY` <a name="BYTES_PROCESSED_QUERY" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimitPropsLimitName.BYTES_PROCESSED_QUERY"></a>

bytesProcessed.query.

---


##### `BYTES_PROCESSED_DAILY` <a name="BYTES_PROCESSED_DAILY" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimitPropsLimitName.BYTES_PROCESSED_DAILY"></a>

bytesProcessed.daily.

---


##### `BYTES_PROCESSED_WEEKLY` <a name="BYTES_PROCESSED_WEEKLY" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimitPropsLimitName.BYTES_PROCESSED_WEEKLY"></a>

bytesProcessed.weekly.

---


##### `BYTES_PROCESSED_MONTHLY` <a name="BYTES_PROCESSED_MONTHLY" id="awscdk-resources-mongodbatlas.CfnFederatedQueryLimitPropsLimitName.BYTES_PROCESSED_MONTHLY"></a>

bytesProcessed.monthly.

---


### CfnOnlineArchivePropsCollectionType <a name="CfnOnlineArchivePropsCollectionType" id="awscdk-resources-mongodbatlas.CfnOnlineArchivePropsCollectionType"></a>

Classification of MongoDB database collection that you want to return.

If you set this parameter to `TIMESERIES`, set `"criteria.type" : "date"` and `"criteria.dateFormat" : "ISODATE"`.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchivePropsCollectionType.STANDARD">STANDARD</a></code> | STANDARD. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOnlineArchivePropsCollectionType.TIMESERIES">TIMESERIES</a></code> | TIMESERIES. |

---

##### `STANDARD` <a name="STANDARD" id="awscdk-resources-mongodbatlas.CfnOnlineArchivePropsCollectionType.STANDARD"></a>

STANDARD.

---


##### `TIMESERIES` <a name="TIMESERIES" id="awscdk-resources-mongodbatlas.CfnOnlineArchivePropsCollectionType.TIMESERIES"></a>

TIMESERIES.

---


### CfnOrgInvitationPropsRoles <a name="CfnOrgInvitationPropsRoles" id="awscdk-resources-mongodbatlas.CfnOrgInvitationPropsRoles"></a>

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitationPropsRoles.ORG_OWNER">ORG_OWNER</a></code> | ORG_OWNER. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitationPropsRoles.ORG_MEMBER">ORG_MEMBER</a></code> | ORG_MEMBER. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitationPropsRoles.ORG_GROUP_CREATOR">ORG_GROUP_CREATOR</a></code> | ORG_GROUP_CREATOR. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitationPropsRoles.ORG_BILLING_ADMIN">ORG_BILLING_ADMIN</a></code> | ORG_BILLING_ADMIN. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitationPropsRoles.ORG_READ_ONLY">ORG_READ_ONLY</a></code> | ORG_READ_ONLY. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitationPropsRoles.GROUP_CLUSTER_MANAGER">GROUP_CLUSTER_MANAGER</a></code> | GROUP_CLUSTER_MANAGER. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitationPropsRoles.GROUP_DATA_ACCESS_ADMIN">GROUP_DATA_ACCESS_ADMIN</a></code> | GROUP_DATA_ACCESS_ADMIN. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitationPropsRoles.GROUP_DATA_ACCESS_READ_ONLY">GROUP_DATA_ACCESS_READ_ONLY</a></code> | GROUP_DATA_ACCESS_READ_ONLY. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitationPropsRoles.GROUP_DATA_ACCESS_READ_WRITE">GROUP_DATA_ACCESS_READ_WRITE</a></code> | GROUP_DATA_ACCESS_READ_WRITE. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitationPropsRoles.GROUP_OWNER">GROUP_OWNER</a></code> | GROUP_OWNER. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnOrgInvitationPropsRoles.GROUP_READ_ONLY">GROUP_READ_ONLY</a></code> | GROUP_READ_ONLY. |

---

##### `ORG_OWNER` <a name="ORG_OWNER" id="awscdk-resources-mongodbatlas.CfnOrgInvitationPropsRoles.ORG_OWNER"></a>

ORG_OWNER.

---


##### `ORG_MEMBER` <a name="ORG_MEMBER" id="awscdk-resources-mongodbatlas.CfnOrgInvitationPropsRoles.ORG_MEMBER"></a>

ORG_MEMBER.

---


##### `ORG_GROUP_CREATOR` <a name="ORG_GROUP_CREATOR" id="awscdk-resources-mongodbatlas.CfnOrgInvitationPropsRoles.ORG_GROUP_CREATOR"></a>

ORG_GROUP_CREATOR.

---


##### `ORG_BILLING_ADMIN` <a name="ORG_BILLING_ADMIN" id="awscdk-resources-mongodbatlas.CfnOrgInvitationPropsRoles.ORG_BILLING_ADMIN"></a>

ORG_BILLING_ADMIN.

---


##### `ORG_READ_ONLY` <a name="ORG_READ_ONLY" id="awscdk-resources-mongodbatlas.CfnOrgInvitationPropsRoles.ORG_READ_ONLY"></a>

ORG_READ_ONLY.

---


##### `GROUP_CLUSTER_MANAGER` <a name="GROUP_CLUSTER_MANAGER" id="awscdk-resources-mongodbatlas.CfnOrgInvitationPropsRoles.GROUP_CLUSTER_MANAGER"></a>

GROUP_CLUSTER_MANAGER.

---


##### `GROUP_DATA_ACCESS_ADMIN` <a name="GROUP_DATA_ACCESS_ADMIN" id="awscdk-resources-mongodbatlas.CfnOrgInvitationPropsRoles.GROUP_DATA_ACCESS_ADMIN"></a>

GROUP_DATA_ACCESS_ADMIN.

---


##### `GROUP_DATA_ACCESS_READ_ONLY` <a name="GROUP_DATA_ACCESS_READ_ONLY" id="awscdk-resources-mongodbatlas.CfnOrgInvitationPropsRoles.GROUP_DATA_ACCESS_READ_ONLY"></a>

GROUP_DATA_ACCESS_READ_ONLY.

---


##### `GROUP_DATA_ACCESS_READ_WRITE` <a name="GROUP_DATA_ACCESS_READ_WRITE" id="awscdk-resources-mongodbatlas.CfnOrgInvitationPropsRoles.GROUP_DATA_ACCESS_READ_WRITE"></a>

GROUP_DATA_ACCESS_READ_WRITE.

---


##### `GROUP_OWNER` <a name="GROUP_OWNER" id="awscdk-resources-mongodbatlas.CfnOrgInvitationPropsRoles.GROUP_OWNER"></a>

GROUP_OWNER.

---


##### `GROUP_READ_ONLY` <a name="GROUP_READ_ONLY" id="awscdk-resources-mongodbatlas.CfnOrgInvitationPropsRoles.GROUP_READ_ONLY"></a>

GROUP_READ_ONLY.

---


### CfnPrivateEndpointServicePropsCloudProvider <a name="CfnPrivateEndpointServicePropsCloudProvider" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointServicePropsCloudProvider"></a>

Cloud service provider that manages this private endpoint, default : AWS.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointServicePropsCloudProvider.AWS">AWS</a></code> | AWS. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointServicePropsCloudProvider.AZURE">AZURE</a></code> | AZURE. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnPrivateEndpointServicePropsCloudProvider.GCP">GCP</a></code> | GCP. |

---

##### `AWS` <a name="AWS" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointServicePropsCloudProvider.AWS"></a>

AWS.

---


##### `AZURE` <a name="AZURE" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointServicePropsCloudProvider.AZURE"></a>

AZURE.

---


##### `GCP` <a name="GCP" id="awscdk-resources-mongodbatlas.CfnPrivateEndpointServicePropsCloudProvider.GCP"></a>

GCP.

---


### CfnProjectInvitationPropsRoles <a name="CfnProjectInvitationPropsRoles" id="awscdk-resources-mongodbatlas.CfnProjectInvitationPropsRoles"></a>

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitationPropsRoles.GROUP_CLUSTER_MANAGER">GROUP_CLUSTER_MANAGER</a></code> | GROUP_CLUSTER_MANAGER. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitationPropsRoles.GROUP_DATA_ACCESS_ADMIN">GROUP_DATA_ACCESS_ADMIN</a></code> | GROUP_DATA_ACCESS_ADMIN. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitationPropsRoles.GROUP_DATA_ACCESS_READ_ONLY">GROUP_DATA_ACCESS_READ_ONLY</a></code> | GROUP_DATA_ACCESS_READ_ONLY. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitationPropsRoles.GROUP_DATA_ACCESS_READ_WRITE">GROUP_DATA_ACCESS_READ_WRITE</a></code> | GROUP_DATA_ACCESS_READ_WRITE. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitationPropsRoles.GROUP_OWNER">GROUP_OWNER</a></code> | GROUP_OWNER. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnProjectInvitationPropsRoles.GROUP_READ_ONLY">GROUP_READ_ONLY</a></code> | GROUP_READ_ONLY. |

---

##### `GROUP_CLUSTER_MANAGER` <a name="GROUP_CLUSTER_MANAGER" id="awscdk-resources-mongodbatlas.CfnProjectInvitationPropsRoles.GROUP_CLUSTER_MANAGER"></a>

GROUP_CLUSTER_MANAGER.

---


##### `GROUP_DATA_ACCESS_ADMIN` <a name="GROUP_DATA_ACCESS_ADMIN" id="awscdk-resources-mongodbatlas.CfnProjectInvitationPropsRoles.GROUP_DATA_ACCESS_ADMIN"></a>

GROUP_DATA_ACCESS_ADMIN.

---


##### `GROUP_DATA_ACCESS_READ_ONLY` <a name="GROUP_DATA_ACCESS_READ_ONLY" id="awscdk-resources-mongodbatlas.CfnProjectInvitationPropsRoles.GROUP_DATA_ACCESS_READ_ONLY"></a>

GROUP_DATA_ACCESS_READ_ONLY.

---


##### `GROUP_DATA_ACCESS_READ_WRITE` <a name="GROUP_DATA_ACCESS_READ_WRITE" id="awscdk-resources-mongodbatlas.CfnProjectInvitationPropsRoles.GROUP_DATA_ACCESS_READ_WRITE"></a>

GROUP_DATA_ACCESS_READ_WRITE.

---


##### `GROUP_OWNER` <a name="GROUP_OWNER" id="awscdk-resources-mongodbatlas.CfnProjectInvitationPropsRoles.GROUP_OWNER"></a>

GROUP_OWNER.

---


##### `GROUP_READ_ONLY` <a name="GROUP_READ_ONLY" id="awscdk-resources-mongodbatlas.CfnProjectInvitationPropsRoles.GROUP_READ_ONLY"></a>

GROUP_READ_ONLY.

---


### CfnStreamConnectionPropsType <a name="CfnStreamConnectionPropsType" id="awscdk-resources-mongodbatlas.CfnStreamConnectionPropsType"></a>

Type of the connection.

Can be either Cluster, Kafka, or Sample.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnectionPropsType.KAFKA">KAFKA</a></code> | Kafka. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnectionPropsType.CLUSTER">CLUSTER</a></code> | Cluster. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnStreamConnectionPropsType.SAMPLE">SAMPLE</a></code> | Sample. |

---

##### `KAFKA` <a name="KAFKA" id="awscdk-resources-mongodbatlas.CfnStreamConnectionPropsType.KAFKA"></a>

Kafka.

---


##### `CLUSTER` <a name="CLUSTER" id="awscdk-resources-mongodbatlas.CfnStreamConnectionPropsType.CLUSTER"></a>

Cluster.

---


##### `SAMPLE` <a name="SAMPLE" id="awscdk-resources-mongodbatlas.CfnStreamConnectionPropsType.SAMPLE"></a>

Sample.

---


### CfnTeamsPropsRoleNames <a name="CfnTeamsPropsRoleNames" id="awscdk-resources-mongodbatlas.CfnTeamsPropsRoleNames"></a>

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTeamsPropsRoleNames.GROUP_CLUSTER_MANAGER">GROUP_CLUSTER_MANAGER</a></code> | GROUP_CLUSTER_MANAGER. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTeamsPropsRoleNames.GROUP_DATA_ACCESS_ADMIN">GROUP_DATA_ACCESS_ADMIN</a></code> | GROUP_DATA_ACCESS_ADMIN. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTeamsPropsRoleNames.GROUP_DATA_ACCESS_READ_ONLY">GROUP_DATA_ACCESS_READ_ONLY</a></code> | GROUP_DATA_ACCESS_READ_ONLY. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTeamsPropsRoleNames.GROUP_DATA_ACCESS_READ_WRITE">GROUP_DATA_ACCESS_READ_WRITE</a></code> | GROUP_DATA_ACCESS_READ_WRITE. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTeamsPropsRoleNames.GROUP_OWNER">GROUP_OWNER</a></code> | GROUP_OWNER. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnTeamsPropsRoleNames.GROUP_READ_ONLY">GROUP_READ_ONLY</a></code> | GROUP_READ_ONLY. |

---

##### `GROUP_CLUSTER_MANAGER` <a name="GROUP_CLUSTER_MANAGER" id="awscdk-resources-mongodbatlas.CfnTeamsPropsRoleNames.GROUP_CLUSTER_MANAGER"></a>

GROUP_CLUSTER_MANAGER.

---


##### `GROUP_DATA_ACCESS_ADMIN` <a name="GROUP_DATA_ACCESS_ADMIN" id="awscdk-resources-mongodbatlas.CfnTeamsPropsRoleNames.GROUP_DATA_ACCESS_ADMIN"></a>

GROUP_DATA_ACCESS_ADMIN.

---


##### `GROUP_DATA_ACCESS_READ_ONLY` <a name="GROUP_DATA_ACCESS_READ_ONLY" id="awscdk-resources-mongodbatlas.CfnTeamsPropsRoleNames.GROUP_DATA_ACCESS_READ_ONLY"></a>

GROUP_DATA_ACCESS_READ_ONLY.

---


##### `GROUP_DATA_ACCESS_READ_WRITE` <a name="GROUP_DATA_ACCESS_READ_WRITE" id="awscdk-resources-mongodbatlas.CfnTeamsPropsRoleNames.GROUP_DATA_ACCESS_READ_WRITE"></a>

GROUP_DATA_ACCESS_READ_WRITE.

---


##### `GROUP_OWNER` <a name="GROUP_OWNER" id="awscdk-resources-mongodbatlas.CfnTeamsPropsRoleNames.GROUP_OWNER"></a>

GROUP_OWNER.

---


##### `GROUP_READ_ONLY` <a name="GROUP_READ_ONLY" id="awscdk-resources-mongodbatlas.CfnTeamsPropsRoleNames.GROUP_READ_ONLY"></a>

GROUP_READ_ONLY.

---


### CfnThirdPartyIntegrationPropsScheme <a name="CfnThirdPartyIntegrationPropsScheme" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationPropsScheme"></a>

Security Scheme to apply to HyperText Transfer Protocol (HTTP) traffic between Prometheus and MongoDB Cloud.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationPropsScheme.HTTP">HTTP</a></code> | http. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationPropsScheme.HTTPS">HTTPS</a></code> | https. |

---

##### `HTTP` <a name="HTTP" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationPropsScheme.HTTP"></a>

http.

---


##### `HTTPS` <a name="HTTPS" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationPropsScheme.HTTPS"></a>

https.

---


### CfnThirdPartyIntegrationPropsServiceDiscovery <a name="CfnThirdPartyIntegrationPropsServiceDiscovery" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationPropsServiceDiscovery"></a>

Desired method to discover the Prometheus service.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationPropsServiceDiscovery.HTTP">HTTP</a></code> | http. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationPropsServiceDiscovery.FILE">FILE</a></code> | file. |

---

##### `HTTP` <a name="HTTP" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationPropsServiceDiscovery.HTTP"></a>

http.

---


##### `FILE` <a name="FILE" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationPropsServiceDiscovery.FILE"></a>

file.

---


### CfnThirdPartyIntegrationPropsType <a name="CfnThirdPartyIntegrationPropsType" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationPropsType"></a>

Human-readable label that identifies the service to which you want to integrate with MongoDB Cloud.

The value must match the third-party service integration type.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationPropsType.PAGER_DUTY">PAGER_DUTY</a></code> | PAGER_DUTY. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationPropsType.MICROSOFT_TEAMS">MICROSOFT_TEAMS</a></code> | MICROSOFT_TEAMS. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationPropsType.SLACK">SLACK</a></code> | SLACK. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationPropsType.DATADOG">DATADOG</a></code> | DATADOG. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationPropsType.OPS_GENIE">OPS_GENIE</a></code> | OPS_GENIE. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationPropsType.VICTOR_OPS">VICTOR_OPS</a></code> | VICTOR_OPS. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationPropsType.WEBHOOK">WEBHOOK</a></code> | WEBHOOK. |
| <code><a href="#awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationPropsType.PROMETHEUS">PROMETHEUS</a></code> | PROMETHEUS. |

---

##### `PAGER_DUTY` <a name="PAGER_DUTY" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationPropsType.PAGER_DUTY"></a>

PAGER_DUTY.

---


##### `MICROSOFT_TEAMS` <a name="MICROSOFT_TEAMS" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationPropsType.MICROSOFT_TEAMS"></a>

MICROSOFT_TEAMS.

---


##### `SLACK` <a name="SLACK" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationPropsType.SLACK"></a>

SLACK.

---


##### `DATADOG` <a name="DATADOG" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationPropsType.DATADOG"></a>

DATADOG.

---


##### `OPS_GENIE` <a name="OPS_GENIE" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationPropsType.OPS_GENIE"></a>

OPS_GENIE.

---


##### `VICTOR_OPS` <a name="VICTOR_OPS" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationPropsType.VICTOR_OPS"></a>

VICTOR_OPS.

---


##### `WEBHOOK` <a name="WEBHOOK" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationPropsType.WEBHOOK"></a>

WEBHOOK.

---


##### `PROMETHEUS` <a name="PROMETHEUS" id="awscdk-resources-mongodbatlas.CfnThirdPartyIntegrationPropsType.PROMETHEUS"></a>

PROMETHEUS.

---


### CriteriaViewDateFormat <a name="CriteriaViewDateFormat" id="awscdk-resources-mongodbatlas.CriteriaViewDateFormat"></a>

Syntax used to write the date after which data moves to the online archive.

Date can be expressed as ISO 8601 or Epoch timestamps. The Epoch timestamp can be expressed as nanoseconds, milliseconds, or seconds. Set this parameter when "criteria.type" : "DATE". You must set "criteria.type" : "DATE" if "collectionType": "TIMESERIES".

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CriteriaViewDateFormat.ISODATE">ISODATE</a></code> | ISODATE. |
| <code><a href="#awscdk-resources-mongodbatlas.CriteriaViewDateFormat.EPOCH_SECONDS">EPOCH_SECONDS</a></code> | EPOCH_SECONDS. |
| <code><a href="#awscdk-resources-mongodbatlas.CriteriaViewDateFormat.EPOCH_MILLIS">EPOCH_MILLIS</a></code> | EPOCH_MILLIS. |
| <code><a href="#awscdk-resources-mongodbatlas.CriteriaViewDateFormat.EPOCH_NANOSECONDS">EPOCH_NANOSECONDS</a></code> | EPOCH_NANOSECONDS. |

---

##### `ISODATE` <a name="ISODATE" id="awscdk-resources-mongodbatlas.CriteriaViewDateFormat.ISODATE"></a>

ISODATE.

---


##### `EPOCH_SECONDS` <a name="EPOCH_SECONDS" id="awscdk-resources-mongodbatlas.CriteriaViewDateFormat.EPOCH_SECONDS"></a>

EPOCH_SECONDS.

---


##### `EPOCH_MILLIS` <a name="EPOCH_MILLIS" id="awscdk-resources-mongodbatlas.CriteriaViewDateFormat.EPOCH_MILLIS"></a>

EPOCH_MILLIS.

---


##### `EPOCH_NANOSECONDS` <a name="EPOCH_NANOSECONDS" id="awscdk-resources-mongodbatlas.CriteriaViewDateFormat.EPOCH_NANOSECONDS"></a>

EPOCH_NANOSECONDS.

---


### CriteriaViewType <a name="CriteriaViewType" id="awscdk-resources-mongodbatlas.CriteriaViewType"></a>

Means by which MongoDB Cloud selects data to archive.

Data can be chosen using the age of the data or a MongoDB query.
**DATE** selects documents to archive based on a date.
**CUSTOM** selects documents to archive based on a custom JSON query. MongoDB Cloud doesn't support **CUSTOM** when `"collectionType": "TIMESERIES"`.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.CriteriaViewType.DATE">DATE</a></code> | DATE. |
| <code><a href="#awscdk-resources-mongodbatlas.CriteriaViewType.CUSTOM">CUSTOM</a></code> | CUSTOM. |

---

##### `DATE` <a name="DATE" id="awscdk-resources-mongodbatlas.CriteriaViewType.DATE"></a>

DATE.

---


##### `CUSTOM` <a name="CUSTOM" id="awscdk-resources-mongodbatlas.CriteriaViewType.CUSTOM"></a>

CUSTOM.

---


### DatabaseConfigOperationTypes <a name="DatabaseConfigOperationTypes" id="awscdk-resources-mongodbatlas.DatabaseConfigOperationTypes"></a>

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.DatabaseConfigOperationTypes.INSERT">INSERT</a></code> | INSERT. |
| <code><a href="#awscdk-resources-mongodbatlas.DatabaseConfigOperationTypes.UPDATE">UPDATE</a></code> | UPDATE. |
| <code><a href="#awscdk-resources-mongodbatlas.DatabaseConfigOperationTypes.REPLACE">REPLACE</a></code> | REPLACE. |
| <code><a href="#awscdk-resources-mongodbatlas.DatabaseConfigOperationTypes.DELETE">DELETE</a></code> | DELETE. |

---

##### `INSERT` <a name="INSERT" id="awscdk-resources-mongodbatlas.DatabaseConfigOperationTypes.INSERT"></a>

INSERT.

---


##### `UPDATE` <a name="UPDATE" id="awscdk-resources-mongodbatlas.DatabaseConfigOperationTypes.UPDATE"></a>

UPDATE.

---


##### `REPLACE` <a name="REPLACE" id="awscdk-resources-mongodbatlas.DatabaseConfigOperationTypes.REPLACE"></a>

REPLACE.

---


##### `DELETE` <a name="DELETE" id="awscdk-resources-mongodbatlas.DatabaseConfigOperationTypes.DELETE"></a>

DELETE.

---


### DatadogRegion <a name="DatadogRegion" id="awscdk-resources-mongodbatlas.DatadogRegion"></a>

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.DatadogRegion.US">US</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.DatadogRegion.EU">EU</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.DatadogRegion.US3">US3</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.DatadogRegion.US5">US5</a></code> | *No description.* |

---

##### `US` <a name="US" id="awscdk-resources-mongodbatlas.DatadogRegion.US"></a>

---


##### `EU` <a name="EU" id="awscdk-resources-mongodbatlas.DatadogRegion.EU"></a>

---


##### `US3` <a name="US3" id="awscdk-resources-mongodbatlas.DatadogRegion.US3"></a>

---


##### `US5` <a name="US5" id="awscdk-resources-mongodbatlas.DatadogRegion.US5"></a>

---


### DataLakeDatabaseDataSourceViewDefaultFormat <a name="DataLakeDatabaseDataSourceViewDefaultFormat" id="awscdk-resources-mongodbatlas.DataLakeDatabaseDataSourceViewDefaultFormat"></a>

File format that MongoDB Cloud uses if it encounters a file without a file extension while searching **storeName**.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeDatabaseDataSourceViewDefaultFormat.AVRO">AVRO</a></code> | .avro. |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeDatabaseDataSourceViewDefaultFormat.AVRO_GZ">AVRO_GZ</a></code> | .avro.gz. |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeDatabaseDataSourceViewDefaultFormat.BSON">BSON</a></code> | .bson. |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeDatabaseDataSourceViewDefaultFormat.BSON_GZ">BSON_GZ</a></code> | .bson.gz. |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeDatabaseDataSourceViewDefaultFormat.CSV">CSV</a></code> | .csv. |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeDatabaseDataSourceViewDefaultFormat.JSON">JSON</a></code> | .json. |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeDatabaseDataSourceViewDefaultFormat.JSON_GZ">JSON_GZ</a></code> | .json.gz. |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeDatabaseDataSourceViewDefaultFormat.ORC">ORC</a></code> | .orc. |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeDatabaseDataSourceViewDefaultFormat.TSV">TSV</a></code> | .tsv. |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeDatabaseDataSourceViewDefaultFormat.TSV_GZ">TSV_GZ</a></code> | .tsv.gz. |

---

##### `AVRO` <a name="AVRO" id="awscdk-resources-mongodbatlas.DataLakeDatabaseDataSourceViewDefaultFormat.AVRO"></a>

.avro.

---


##### `AVRO_GZ` <a name="AVRO_GZ" id="awscdk-resources-mongodbatlas.DataLakeDatabaseDataSourceViewDefaultFormat.AVRO_GZ"></a>

.avro.gz.

---


##### `BSON` <a name="BSON" id="awscdk-resources-mongodbatlas.DataLakeDatabaseDataSourceViewDefaultFormat.BSON"></a>

.bson.

---


##### `BSON_GZ` <a name="BSON_GZ" id="awscdk-resources-mongodbatlas.DataLakeDatabaseDataSourceViewDefaultFormat.BSON_GZ"></a>

.bson.gz.

---


##### `CSV` <a name="CSV" id="awscdk-resources-mongodbatlas.DataLakeDatabaseDataSourceViewDefaultFormat.CSV"></a>

.csv.

---


##### `JSON` <a name="JSON" id="awscdk-resources-mongodbatlas.DataLakeDatabaseDataSourceViewDefaultFormat.JSON"></a>

.json.

---


##### `JSON_GZ` <a name="JSON_GZ" id="awscdk-resources-mongodbatlas.DataLakeDatabaseDataSourceViewDefaultFormat.JSON_GZ"></a>

.json.gz.

---


##### `ORC` <a name="ORC" id="awscdk-resources-mongodbatlas.DataLakeDatabaseDataSourceViewDefaultFormat.ORC"></a>

.orc.

---


##### `TSV` <a name="TSV" id="awscdk-resources-mongodbatlas.DataLakeDatabaseDataSourceViewDefaultFormat.TSV"></a>

.tsv.

---


##### `TSV_GZ` <a name="TSV_GZ" id="awscdk-resources-mongodbatlas.DataLakeDatabaseDataSourceViewDefaultFormat.TSV_GZ"></a>

.tsv.gz.

---


### DataLakeDataProcessRegionViewCloudProvider <a name="DataLakeDataProcessRegionViewCloudProvider" id="awscdk-resources-mongodbatlas.DataLakeDataProcessRegionViewCloudProvider"></a>

Name of the cloud service that hosts the data lake's data stores.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeDataProcessRegionViewCloudProvider.AWS">AWS</a></code> | AWS. |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeDataProcessRegionViewCloudProvider.GCP">GCP</a></code> | GCP. |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeDataProcessRegionViewCloudProvider.AZURE">AZURE</a></code> | AZURE. |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeDataProcessRegionViewCloudProvider.TENANT">TENANT</a></code> | TENANT. |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeDataProcessRegionViewCloudProvider.SERVERLESS">SERVERLESS</a></code> | SERVERLESS. |

---

##### `AWS` <a name="AWS" id="awscdk-resources-mongodbatlas.DataLakeDataProcessRegionViewCloudProvider.AWS"></a>

AWS.

---


##### `GCP` <a name="GCP" id="awscdk-resources-mongodbatlas.DataLakeDataProcessRegionViewCloudProvider.GCP"></a>

GCP.

---


##### `AZURE` <a name="AZURE" id="awscdk-resources-mongodbatlas.DataLakeDataProcessRegionViewCloudProvider.AZURE"></a>

AZURE.

---


##### `TENANT` <a name="TENANT" id="awscdk-resources-mongodbatlas.DataLakeDataProcessRegionViewCloudProvider.TENANT"></a>

TENANT.

---


##### `SERVERLESS` <a name="SERVERLESS" id="awscdk-resources-mongodbatlas.DataLakeDataProcessRegionViewCloudProvider.SERVERLESS"></a>

SERVERLESS.

---


### DataLakeDataProcessRegionViewRegion <a name="DataLakeDataProcessRegionViewRegion" id="awscdk-resources-mongodbatlas.DataLakeDataProcessRegionViewRegion"></a>

Name of the region to which the data lake routes client connections.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeDataProcessRegionViewRegion.DUBLIN_IRL">DUBLIN_IRL</a></code> | DUBLIN_IRL. |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeDataProcessRegionViewRegion.FRANKFURT_DEU">FRANKFURT_DEU</a></code> | FRANKFURT_DEU. |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeDataProcessRegionViewRegion.LONDON_GBR">LONDON_GBR</a></code> | LONDON_GBR. |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeDataProcessRegionViewRegion.MUMBAI_IND">MUMBAI_IND</a></code> | MUMBAI_IND. |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeDataProcessRegionViewRegion.OREGON_USA">OREGON_USA</a></code> | OREGON_USA. |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeDataProcessRegionViewRegion.SYDNEY_AUS">SYDNEY_AUS</a></code> | SYDNEY_AUS. |
| <code><a href="#awscdk-resources-mongodbatlas.DataLakeDataProcessRegionViewRegion.VIRGINIA_USA">VIRGINIA_USA</a></code> | VIRGINIA_USA. |

---

##### `DUBLIN_IRL` <a name="DUBLIN_IRL" id="awscdk-resources-mongodbatlas.DataLakeDataProcessRegionViewRegion.DUBLIN_IRL"></a>

DUBLIN_IRL.

---


##### `FRANKFURT_DEU` <a name="FRANKFURT_DEU" id="awscdk-resources-mongodbatlas.DataLakeDataProcessRegionViewRegion.FRANKFURT_DEU"></a>

FRANKFURT_DEU.

---


##### `LONDON_GBR` <a name="LONDON_GBR" id="awscdk-resources-mongodbatlas.DataLakeDataProcessRegionViewRegion.LONDON_GBR"></a>

LONDON_GBR.

---


##### `MUMBAI_IND` <a name="MUMBAI_IND" id="awscdk-resources-mongodbatlas.DataLakeDataProcessRegionViewRegion.MUMBAI_IND"></a>

MUMBAI_IND.

---


##### `OREGON_USA` <a name="OREGON_USA" id="awscdk-resources-mongodbatlas.DataLakeDataProcessRegionViewRegion.OREGON_USA"></a>

OREGON_USA.

---


##### `SYDNEY_AUS` <a name="SYDNEY_AUS" id="awscdk-resources-mongodbatlas.DataLakeDataProcessRegionViewRegion.SYDNEY_AUS"></a>

SYDNEY_AUS.

---


##### `VIRGINIA_USA` <a name="VIRGINIA_USA" id="awscdk-resources-mongodbatlas.DataLakeDataProcessRegionViewRegion.VIRGINIA_USA"></a>

VIRGINIA_USA.

---


### DbRoleToExecuteType <a name="DbRoleToExecuteType" id="awscdk-resources-mongodbatlas.DbRoleToExecuteType"></a>

Type of the DB role.

Can be either BuiltIn or Custom.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.DbRoleToExecuteType.BUILT_IN">BUILT_IN</a></code> | BUILT_IN. |
| <code><a href="#awscdk-resources-mongodbatlas.DbRoleToExecuteType.CUSTOM">CUSTOM</a></code> | CUSTOM. |

---

##### `BUILT_IN` <a name="BUILT_IN" id="awscdk-resources-mongodbatlas.DbRoleToExecuteType.BUILT_IN"></a>

BUILT_IN.

---


##### `CUSTOM` <a name="CUSTOM" id="awscdk-resources-mongodbatlas.DbRoleToExecuteType.CUSTOM"></a>

CUSTOM.

---


### FilterCloudProvider <a name="FilterCloudProvider" id="awscdk-resources-mongodbatlas.FilterCloudProvider"></a>

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.FilterCloudProvider.AWS">AWS</a></code> | AWS. |
| <code><a href="#awscdk-resources-mongodbatlas.FilterCloudProvider.AZURE">AZURE</a></code> | AZURE. |
| <code><a href="#awscdk-resources-mongodbatlas.FilterCloudProvider.GCP">GCP</a></code> | GCP. |

---

##### `AWS` <a name="AWS" id="awscdk-resources-mongodbatlas.FilterCloudProvider.AWS"></a>

AWS.

---


##### `AZURE` <a name="AZURE" id="awscdk-resources-mongodbatlas.FilterCloudProvider.AZURE"></a>

AZURE.

---


##### `GCP` <a name="GCP" id="awscdk-resources-mongodbatlas.FilterCloudProvider.GCP"></a>

GCP.

---


### IntegerThresholdViewOperator <a name="IntegerThresholdViewOperator" id="awscdk-resources-mongodbatlas.IntegerThresholdViewOperator"></a>

Comparison operator to apply when checking the current metric value.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.IntegerThresholdViewOperator.GREATER_THAN">GREATER_THAN</a></code> | GREATER_THAN. |
| <code><a href="#awscdk-resources-mongodbatlas.IntegerThresholdViewOperator.LESS_THAN">LESS_THAN</a></code> | LESS_THAN. |

---

##### `GREATER_THAN` <a name="GREATER_THAN" id="awscdk-resources-mongodbatlas.IntegerThresholdViewOperator.GREATER_THAN"></a>

GREATER_THAN.

---


##### `LESS_THAN` <a name="LESS_THAN" id="awscdk-resources-mongodbatlas.IntegerThresholdViewOperator.LESS_THAN"></a>

LESS_THAN.

---


### MatcherFieldName <a name="MatcherFieldName" id="awscdk-resources-mongodbatlas.MatcherFieldName"></a>

Name of the parameter in the target object that MongoDB Cloud checks.

The parameter must match all rules for MongoDB Cloud to check for alert configurations.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.MatcherFieldName.CLUSTER_NAME">CLUSTER_NAME</a></code> | CLUSTER_NAME. |
| <code><a href="#awscdk-resources-mongodbatlas.MatcherFieldName.HOSTNAME">HOSTNAME</a></code> | HOSTNAME. |
| <code><a href="#awscdk-resources-mongodbatlas.MatcherFieldName.HOSTNAME_AND_PORT">HOSTNAME_AND_PORT</a></code> | HOSTNAME_AND_PORT. |
| <code><a href="#awscdk-resources-mongodbatlas.MatcherFieldName.PORT">PORT</a></code> | PORT. |
| <code><a href="#awscdk-resources-mongodbatlas.MatcherFieldName.REPLICA_SET_NAME">REPLICA_SET_NAME</a></code> | REPLICA_SET_NAME. |
| <code><a href="#awscdk-resources-mongodbatlas.MatcherFieldName.SHARD_NAME">SHARD_NAME</a></code> | SHARD_NAME. |
| <code><a href="#awscdk-resources-mongodbatlas.MatcherFieldName.TYPE_NAME">TYPE_NAME</a></code> | TYPE_NAME. |

---

##### `CLUSTER_NAME` <a name="CLUSTER_NAME" id="awscdk-resources-mongodbatlas.MatcherFieldName.CLUSTER_NAME"></a>

CLUSTER_NAME.

---


##### `HOSTNAME` <a name="HOSTNAME" id="awscdk-resources-mongodbatlas.MatcherFieldName.HOSTNAME"></a>

HOSTNAME.

---


##### `HOSTNAME_AND_PORT` <a name="HOSTNAME_AND_PORT" id="awscdk-resources-mongodbatlas.MatcherFieldName.HOSTNAME_AND_PORT"></a>

HOSTNAME_AND_PORT.

---


##### `PORT` <a name="PORT" id="awscdk-resources-mongodbatlas.MatcherFieldName.PORT"></a>

PORT.

---


##### `REPLICA_SET_NAME` <a name="REPLICA_SET_NAME" id="awscdk-resources-mongodbatlas.MatcherFieldName.REPLICA_SET_NAME"></a>

REPLICA_SET_NAME.

---


##### `SHARD_NAME` <a name="SHARD_NAME" id="awscdk-resources-mongodbatlas.MatcherFieldName.SHARD_NAME"></a>

SHARD_NAME.

---


##### `TYPE_NAME` <a name="TYPE_NAME" id="awscdk-resources-mongodbatlas.MatcherFieldName.TYPE_NAME"></a>

TYPE_NAME.

---


### MatcherOperator <a name="MatcherOperator" id="awscdk-resources-mongodbatlas.MatcherOperator"></a>

Comparison operator to apply when checking the current metric value against **matcher[n].value**.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.MatcherOperator.EQUALS">EQUALS</a></code> | EQUALS. |
| <code><a href="#awscdk-resources-mongodbatlas.MatcherOperator.CONTAINS">CONTAINS</a></code> | CONTAINS. |
| <code><a href="#awscdk-resources-mongodbatlas.MatcherOperator.STARTS_WITH">STARTS_WITH</a></code> | STARTS_WITH. |
| <code><a href="#awscdk-resources-mongodbatlas.MatcherOperator.ENDS_WITH">ENDS_WITH</a></code> | ENDS_WITH. |
| <code><a href="#awscdk-resources-mongodbatlas.MatcherOperator.NOT_EQUALS">NOT_EQUALS</a></code> | NOT_EQUALS. |
| <code><a href="#awscdk-resources-mongodbatlas.MatcherOperator.NOT_CONTAINS">NOT_CONTAINS</a></code> | NOT_CONTAINS. |
| <code><a href="#awscdk-resources-mongodbatlas.MatcherOperator.REGEX">REGEX</a></code> | REGEX. |

---

##### `EQUALS` <a name="EQUALS" id="awscdk-resources-mongodbatlas.MatcherOperator.EQUALS"></a>

EQUALS.

---


##### `CONTAINS` <a name="CONTAINS" id="awscdk-resources-mongodbatlas.MatcherOperator.CONTAINS"></a>

CONTAINS.

---


##### `STARTS_WITH` <a name="STARTS_WITH" id="awscdk-resources-mongodbatlas.MatcherOperator.STARTS_WITH"></a>

STARTS_WITH.

---


##### `ENDS_WITH` <a name="ENDS_WITH" id="awscdk-resources-mongodbatlas.MatcherOperator.ENDS_WITH"></a>

ENDS_WITH.

---


##### `NOT_EQUALS` <a name="NOT_EQUALS" id="awscdk-resources-mongodbatlas.MatcherOperator.NOT_EQUALS"></a>

NOT_EQUALS.

---


##### `NOT_CONTAINS` <a name="NOT_CONTAINS" id="awscdk-resources-mongodbatlas.MatcherOperator.NOT_CONTAINS"></a>

NOT_CONTAINS.

---


##### `REGEX` <a name="REGEX" id="awscdk-resources-mongodbatlas.MatcherOperator.REGEX"></a>

REGEX.

---


### MetricThresholdViewMode <a name="MetricThresholdViewMode" id="awscdk-resources-mongodbatlas.MetricThresholdViewMode"></a>

MongoDB Cloud computes the current metric value as an average.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.MetricThresholdViewMode.AVERAGE">AVERAGE</a></code> | AVERAGE. |

---

##### `AVERAGE` <a name="AVERAGE" id="awscdk-resources-mongodbatlas.MetricThresholdViewMode.AVERAGE"></a>

AVERAGE.

---


### MetricThresholdViewOperator <a name="MetricThresholdViewOperator" id="awscdk-resources-mongodbatlas.MetricThresholdViewOperator"></a>

Comparison operator to apply when checking the current metric value.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.MetricThresholdViewOperator.GREATER_THAN">GREATER_THAN</a></code> | GREATER_THAN. |
| <code><a href="#awscdk-resources-mongodbatlas.MetricThresholdViewOperator.LESS_THAN">LESS_THAN</a></code> | LESS_THAN. |

---

##### `GREATER_THAN` <a name="GREATER_THAN" id="awscdk-resources-mongodbatlas.MetricThresholdViewOperator.GREATER_THAN"></a>

GREATER_THAN.

---


##### `LESS_THAN` <a name="LESS_THAN" id="awscdk-resources-mongodbatlas.MetricThresholdViewOperator.LESS_THAN"></a>

LESS_THAN.

---


### NotificationViewDatadogRegion <a name="NotificationViewDatadogRegion" id="awscdk-resources-mongodbatlas.NotificationViewDatadogRegion"></a>

Datadog region that indicates which API Uniform Resource Locator (URL) to use.

The resource requires this parameter when '"notifications.typeName" : "DATADOG"'.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationViewDatadogRegion.EU">EU</a></code> | EU. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationViewDatadogRegion.US">US</a></code> | US. |

---

##### `EU` <a name="EU" id="awscdk-resources-mongodbatlas.NotificationViewDatadogRegion.EU"></a>

EU.

---


##### `US` <a name="US" id="awscdk-resources-mongodbatlas.NotificationViewDatadogRegion.US"></a>

US.

---


### NotificationViewOpsGenieRegion <a name="NotificationViewOpsGenieRegion" id="awscdk-resources-mongodbatlas.NotificationViewOpsGenieRegion"></a>

Opsgenie region that indicates which API Uniform Resource Locator (URL) to use.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationViewOpsGenieRegion.EU">EU</a></code> | EU. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationViewOpsGenieRegion.US">US</a></code> | US. |

---

##### `EU` <a name="EU" id="awscdk-resources-mongodbatlas.NotificationViewOpsGenieRegion.EU"></a>

EU.

---


##### `US` <a name="US" id="awscdk-resources-mongodbatlas.NotificationViewOpsGenieRegion.US"></a>

US.

---


### NotificationViewRoles <a name="NotificationViewRoles" id="awscdk-resources-mongodbatlas.NotificationViewRoles"></a>

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationViewRoles.GROUP_CLUSTER_MANAGER">GROUP_CLUSTER_MANAGER</a></code> | GROUP_CLUSTER_MANAGER. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationViewRoles.GROUP_DATA_ACCESS_ADMIN">GROUP_DATA_ACCESS_ADMIN</a></code> | GROUP_DATA_ACCESS_ADMIN. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationViewRoles.GROUP_DATA_ACCESS_READ_ONLY">GROUP_DATA_ACCESS_READ_ONLY</a></code> | GROUP_DATA_ACCESS_READ_ONLY. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationViewRoles.GROUP_DATA_ACCESS_READ_WRITE">GROUP_DATA_ACCESS_READ_WRITE</a></code> | GROUP_DATA_ACCESS_READ_WRITE. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationViewRoles.GROUP_OWNER">GROUP_OWNER</a></code> | GROUP_OWNER. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationViewRoles.GROUP_READ_WRITE">GROUP_READ_WRITE</a></code> | GROUP_READ_WRITE. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationViewRoles.ORG_OWNER">ORG_OWNER</a></code> | ORG_OWNER. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationViewRoles.ORG_MEMBER">ORG_MEMBER</a></code> | ORG_MEMBER. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationViewRoles.ORG_GROUP_CREATOR">ORG_GROUP_CREATOR</a></code> | ORG_GROUP_CREATOR. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationViewRoles.ORG_BILLING_ADMIN">ORG_BILLING_ADMIN</a></code> | ORG_BILLING_ADMIN. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationViewRoles.ORG_READ_ONLY">ORG_READ_ONLY</a></code> | ORG_READ_ONLY. |

---

##### `GROUP_CLUSTER_MANAGER` <a name="GROUP_CLUSTER_MANAGER" id="awscdk-resources-mongodbatlas.NotificationViewRoles.GROUP_CLUSTER_MANAGER"></a>

GROUP_CLUSTER_MANAGER.

---


##### `GROUP_DATA_ACCESS_ADMIN` <a name="GROUP_DATA_ACCESS_ADMIN" id="awscdk-resources-mongodbatlas.NotificationViewRoles.GROUP_DATA_ACCESS_ADMIN"></a>

GROUP_DATA_ACCESS_ADMIN.

---


##### `GROUP_DATA_ACCESS_READ_ONLY` <a name="GROUP_DATA_ACCESS_READ_ONLY" id="awscdk-resources-mongodbatlas.NotificationViewRoles.GROUP_DATA_ACCESS_READ_ONLY"></a>

GROUP_DATA_ACCESS_READ_ONLY.

---


##### `GROUP_DATA_ACCESS_READ_WRITE` <a name="GROUP_DATA_ACCESS_READ_WRITE" id="awscdk-resources-mongodbatlas.NotificationViewRoles.GROUP_DATA_ACCESS_READ_WRITE"></a>

GROUP_DATA_ACCESS_READ_WRITE.

---


##### `GROUP_OWNER` <a name="GROUP_OWNER" id="awscdk-resources-mongodbatlas.NotificationViewRoles.GROUP_OWNER"></a>

GROUP_OWNER.

---


##### `GROUP_READ_WRITE` <a name="GROUP_READ_WRITE" id="awscdk-resources-mongodbatlas.NotificationViewRoles.GROUP_READ_WRITE"></a>

GROUP_READ_WRITE.

---


##### `ORG_OWNER` <a name="ORG_OWNER" id="awscdk-resources-mongodbatlas.NotificationViewRoles.ORG_OWNER"></a>

ORG_OWNER.

---


##### `ORG_MEMBER` <a name="ORG_MEMBER" id="awscdk-resources-mongodbatlas.NotificationViewRoles.ORG_MEMBER"></a>

ORG_MEMBER.

---


##### `ORG_GROUP_CREATOR` <a name="ORG_GROUP_CREATOR" id="awscdk-resources-mongodbatlas.NotificationViewRoles.ORG_GROUP_CREATOR"></a>

ORG_GROUP_CREATOR.

---


##### `ORG_BILLING_ADMIN` <a name="ORG_BILLING_ADMIN" id="awscdk-resources-mongodbatlas.NotificationViewRoles.ORG_BILLING_ADMIN"></a>

ORG_BILLING_ADMIN.

---


##### `ORG_READ_ONLY` <a name="ORG_READ_ONLY" id="awscdk-resources-mongodbatlas.NotificationViewRoles.ORG_READ_ONLY"></a>

ORG_READ_ONLY.

---


### NotificationViewSeverity <a name="NotificationViewSeverity" id="awscdk-resources-mongodbatlas.NotificationViewSeverity"></a>

Degree of seriousness given to this notification.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationViewSeverity.CRITICAL">CRITICAL</a></code> | CRITICAL. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationViewSeverity.ERROR">ERROR</a></code> | ERROR. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationViewSeverity.WARNING">WARNING</a></code> | WARNING. |

---

##### `CRITICAL` <a name="CRITICAL" id="awscdk-resources-mongodbatlas.NotificationViewSeverity.CRITICAL"></a>

CRITICAL.

---


##### `ERROR` <a name="ERROR" id="awscdk-resources-mongodbatlas.NotificationViewSeverity.ERROR"></a>

ERROR.

---


##### `WARNING` <a name="WARNING" id="awscdk-resources-mongodbatlas.NotificationViewSeverity.WARNING"></a>

WARNING.

---


### NotificationViewTypeName <a name="NotificationViewTypeName" id="awscdk-resources-mongodbatlas.NotificationViewTypeName"></a>

Human-readable label that displays the alert notification type.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationViewTypeName.DATADOG">DATADOG</a></code> | DATADOG. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationViewTypeName.EMAIL">EMAIL</a></code> | EMAIL. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationViewTypeName.FLOWDOCK">FLOWDOCK</a></code> | FLOWDOCK. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationViewTypeName.GROUP">GROUP</a></code> | GROUP. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationViewTypeName.MICROSOFT_TEAMS">MICROSOFT_TEAMS</a></code> | MICROSOFT_TEAMS. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationViewTypeName.OPS_GENIE">OPS_GENIE</a></code> | OPS_GENIE. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationViewTypeName.ORG">ORG</a></code> | ORG. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationViewTypeName.PAGER_DUTY">PAGER_DUTY</a></code> | PAGER_DUTY. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationViewTypeName.PROMETHEUS">PROMETHEUS</a></code> | PROMETHEUS. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationViewTypeName.SLACK">SLACK</a></code> | SLACK. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationViewTypeName.SMS">SMS</a></code> | SMS. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationViewTypeName.TEAM">TEAM</a></code> | TEAM. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationViewTypeName.USER">USER</a></code> | USER. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationViewTypeName.VICTOR_OPS">VICTOR_OPS</a></code> | VICTOR_OPS. |
| <code><a href="#awscdk-resources-mongodbatlas.NotificationViewTypeName.WEBHOOK">WEBHOOK</a></code> | WEBHOOK. |

---

##### `DATADOG` <a name="DATADOG" id="awscdk-resources-mongodbatlas.NotificationViewTypeName.DATADOG"></a>

DATADOG.

---


##### `EMAIL` <a name="EMAIL" id="awscdk-resources-mongodbatlas.NotificationViewTypeName.EMAIL"></a>

EMAIL.

---


##### `FLOWDOCK` <a name="FLOWDOCK" id="awscdk-resources-mongodbatlas.NotificationViewTypeName.FLOWDOCK"></a>

FLOWDOCK.

---


##### `GROUP` <a name="GROUP" id="awscdk-resources-mongodbatlas.NotificationViewTypeName.GROUP"></a>

GROUP.

---


##### `MICROSOFT_TEAMS` <a name="MICROSOFT_TEAMS" id="awscdk-resources-mongodbatlas.NotificationViewTypeName.MICROSOFT_TEAMS"></a>

MICROSOFT_TEAMS.

---


##### `OPS_GENIE` <a name="OPS_GENIE" id="awscdk-resources-mongodbatlas.NotificationViewTypeName.OPS_GENIE"></a>

OPS_GENIE.

---


##### `ORG` <a name="ORG" id="awscdk-resources-mongodbatlas.NotificationViewTypeName.ORG"></a>

ORG.

---


##### `PAGER_DUTY` <a name="PAGER_DUTY" id="awscdk-resources-mongodbatlas.NotificationViewTypeName.PAGER_DUTY"></a>

PAGER_DUTY.

---


##### `PROMETHEUS` <a name="PROMETHEUS" id="awscdk-resources-mongodbatlas.NotificationViewTypeName.PROMETHEUS"></a>

PROMETHEUS.

---


##### `SLACK` <a name="SLACK" id="awscdk-resources-mongodbatlas.NotificationViewTypeName.SLACK"></a>

SLACK.

---


##### `SMS` <a name="SMS" id="awscdk-resources-mongodbatlas.NotificationViewTypeName.SMS"></a>

SMS.

---


##### `TEAM` <a name="TEAM" id="awscdk-resources-mongodbatlas.NotificationViewTypeName.TEAM"></a>

TEAM.

---


##### `USER` <a name="USER" id="awscdk-resources-mongodbatlas.NotificationViewTypeName.USER"></a>

USER.

---


##### `VICTOR_OPS` <a name="VICTOR_OPS" id="awscdk-resources-mongodbatlas.NotificationViewTypeName.VICTOR_OPS"></a>

VICTOR_OPS.

---


##### `WEBHOOK` <a name="WEBHOOK" id="awscdk-resources-mongodbatlas.NotificationViewTypeName.WEBHOOK"></a>

WEBHOOK.

---


### PagerDutyRegion <a name="PagerDutyRegion" id="awscdk-resources-mongodbatlas.PagerDutyRegion"></a>

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.PagerDutyRegion.US">US</a></code> | *No description.* |
| <code><a href="#awscdk-resources-mongodbatlas.PagerDutyRegion.EU">EU</a></code> | *No description.* |

---

##### `US` <a name="US" id="awscdk-resources-mongodbatlas.PagerDutyRegion.US"></a>

---


##### `EU` <a name="EU" id="awscdk-resources-mongodbatlas.PagerDutyRegion.EU"></a>

---


### PartitionFieldViewFieldType <a name="PartitionFieldViewFieldType" id="awscdk-resources-mongodbatlas.PartitionFieldViewFieldType"></a>

Data type of the parameter that that MongoDB Cloud uses to partition data.

Partition parameters of type [UUID](http://bsonspec.org/spec.html) must be of binary subtype 4. MongoDB Cloud skips partition parameters of type UUID with subtype 3.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.PartitionFieldViewFieldType.DATE">DATE</a></code> | date. |
| <code><a href="#awscdk-resources-mongodbatlas.PartitionFieldViewFieldType.INT">INT</a></code> | int. |
| <code><a href="#awscdk-resources-mongodbatlas.PartitionFieldViewFieldType.LONG">LONG</a></code> | long. |
| <code><a href="#awscdk-resources-mongodbatlas.PartitionFieldViewFieldType.OBJECT_ID">OBJECT_ID</a></code> | objectId. |
| <code><a href="#awscdk-resources-mongodbatlas.PartitionFieldViewFieldType.STRING">STRING</a></code> | string. |
| <code><a href="#awscdk-resources-mongodbatlas.PartitionFieldViewFieldType.UUID">UUID</a></code> | uuid. |

---

##### `DATE` <a name="DATE" id="awscdk-resources-mongodbatlas.PartitionFieldViewFieldType.DATE"></a>

date.

---


##### `INT` <a name="INT" id="awscdk-resources-mongodbatlas.PartitionFieldViewFieldType.INT"></a>

int.

---


##### `LONG` <a name="LONG" id="awscdk-resources-mongodbatlas.PartitionFieldViewFieldType.LONG"></a>

long.

---


##### `OBJECT_ID` <a name="OBJECT_ID" id="awscdk-resources-mongodbatlas.PartitionFieldViewFieldType.OBJECT_ID"></a>

objectId.

---


##### `STRING` <a name="STRING" id="awscdk-resources-mongodbatlas.PartitionFieldViewFieldType.STRING"></a>

string.

---


##### `UUID` <a name="UUID" id="awscdk-resources-mongodbatlas.PartitionFieldViewFieldType.UUID"></a>

uuid.

---


### ScheduleViewType <a name="ScheduleViewType" id="awscdk-resources-mongodbatlas.ScheduleViewType"></a>

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.ScheduleViewType.DAILY">DAILY</a></code> | DAILY. |
| <code><a href="#awscdk-resources-mongodbatlas.ScheduleViewType.MONTHLY">MONTHLY</a></code> | MONTHLY. |
| <code><a href="#awscdk-resources-mongodbatlas.ScheduleViewType.DEFAULT">DEFAULT</a></code> | DEFAULT. |
| <code><a href="#awscdk-resources-mongodbatlas.ScheduleViewType.WEEKLY">WEEKLY</a></code> | WEEKLY. |

---

##### `DAILY` <a name="DAILY" id="awscdk-resources-mongodbatlas.ScheduleViewType.DAILY"></a>

DAILY.

---


##### `MONTHLY` <a name="MONTHLY" id="awscdk-resources-mongodbatlas.ScheduleViewType.MONTHLY"></a>

MONTHLY.

---


##### `DEFAULT` <a name="DEFAULT" id="awscdk-resources-mongodbatlas.ScheduleViewType.DEFAULT"></a>

DEFAULT.

---


##### `WEEKLY` <a name="WEEKLY" id="awscdk-resources-mongodbatlas.ScheduleViewType.WEEKLY"></a>

WEEKLY.

---


### ScopeDefinitionType <a name="ScopeDefinitionType" id="awscdk-resources-mongodbatlas.ScopeDefinitionType"></a>

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.ScopeDefinitionType.CLUSTER">CLUSTER</a></code> | CLUSTER. |
| <code><a href="#awscdk-resources-mongodbatlas.ScopeDefinitionType.DATA_LAKE">DATA_LAKE</a></code> | DATA_LAKE. |

---

##### `CLUSTER` <a name="CLUSTER" id="awscdk-resources-mongodbatlas.ScopeDefinitionType.CLUSTER"></a>

CLUSTER.

---


##### `DATA_LAKE` <a name="DATA_LAKE" id="awscdk-resources-mongodbatlas.ScopeDefinitionType.DATA_LAKE"></a>

DATA_LAKE.

---


### ServerlessInstancePrivateEndpointType <a name="ServerlessInstancePrivateEndpointType" id="awscdk-resources-mongodbatlas.ServerlessInstancePrivateEndpointType"></a>

MongoDB process type to which your application connects.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.ServerlessInstancePrivateEndpointType.MONGOS">MONGOS</a></code> | MONGOS. |

---

##### `MONGOS` <a name="MONGOS" id="awscdk-resources-mongodbatlas.ServerlessInstancePrivateEndpointType.MONGOS"></a>

MONGOS.

---


### ServerlessInstanceProviderSettingsProviderName <a name="ServerlessInstanceProviderSettingsProviderName" id="awscdk-resources-mongodbatlas.ServerlessInstanceProviderSettingsProviderName"></a>

Human-readable label that identifies the cloud service provider.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.ServerlessInstanceProviderSettingsProviderName.SERVERLESS">SERVERLESS</a></code> | SERVERLESS. |

---

##### `SERVERLESS` <a name="SERVERLESS" id="awscdk-resources-mongodbatlas.ServerlessInstanceProviderSettingsProviderName.SERVERLESS"></a>

SERVERLESS.

---


### SinkType <a name="SinkType" id="awscdk-resources-mongodbatlas.SinkType"></a>

Type of ingestion destination of this Data Lake Pipeline.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.SinkType.DLS">DLS</a></code> | DLS. |

---

##### `DLS` <a name="DLS" id="awscdk-resources-mongodbatlas.SinkType.DLS"></a>

DLS.

---


### SourceType <a name="SourceType" id="awscdk-resources-mongodbatlas.SourceType"></a>

Type of ingestion source of this Data Lake Pipeline.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.SourceType.ON_DEMAND_CPS">ON_DEMAND_CPS</a></code> | ON_DEMAND_CPS. |
| <code><a href="#awscdk-resources-mongodbatlas.SourceType.PERIODIC_CPS">PERIODIC_CPS</a></code> | PERIODIC_CPS. |

---

##### `ON_DEMAND_CPS` <a name="ON_DEMAND_CPS" id="awscdk-resources-mongodbatlas.SourceType.ON_DEMAND_CPS"></a>

ON_DEMAND_CPS.

---


##### `PERIODIC_CPS` <a name="PERIODIC_CPS" id="awscdk-resources-mongodbatlas.SourceType.PERIODIC_CPS"></a>

PERIODIC_CPS.

---


### StreamsConnectionType <a name="StreamsConnectionType" id="awscdk-resources-mongodbatlas.StreamsConnectionType"></a>

Type of the connection.

Can be either Cluster or Kafka.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.StreamsConnectionType.KAFKA">KAFKA</a></code> | Kafka. |
| <code><a href="#awscdk-resources-mongodbatlas.StreamsConnectionType.CLUSTER">CLUSTER</a></code> | Cluster. |
| <code><a href="#awscdk-resources-mongodbatlas.StreamsConnectionType.SAMPLE">SAMPLE</a></code> | Sample. |

---

##### `KAFKA` <a name="KAFKA" id="awscdk-resources-mongodbatlas.StreamsConnectionType.KAFKA"></a>

Kafka.

---


##### `CLUSTER` <a name="CLUSTER" id="awscdk-resources-mongodbatlas.StreamsConnectionType.CLUSTER"></a>

Cluster.

---


##### `SAMPLE` <a name="SAMPLE" id="awscdk-resources-mongodbatlas.StreamsConnectionType.SAMPLE"></a>

Sample.

---


### StreamsDataProcessRegionCloudProvider <a name="StreamsDataProcessRegionCloudProvider" id="awscdk-resources-mongodbatlas.StreamsDataProcessRegionCloudProvider"></a>

Label that identifies the cloud service provider where MongoDB Cloud performs stream processing.

Currently, this parameter supports AWS only.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#awscdk-resources-mongodbatlas.StreamsDataProcessRegionCloudProvider.AWS">AWS</a></code> | AWS. |
| <code><a href="#awscdk-resources-mongodbatlas.StreamsDataProcessRegionCloudProvider.GCP">GCP</a></code> | GCP. |
| <code><a href="#awscdk-resources-mongodbatlas.StreamsDataProcessRegionCloudProvider.AZURE">AZURE</a></code> | AZURE. |
| <code><a href="#awscdk-resources-mongodbatlas.StreamsDataProcessRegionCloudProvider.TENANT">TENANT</a></code> | TENANT. |
| <code><a href="#awscdk-resources-mongodbatlas.StreamsDataProcessRegionCloudProvider.SERVERLESS">SERVERLESS</a></code> | SERVERLESS. |

---

##### `AWS` <a name="AWS" id="awscdk-resources-mongodbatlas.StreamsDataProcessRegionCloudProvider.AWS"></a>

AWS.

---


##### `GCP` <a name="GCP" id="awscdk-resources-mongodbatlas.StreamsDataProcessRegionCloudProvider.GCP"></a>

GCP.

---


##### `AZURE` <a name="AZURE" id="awscdk-resources-mongodbatlas.StreamsDataProcessRegionCloudProvider.AZURE"></a>

AZURE.

---


##### `TENANT` <a name="TENANT" id="awscdk-resources-mongodbatlas.StreamsDataProcessRegionCloudProvider.TENANT"></a>

TENANT.

---


##### `SERVERLESS` <a name="SERVERLESS" id="awscdk-resources-mongodbatlas.StreamsDataProcessRegionCloudProvider.SERVERLESS"></a>

SERVERLESS.

---

